@@ -140,24 +140,24 @@ def run_clean(refresh_token):
             sys.exit("ERROR: Invalid access token; try re-generating an "
                      "access token from the app console on the web.")
 
-        clean_folders = ["/0.7.x/Mac OS X", "/0.7.x/Windows", "/0.7.x/Linux"]
-        arhive_types = [r'^valentina-Windows10\+-mingw-x64-Qt.*-develop-[a-f0-9]{40}\.exe$',
-                        r'^valentina-Windows7\+-mingw-x86-Qt.*-develop-[a-f0-9]{40}\.exe$',
-                        r'^valentina-Windows10\+-msvc-x64-Qt.*-develop-[a-f0-9]{40}\.exe$',
-                        r'^valentina-Windows7\+-msvc-x86-Qt.*-develop-[a-f0-9]{40}\.exe$',
-                        r'^valentina-portable-Windows10\+-mingw-x64-Qt.*-develop-[a-f0-9]{40}\.7z$',
-                        r'^valentina-portable-Windows7\+-mingw-x86-Qt.*-develop-[a-f0-9]{40}\.7z$',
-                        r'^valentina-portable-Windows10\+-msvc-x64-Qt.*-develop-[a-f0-9]{40}\.7z$',
-                        r'^valentina-portable-Windows7\+-msvc-x86-Qt.*-develop-[a-f0-9]{40}\.7z$',
-                        r'^valentina-macOS_12.4\+-Qt.*-x64-develop-[a-f0-9]{40}\.dmg$',
-                        r'^valentina-macOS_12.4\+-Qt.*-x64-develop-multibundle-[a-f0-9]{40}\.dmg$',
-                        r'^valentina-macOS_12\+-Qt.*-x64-develop-[a-f0-9]{40}\.dmg$',
-                        r'^valentina-macOS_12\+-Qt.*-x64-develop-multibundle-[a-f0-9]{40}\.dmg$',
-                        r'^valentina-macOS_10.13\+-Qt.*-x64-develop-[a-f0-9]{40}\.dmg$',
-                        r'^valentina-macOS_10.13\+-Qt.*-x64-develop-multibundle-[a-f0-9]{40}\.dmg$',
-                        r'^valentina-macOS.*\+-Qt.*-arm.*-develop-[a-f0-9]{40}\.dmg$',
-                        r'^valentina-macOS.*\+-Qt.*-arm.*-develop-multibundle-[a-f0-9]{40}\.dmg$',
-                        r'^valentina-Linux-x86_64-develop-[a-f0-9]{40}\.AppImage$']
+        clean_folders = ["/1.0.x/MacOS", "/1.0.x/Windows", "/1.0.x/Linux", "/1.1.x/MacOS", "/1.1.x/Windows", "/1.1.x/Linux"]
+        arhive_types = [r'^valentina-Windows10\+-mingw-x64-Qt.*-(?:develop|master)-[a-f0-9]{40}\.exe$',
+                        r'^valentina-Windows7\+-mingw-x86-Qt.*-(?:develop|master)-[a-f0-9]{40}\.exe$',
+                        r'^valentina-Windows10\+-msvc-x64-Qt.*-(?:develop|master)-[a-f0-9]{40}\.exe$',
+                        r'^valentina-Windows7\+-msvc-x86-Qt.*-(?:develop|master)-[a-f0-9]{40}\.exe$',
+                        r'^valentina-portable-Windows10\+-mingw-x64-Qt.*-(?:develop|master)-[a-f0-9]{40}\.7z$',
+                        r'^valentina-portable-Windows7\+-mingw-x86-Qt.*-(?:develop|master)-[a-f0-9]{40}\.7z$',
+                        r'^valentina-portable-Windows10\+-msvc-x64-Qt.*-(?:develop|master)-[a-f0-9]{40}\.7z$',
+                        r'^valentina-portable-Windows7\+-msvc-x86-Qt.*-(?:develop|master)-[a-f0-9]{40}\.7z$',
+                        r'^valentina-MacOS_10_15\+-Qt.*-x64-(?:develop|master)-[a-f0-9]{40}\.dmg$',
+                        r'^valentina-MacOS_10_15\+-Qt.*-x64-(?:develop|master)-multibundle-[a-f0-9]{40}\.dmg$',
+                        r'^valentina-MacOS_12\+-Qt.*-x64-(?:develop|master)-[a-f0-9]{40}\.dmg$',
+                        r'^valentina-MacOS_12\+-Qt.*-x64-(?:develop|master)-multibundle-[a-f0-9]{40}\.dmg$',
+                        r'^valentina-MacOS_12\+-Qt.*-arm.*-(?:develop|master)-[a-f0-9]{40}\.dmg$',
+                        r'^valentina-MacOS_12\+-Qt.*-arm.*-(?:develop|master)-multibundle-[a-f0-9]{40}\.dmg$',
+                        r'^valentina-MacOS_11\+-Qt.*-arm.*-(?:develop|master)-[a-f0-9]{40}\.dmg$',
+                        r'^valentina-MacOS_11\+-Qt.*-arm.*-(?:develop|master)-multibundle-[a-f0-9]{40}\.dmg$',
+                        r'^valentina-Linux-x86_64-(?:develop|master)-[a-f0-9]{40}\.AppImage$']
 
         item_types = {}
 
@@ -171,7 +171,6 @@ def run_clean(refresh_token):
                         item_types[archive_type].append(entry)
                         break
 
-        # Keep only the first two files of each type
         to_delete = []
         for items in item_types.values():
             # Separate files and folders
@@ -184,8 +183,8 @@ def run_clean(refresh_token):
             # Sort folders by last modified time on server
             folders = sorted(folders, key=lambda f: folder_mod_time(dbx, f))
 
-            # Keep only the first two items of each type
-            to_delete += files[:-2] + folders[:-2]
+            # Keep only the latest item of each type
+            to_delete += files[:-1] + folders[:-1]
 
         # Delete the remaining items
         for item in to_delete:
