@@ -29,13 +29,13 @@
 #ifndef VPCARROUSEL_H
 #define VPCARROUSEL_H
 
-#include <QWidget>
 #include <QComboBox>
 #include <QScrollArea>
 #include <QUuid>
+#include <QWidget>
+#include <memory>
 
 #include "../layout/layoutdef.h"
-#include "../vmisc/defglobal.h"
 
 namespace Ui
 {
@@ -54,9 +54,10 @@ struct VPCarrouselSheet
 class VPCarrousel : public QWidget
 {
     Q_OBJECT // NOLINT
+
 public:
     explicit VPCarrousel(const VPLayoutPtr &layout, QWidget *parent = nullptr);
-    ~VPCarrousel() override = default;
+    ~VPCarrousel() override;
 
     /**
      * @brief SetOrientation Sets the orientation to the given value and refreshes
@@ -65,6 +66,8 @@ public:
      */
     void SetOrientation(Qt::Orientation orientation);
 
+    void RefreshPieceMiniature();
+
     /**
      * @brief RefreshOrientation Refreshes the orientation of the carrousel with the
      * m_orientation value;
@@ -87,7 +90,7 @@ public slots:
     void on_ActiveSheetChanged(const VPSheetPtr &sheet);
 
 protected:
-    void changeEvent(QEvent* event) override;
+    void changeEvent(QEvent *event) override;
 
 private slots:
 
@@ -100,7 +103,7 @@ private slots:
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(VPCarrousel) // NOLINT
-    Ui::VPCarrousel *ui;
+    std::unique_ptr<Ui::VPCarrousel> ui;
 
     VPLayoutWeakPtr m_layout{};
 
