@@ -28,18 +28,20 @@
 #ifndef VPCARROUSELPIECE_H
 #define VPCARROUSELPIECE_H
 
-#include <QMouseEvent>
 #include <QListWidgetItem>
+#include <QMouseEvent>
 
 #include "../layout/layoutdef.h"
-#include "../vmisc/defglobal.h"
 
 class VPCarrouselPiece : public QListWidgetItem
 {
 public:
-    enum { Type = UserType + 1};
+    enum
+    {
+        Type = UserType + 1
+    };
 
-    explicit VPCarrouselPiece(const VPPiecePtr &piece, QListWidget* parent);
+    explicit VPCarrouselPiece(const VPPiecePtr &piece, QListWidget *parent);
     ~VPCarrouselPiece() override = default;
 
     /**
@@ -53,6 +55,8 @@ public:
      */
     void RefreshSelection();
 
+    void RefreshPieceIcon();
+
     /**
      * @brief CreatePieceIcon Creates an icon of the piece of given size
      * @param size of the icon
@@ -60,7 +64,6 @@ public:
      */
     auto CreatePieceIcon(const QSize &size, bool isDragIcon = false) const -> QIcon;
 
-
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(VPCarrouselPiece) // NOLINT
