@@ -29,12 +29,11 @@
 #define PUZZLEPREFERENCESCONFIGURATIONPAGE_H
 
 #include <QWidget>
-
-#include "../vmisc/defglobal.h"
+#include <memory>
 
 namespace Ui
 {
-    class PuzzlePreferencesConfigurationPage;
+class PuzzlePreferencesConfigurationPage;
 }
 
 class PuzzlePreferencesConfigurationPage : public QWidget
@@ -48,13 +47,24 @@ public:
     auto Apply() -> QStringList;
 
 protected:
-    void changeEvent(QEvent* event) override;
+    void changeEvent(QEvent *event) override;
+
+private slots:
+    void ShortcutCellDoubleClicked(int row, int column);
 
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(PuzzlePreferencesConfigurationPage) // NOLINT
-    Ui::PuzzlePreferencesConfigurationPage *ui;
+    std::unique_ptr<Ui::PuzzlePreferencesConfigurationPage> ui;
     bool m_langChanged{false};
+    bool m_sendCrashReportsChanged{false};
+    bool m_crashUserEmailChanged{false};
+    QList<QStringList> m_transientShortcuts{};
+
+    void SetThemeModeComboBox();
+    void InitShortcuts(bool defaults = false);
+    void UpdateShortcutsTable() const;
+    void RetranslateShortcutsTable() const;
 };
 
 #endif // PUZZLEPREFERENCESCONFIGURATIONPAGE_H
