@@ -101,15 +101,29 @@ DialogSaveManualLayout::DialogSaveManualLayout(vsizetype count, bool consoleExpo
         }
     }
 
-    for (auto &[first, second] : InitFormats())
-    {
-        ui->comboBoxFormat->addItem(first, QVariant(static_cast<int>(second)));
-    }
-#ifdef V_NO_ASSERT // Temporarily unavailable
-    RemoveFormatFromList(LayoutExportFormats::OBJ);
-#endif
+    InitFileFormats();
+    connect(ui->comboBoxFormatType,
+            QOverload<int>::of(&QComboBox::currentIndexChanged),
+            this,
+            &DialogSaveManualLayout::ShowExample);
+    connect(ui->comboBoxFormat,
+            QOverload<int>::of(&QComboBox::currentIndexChanged),
+            this,
+            [this](int index)
+            {
+                if (index == -1)
+                {
+                    ui->comboBoxFormatType->clear();
+                    return;
+                }
 
-    //    RemoveFormatFromList(LayoutExportFormats::NC); // No support for now
+                ui->comboBoxFormatType->blockSignals(true);
+                InitFileFormatTypes(static_cast<LayoutExportFileFormat>(ui->comboBoxFormat->currentData().toInt()));
+                ui->comboBoxFormatType->setCurrentIndex(-1);
+                ui->comboBoxFormatType->blockSignals(false);
+
+                ui->comboBoxFormatType->setCurrentIndex(0);
+            });
 
     InitDxfCompatibility();
 
@@ -118,10 +132,12 @@ DialogSaveManualLayout::DialogSaveManualLayout(vsizetype count, bool consoleExpo
     connect(ui->comboBoxFormat, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
             &DialogSaveManualLayout::ShowExample);
 
-    connect(ui->pushButtonBrowse, &QPushButton::clicked, this,
+    connect(ui->pushButtonBrowse,
+            &QPushButton::clicked,
+            this,
             [this]()
             {
-                const QString dirPath = VPApplication::VApp()->PuzzleSettings()->GetPathManualLayouts();
+                const QString dirPath = VPApplication::VApp()->PuzzleSettings()->GetPathLayoutExport();
 
                 const QString dir = QFileDialog::getExistingDirectory(
                     this, tr("Select folder"), dirPath,
@@ -131,12 +147,12 @@ DialogSaveManualLayout::DialogSaveManualLayout(vsizetype count, bool consoleExpo
                 { // If paths equal the signal will not be called, we will do this manually
                     dir == ui->lineEditPath->text() ? PathChanged(dir) : ui->lineEditPath->setText(dir);
 
-                    VPApplication::VApp()->PuzzleSettings()->SetPathManualLayouts(dir);
+                    VPApplication::VApp()->PuzzleSettings()->SetPathLayoutExport(dir);
                 }
             });
     connect(ui->lineEditPath, &QLineEdit::textChanged, this, &DialogSaveManualLayout::PathChanged);
 
-    ui->lineEditPath->setText(VPApplication::VApp()->PuzzleSettings()->GetPathManualLayouts());
+    ui->lineEditPath->setText(VPApplication::VApp()->PuzzleSettings()->GetPathLayoutExport());
 
     ReadSettings();
 
@@ -161,7 +177,7 @@ auto DialogSaveManualLayout::FileName() const -> QString
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogSaveManualLayout::Format() const -> LayoutExportFormats
 {
-    return static_cast<LayoutExportFormats>(ui->comboBoxFormat->currentData().toInt());
+    return static_cast<LayoutExportFormats>(ui->comboBoxFormatType->currentData().toInt());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -169,15 +185,34 @@ void DialogSaveManualLayout::SelectFormat(LayoutExportFormats format)
 {
     if (static_cast<int>(format) < 0 || format >= LayoutExportFormats::COUNT)
     {
-        throw VException(tr("Tried to use out of range format number."));
+        throw VException(tr("Tried to use out of range file format type number."));
     }
 
-    const int i = ui->comboBoxFormat->findData(static_cast<int>(format));
+    const LayoutExportFileFormat fileFormat = VLayoutExporter::LayoutExportFileFormat(format);
+
+    int i = ui->comboBoxFormat->findData(static_cast<int>(fileFormat));
     if (i < 0)
     {
-        throw VException(tr("Selected not present format."));
+        throw VException(tr("Selected not present file format."));
     }
+
+    ui->comboBoxFormat->blockSignals(true);
     ui->comboBoxFormat->setCurrentIndex(i);
+    ui->comboBoxFormat->blockSignals(false);
+
+    ui->comboBoxFormatType->blockSignals(true);
+    InitFileFormatTypes(fileFormat);
+    ui->comboBoxFormatType->setCurrentIndex(-1);
+    ui->comboBoxFormatType->blockSignals(false);
+
+    i = ui->comboBoxFormatType->findData(static_cast<int>(format));
+    if (i < 0)
+    {
+        throw VException(tr("Selected not present file format type."));
+    }
+    ui->comboBoxFormatType->setCurrentIndex(i);
+
+    SetExportUnified(m_count > 1);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -288,6 +323,8 @@ void DialogSaveManualLayout::SetShowGrainline(bool show)
         case LayoutExportFormats::DXF_AC1027_Flat:
         case LayoutExportFormats::HPGL:
         case LayoutExportFormats::HPGL2:
+        case LayoutExportFormats::HPGL_PLT:
+        case LayoutExportFormats::HPGL2_PLT:
             ui->checkBoxShowGrainline->setChecked(show);
             break;
         default:
@@ -319,6 +356,8 @@ auto DialogSaveManualLayout::IsShowGrainline() const -> bool
         case LayoutExportFormats::DXF_AC1027_Flat:
         case LayoutExportFormats::HPGL:
         case LayoutExportFormats::HPGL2:
+        case LayoutExportFormats::HPGL_PLT:
+        case LayoutExportFormats::HPGL2_PLT:
             return ui->checkBoxShowGrainline->isChecked();
         default:
             return true;
@@ -360,8 +399,8 @@ auto DialogSaveManualLayout::IsTextAsPaths() const -> bool
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveManualLayout::SetTextAsPaths(bool textAsPaths)
 {
-    VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
-    if (settings->GetSingleLineFonts() || settings->GetSingleStrokeOutlineFont())
+    if (const VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
+        settings->GetSingleLineFonts() || settings->GetSingleStrokeOutlineFont())
     {
         ui->checkBoxTextAsPaths->setChecked(true);
     }
@@ -429,6 +468,18 @@ auto DialogSaveManualLayout::IsTilesScheme() const -> bool
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSaveManualLayout::SetHideRuler(bool value)
+{
+    ui->checkBoxHideRuler->setChecked(Format() == LayoutExportFormats::PDFTiled ? value : false);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto DialogSaveManualLayout::IsHideRuler() const -> bool
+{
+    return Format() == LayoutExportFormats::PDFTiled && ui->checkBoxHideRuler->isChecked();
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveManualLayout::showEvent(QShowEvent *event)
 {
@@ -511,6 +562,18 @@ void DialogSaveManualLayout::PathChanged(const QString &text)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveManualLayout::ShowExample()
 {
+    const bool hasValues = ui->comboBoxFormatType->currentIndex() != -1;
+    ui->groupBoxFormatOptions->setEnabled(hasValues);
+
+    QPushButton *bOk = ui->buttonBox->button(QDialogButtonBox::Ok);
+    SCASSERT(bOk != nullptr)
+    bOk->setEnabled(hasValues);
+
+    if (!hasValues)
+    {
+        return;
+    }
+
     const LayoutExportFormats currentFormat = Format();
 
     QString example;
@@ -524,7 +587,7 @@ void DialogSaveManualLayout::ShowExample()
     }
     ui->labelExample->setText(example);
 
-    VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
+    const VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
 
     ui->labelOptionsNotAvailable->setVisible(false);
     ui->checkBoxBinaryDXF->setVisible(false);
@@ -534,6 +597,7 @@ void DialogSaveManualLayout::ShowExample()
     ui->checkBoxShowGrainline->setVisible(false);
     ui->labelDxfCompatibility->setVisible(false);
     ui->comboBoxDxfCompatibility->setVisible(false);
+    ui->checkBoxHideRuler->setVisible(false);
 
     const bool editableTextAsPaths = !settings->GetSingleLineFonts() && !settings->GetSingleStrokeOutlineFont();
 
@@ -550,6 +614,7 @@ void DialogSaveManualLayout::ShowExample()
             ui->checkBoxTilesScheme->setVisible(true);
             ui->checkBoxExportUnified->setVisible(m_count > 1);
             ui->checkBoxShowGrainline->setVisible(true);
+            ui->checkBoxHideRuler->setVisible(true);
             break;
         case LayoutExportFormats::PDF:
         case LayoutExportFormats::PS:
@@ -560,6 +625,8 @@ void DialogSaveManualLayout::ShowExample()
             break;
         case LayoutExportFormats::HPGL:
         case LayoutExportFormats::HPGL2:
+        case LayoutExportFormats::HPGL_PLT:
+        case LayoutExportFormats::HPGL2_PLT:
             ui->checkBoxShowGrainline->setVisible(true);
             break;
         case LayoutExportFormats::SVG:
@@ -587,66 +654,6 @@ void DialogSaveManualLayout::ShowExample()
     }
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-auto DialogSaveManualLayout::SupportPSTest() -> bool
-{
-    static bool havePdf = false;
-    if (static bool tested = false; !tested)
-    {
-        havePdf = VLayoutExporter::SupportPDFConversion();
-        tested = true;
-    }
-    return havePdf;
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-auto DialogSaveManualLayout::InitFormats() -> QVector<std::pair<QString, LayoutExportFormats>>
-{
-    QVector<std::pair<QString, LayoutExportFormats>> list;
-
-    auto InitFormat = [&list](LayoutExportFormats format)
-    { list.append(std::make_pair(VLayoutExporter::ExportFormatDescription(format), format)); };
-
-    InitFormat(LayoutExportFormats::SVG);
-    InitFormat(LayoutExportFormats::PDF);
-    InitFormat(LayoutExportFormats::PNG);
-    InitFormat(LayoutExportFormats::OBJ);
-    if (SupportPSTest())
-    {
-        InitFormat(LayoutExportFormats::PS);
-        InitFormat(LayoutExportFormats::EPS);
-    }
-    InitFormat(LayoutExportFormats::DXF_AC1006_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1009_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1012_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1014_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1015_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1018_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1021_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1024_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1027_Flat);
-    InitFormat(LayoutExportFormats::DXF_AAMA);
-    InitFormat(LayoutExportFormats::DXF_ASTM);
-    InitFormat(LayoutExportFormats::PDFTiled);
-    //    InitFormat(LayoutExportFormats::NC);
-    InitFormat(LayoutExportFormats::RLD);
-    InitFormat(LayoutExportFormats::TIF);
-    InitFormat(LayoutExportFormats::HPGL);
-    InitFormat(LayoutExportFormats::HPGL2);
-
-    return list;
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-void DialogSaveManualLayout::RemoveFormatFromList(LayoutExportFormats format)
-{
-    const int index = ui->comboBoxFormat->findData(static_cast<int>(format));
-    if (index != -1)
-    {
-        ui->comboBoxFormat->removeItem(index);
-    }
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveManualLayout::ReadSettings()
 {
@@ -660,8 +667,10 @@ void DialogSaveManualLayout::ReadSettings()
         qDebug() << qUtf8Printable(e.ErrorMessage());
     }
     SetShowGrainline(settings->GetShowGrainline());
-
     SetDxfCompatibility(static_cast<DXFApparelCompatibility>(settings->GetDxfCompatibility()));
+    SetHideRuler(settings->GetHideRuler());
+    SetTilesScheme(settings->GetTilesScheme());
+    SetTextAsPaths(settings->GetTextAsPaths());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -675,8 +684,10 @@ void DialogSaveManualLayout::WriteSettings() const
     VPSettings *settings = VPApplication::VApp()->PuzzleSettings();
     settings->SetLayoutExportFormat(static_cast<qint8>(Format()));
     settings->SetShowGrainline(IsShowGrainline());
-
     settings->SetDxfCompatibility(static_cast<qint8>(DxfCompatibility()));
+    settings->SetHideRuler(IsHideRuler());
+    settings->SetTilesScheme(IsTilesScheme());
+    settings->SetTextAsPaths(IsTextAsPaths());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -690,4 +701,52 @@ void DialogSaveManualLayout::InitDxfCompatibility()
                                           QVariant(static_cast<int>(DXFApparelCompatibility::RPCADV09)));
     ui->comboBoxDxfCompatibility->addItem("Richpeace CAD V10"_L1,
                                           QVariant(static_cast<int>(DXFApparelCompatibility::RPCADV10)));
+    ui->comboBoxDxfCompatibility->addItem("Clo3D"_L1, QVariant(static_cast<int>(DXFApparelCompatibility::CLO3D)));
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSaveManualLayout::InitFileFormats()
+{
+    auto AddItem = [this](const QString &label, LayoutExportFileFormat format)
+    { ui->comboBoxFormat->addItem(label, QVariant(static_cast<int>(format))); };
+
+    Q_STATIC_ASSERT_X(static_cast<int>(LayoutExportFileFormat::COUNT) == 10, "Update to cover all cases.");
+
+    AddItem("PDF"_L1, LayoutExportFileFormat::PDF);
+    AddItem("SVG"_L1, LayoutExportFileFormat::SVG);
+    AddItem("PNG"_L1, LayoutExportFileFormat::PNG);
+    // AddItem("OBJ"_L1, LayoutExportFileFormat::OBJ); // Temporarily unavailable
+    AddItem("DXF"_L1, LayoutExportFileFormat::DXF);
+    // AddItem("NC"_L1, LayoutExportFileFormat::NC);// No support for now
+    AddItem("PLT"_L1, LayoutExportFileFormat::PLT);
+    AddItem("HPGL"_L1, LayoutExportFileFormat::HPGL);
+    AddItem("TIF"_L1, LayoutExportFileFormat::TIF);
+    AddItem("RLD"_L1, LayoutExportFileFormat::RLD);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSaveManualLayout::InitFileFormatTypes(LayoutExportFileFormat format)
+{
+    ui->comboBoxFormatType->clear();
+    const QVector<LayoutExportFormats> types = VLayoutExporter::MapLayoutExportFormats(format);
+
+    for (const auto &type : types)
+    {
+        ui->comboBoxFormatType->addItem(VLayoutExporter::ExportFormatDescription(type),
+                                        QVariant(static_cast<int>(type)));
+    }
+
+#ifdef V_NO_ASSERT // Temporarily unavailable
+    auto RemoveFormatFromList = [this](LayoutExportFormats exportFormat)
+    {
+        const int index = ui->comboBoxFormatType->findData(static_cast<int>(exportFormat));
+        if (index != -1)
+        {
+            ui->comboBoxFormatType->removeItem(index);
+        }
+    };
+
+    //    RemoveFormatFromList(LayoutExportFormats::NC); // No support for now
+    RemoveFormatFromList(LayoutExportFormats::OBJ);
+#endif
 }
