@@ -66,6 +66,18 @@ auto VPLayoutSettings::GetWarningPiecesOutOfBound() const -> bool
     return m_warningPiecesOutOfBound;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VPLayoutSettings::SetWarningPieceGapePosition(bool state)
+{
+    m_warningPieceGapePosition = state;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPLayoutSettings::GetWarningPieceGapePosition() const -> bool
+{
+    return m_warningPieceGapePosition;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VPLayoutSettings::SetTitle(const QString &title)
 {
@@ -113,10 +125,8 @@ void VPLayoutSettings::SetTilesSize(const QSizeF &size)
 //---------------------------------------------------------------------------------------------------------------------
 void VPLayoutSettings::SetTilesSizeConverted(const QSizeF &size)
 {
-    m_tilesSize = QSizeF(
-                UnitConvertor(size.width(), GetUnit(), Unit::Px),
-                UnitConvertor(size.height(), GetUnit(), Unit::Px)
-                );
+    m_tilesSize =
+        QSizeF(UnitConvertor(size.width(), GetUnit(), Unit::Px), UnitConvertor(size.height(), GetUnit(), Unit::Px));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -134,8 +144,7 @@ auto VPLayoutSettings::GetTilesSize() const -> QSizeF
 //---------------------------------------------------------------------------------------------------------------------
 auto VPLayoutSettings::GetTilesSize(Unit unit) const -> QSizeF
 {
-    return {UnitConvertor(m_tilesSize.width(), Unit::Px, unit),
-            UnitConvertor(m_tilesSize.height(), Unit::Px, unit)};
+    return {UnitConvertor(m_tilesSize.width(), Unit::Px, unit), UnitConvertor(m_tilesSize.height(), Unit::Px, unit)};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -240,7 +249,6 @@ auto VPLayoutSettings::GetPiecesGapConverted() const -> qreal
     return UnitConvertor(m_piecesGap, Unit::Px, m_unit);
 }
 
-
 //---------------------------------------------------------------------------------------------------------------------
 void VPLayoutSettings::SetStickyEdges(bool state)
 {
@@ -248,7 +256,7 @@ void VPLayoutSettings::SetStickyEdges(bool state)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VPLayoutSettings::GetStickyEdges() const -> bool
+auto VPLayoutSettings::IsStickyEdges() const -> bool
 {
     return m_stickyEdges;
 }
@@ -396,3 +404,27 @@ void VPLayoutSettings::SetShowTileNumber(bool newTileNumbers)
 {
     m_showTileNumbers = newTileNumbers;
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPLayoutSettings::SetBoundaryTogetherWithNotches(bool value)
+{
+    m_togetherWithNotches = value;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPLayoutSettings::IsBoundaryTogetherWithNotches() const -> bool
+{
+    return m_togetherWithNotches;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPLayoutSettings::SetCutOnFold(bool value)
+{
+    m_cutOnFold = value;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPLayoutSettings::IsCutOnFold() const -> bool
+{
+    return m_cutOnFold;
+}
