@@ -28,23 +28,28 @@
 #ifndef VPPIECE_H
 #define VPPIECE_H
 
-#include <QUuid>
-#include <QVector>
 #include <QPoint>
 #include <QTransform>
+#include <QUuid>
+#include <QVector>
 
-#include "../vlayout/vlayoutpiece.h"
 #include "../layout/layoutdef.h"
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-#include "../vmisc/defglobal.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
+#include "../vlayout/vlayoutpiece.h"
+#include "vpiecegrainline.h"
 
 class VPLayout;
 class VPSheet;
 
+struct VStickyDistance
+{
+    QLineF m_closestDistance{};
+    qreal m_pieceGap{0};
+};
+
 class VPPiece : public VLayoutPiece
 {
+    Q_DECLARE_TR_FUNCTIONS(VPPiece) // NOLINT
+
 public:
     VPPiece() = default;
     explicit VPPiece(const VLayoutPiece &layoutPiece);
@@ -66,7 +71,7 @@ public:
      * @brief GetPosition Returns the position of the piece
      * @return the position of the piece
      */
-    auto GetPosition() -> QPointF;
+    auto GetPosition() const -> QPointF;
 
     /**
      * @brief RotateToGrainline  rotates the piece to follow the grainline
@@ -91,27 +96,13 @@ public:
     auto Layout() const -> VPLayoutPtr;
     void SetLayout(const VPLayoutPtr &layout);
 
-    void SetGrainlineEnabled(bool enabled);
-    void SetGrainlineAngle(qreal angle);
-    void SetGrainlineArrowType(GrainlineArrowDirection type);
-    void SetGrainlinePoints(const QVector<QPointF> &points);
-
-    auto GetPieceLabelRect() const -> QVector<QPointF>;
-    void SetPieceLabelRect(const QVector<QPointF> &rect);
-
-    auto GetPieceLabelData() const ->VTextManager;
-    void SetPieceLabelData(const VTextManager &data);
-
-    auto GetPatternLabelRect() const -> QVector<QPointF>;
-    void SetPatternLabelRect(const QVector<QPointF> &rect);
-
-    auto GetPatternLabelData() const ->VTextManager;
-    void SetPatternLabelData(const VTextManager &data);
+    void SetVPGrainline(const VPieceGrainline &grainline);
 
     /**
-     * @brief Flip horizontally mirror around center of bounding rect
+     * @brief Flip verticvally mirror around center of bounding rect
      */
-    void Flip();
+    void FlipVertically();
+    void FlipHorizontally();
 
     auto OutOfBound() const -> bool;
     void SetOutOfBound(bool newOutOfBound);
@@ -119,11 +110,17 @@ public:
     auto HasSuperpositionWithPieces() const -> bool;
     void SetHasSuperpositionWithPieces(bool newHasSuperpositionWithPieces);
 
+    auto HasInvalidPieceGapPosition() const -> bool;
+    void SetHasInvalidPieceGapPosition(bool status);
+
     auto StickyPosition(qreal &dx, qreal &dy) const -> bool;
 
     static auto PathsSuperposition(const QVector<QPointF> &path1, const QVector<QPointF> &path2) -> bool;
+    static auto PrepareStickyPath(const QVector<QPointF> &path) -> QVector<QPointF>;
+    static auto ClosestDistance(const QVector<QPointF> &path1, const QVector<QPointF> &path2) -> QLineF;
+    static void CleanPosition(const VPPiecePtr &piece);
 
-    auto IsValid() const -> bool;
+    auto IsValid(QString &error) const -> bool;
 
     auto CopyNumber() const -> quint16;
     void SetCopyNumber(quint16 newCopyNumber);
@@ -142,10 +139,14 @@ private:
     bool m_isSelected{false};
     bool m_outOfBound{false};
     bool m_hasSuperpositionWithPieces{false};
+    bool m_invalidPieceGapPosition{false};
 
     quint16 m_copyNumber{1};
 
     qreal m_zValue{1.0};
+
+    auto StickySheet(VStickyDistance &match) const -> bool;
+    auto StickyPieces(VStickyDistance &match) const -> bool;
 };
 
 //---------------------------------------------------------------------------------------------------------------------
