@@ -172,11 +172,10 @@ void ValidatePiecesGapePosition(const VPiecesValidationData &data, QHash<QString
                 continue;
             }
 
-            QRectF const path2Rect =
-                VLayoutPiece::BoundingRect(p.m_externalContourPoints)
-                    .adjusted(-data.m_pieceGap, -data.m_pieceGap, data.m_pieceGap, data.m_pieceGap);
-
-            if (!path1Rect.intersects(path2Rect) && !path1Rect.contains(path2Rect) && !path2Rect.contains(path1Rect))
+            if (QRectF const path2Rect =
+                    VLayoutPiece::BoundingRect(p.m_externalContourPoints)
+                        .adjusted(-data.m_pieceGap, -data.m_pieceGap, data.m_pieceGap, data.m_pieceGap);
+                !path1Rect.intersects(path2Rect) && !path1Rect.contains(path2Rect) && !path2Rect.contains(path1Rect))
             {
                 continue;
             }
@@ -251,6 +250,7 @@ VPSheetSceneData::VPSheetSceneData(const VPLayoutPtr &layout, const QUuid &sheet
     m_scene->addItem(m_graphicsSheet);
 
     m_graphicsTileGrid = new VPGraphicsTileGrid(layout, m_sheetUuid);
+    m_graphicsTileGrid->setZValue(10);
     m_scene->addItem(m_graphicsTileGrid);
 
     m_rotationControls = new VPGraphicsPieceControls(layout);
@@ -286,7 +286,7 @@ void VPSheetSceneData::RefreshLayout()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPSheetSceneData::RefreshPieces()
+void VPSheetSceneData::RefreshPieces(bool printMode)
 {
     qDeleteAll(m_graphicsPieces);
     m_graphicsPieces.clear();
@@ -314,6 +314,7 @@ void VPSheetSceneData::RefreshPieces()
         }
 
         auto *graphicsPiece = new VPGraphicsPiece(piece);
+        graphicsPiece->SetPrintMode(printMode);
         m_graphicsPieces.append(graphicsPiece);
         m_scene->addItem(graphicsPiece);
 
@@ -328,13 +329,17 @@ void VPSheetSceneData::RefreshPieces()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPSheetSceneData::PrepareForExport()
+void VPSheetSceneData::PrepareForExport(LayoutExportFormats format)
 {
-    VStylesheetStyle::SetExportColorScheme(ExportColorScheme::BackAndWhite);
+    VStylesheetStyle::SetExportColorScheme(ExportColorScheme::BlackAndWhite);
     VSceneStylesheet::ResetStyles();
 
+    const bool printMode = true;
+
     m_graphicsSheet->SetShowBorder(false);
     m_graphicsSheet->SetShowMargin(false);
+    m_graphicsSheet->SetPrintMode(printMode);
+    m_graphicsSheet->SetPDFTiledExport(format == LayoutExportFormats::PDFTiled);
 
     m_rotationControls->setVisible(false);
     m_rotationOrigin->setVisible(false);
@@ -368,8 +373,8 @@ void VPSheetSceneData::PrepareForExport()
         layout->LayoutSettings().SetWarningPieceGapePosition(false);
     }
 
+    RefreshPieces(printMode);
     RefreshLayout();
-    RefreshPieces();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -378,8 +383,12 @@ void VPSheetSceneData::CleanAfterExport()
     VStylesheetStyle::SetExportColorScheme(ExportColorScheme::Default);
     VSceneStylesheet::ResetStyles();
 
+    const bool printMode = false;
+
     m_graphicsSheet->SetShowBorder(true);
     m_graphicsSheet->SetShowMargin(true);
+    m_graphicsSheet->SetPrintMode(printMode);
+    m_graphicsSheet->SetPDFTiledExport(false);
 
     m_rotationControls->setVisible(true);
 
@@ -402,8 +411,8 @@ void VPSheetSceneData::CleanAfterExport()
         layout->LayoutSettings().SetWarningPieceGapePosition(m_pieceGapePositionTmp);
     }
 
+    RefreshPieces(printMode);
     RefreshLayout();
-    RefreshPieces();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -460,15 +469,17 @@ void VPSheetSceneData::AddPiece(VPGraphicsPiece *piece)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPSheetSceneData::SetTextAsPaths(bool textAsPaths) const
+void VPSheetSceneData::SetTextAsPaths(bool textAsPaths)
 {
-    for (auto *piece : m_graphicsPieces)
+    for (auto *piece : qAsConst(m_graphicsPieces))
     {
         if (piece != nullptr)
         {
             piece->SetTextAsPaths(textAsPaths);
         }
     }
+
+    m_textAsPaths = textAsPaths;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -483,6 +494,9 @@ void VPSheetSceneData::PrepareTilesScheme()
         layout->LayoutSettings().SetShowWatermark(false);
     }
 
+    m_graphicsTileGrid->SetPrintMode(true);
+    m_graphicsTileGrid->SetTextAsPaths(m_textAsPaths);
+
     RefreshLayout();
 }
 
@@ -495,6 +509,9 @@ void VPSheetSceneData::ClearTilesScheme()
         layout->LayoutSettings().SetShowWatermark(m_showTilesWatermarkSchemeTmp);
     }
 
+    m_graphicsTileGrid->SetPrintMode(false);
+    m_graphicsTileGrid->SetTextAsPaths(false);
+
     RefreshLayout();
 }
 
@@ -823,17 +840,17 @@ void VPSheet::CheckPiecesPositionValidity() const
 
         for (const auto &piece : pieces)
         {
-            VSheetPiece data;
-            data.m_showFullPiece = piece->IsShowFullPiece();
-            data.m_id = piece->GetUniqueID();
-            data.m_seamMirrorLine = piece->GetMappedSeamMirrorLine();
-            data.m_seamAllowanceMirrorLine = piece->GetMappedSeamAllowanceMirrorLine();
+            VSheetPiece pieceData;
+            pieceData.m_showFullPiece = piece->IsShowFullPiece();
+            pieceData.m_id = piece->GetUniqueID();
+            pieceData.m_seamMirrorLine = piece->GetMappedSeamMirrorLine();
+            pieceData.m_seamAllowanceMirrorLine = piece->GetMappedSeamAllowanceMirrorLine();
 
             QVector<QPointF> points;
             CastTo(piece->GetMappedExternalContourPoints(), points);
-            data.m_externalContourPoints = points;
+            pieceData.m_externalContourPoints = points;
 
-            sheetPieces.append(data);
+            sheetPieces.append(pieceData);
         }
 
         data.m_pieces = sheetPieces;
