@@ -28,6 +28,7 @@
 #ifndef SCENEDEF_H
 #define SCENEDEF_H
 
+#include <QColor>
 #include <QtGlobal>
 
 enum class PGraphicsItem : int
@@ -39,5 +40,6 @@ enum class PGraphicsItem : int
 
 constexpr qreal foldTextMargin = 5;
 constexpr int foldFontSize = 34;
+constexpr QColor tileColor(180, 180, 180);
 
 #endif // SCENEDEF_H
