@@ -44,7 +44,6 @@
 #include "../layout/vpsheet.h"
 #include "../vformat/vsinglelineoutlinechar.h"
 #include "../vgeometry/vlayoutplacelabel.h"
-#include "../vlayout/vboundary.h"
 #include "../vlayout/vfoldline.h"
 #include "../vlayout/vgraphicsfillitem.h"
 #include "../vlayout/vlayoutpiecepath.h"
@@ -60,6 +59,12 @@
 #include "undocommands/vpundopiecemove.h"
 #include "vpiecegrainline.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
+#include "../vmisc/backport/qpainterstateguard.h"
+#else
+#include <QPainterStateGuard>
+#endif
+
 #include <QLoggingCategory>
 
 QT_WARNING_PUSH
@@ -77,7 +82,10 @@ inline auto LineFont(const TextLine &tl, const QFont &base) -> QFont
 {
     QFont fnt = base;
     fnt.setPointSize(qMax(base.pointSize() + tl.m_iFontSize, 1));
-    fnt.setBold(tl.m_bold);
+    if (!VAbstractApplication::VApp()->Settings()->GetSingleStrokeOutlineFont())
+    {
+        fnt.setBold(tl.m_bold);
+    }
     fnt.setItalic(tl.m_italic);
     return fnt;
 }
@@ -142,6 +150,12 @@ inline auto SelectionBrush() -> QBrush
 {
     return {VSceneStylesheet::ManualLayoutStyle().PieceSelectionBrushColor()};
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto ShouldSkipPainting(const VPPiecePtr &piece) -> bool
+{
+    return (piece->GetFoldLineType() == FoldLineType::None || (piece->IsShowFullPiece() && !piece->IsShowMirrorLine()));
+}
 } // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -182,6 +196,7 @@ auto VPGraphicsPiece::boundingRect() const -> QRectF
     shape.addPath(m_stickyPath);
     shape.addPath(m_foldLineMarkPath);
     shape.addPath(m_foldLineLabelPath);
+    shape.addPath(m_mirrorLinePath);
 
     VPSettings *settings = VPApplication::VApp()->PuzzleSettings();
     const qreal halfPenWidth = settings->GetLayoutLineWidth() / 2.;
@@ -309,7 +324,7 @@ void VPGraphicsPiece::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
     {
         QMenu *moveMenu = menu.addMenu(tr("Move to"));
 
-        for (const auto &sheet : sheets)
+        for (const auto &sheet : qAsConst(sheets))
         {
             if (not sheet.isNull())
             {
@@ -344,6 +359,13 @@ void VPGraphicsPiece::SetTextAsPaths(bool newTextAsPaths)
     InitLabels();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VPGraphicsPiece::SetPrintMode(bool newPrintMode)
+{
+    m_printMode = newPrintMode;
+    InitGrainlineItem();
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VPGraphicsPiece::InitLabels()
 {
@@ -465,7 +487,7 @@ void VPGraphicsPiece::InitPieceLabelOutlineFont(const QVector<QPointF> &labelSha
 
     qreal dY = 0;
 
-    VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
+    const VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
 
     bool textAsPaths = m_textAsPaths;
     if (settings->GetSingleStrokeOutlineFont())
@@ -546,8 +568,7 @@ void VPGraphicsPiece::InitPieceLabelOutlineFont(const QVector<QPointF> &labelSha
 //---------------------------------------------------------------------------------------------------------------------
 void VPGraphicsPiece::InitPieceLabel(const QVector<QPointF> &labelShape, const VTextManager &tm)
 {
-    VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
-    if (settings->GetSingleLineFonts())
+    if (const VCommonSettings *settings = VAbstractApplication::VApp()->Settings(); settings->GetSingleLineFonts())
     {
         InitPieceLabelSVGFont(labelShape, tm);
     }
@@ -579,10 +600,16 @@ void VPGraphicsPiece::InitGrainlineItem()
         }
         m_grainlineItem->setPath(VLayoutPiece::GrainlinePath(piece->GetMappedGrainlineShape()));
 
-        VPSettings *settings = VPApplication::VApp()->PuzzleSettings();
+        const VPSettings *settings = VPApplication::VApp()->PuzzleSettings();
+
         QPen const pen(PieceColor(), settings->GetLayoutLineWidth(), Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
         m_grainlineItem->SetCustomPen(true);
         m_grainlineItem->setPen(pen);
+
+        const bool penPrinting = m_printMode
+                                 && (settings->GetSingleLineFonts() || settings->GetSingleStrokeOutlineFont());
+        m_grainlineItem->SetNoBrush(penPrinting);
+
         m_grainlineItem->show();
     }
 }
@@ -598,6 +625,7 @@ void VPGraphicsPiece::PaintPiece(QPainter *painter)
     m_stickyPath = QPainterPath();
     m_foldLineMarkPath = QPainterPath();
     m_foldLineLabelPath = QPainterPath();
+    m_mirrorLinePath = QPainterPath();
 
     VPPiecePtr const piece = m_piece.toStrongRef();
     if (piece.isNull())
@@ -635,124 +663,65 @@ void VPGraphicsPiece::PaintSeamLine(QPainter *painter, const VPPiecePtr &piece)
         return;
     }
 
-    QVector<VLayoutPoint> const seamLinePoints = piece->GetMappedFullContourPoints();
+    VPLayoutPtr const layout = piece->Layout();
+    if (layout.isNull())
+    {
+        return;
+    }
 
+    QVector<VLayoutPoint> const seamLinePoints = piece->GetMappedFullContourPoints(
+        layout->LayoutSettings().IsBoundaryTogetherWithNotches());
     if (seamLinePoints.isEmpty())
     {
         return;
     }
 
+    QVector<QPointF> convertedPoints;
+    CastTo(seamLinePoints, convertedPoints);
+
+    m_seamLine.addPolygon(QPolygonF(convertedPoints));
+    m_seamLine.closeSubpath();
+
+    if (painter != nullptr)
+    {
+        QPainterStateGuard const guard(painter);
+        painter->setBrush(piece->IsSelected() ? SelectionBrush() : NoBrush());
+        painter->drawPath(m_seamLine);
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPGraphicsPiece::PaintCuttingLine(QPainter *painter, const VPPiecePtr &piece)
+{
+    if (!piece->IsSeamAllowance() || piece->IsSeamAllowanceBuiltIn())
+    {
+        return;
+    }
+
     VPLayoutPtr const layout = piece->Layout();
     if (layout.isNull())
     {
         return;
     }
 
-    if (layout->LayoutSettings().IsBoundaryTogetherWithNotches())
+    QVector<VLayoutPoint> const cuttingLinepoints = piece->GetMappedFullSeamAllowancePoints(
+        layout->LayoutSettings().IsBoundaryTogetherWithNotches());
+    if (cuttingLinepoints.isEmpty())
     {
-        QVector<VLayoutPassmark> const passmarks = piece->GetMappedPassmarks();
-
-        bool const seamAllowance = piece->IsSeamAllowance() && piece->IsSeamAllowanceBuiltIn();
-        bool const builtInSeamAllowance = piece->IsSeamAllowance() && piece->IsSeamAllowanceBuiltIn();
-
-        VBoundary boundary(seamLinePoints, seamAllowance, builtInSeamAllowance);
-        boundary.SetPieceName(piece->GetName());
-        if (piece->IsShowFullPiece())
-        {
-            boundary.SetMirrorLine(piece->GetMappedSeamMirrorLine());
-        }
-        const QList<VBoundarySequenceItemData> sequence = boundary.Combine(passmarks, false, false);
-
-        QVector<QPointF> combinedBoundary;
-        for (const auto &item : sequence)
-        {
-            const auto path = item.item.value<VLayoutPiecePath>().Points();
-            QVector<QPointF> convertedPoints;
-            CastTo(path, convertedPoints);
-            combinedBoundary += convertedPoints;
-        }
-
-        m_seamLine.addPolygon(QPolygonF(combinedBoundary));
-        m_seamLine.closeSubpath();
+        return;
     }
-    else
-    {
-        QVector<QPointF> convertedPoints;
-        CastTo(seamLinePoints, convertedPoints);
 
-        m_seamLine.addPolygon(QPolygonF(convertedPoints));
-        m_seamLine.closeSubpath();
-    }
+    QVector<QPointF> convertedPoints;
+    CastTo(cuttingLinepoints, convertedPoints);
+
+    m_cuttingLine.addPolygon(QPolygonF(convertedPoints));
+    m_cuttingLine.closeSubpath();
 
     if (painter != nullptr)
     {
-        painter->save();
+        QPainterStateGuard const guard(painter);
         painter->setBrush(piece->IsSelected() ? SelectionBrush() : NoBrush());
-        painter->drawPath(m_seamLine);
-        painter->restore();
-    }
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-void VPGraphicsPiece::PaintCuttingLine(QPainter *painter, const VPPiecePtr &piece)
-{
-    if (piece->IsSeamAllowance() && not piece->IsSeamAllowanceBuiltIn())
-    {
-        QVector<VLayoutPoint> const cuttingLinepoints = piece->GetMappedFullSeamAllowancePoints();
-        if (cuttingLinepoints.isEmpty())
-        {
-            return;
-        }
-
-        VPLayoutPtr const layout = piece->Layout();
-        if (layout.isNull())
-        {
-            return;
-        }
-
-        if (layout->LayoutSettings().IsBoundaryTogetherWithNotches())
-        {
-            const QVector<VLayoutPassmark> passmarks = piece->GetMappedPassmarks();
-
-            bool const seamAllowance = piece->IsSeamAllowance() && !piece->IsSeamAllowanceBuiltIn();
-            bool const builtInSeamAllowance = piece->IsSeamAllowance() && piece->IsSeamAllowanceBuiltIn();
-
-            VBoundary boundary(cuttingLinepoints, seamAllowance, builtInSeamAllowance);
-            boundary.SetPieceName(piece->GetName());
-            if (piece->IsShowFullPiece())
-            {
-                boundary.SetMirrorLine(piece->GetMappedSeamAllowanceMirrorLine());
-            }
-            const QList<VBoundarySequenceItemData> sequence = boundary.Combine(passmarks, false, false);
-
-            QVector<QPointF> combinedBoundary;
-            for (const auto &item : sequence)
-            {
-                const auto path = item.item.value<VLayoutPiecePath>().Points();
-                QVector<QPointF> convertedPoints;
-                CastTo(path, convertedPoints);
-                combinedBoundary += convertedPoints;
-            }
-
-            m_cuttingLine.addPolygon(QPolygonF(combinedBoundary));
-            m_cuttingLine.closeSubpath();
-        }
-        else
-        {
-            QVector<QPointF> convertedPoints;
-            CastTo(cuttingLinepoints, convertedPoints);
-
-            m_cuttingLine.addPolygon(QPolygonF(convertedPoints));
-            m_cuttingLine.closeSubpath();
-        }
-
-        if (painter != nullptr)
-        {
-            painter->save();
-            painter->setBrush(piece->IsSelected() ? SelectionBrush() : NoBrush());
-            painter->drawPath(m_cuttingLine);
-            painter->restore();
-        }
+        painter->drawPath(m_cuttingLine);
     }
 }
 
@@ -777,12 +746,11 @@ void VPGraphicsPiece::PaintInternalPaths(QPainter *painter, const VPPiecePtr &pi
 
         if (painter != nullptr)
         {
-            painter->save();
+            QPainterStateGuard const guard(painter);
             QPen pen = painter->pen();
             pen.setStyle(piecePath.PenStyle());
             painter->setPen(pen);
             painter->drawPath(path);
-            painter->restore();
         }
         m_internalPaths.addPath(path);
     }
@@ -836,10 +804,9 @@ void VPGraphicsPiece::PaintPassmarks(QPainter *painter, const VPPiecePtr &piece)
 
         if (painter != nullptr)
         {
-            painter->save();
+            QPainterStateGuard const guard(painter);
             painter->setBrush(NoBrush());
             painter->drawPath(m_passmarks);
-            painter->restore();
         }
     }
 }
@@ -869,10 +836,9 @@ void VPGraphicsPiece::PaintPlaceLabels(QPainter *painter, const VPPiecePtr &piec
 
         if (painter != nullptr)
         {
-            painter->save();
+            QPainterStateGuard const guard(painter);
             painter->setBrush(NoBrush());
             painter->drawPath(path);
-            painter->restore();
         }
 
         m_placeLabels.addPath(path);
@@ -892,7 +858,7 @@ void VPGraphicsPiece::PaintStickyPath(QPainter *painter)
 
         if (painter != nullptr)
         {
-            painter->save();
+            QPainterStateGuard const guard(painter);
             painter->setBrush(QBrush(VSceneStylesheet::ManualLayoutStyle().PieceOkColor(), Qt::BDiagPattern));
 
             QPen pen = painter->pen();
@@ -901,98 +867,71 @@ void VPGraphicsPiece::PaintStickyPath(QPainter *painter)
             painter->setPen(pen);
 
             painter->drawPath(m_stickyPath);
-            painter->restore();
         }
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPGraphicsPiece::PaintMirrorLine(QPainter *painter, const VPPiecePtr &piece) const
+void VPGraphicsPiece::PaintMirrorLine(QPainter *painter, const VPPiecePtr &piece)
 {
-    if (piece->IsShowFullPiece())
+    VPLayoutPtr const layout = piece->Layout();
+    if (layout.isNull() || !piece->IsShowFullPiece())
     {
-        bool mirrorFlag = false;
-        QPainterPath mirrorLinePath;
-        if (not piece->IsSeamAllowance() || piece->IsSeamAllowanceBuiltIn())
-        {
-            QLineF const seamMirrorLine = piece->GetMappedSeamMirrorLine();
-            if (!seamMirrorLine.isNull() && piece->IsShowMirrorLine())
-            {
-                QPainterPath mirrorPath;
-                mirrorPath.moveTo(seamMirrorLine.p1());
-                mirrorPath.lineTo(seamMirrorLine.p2());
-                mirrorLinePath.addPath(mirrorPath);
-                mirrorFlag = true;
-            }
-        }
-        else if (not piece->IsSeamAllowanceBuiltIn())
-        {
-            QLineF const seamAllowanceMirrorLine = piece->GetMappedSeamAllowanceMirrorLine();
-            if (!seamAllowanceMirrorLine.isNull() && piece->IsShowMirrorLine())
-            {
-                QPainterPath mirrorPath;
-                mirrorPath.moveTo(seamAllowanceMirrorLine.p1());
-                mirrorPath.lineTo(seamAllowanceMirrorLine.p2());
-                mirrorLinePath.addPath(mirrorPath);
-                mirrorFlag = true;
-            }
-        }
+        return;
+    }
 
-        if (mirrorFlag && painter != nullptr)
-        {
-            painter->save();
-            QPen pen = painter->pen();
-            pen.setStyle(Qt::DashDotLine);
-            painter->setPen(pen);
-            painter->drawPath(mirrorLinePath);
-            painter->restore();
-        }
+    QLineF const mirrorLine = piece->GetMappedCorrectedMirrorLine(
+        layout->LayoutSettings().IsBoundaryTogetherWithNotches());
+    if (mirrorLine.isNull())
+    {
+        return;
+    }
+
+    QPainterPath mirrorPath;
+    mirrorPath.moveTo(mirrorLine.p1());
+    mirrorPath.lineTo(mirrorLine.p2());
+    m_mirrorLinePath.addPath(mirrorPath);
+
+    if (painter != nullptr)
+    {
+        QPainterStateGuard const guard(painter);
+        QPen pen = painter->pen();
+        pen.setStyle(Qt::DashDotLine);
+        painter->setPen(pen);
+        painter->drawPath(m_mirrorLinePath);
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPGraphicsPiece::PaintFoldLine(QPainter *painter, const VPPiecePtr &piece)
+void VPGraphicsPiece::HideFoldLineLabel()
 {
-    if (piece->GetFoldLineType() == FoldLineType::None || (piece->IsShowFullPiece() && !piece->IsShowMirrorLine()))
+    if (m_foldLineLabelText != nullptr)
     {
-        if (m_foldLineLabelText != nullptr)
-        {
-            m_foldLineLabelText->setVisible(false);
-        }
-
-        return;
+        m_foldLineLabelText->setVisible(false);
     }
+}
 
-    VFoldLine const fLine = piece->FoldLine();
-    QVector<QPainterPath> const shape = fLine.FoldLinePath();
-
-    if (shape.isEmpty())
-    {
-        return;
-    }
-
-    VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
+//---------------------------------------------------------------------------------------------------------------------
+void VPGraphicsPiece::PrepareFoldLineLabel(const VFoldLine &fLine, const VCommonSettings *settings)
+{
     if (!m_textAsPaths && !settings->GetSingleStrokeOutlineFont() && !settings->GetSingleLineFonts())
     {
         if (m_foldLineLabelText == nullptr)
         {
             m_foldLineLabelText = new QGraphicsSimpleTextItem(this);
         }
-
         fLine.UpdateFoldLineLabel(m_foldLineLabelText);
-
         m_foldLineLabelText->setBrush(QBrush(PieceColor()));
     }
-    else
+    else if (m_foldLineLabelText != nullptr)
     {
-        if (m_foldLineLabelText != nullptr)
-        {
-            m_foldLineLabelText->setVisible(false);
-        }
+        m_foldLineLabelText->setVisible(false);
     }
+}
 
-    const bool singleLineFont = settings->GetSingleStrokeOutlineFont() || settings->GetSingleLineFonts();
-
+//---------------------------------------------------------------------------------------------------------------------
+void VPGraphicsPiece::AddFoldLinePaths(const VPPiecePtr &piece, const QVector<QPainterPath> &shape, bool singleLineFont)
+{
     if (piece->GetFoldLineType() == FoldLineType::ThreeDots || piece->GetFoldLineType() == FoldLineType::ThreeX ||
         piece->GetFoldLineType() == FoldLineType::TwoArrows)
     {
@@ -1014,26 +953,61 @@ void VPGraphicsPiece::PaintFoldLine(QPainter *painter, const VPPiecePtr &piece)
             m_foldLineLabelPath.addPath(shape.constLast());
         }
     }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPGraphicsPiece::DrawFoldLineMark(QPainter *painter) const
+{
+    QPainterStateGuard const guard(painter);
+    painter->setBrush(Qt::SolidPattern);
+    painter->drawPath(m_foldLineMarkPath);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPGraphicsPiece::DrawFoldLineLabel(QPainter *painter, const VPPiecePtr &piece, bool singleLineFont) const
+{
+    const qreal penWidth = VPApplication::VApp()->PuzzleSettings()->GetLayoutLineWidth();
+
+    QPainterStateGuard const guard(painter);
+    QPen pen = painter->pen();
+    pen.setWidthF(penWidth * qMin(piece->GetXScale(), piece->GetYScale()));
+    pen.setColor(PieceColor());
+    pen.setCapStyle(Qt::RoundCap);
+    pen.setJoinStyle(Qt::RoundJoin);
+    painter->setPen(pen);
+    painter->setBrush(singleLineFont ? Qt::NoBrush : Qt::SolidPattern);
+    painter->drawPath(m_foldLineLabelPath);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPGraphicsPiece::PaintFoldLine(QPainter *painter, const VPPiecePtr &piece)
+{
+    if (ShouldSkipPainting(piece))
+    {
+        HideFoldLineLabel();
+
+        return;
+    }
+
+    VFoldLine const fLine = piece->FoldLine();
+    QVector<QPainterPath> const shape = fLine.FoldLinePath();
+
+    if (shape.isEmpty())
+    {
+        return;
+    }
+
+    const VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
+
+    PrepareFoldLineLabel(fLine, settings);
+
+    const bool singleLineFont = settings->GetSingleStrokeOutlineFont() || settings->GetSingleLineFonts();
+    AddFoldLinePaths(piece, shape, singleLineFont);
 
     if (painter != nullptr)
     {
-        painter->save();
-        painter->setBrush(Qt::SolidPattern);
-        painter->drawPath(m_foldLineMarkPath);
-        painter->restore();
-
-        qreal const penWidth = VPApplication::VApp()->PuzzleSettings()->GetLayoutLineWidth();
-
-        painter->save();
-        QPen pen = painter->pen();
-        pen.setWidthF(penWidth * qMin(piece->GetXScale(), piece->GetYScale()));
-        pen.setColor(PieceColor());
-        pen.setCapStyle(Qt::RoundCap);
-        pen.setJoinStyle(Qt::RoundJoin);
-        painter->setPen(pen);
-        painter->setBrush(singleLineFont ? Qt::NoBrush : Qt::SolidPattern);
-        painter->drawPath(m_foldLineLabelPath);
-        painter->restore();
+        DrawFoldLineMark(painter);
+        DrawFoldLineLabel(painter, piece, singleLineFont);
     }
 }
 
