@@ -27,6 +27,7 @@
  *************************************************************************/
 #include "vpgraphicspiececontrols.h"
 
+#include <cmath>
 #include <QCursor>
 #include <QFileInfo>
 #include <QGraphicsScene>
@@ -37,6 +38,7 @@
 #include <QPainter>
 #include <QScreen>
 #include <QtDebug>
+#include <QtMath>
 
 #include "../layout/vplayout.h"
 #include "../layout/vppiece.h"
@@ -47,6 +49,12 @@
 #include "../vmisc/theme/vtheme.h"
 #include "../vwidgets/global.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
+#include "../vmisc/backport/qpainterstateguard.h"
+#else
+#include <QPainterStateGuard>
+#endif
+
 namespace
 {
 constexpr qreal penWidth = 2;
@@ -143,15 +151,14 @@ void VPGraphicsTransformationOrigin::paint(QPainter *painter, const QStyleOption
 
     if (m_originVisible)
     {
-        painter->save();
+        QPainterStateGuard guard(painter);
         painter->setBrush(QBrush(CurrentColor()));
         painter->drawPath(Center1());
-        painter->restore();
+        guard.restore();
 
-        painter->save();
+        guard.save();
         painter->setBrush(QBrush());
         painter->drawPath(Center2());
-        painter->restore();
     }
 }
 
@@ -236,10 +243,9 @@ auto VPGraphicsTransformationOrigin::RotationCenter(QPainter *painter) const ->
 
     if (painter != nullptr)
     {
-        painter->save();
+        QPainterStateGuard const guard(painter);
         painter->setBrush(QBrush(CurrentColor()));
         painter->drawPath(Center1());
-        painter->restore();
     }
     path.addPath(center1);
 
@@ -252,10 +258,9 @@ auto VPGraphicsTransformationOrigin::RotationCenter(QPainter *painter) const ->
 
     if (painter != nullptr)
     {
-        painter->save();
+        QPainterStateGuard const guard(painter);
         painter->setBrush(QBrush());
         painter->drawPath(Center2());
-        painter->restore();
     }
     path.addPath(center2);
 
@@ -409,6 +414,7 @@ void VPGraphicsPieceControls::mousePressEvent(QGraphicsSceneMouseEvent *event)
     if (event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick)
     {
         m_rotationStartPoint = event->scenePos();
+        m_rotationSum = 0;
         m_controlsVisible = false;
         m_handleCorner = SelectedHandleCorner(event->pos());
         m_ignorePieceTransformation = true;
@@ -421,7 +427,7 @@ void VPGraphicsPieceControls::mousePressEvent(QGraphicsSceneMouseEvent *event)
         }
         else
         {
-            if (QGraphicsView *view = ItemView(); view != nullptr)
+            if (const QGraphicsView *view = ItemView(); view != nullptr)
             {
                 setCursor(view->viewport()->cursor()); // clazy:exclude=clazy-qt6-deprecated-api-fixes
             }
@@ -453,6 +459,16 @@ void VPGraphicsPieceControls::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
         rotateOn = rotateOn - 360.;
     }
 
+    m_rotationSum += rotateOn;
+
+    if (event->modifiers() & Qt::ControlModifier)
+    {
+        const qreal sign = std::copysign(1.0, m_rotationSum);
+        const int steps = qFloor(qAbs(m_rotationSum / 15));
+        rotateOn = 15 * steps * sign;
+        m_rotationSum -= rotateOn;
+    }
+
     if (not qFuzzyIsNull(rotateOn))
     {
         if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
@@ -510,7 +526,7 @@ void VPGraphicsPieceControls::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
         }
         else
         {
-            if (QGraphicsView *view = ItemView(); view != nullptr)
+            if (const QGraphicsView *view = ItemView(); view != nullptr)
             {
                 setCursor(view->viewport()->cursor()); // clazy:exclude=clazy-qt6-deprecated-api-fixes
             }
@@ -751,7 +767,7 @@ auto VPGraphicsPieceControls::PiecesBoundingRect(const QList<VPPiecePtr> &select
 //---------------------------------------------------------------------------------------------------------------------
 auto VPGraphicsPieceControls::ItemView() -> QGraphicsView *
 {
-    if (QGraphicsScene *scene = this->scene(); scene != nullptr)
+    if (const QGraphicsScene *scene = this->scene(); scene != nullptr)
     {
         if (QList<QGraphicsView *> const views = scene->views(); not views.isEmpty())
         {
@@ -773,7 +789,7 @@ void VPGraphicsPieceControls::UpdateCursor(VPHandleCorner corner)
     }
     else
     {
-        if (QGraphicsView *view = ItemView(); view != nullptr)
+        if (const QGraphicsView *view = ItemView(); view != nullptr)
         {
             setCursor(view->viewport()->cursor()); // clazy:exclude=clazy-qt6-deprecated-api-fixes
         }
