@@ -33,32 +33,62 @@
 #include <QPainter>
 #include <QUuid>
 
-#include "../vmisc/def.h"
 #include "../layout/layoutdef.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-#include "../vmisc/defglobal.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-
 class VPTileFactory;
 class VPLayout;
 struct VWatermarkData;
+class VSvgFontEngine;
 
 class VPGraphicsTileGrid : public QGraphicsItem
 {
 public:
     explicit VPGraphicsTileGrid(const VPLayoutPtr &layout, const QUuid &sheetUuid, QGraphicsItem *parent = nullptr);
-    ~VPGraphicsTileGrid() override =default;
+    ~VPGraphicsTileGrid() override = default;
 
     auto boundingRect() const -> QRectF override;
     void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) override;
 
+    void SetPrintMode(bool newPrintMode);
+    void SetTextAsPaths(bool textAsPaths);
+
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(VPGraphicsTileGrid) // NOLINT
 
     VPLayoutWeakPtr m_layout;
     QUuid m_sheetUuid;
+    bool m_printMode{false};
+    bool m_textAsPaths{false};
+
+    void PaintTileNumberOutlineFont(QPainter *painter,
+                                    const QRectF &img,
+                                    int i,
+                                    int j,
+                                    const VPLayoutPtr &layout,
+                                    const QFont &font,
+                                    int nbCol) const;
+    void PaintTileNumberSVGFont(QPainter *painter,
+                                const QRectF &img,
+                                int i,
+                                int j,
+                                const VPLayoutPtr &layout,
+                                const QFont &font,
+                                int nbCol,
+                                const VSvgFontEngine &engine) const;
+    void DrawGrid(QPainter *painter, int nbRow, int nbCol, const QMarginsF &margins, qreal width, qreal height) const;
 };
 
+//---------------------------------------------------------------------------------------------------------------------
+inline void VPGraphicsTileGrid::SetPrintMode(bool newPrintMode)
+{
+    m_printMode = newPrintMode;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+inline void VPGraphicsTileGrid::SetTextAsPaths(bool textAsPaths)
+{
+    m_textAsPaths = textAsPaths;
+}
+
 #endif // VPGRAPHICSTILEGRID_H
