@@ -120,11 +120,9 @@ void VPMainGraphicsView::RefreshLayout() const
 //---------------------------------------------------------------------------------------------------------------------
 void VPMainGraphicsView::RefreshPieces() const
 {
-    VPLayoutPtr const layout = m_layout.toStrongRef();
-    if (not layout.isNull())
+    if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
     {
-        VPSheetPtr const sheet = layout->GetFocusedSheet();
-        if (not sheet.isNull())
+        if (VPSheetPtr const sheet = layout->GetFocusedSheet(); not sheet.isNull())
         {
             sheet->SceneData()->RefreshPieces();
         }
@@ -134,9 +132,7 @@ void VPMainGraphicsView::RefreshPieces() const
 //---------------------------------------------------------------------------------------------------------------------
 void VPMainGraphicsView::dragEnterEvent(QDragEnterEvent *event)
 {
-    const QMimeData *mime = event->mimeData();
-
-    if (mime->hasFormat(VPMimeDataPiece::mineFormatPiecePtr))
+    if (const QMimeData *mime = event->mimeData(); mime->hasFormat(VPMimeDataPiece::mineFormatPiecePtr))
     {
         VPLayoutPtr const layout = m_layout.toStrongRef();
         if (layout.isNull())
@@ -144,8 +140,8 @@ void VPMainGraphicsView::dragEnterEvent(QDragEnterEvent *event)
             return;
         }
 
-        const auto *mimePiece = qobject_cast<const VPMimeDataPiece *>(mime);
-        if (mimePiece != nullptr && mimePiece->LayoutUuid() == layout->Uuid())
+        if (const auto *mimePiece = qobject_cast<const VPMimeDataPiece *>(mime);
+            mimePiece != nullptr && mimePiece->LayoutUuid() == layout->Uuid())
         {
             qCDebug(pMainGraphicsView(), "drag enter");
             event->acceptProposedAction();
@@ -156,9 +152,7 @@ void VPMainGraphicsView::dragEnterEvent(QDragEnterEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void VPMainGraphicsView::dragMoveEvent(QDragMoveEvent *event)
 {
-    const QMimeData *mime = event->mimeData();
-
-    if (mime->hasFormat(VPMimeDataPiece::mineFormatPiecePtr))
+    if (const QMimeData *mime = event->mimeData(); mime->hasFormat(VPMimeDataPiece::mineFormatPiecePtr))
     {
         VPLayoutPtr const layout = m_layout.toStrongRef();
         if (layout.isNull())
@@ -166,8 +160,8 @@ void VPMainGraphicsView::dragMoveEvent(QDragMoveEvent *event)
             return;
         }
 
-        const auto *mimePiece = qobject_cast<const VPMimeDataPiece *>(mime);
-        if (mimePiece != nullptr && mimePiece->LayoutUuid() == layout->Uuid())
+        if (const auto *mimePiece = qobject_cast<const VPMimeDataPiece *>(mime);
+            mimePiece != nullptr && mimePiece->LayoutUuid() == layout->Uuid())
         {
             event->acceptProposedAction();
         }
@@ -202,8 +196,7 @@ void VPMainGraphicsView::dropEvent(QDropEvent *event)
             return;
         }
 
-        VPPiecePtr const piece = mimePiece->GetPiecePtr();
-        if (not piece.isNull())
+        if (VPPiecePtr const piece = mimePiece->GetPiecePtr(); not piece.isNull())
         {
             qCDebug(pMainGraphicsView(), "element dropped, %s", qUtf8Printable(piece->GetName()));
             event->acceptProposedAction();
@@ -326,7 +319,7 @@ void VPMainGraphicsView::keyReleaseEvent(QKeyEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void VPMainGraphicsView::contextMenuEvent(QContextMenuEvent *event)
 {
-    if (QGraphicsItem *item = itemAt(event->pos()); item != nullptr && item->type() == VPGraphicsPiece::Type)
+    if (const QGraphicsItem *item = itemAt(event->pos()); item != nullptr && item->type() == VPGraphicsPiece::Type)
     {
         VMainGraphicsView::contextMenuEvent(event);
         return;
@@ -420,23 +413,7 @@ void VPMainGraphicsView::RotatePiecesByAngle(qreal angle)
 
     VPTransformationOrigon const origin = sheet->TransformationOrigin();
 
-    auto PreparePieces = [this]()
-    {
-        QList<VPPiecePtr> pieces;
-        if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
-        {
-            VPSheetPtr const sheet = layout->GetFocusedSheet();
-            if (not sheet.isNull())
-            {
-                pieces = sheet->GetSelectedPieces();
-            }
-        }
-
-        return pieces;
-    };
-
-    QList<VPPiecePtr> const pieces = PreparePieces();
-
+    QList<VPPiecePtr> const pieces = sheet->GetSelectedPieces();
     if (pieces.size() == 1)
     {
         layout->UndoStack()->push(new VPUndoPieceRotate(pieces.constFirst(), origin, angle, m_allowChangeMerge));
@@ -495,21 +472,7 @@ void VPMainGraphicsView::TranslatePiecesOn(qreal dx, qreal dy)
         return;
     }
 
-    auto PreparePieces = [this]()
-    {
-        QList<VPPiecePtr> pieces;
-        if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
-        {
-            if (VPSheetPtr const sheet = layout->GetFocusedSheet(); not sheet.isNull())
-            {
-                pieces = sheet->GetSelectedPieces();
-            }
-        }
-
-        return pieces;
-    };
-
-    if (QList<VPPiecePtr> const pieces = PreparePieces(); pieces.size() == 1)
+    if (QList<VPPiecePtr> const pieces = sheet->GetSelectedPieces(); pieces.size() == 1)
     {
         const VPPiecePtr &p = pieces.constFirst();
         auto *command = new VPUndoPieceMove(p, dx, dy, m_allowChangeMerge);
@@ -689,18 +652,7 @@ void VPMainGraphicsView::MovePiece(QKeyEvent *event)
         if (const QList<VPGraphicsPiece *> &graphicsPieces = sheet->SceneData()->GraphicsPieces();
             m_hasStickyPosition && not graphicsPieces.isEmpty() && layout->LayoutSettings().IsStickyEdges())
         {
-            auto PreparePieces = [layout]()
-            {
-                QList<VPPiecePtr> pieces;
-                if (VPSheetPtr const sheet = layout->GetFocusedSheet(); not sheet.isNull())
-                {
-                    pieces = sheet->GetSelectedPieces();
-                }
-
-                return pieces;
-            };
-
-            if (QList<VPPiecePtr> const pieces = PreparePieces(); pieces.size() == 1)
+            if (QList<VPPiecePtr> const pieces = sheet->GetSelectedPieces(); pieces.size() == 1)
             {
                 const VPPiecePtr &p = pieces.constFirst();
 
