@@ -29,8 +29,8 @@
 #ifndef VPMAINGRAPHICSVIEW_H
 #define VPMAINGRAPHICSVIEW_H
 
-#include "../vwidgets/vmaingraphicsview.h"
 #include "../layout/layoutdef.h"
+#include "../vwidgets/vmaingraphicsview.h"
 
 class VMainGraphicsScene;
 class VPGraphicsPieceControls;
@@ -45,6 +45,7 @@ class VPPiece;
 class VPMainGraphicsView : public VMainGraphicsView
 {
     Q_OBJECT // NOLINT
+
 public:
     VPMainGraphicsView(const VPLayoutPtr &layout, QWidget *parent);
     ~VPMainGraphicsView() override = default;
@@ -52,7 +53,7 @@ public:
     /**
      * @brief RefreshLayout Refreshes the rectangles for the layout border and the margin
      */
-    void RefreshLayout();
+    void RefreshLayout() const;
 
 public slots:
     /**
@@ -64,7 +65,7 @@ public slots:
 
     void on_ActiveSheetChanged(const VPSheetPtr &focusedSheet);
 
-    void RefreshPieces();
+    void RefreshPieces() const;
 
 signals:
     /**
@@ -98,8 +99,6 @@ private:
 
     bool m_allowChangeMerge{false};
 
-    qreal m_rotationSum{0};
-
     bool m_hasStickyPosition{false};
     qreal m_stickyTranslateX{0};
     qreal m_stickyTranslateY{0};
@@ -108,9 +107,9 @@ private:
     void TranslatePiecesOn(qreal dx, qreal dy);
 
     void SwitchScene(const VPSheetPtr &sheet);
-    void ClearSelection();
+    void ClearSelection() const;
 
-    void ZValueMove(int move);
+    void ZValueMove(int move) const;
 
     void RemovePiece() const;
     void MovePiece(QKeyEvent *event);
