@@ -26,16 +26,16 @@
  **
  *************************************************************************/
 #include "vpundopiecemove.h"
-#include "../vmisc/def.h"
-#include "../layout/vppiece.h"
 #include "../layout/vplayout.h"
+#include "../layout/vppiece.h"
+#include "../vmisc/def.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 VPUndoPieceMove::VPUndoPieceMove(const VPPiecePtr &piece, qreal dx, qreal dy, bool allowMerge, QUndoCommand *parent)
-    : VPUndoCommand(allowMerge, parent),
-      m_piece(piece),
-      m_dx(dx),
-      m_dy(dy)
+  : VPUndoCommand(allowMerge, parent),
+    m_piece(piece),
+    m_dx(dx),
+    m_dy(dy)
 {
     SCASSERT(not piece.isNull())
 
@@ -47,13 +47,13 @@ VPUndoPieceMove::VPUndoPieceMove(const VPPiecePtr &piece, qreal dx, qreal dy, bo
 //---------------------------------------------------------------------------------------------------------------------
 void VPUndoPieceMove::undo()
 {
-    VPPiecePtr piece = Piece();
+    VPPiecePtr const piece = Piece();
     if (piece.isNull())
     {
         return;
     }
 
-    VPLayoutPtr layout = piece->Layout();
+    VPLayoutPtr const layout = piece->Layout();
     if (layout.isNull())
     {
         return;
@@ -71,13 +71,13 @@ void VPUndoPieceMove::undo()
 //---------------------------------------------------------------------------------------------------------------------
 void VPUndoPieceMove::redo()
 {
-    VPPiecePtr piece = Piece();
+    VPPiecePtr const piece = Piece();
     if (piece.isNull())
     {
         return;
     }
 
-    VPLayoutPtr layout = piece->Layout();
+    VPLayoutPtr const layout = piece->Layout();
     if (layout.isNull())
     {
         return;
@@ -104,9 +104,8 @@ auto VPUndoPieceMove::mergeWith(const QUndoCommand *command) -> bool
     const auto *moveCommand = dynamic_cast<const VPUndoPieceMove *>(command);
     SCASSERT(moveCommand != nullptr)
 
-    VPPiecePtr piece = Piece();
-    if (moveCommand->Piece().isNull() || piece.isNull() || moveCommand->Piece() != piece ||
-            not moveCommand->AllowMerge())
+    if (VPPiecePtr const piece = Piece(); moveCommand->Piece().isNull() || piece.isNull() ||
+                                          moveCommand->Piece() != piece || not moveCommand->AllowMerge())
     {
         return false;
     }
@@ -126,13 +125,13 @@ auto VPUndoPieceMove::id() const -> int
 //---------------------------------------------------------------------------------------------------------------------
 VPUndoPiecesMove::VPUndoPiecesMove(const QList<VPPiecePtr> &pieces, qreal dx, qreal dy, bool allowMerge,
                                    QUndoCommand *parent)
-    : VPUndoCommand(allowMerge, parent),
-      m_dx(dx),
-      m_dy(dy)
+  : VPUndoCommand(allowMerge, parent),
+    m_dx(dx),
+    m_dy(dy)
 {
     setText(QObject::tr("move pieces"));
 
-    for (const auto& piece : pieces)
+    for (const auto &piece : pieces)
     {
         if (not piece.isNull())
         {
@@ -150,28 +149,24 @@ void VPUndoPiecesMove::undo()
         return;
     }
 
-    VPLayoutPtr layout = Layout();
+    VPLayoutPtr const layout = Layout();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = Sheet();
-    if (layout->GetFocusedSheet() != sheet)
+    if (VPSheetPtr const sheet = Sheet(); layout->GetFocusedSheet() != sheet)
     {
         layout->SetFocusedSheet(sheet);
     }
 
-    for (const auto& piece : qAsConst(m_pieces))
+    for (const auto &piece : qAsConst(m_pieces))
     {
-        VPPiecePtr p = piece.toStrongRef();
-        if (not p.isNull())
+        VPPiecePtr const p = piece.toStrongRef();
+        if (not p.isNull() && m_oldTransforms.contains(p->GetUniqueID()))
         {
-            if (m_oldTransforms.contains(p->GetUniqueID()))
-            {
-                p->SetMatrix(m_oldTransforms.value(p->GetUniqueID()));
-                emit layout->PieceTransformationChanged(p);
-            }
+            p->SetMatrix(m_oldTransforms.value(p->GetUniqueID()));
+            emit layout->PieceTransformationChanged(p);
         }
     }
 }
@@ -184,21 +179,20 @@ void VPUndoPiecesMove::redo()
         return;
     }
 
-    VPLayoutPtr layout = Layout();
+    VPLayoutPtr const layout = Layout();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = Sheet();
-    if (layout->GetFocusedSheet() != sheet)
+    if (VPSheetPtr const sheet = Sheet(); layout->GetFocusedSheet() != sheet)
     {
         layout->SetFocusedSheet(sheet);
     }
 
-    for (const auto& piece : qAsConst(m_pieces))
+    for (const auto &piece : qAsConst(m_pieces))
     {
-        VPPiecePtr p = piece.toStrongRef();
+        VPPiecePtr const p = piece.toStrongRef();
         if (not p.isNull())
         {
             p->Translate(m_dx, m_dy);
@@ -244,9 +238,9 @@ auto VPUndoPiecesMove::id() const -> int
 //---------------------------------------------------------------------------------------------------------------------
 auto VPUndoPiecesMove::Layout() const -> VPLayoutPtr
 {
-    for (const auto& piece : m_pieces)
+    for (const auto &piece : m_pieces)
     {
-        VPPiecePtr p = piece.toStrongRef();
+        VPPiecePtr const p = piece.toStrongRef();
         if (not p.isNull())
         {
             return p->Layout();
@@ -257,11 +251,11 @@ auto VPUndoPiecesMove::Layout() const -> VPLayoutPtr
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VPUndoPiecesMove::Sheet() const  -> VPSheetPtr
+auto VPUndoPiecesMove::Sheet() const -> VPSheetPtr
 {
-    for (const auto& piece : m_pieces)
+    for (const auto &piece : m_pieces)
     {
-        VPPiecePtr p = piece.toStrongRef();
+        VPPiecePtr const p = piece.toStrongRef();
         if (not p.isNull())
         {
             return p->Sheet();
@@ -275,9 +269,9 @@ auto VPUndoPiecesMove::Sheet() const  -> VPSheetPtr
 inline auto VPUndoPiecesMove::PieceIds() const -> QSet<QString>
 {
     QSet<QString> ids;
-    for (const auto& piece : m_pieces)
+    for (const auto &piece : m_pieces)
     {
-        VPPiecePtr p = piece.toStrongRef();
+        VPPiecePtr const p = piece.toStrongRef();
         if (not p.isNull())
         {
             ids.insert(p->GetUniqueID());
