@@ -26,8 +26,8 @@
  **
  *************************************************************************/
 #include "vpundopiecezvaluemove.h"
-#include "../layout/vppiece.h"
 #include "../layout/vplayout.h"
+#include "../layout/vppiece.h"
 #include "../layout/vpsheet.h"
 #include "undocommands/vpundocommand.h"
 
@@ -41,7 +41,7 @@ auto CorrectedZValues(const QList<QVector<QString>> &order) -> QHash<QString, qr
     qreal step = 0;
     if (not order.isEmpty())
     {
-        step = 1.0/order.size();
+        step = 1.0 / static_cast<int>(order.size());
     }
 
     for (int i = 0; i < order.size(); ++i)
@@ -49,27 +49,27 @@ auto CorrectedZValues(const QList<QVector<QString>> &order) -> QHash<QString, qr
         const QVector<QString> &level = order.at(i);
         for (const auto &pieceId : level)
         {
-            correctedZValues.insert(pieceId, i*step);
+            correctedZValues.insert(pieceId, i * step);
         }
     }
 
     return correctedZValues;
 }
-}  // namespace
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 VPUndoPieceZValueMove::VPUndoPieceZValueMove(const VPPiecePtr &piece, ML::ZValueMove move, QUndoCommand *parent)
-    : VPUndoCommand(parent),
-      m_piece(piece),
-      m_move(move)
+  : VPUndoCommand(parent),
+    m_piece(piece),
+    m_move(move)
 {
     setText(QObject::tr("z value move piece"));
 
-    VPSheetPtr sheet = Sheet();
+    VPSheetPtr const sheet = Sheet();
     if (not sheet.isNull())
     {
         const QList<VPPiecePtr> pieces = sheet->GetPieces();
-        for(const auto& p : pieces)
+        for (const auto &p : pieces)
         {
             if (not p.isNull())
             {
@@ -82,19 +82,19 @@ VPUndoPieceZValueMove::VPUndoPieceZValueMove(const VPPiecePtr &piece, ML::ZValue
 //---------------------------------------------------------------------------------------------------------------------
 void VPUndoPieceZValueMove::undo()
 {
-    VPPiecePtr piece = Piece();
+    VPPiecePtr const piece = Piece();
     if (piece.isNull())
     {
         return;
     }
 
-    VPLayoutPtr layout = piece->Layout();
+    VPLayoutPtr const layout = piece->Layout();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = Sheet();
+    VPSheetPtr const sheet = Sheet();
     if (sheet.isNull())
     {
         return;
@@ -107,15 +107,12 @@ void VPUndoPieceZValueMove::undo()
 
     const QList<VPPiecePtr> pieces = sheet->GetPieces();
 
-    for (const auto &p: pieces)
+    for (const auto &p : pieces)
     {
-        if (not p.isNull())
+        if (not p.isNull() && m_oldValues.contains(p->GetUniqueID()))
         {
-            if (m_oldValues.contains(p->GetUniqueID()))
-            {
-                p->SetZValue(m_oldValues.value(p->GetUniqueID()));
-                emit layout->PieceZValueChanged(p);
-            }
+            p->SetZValue(m_oldValues.value(p->GetUniqueID()));
+            emit layout->PieceZValueChanged(p);
         }
     }
 }
@@ -123,19 +120,19 @@ void VPUndoPieceZValueMove::undo()
 //---------------------------------------------------------------------------------------------------------------------
 void VPUndoPieceZValueMove::redo()
 {
-    VPPiecePtr piece = Piece();
+    VPPiecePtr const piece = Piece();
     if (piece.isNull())
     {
         return;
     }
 
-    VPLayoutPtr layout = piece->Layout();
+    VPLayoutPtr const layout = piece->Layout();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = Sheet();
+    VPSheetPtr const sheet = Sheet();
     if (sheet.isNull())
     {
         return;
@@ -158,7 +155,7 @@ void VPUndoPieceZValueMove::redo()
     else if (m_move == ML::ZValueMove::Up)
     {
         const qreal step = LevelStep(pieces);
-        for (const auto &p: pieces)
+        for (const auto &p : pieces)
         {
             if (p->GetUniqueID() != piece->GetUniqueID())
             {
@@ -171,7 +168,7 @@ void VPUndoPieceZValueMove::redo()
     else if (m_move == ML::ZValueMove::Down)
     {
         const qreal step = LevelStep(pieces);
-        for (const auto &p: pieces)
+        for (const auto &p : pieces)
         {
             if (p->GetUniqueID() != piece->GetUniqueID())
             {
@@ -187,8 +184,8 @@ void VPUndoPieceZValueMove::redo()
         order.prepend({piece->GetUniqueID()});
     }
 
-    QHash<QString, qreal> correctedZValues = CorrectedZValues(order);
-    for (const auto &p: pieces)
+    QHash<QString, qreal> const correctedZValues = CorrectedZValues(order);
+    for (const auto &p : pieces)
     {
         if (not p.isNull())
         {
@@ -215,8 +212,7 @@ auto VPUndoPieceZValueMove::Piece() const -> VPPiecePtr
 //---------------------------------------------------------------------------------------------------------------------
 auto VPUndoPieceZValueMove::Sheet() const -> VPSheetPtr
 {
-    VPPiecePtr p = Piece();
-    if (not p.isNull())
+    if (VPPiecePtr const p = Piece(); not p.isNull())
     {
         return p->Sheet();
     }
@@ -225,9 +221,9 @@ auto VPUndoPieceZValueMove::Sheet() const -> VPSheetPtr
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VPUndoPieceZValueMove::Levels(const QList<VPPiecePtr> &pieces, bool skip) const -> QList<QVector<QString> >
+auto VPUndoPieceZValueMove::Levels(const QList<VPPiecePtr> &pieces, bool skip) const -> QList<QVector<QString>>
 {
-    VPPiecePtr piece = Piece();
+    VPPiecePtr const piece = Piece();
     if (piece.isNull())
     {
         return {};
@@ -235,7 +231,7 @@ auto VPUndoPieceZValueMove::Levels(const QList<VPPiecePtr> &pieces, bool skip) c
 
     QMap<qreal, QVector<QString>> levels;
 
-    for (const auto &p: pieces)
+    for (const auto &p : pieces)
     {
         if (p.isNull() || (skip && p->GetUniqueID() == piece->GetUniqueID()))
         {
@@ -260,35 +256,35 @@ auto VPUndoPieceZValueMove::Levels(const QList<VPPiecePtr> &pieces, bool skip) c
 //---------------------------------------------------------------------------------------------------------------------
 auto VPUndoPieceZValueMove::LevelStep(const QList<VPPiecePtr> &pieces) const -> qreal
 {
-    QList<QVector<QString>> levels = Levels(pieces, false);
+    QList<QVector<QString>> const levels = Levels(pieces, false);
     if (levels.isEmpty())
     {
         return 0;
     }
 
-    return 1.0/levels.size();
+    return 1.0 / static_cast<int>(levels.size());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 // Z value pieces
 VPUndoPiecesZValueMove::VPUndoPiecesZValueMove(const QList<VPPiecePtr> &pieces, ML::ZValueMove move,
                                                QUndoCommand *parent)
-    : VPUndoCommand(parent),
-      m_move(move)
+  : VPUndoCommand(parent),
+    m_move(move)
 {
     setText(QObject::tr("z value move pieces"));
 
     m_pieces.reserve(pieces.size());
-    for(const auto& p : pieces)
+    for (const auto &p : pieces)
     {
         m_pieces.append(p);
     }
 
-    VPSheetPtr sheet = Sheet();
+    VPSheetPtr const sheet = Sheet();
     if (not sheet.isNull())
     {
         const QList<VPPiecePtr> pieces = sheet->GetPieces();
-        for(const auto& p : pieces)
+        for (const auto &p : pieces)
         {
             if (not p.isNull())
             {
@@ -306,13 +302,13 @@ void VPUndoPiecesZValueMove::undo()
         return;
     }
 
-    VPLayoutPtr layout = Layout();
+    VPLayoutPtr const layout = Layout();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = Sheet();
+    VPSheetPtr const sheet = Sheet();
     if (sheet.isNull())
     {
         return;
@@ -325,15 +321,12 @@ void VPUndoPiecesZValueMove::undo()
 
     const QList<VPPiecePtr> pieces = sheet->GetPieces();
 
-    for (const auto &p: pieces)
+    for (const auto &p : pieces)
     {
-        if (not p.isNull())
+        if (not p.isNull() && m_oldValues.contains(p->GetUniqueID()))
         {
-            if (m_oldValues.contains(p->GetUniqueID()))
-            {
-                p->SetZValue(m_oldValues.value(p->GetUniqueID()));
-                emit layout->PieceZValueChanged(p);
-            }
+            p->SetZValue(m_oldValues.value(p->GetUniqueID()));
+            emit layout->PieceZValueChanged(p);
         }
     }
 }
@@ -346,13 +339,13 @@ void VPUndoPiecesZValueMove::redo()
         return;
     }
 
-    VPLayoutPtr layout = Layout();
+    VPLayoutPtr const layout = Layout();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = Sheet();
+    VPSheetPtr const sheet = Sheet();
     if (sheet.isNull())
     {
         return;
@@ -364,7 +357,7 @@ void VPUndoPiecesZValueMove::redo()
     }
 
     const QList<VPPiecePtr> allPieces = sheet->GetPieces();
-    QVector<QString> ids = PieceIds();
+    QVector<QString> const ids = PieceIds();
 
     QList<QVector<QString>> order;
 
@@ -376,7 +369,7 @@ void VPUndoPiecesZValueMove::redo()
     else if (m_move == ML::ZValueMove::Up)
     {
         const qreal step = LevelStep(allPieces);
-        for (const auto &p: allPieces)
+        for (const auto &p : allPieces)
         {
             if (not ids.contains(p->GetUniqueID()))
             {
@@ -389,7 +382,7 @@ void VPUndoPiecesZValueMove::redo()
     else if (m_move == ML::ZValueMove::Down)
     {
         const qreal step = LevelStep(allPieces);
-        for (const auto &p: allPieces)
+        for (const auto &p : allPieces)
         {
             if (not ids.contains(p->GetUniqueID()))
             {
@@ -405,8 +398,8 @@ void VPUndoPiecesZValueMove::redo()
         order.prepend(ids);
     }
 
-    QHash<QString, qreal> correctedZValues = CorrectedZValues(order);
-    for (const auto &p: allPieces)
+    QHash<QString, qreal> const correctedZValues = CorrectedZValues(order);
+    for (const auto &p : allPieces)
     {
         if (not p.isNull())
         {
@@ -427,9 +420,9 @@ auto VPUndoPiecesZValueMove::id() const -> int
 //---------------------------------------------------------------------------------------------------------------------
 auto VPUndoPiecesZValueMove::Layout() const -> VPLayoutPtr
 {
-    for (const auto& piece : m_pieces)
+    for (const auto &piece : m_pieces)
     {
-        VPPiecePtr p = piece.toStrongRef();
+        VPPiecePtr const p = piece.toStrongRef();
         if (not p.isNull())
         {
             return p->Layout();
@@ -442,9 +435,9 @@ auto VPUndoPiecesZValueMove::Layout() const -> VPLayoutPtr
 //---------------------------------------------------------------------------------------------------------------------
 auto VPUndoPiecesZValueMove::Sheet() const -> VPSheetPtr
 {
-    for (const auto& piece : m_pieces)
+    for (const auto &piece : m_pieces)
     {
-        VPPiecePtr p = piece.toStrongRef();
+        VPPiecePtr const p = piece.toStrongRef();
         if (not p.isNull())
         {
             return p->Sheet();
@@ -460,9 +453,9 @@ auto VPUndoPiecesZValueMove::PieceIds() const -> QVector<QString>
     QVector<QString> ids;
     ids.reserve(m_pieces.size());
 
-    for (const auto& piece : m_pieces)
+    for (const auto &piece : m_pieces)
     {
-        VPPiecePtr p = piece.toStrongRef();
+        VPPiecePtr const p = piece.toStrongRef();
         if (not p.isNull())
         {
             ids.append(p->GetUniqueID());
@@ -473,12 +466,12 @@ auto VPUndoPiecesZValueMove::PieceIds() const -> QVector<QString>
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VPUndoPiecesZValueMove::Levels(const QList<VPPiecePtr> &allPieces, const QVector<QString> &skipPieces,
-                                    bool skip) -> QList<QVector<QString> >
+auto VPUndoPiecesZValueMove::Levels(const QList<VPPiecePtr> &allPieces, const QVector<QString> &skipPieces, bool skip)
+    -> QList<QVector<QString>>
 {
     QMap<qreal, QVector<QString>> levels;
 
-    for (const auto &p: allPieces)
+    for (const auto &p : allPieces)
     {
         if (p.isNull() || (skip && skipPieces.contains(p->GetUniqueID())))
         {
@@ -503,11 +496,11 @@ auto VPUndoPiecesZValueMove::Levels(const QList<VPPiecePtr> &allPieces, const QV
 //---------------------------------------------------------------------------------------------------------------------
 auto VPUndoPiecesZValueMove::LevelStep(const QList<VPPiecePtr> &pieces) -> qreal
 {
-    QList<QVector<QString>> levels = Levels(pieces, QVector<QString>(), false);
+    QList<QVector<QString>> const levels = Levels(pieces, QVector<QString>(), false);
     if (levels.isEmpty())
     {
         return 0;
     }
 
-    return 1.0/levels.size();
+    return 1.0 / static_cast<int>(levels.size());
 }
