@@ -41,6 +41,7 @@
 #include "vpmainwindow.h"
 #include "vpuzzleshortcutmanager.h"
 
+#include <vcsRepoState.h>
 #include <QCommandLineParser>
 #include <QEvent>
 #include <QFileOpenEvent>
@@ -50,16 +51,12 @@
 #include <QMessageBox>
 #include <QPixmapCache>
 #include <QStyleFactory>
+#include <QTimer>
 
 #if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
 #include "../vmisc/compatibility.h"
 #endif
 
-#if !defined(BUILD_REVISION) && defined(QBS_BUILD)
-#include <vcsRepoState.h>
-#define BUILD_REVISION VCS_REPO_STATE_REVISION
-#endif
-
 using namespace Qt::Literals::StringLiterals;
 
 QT_WARNING_PUSH
@@ -75,6 +72,59 @@ QT_WARNING_POP
 #define VER_PRODUCTNAME_STR "Puzzle"
 #define VER_FILEDESCRIPTION_STR "Valentina's manual layout creator."
 
+//---------------------------------------------------------------------------------------------------------------------
+inline void LogMessageDetails(QtMsgType type, const QMessageLogContext &context, const QString &msg)
+{
+    QString debugdate = "["_L1 + QDateTime::currentDateTime().toString(QStringLiteral("yyyy.MM.dd hh:mm:ss"));
+    QString const file = VAbstractApplication::ReduceLogContextFilePath(context.file);
+
+    switch (type)
+    {
+        case QtDebugMsg:
+            debugdate += QStringLiteral(":DEBUG:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdOut() << QApplication::translate("mNoisyHandler", "DEBUG:") << msg << "\n";
+            break;
+        case QtWarningMsg:
+            debugdate += QStringLiteral(":WARNING:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdErr() << QApplication::translate("mNoisyHandler", "WARNING:") << msg << "\n";
+            break;
+        case QtCriticalMsg:
+            debugdate += QStringLiteral(":CRITICAL:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdErr() << QApplication::translate("mNoisyHandler", "CRITICAL:") << msg << "\n";
+            break;
+        case QtFatalMsg:
+            debugdate += QStringLiteral(":FATAL:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdErr() << QApplication::translate("mNoisyHandler", "FATAL:") << msg << "\n";
+            break;
+        case QtInfoMsg:
+            debugdate += QStringLiteral(":INFO:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdOut() << QApplication::translate("mNoisyHandler", "INFO:") << msg << "\n";
+            break;
+        default:
+            break;
+    }
+
+    vStdOut().flush();
+    vStdErr().flush();
+
+    (*VPApplication::VApp()->LogFile()) << debugdate << Qt::endl;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &context,
                                    const QString &msg) // NOLINT(readability-function-cognitive-complexity)
@@ -158,56 +208,7 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
         type = QtDebugMsg;
     }
 
-    {
-        QString debugdate = "["_L1 + QDateTime::currentDateTime().toString(QStringLiteral("yyyy.MM.dd hh:mm:ss"));
-        QString const file = VAbstractApplication::ReduceLogContextFilePath(context.file);
-
-        switch (type)
-        {
-            case QtDebugMsg:
-                debugdate += QStringLiteral(":DEBUG:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, msg);
-                vStdOut() << QApplication::translate("mNoisyHandler", "DEBUG:") << msg << "\n";
-                break;
-            case QtWarningMsg:
-                debugdate += QStringLiteral(":WARNING:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, msg);
-                vStdErr() << QApplication::translate("mNoisyHandler", "WARNING:") << msg << "\n";
-                break;
-            case QtCriticalMsg:
-                debugdate += QStringLiteral(":CRITICAL:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, msg);
-                vStdErr() << QApplication::translate("mNoisyHandler", "CRITICAL:") << msg << "\n";
-                break;
-            case QtFatalMsg:
-                debugdate += QStringLiteral(":FATAL:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, msg);
-                vStdErr() << QApplication::translate("mNoisyHandler", "FATAL:") << msg << "\n";
-                break;
-            case QtInfoMsg:
-                debugdate += QStringLiteral(":INFO:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, msg);
-                vStdOut() << QApplication::translate("mNoisyHandler", "INFO:") << msg << "\n";
-                break;
-            default:
-                break;
-        }
-
-        vStdOut().flush();
-        vStdErr().flush();
-
-        (*VPApplication::VApp()->LogFile()) << debugdate << Qt::endl;
-    }
+    LogMessageDetails(type, context, msg);
 
     if (isGuiThread)
     {
@@ -386,7 +387,7 @@ auto VPApplication::MainWindow() -> VPMainWindow *
     {
         NewMainWindow();
     }
-    return m_mainWindows[0];
+    return m_mainWindows.first();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -413,11 +414,29 @@ auto VPApplication::NewMainWindow() -> VPMainWindow *
 //---------------------------------------------------------------------------------------------------------------------
 auto VPApplication::NewMainWindow(const VPCommandLinePtr &cmd) -> VPMainWindow *
 {
+    Clean();
+    int maxIndex = 1;
+    QSet<int> occupiedIndices;
+    for (const auto &window : m_mainWindows)
+    {
+        if (window->IsUntitled())
+        {
+            occupiedIndices.insert(window->GetUntitledIndex());
+        }
+    }
+
+    while (occupiedIndices.contains(maxIndex))
+    {
+        ++maxIndex;
+    }
+
     auto *puzzle = new VPMainWindow(cmd);
     m_mainWindows.prepend(puzzle);
     puzzle->show();
+    puzzle->SetUntitledIndex(maxIndex);
     puzzle->UpdateWindowTitle();
     puzzle->InitZoom();
+
     return puzzle;
 }
 
@@ -429,7 +448,7 @@ void VPApplication::InitOptions()
     StartLogging();
 
     qCDebug(pApp, "Version: %s", qUtf8Printable(AppVersionStr()));
-    qCDebug(pApp, "Build revision: %s", BUILD_REVISION);
+    qCDebug(pApp, "Build revision: %s", VCS_REPO_STATE_REVISION);
     qCDebug(pApp, "%s", qUtf8Printable(buildCompatibilityString()));
     qCDebug(pApp, "Built on %s at %s", __DATE__, __TIME__);
     qCDebug(pApp, "Command-line arguments: %s", qUtf8Printable(arguments().join(QStringLiteral(", "))));
@@ -443,13 +462,14 @@ void VPApplication::InitOptions()
 
     CheckSystemLocale();
 
-    QTimer::singleShot(0, this,
+    QTimer::singleShot(0,
+                       this,
                        []()
                        {
-                           QString const country = VGAnalytics::CountryCode();
-                           if (country == "ru"_L1 || country == "by"_L1)
+                           if (QString const country = VGAnalytics::CountryCode();
+                               country == "ru"_L1 || country == "by"_L1 || country == "ir"_L1)
                            {
-                               qFatal("country not detected");
+                               QCoreApplication::exit();
                            }
                        });
 
@@ -564,6 +584,8 @@ void VPApplication::ProcessCMD()
         // Set feed URL before doing anything else
         FvUpdater::sharedUpdater()->SetFeedURL(FvUpdater::CurrentFeedURL());
 
+        FvUpdater::sharedUpdater()->SetMainWindow(MainWindow());
+
         // Check for updates automatically
         FvUpdater::sharedUpdater()->CheckForUpdatesSilent();
     }
@@ -585,6 +607,7 @@ auto VPApplication::event(QEvent *e) -> bool
                 if (VPMainWindow *mw = MainWindow(); mw != nullptr)
                 {
                     mw->LoadFile(macFileOpen); // open file in existing window
+                    PuzzleSettings()->SetPathManualLayouts(QFileInfo(macFileOpen).absolutePath());
                 }
                 return true;
             }
@@ -728,7 +751,7 @@ auto VPApplication::StartWithFiles(const VPCommandLinePtr &cmd, const QStringLis
             if (not rawLayouts.isEmpty())
             {
                 // Maybe already opened
-                QList<VPMainWindow *> list = VPApplication::VApp()->MainWindows();
+                QList<VPMainWindow *> list = MainWindows();
                 auto w = std::find_if(list.begin(), list.end(),
                                       [arg](VPMainWindow *window) { return window->CurrentFile() == arg; });
                 if (w != list.end())
@@ -739,6 +762,10 @@ auto VPApplication::StartWithFiles(const VPCommandLinePtr &cmd, const QStringLis
             }
             continue;
         }
+        else
+        {
+            PuzzleSettings()->SetPathManualLayouts(QFileInfo(arg).absolutePath());
+        }
 
         if (not rawLayouts.isEmpty())
         {
