@@ -29,39 +29,47 @@
 #define VPAPPLICATION_H
 
 #include "../vmisc/def.h"
-#include "vpsettings.h"
 #include "../vmisc/vabstractapplication.h"
+#include "../vmisc/vlockguard.h"
 #include "vpcommandline.h"
+#include "vpsettings.h"
 
 template <typename T> class QWeakPointer;
 class VPMainWindow;
 class QLocalServer;
 class DialogPuzzlePreferences;
 
-enum class SocketConnection : bool {Client = false, Server = true};
+enum class SocketConnection : bool
+{
+    Client = false,
+    Server = true
+};
 
 class VPApplication : public VAbstractApplication
 {
     Q_OBJECT // NOLINT
+
 public:
     VPApplication(int &argc, char **argv);
     ~VPApplication() override;
 
-    auto notify(QObject * receiver, QEvent * event) -> bool override;
+    auto notify(QObject *receiver, QEvent *event) -> bool override;
 
     auto IsAppInGUIMode() const -> bool override;
     auto MainWindow() -> VPMainWindow *;
-    auto MainWindows() -> QList<VPMainWindow*>;
+    auto MainWindows() -> QList<VPMainWindow *>;
     auto NewMainWindow() -> VPMainWindow *;
     auto NewMainWindow(const VPCommandLinePtr &cmd) -> VPMainWindow *;
 
     void InitOptions();
 
+    void StartLogging();
+    auto LogFile() -> QTextStream *;
+
     auto TrVars() -> const VTranslateVars * override;
 
     void OpenSettings() override;
     auto PuzzleSettings() -> VPSettings *;
-    void ActivateDarkMode();
 
     void ParseCommandLine(const SocketConnection &connection, const QStringList &arguments);
     void ProcessArguments(const VPCommandLinePtr &cmd);
@@ -87,10 +95,12 @@ private slots:
 
 private:
     // cppcheck-suppress unknownMacro
-    Q_DISABLE_COPY_MOVE(VPApplication) //NOLINT
-    QList<QPointer<VPMainWindow> > m_mainWindows{};
+    Q_DISABLE_COPY_MOVE(VPApplication) // NOLINT
+    QList<QPointer<VPMainWindow>> m_mainWindows{};
     QLocalServer *m_localServer{nullptr};
     QWeakPointer<DialogPuzzlePreferences> m_preferencesDialog{};
+    QSharedPointer<VLockGuard<QFile>> m_lockLog{};
+    std::shared_ptr<QTextStream> m_out{nullptr};
 
     void Clean();
 
@@ -98,6 +108,9 @@ private:
 
     auto StartWithFiles(const VPCommandLinePtr &cmd, const QStringList &rawLayouts) -> bool;
     auto SingleStart(const VPCommandLinePtr &cmd, const QStringList &rawLayouts) -> bool;
+
+    static auto LogPath() -> QString;
+    void BeginLogging();
 };
 
 #endif // VPAPPLICATION_H
