@@ -76,6 +76,9 @@ Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingDxfCompatibility, ("layout/dxfCo
 Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutLineWidth, ("layout/lineWidth"_L1))         // NOLINT
 Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutShowGrainline, ("layout/showGrainline"_L1)) // NOLINT
 Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingPathsRawLayoutData, ("paths/rawLatoutData"_L1))   // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutHideRuler, ("layout/hideRuler"_L1))         // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTilesScheme, ("layout/tilesScheme"_L1))     // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTextAsPaths, ("layout/textAsPaths"_L1))     // NOLINT
 
 QT_WARNING_POP
 
@@ -413,3 +416,39 @@ void VPSettings::SetShowGrainline(bool value)
 {
     setValue(*settingLayoutShowGrainline, value);
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPSettings::GetHideRuler() const -> bool
+{
+    return value(*settingLayoutHideRuler, false).toBool();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPSettings::SetHideRuler(bool value)
+{
+    setValue(*settingLayoutHideRuler, value);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPSettings::GetTilesScheme() const -> bool
+{
+    return value(*settingLayoutTilesScheme, false).toBool();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPSettings::SetTilesScheme(bool value)
+{
+    setValue(*settingLayoutTilesScheme, value);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPSettings::GetTextAsPaths() const -> bool
+{
+    return value(*settingLayoutTextAsPaths, false).toBool();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPSettings::SetTextAsPaths(bool value)
+{
+    setValue(*settingLayoutTextAsPaths, value);
+}
