@@ -65,9 +65,12 @@ extern const QString TagLines;
 extern const QString TagLine;
 extern const QString TagScale;
 extern const QString TagWatermark;
+extern const QString TagPoint;
+extern const QString TagMirrorLine;
 
 extern const QString AttrWarningSuperposition;
 extern const QString AttrWarningOutOfBound;
+extern const QString AttrWarningPieceGape;
 extern const QString AttrStickyEdges;
 extern const QString AttrPiecesGap;
 extern const QString AttrVisible;
@@ -80,15 +83,17 @@ extern const QString AttrBottom;
 extern const QString AttrWidth;
 extern const QString AttrLength;
 extern const QString AttrFollowGrainline;
-extern const QString AttrID;
-extern const QString AttrMirrored;
+extern const QString AttrBoundaryTogetherWithNotches;
+extern const QString AttrUID;
+extern const QString AttrVerticallyFlipped;
+extern const QString AttrHorizontallyFlipped;
 extern const QString AttrForbidFlipping;
 extern const QString AttrForceFlipping;
+extern const QString AttrSewLineOnDrawing;
 extern const QString AttrTransform;
 extern const QString AttrShowSeamline;
 extern const QString AttrEnabled;
 extern const QString AttrBuiltIn;
-extern const QString AttrAngle;
 extern const QString AttrArrowDirection;
 extern const QString AttrType;
 extern const QString AttrBaseLine;
@@ -99,6 +104,7 @@ extern const QString AttrCenter;
 extern const QString AttrBox;
 extern const QString AttrShape;
 extern const QString AttrFont;
+extern const QString AttrSVGFont;
 extern const QString AttrFontSize;
 extern const QString AttrBold;
 extern const QString AttrItalic;
@@ -113,16 +119,37 @@ extern const QString AttrShowPreview;
 extern const QString AttrPrintScheme;
 extern const QString AttrTileNumber;
 extern const QString AttrZValue;
+extern const QString AttrX;
+extern const QString AttrY;
+extern const QString AttrTurnPoint;
+extern const QString AttrCurvePoint;
+extern const QString AttrClockwiseOpening;
+extern const QString AttrShowFullPiece;
+extern const QString AttrNotMirrored;
+extern const QString AttrCutOnFold;
+extern const QString AttrFoldLineType;
+extern const QString AttrFoldLineHeight;
+extern const QString AttrFoldLineWidth;
+extern const QString AttrFoldLineCenter;
+extern const QString AttrFoldLineLabel;
 
-extern const QString atFrontStr;
-extern const QString atRearStr;
-extern const QString atBothStr;
+extern const QString oneWayUpStr;
+extern const QString oneWayDownStr;
+extern const QString fourWaysStr;
+extern const QString twoWaysUpDownStr;
+extern const QString twoWaysUpLeftStr;
+extern const QString twoWaysUpRightStr;
+extern const QString twoWaysDownLeftStr;
+extern const QString twoWaysDownRightStr;
+extern const QString threeWaysUpDownLeftStr;
+extern const QString threeWaysUpDownRightStr;
+extern const QString threeWaysUpLeftRightStr;
+extern const QString threeWaysDownLeftRightStr;
 
 extern const QChar groupSep;
 extern const QChar coordintatesSep;
 extern const QChar pointsSep;
 extern const QChar itemsSep;
-}  // namespace ML
-
+} // namespace ML
 
 #endif // VPLAYOUTLITERALS_H
