@@ -30,12 +30,13 @@
 #define TAPEPREFERENCESCONFIGURATIONPAGE_H
 
 #include <QWidget>
+#include <memory>
 
-#include "../vmisc/defglobal.h"
+class QComboBox;
 
 namespace Ui
 {
-    class TapePreferencesConfigurationPage;
+class TapePreferencesConfigurationPage;
 }
 
 class TapePreferencesConfigurationPage : public QWidget
@@ -47,16 +48,30 @@ public:
     ~TapePreferencesConfigurationPage() override;
 
     auto Apply() -> QStringList;
+
 protected:
-    void changeEvent(QEvent* event) override;
+    void changeEvent(QEvent *event) override;
+
+private slots:
+    void ShortcutCellDoubleClicked(int row, int column);
+
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(TapePreferencesConfigurationPage) // NOLINT
-    Ui::TapePreferencesConfigurationPage *ui;
+    std::unique_ptr<Ui::TapePreferencesConfigurationPage> ui;
     bool m_langChanged;
     bool m_systemChanged;
+    bool m_sendCrashReportsChanged{false};
+    bool m_crashUserEmailChanged{false};
+    QList<QStringList> m_transientShortcuts{};
 
     void RetranslateUi();
+    void SetThemeModeComboBox();
+    void InitShortcuts(bool defaults = false);
+    void UpdateShortcutsTable();
+    void RetranslateShortcutsTable();
+    static void InitKnownMeasurements(QComboBox *combo);
+    void InitKnownMeasurementsDescription();
 };
 
 #endif // TAPEPREFERENCESCONFIGURATIONPAGE_H
