@@ -30,12 +30,11 @@
 #define DIALOGABOUTTAPE_H
 
 #include <QDialog>
-
-#include "../vmisc/defglobal.h"
+#include <memory>
 
 namespace Ui
 {
-    class DialogAboutTape;
+class DialogAboutTape;
 }
 
 class DialogAboutTape : public QDialog
@@ -47,13 +46,13 @@ public:
     ~DialogAboutTape() override;
 
 protected:
-    void changeEvent(QEvent* event) override;
+    void changeEvent(QEvent *event) override;
     void showEvent(QShowEvent *event) override;
 
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(DialogAboutTape) // NOLINT
-    Ui::DialogAboutTape *ui;
+    std::unique_ptr<Ui::DialogAboutTape> ui;
     bool m_isInitialized;
 
     static void FontPointSize(QWidget *w, int pointSize);
