@@ -29,13 +29,10 @@
 #define DIALOGDIMENSIONCUSTOMNAMES_H
 
 #include <QDialog>
+#include <memory>
 
 #include "../vformat/vdimensions.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-#include "../vmisc/defglobal.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-
 namespace Ui
 {
 class DialogDimensionCustomNames;
@@ -46,7 +43,7 @@ class DialogDimensionCustomNames : public QDialog
     Q_OBJECT // NOLINT
 
 public:
-    explicit DialogDimensionCustomNames(const QMap<MeasurementDimension, MeasurementDimension_p > &dimensions,
+    explicit DialogDimensionCustomNames(const QMap<MeasurementDimension, MeasurementDimension_p> &dimensions,
                                         QWidget *parent = nullptr);
     ~DialogDimensionCustomNames() override;
 
@@ -55,7 +52,7 @@ public:
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(DialogDimensionCustomNames) // NOLINT
-    Ui::DialogDimensionCustomNames *ui;
+    std::unique_ptr<Ui::DialogDimensionCustomNames> ui;
 
     void InitTable(const QMap<MeasurementDimension, MeasurementDimension_p> &dimensions);
 };
