@@ -139,6 +139,19 @@ DialogSetupMultisize::DialogSetupMultisize(Unit unit, QWidget *parent)
     connect(ui->groupBoxWDimension, &QGroupBox::clicked, this, [this]() { CheckState(); });
     connect(ui->groupBoxZDimension, &QGroupBox::clicked, this, [this]() { CheckState(); });
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+    connect(ui->checkBoxFullCircumference, &QCheckBox::checkStateChanged, this,
+            &DialogSetupMultisize::ShowFullCircumference);
+
+    connect(ui->checkBoxXDimensionBodyMeasurement, &QCheckBox::checkStateChanged, this,
+            &DialogSetupMultisize::XDimensionBodyMeasurementChanged);
+    connect(ui->checkBoxYDimensionBodyMeasurement, &QCheckBox::checkStateChanged, this,
+            &DialogSetupMultisize::YDimensionBodyMeasurementChanged);
+    connect(ui->checkBoxWDimensionBodyMeasurement, &QCheckBox::checkStateChanged, this,
+            &DialogSetupMultisize::WDimensionBodyMeasurementChanged);
+    connect(ui->checkBoxZDimensionBodyMeasurement, &QCheckBox::checkStateChanged, this,
+            &DialogSetupMultisize::ZDimensionBodyMeasurementChanged);
+#else
     connect(ui->checkBoxFullCircumference, &QCheckBox::stateChanged, this,
             &DialogSetupMultisize::ShowFullCircumference);
 
@@ -150,6 +163,7 @@ DialogSetupMultisize::DialogSetupMultisize(Unit unit, QWidget *parent)
             &DialogSetupMultisize::WDimensionBodyMeasurementChanged);
     connect(ui->checkBoxZDimensionBodyMeasurement, &QCheckBox::stateChanged, this,
             &DialogSetupMultisize::ZDimensionBodyMeasurementChanged);
+#endif
 
     connect(ui->lineEditCustomXDimensionName, &QLineEdit::textChanged, this,
             [this](const QString &text)
@@ -472,7 +486,7 @@ void DialogSetupMultisize::InitDimensionMinMax(QDoubleSpinBox *doubleSpinBoxMinV
 
     doubleSpinBoxMinValue->blockSignals(true);
     doubleSpinBoxMinValue->setSuffix(unitStr);
-    doubleSpinBoxMinValue->setDecimals(dimension->Units() == Unit::Mm ? 0 : 1);
+    doubleSpinBoxMinValue->setDecimals(dimension->Decimals());
     doubleSpinBoxMinValue->setMinimum(m && fc ? dimension->RangeMin() * 2 : dimension->RangeMin());
     doubleSpinBoxMinValue->setMaximum(m && fc ? dimension->MaxValue() * 2 : dimension->MaxValue());
     doubleSpinBoxMinValue->setValue(m && fc ? dimension->MinValue() * 2 : dimension->MinValue());
@@ -480,7 +494,7 @@ void DialogSetupMultisize::InitDimensionMinMax(QDoubleSpinBox *doubleSpinBoxMinV
 
     doubleSpinBoxMaxValue->blockSignals(true);
     doubleSpinBoxMaxValue->setSuffix(unitStr);
-    doubleSpinBoxMaxValue->setDecimals(dimension->Units() == Unit::Mm ? 0 : 1);
+    doubleSpinBoxMaxValue->setDecimals(dimension->Decimals());
     doubleSpinBoxMaxValue->setMinimum(m && fc ? dimension->MinValue() * 2 : dimension->MinValue());
     doubleSpinBoxMaxValue->setMaximum(m && fc ? dimension->RangeMax() * 2 : dimension->RangeMax());
     doubleSpinBoxMaxValue->setValue(m && fc ? dimension->RangeMax() * 2 : dimension->RangeMax());
