@@ -48,8 +48,11 @@
 #include "vtapeshortcutmanager.h"
 
 #include "QtConcurrent/qtconcurrentrun.h"
+#include <vcsRepoState.h>
 #include <QCommandLineParser>
 #include <QDir>
+#include <QDirIterator>
+#include <QEvent>
 #include <QFileOpenEvent>
 #include <QFileSystemWatcher>
 #include <QFuture>
@@ -63,15 +66,10 @@
 #include <QSpacerItem>
 #include <QStyleFactory>
 #include <QThread>
+#include <QTimer>
 #include <QTranslator>
 #include <QUuid>
 
-#if !defined(BUILD_REVISION) && defined(QBS_BUILD)
-#include <QEvent>
-#include <vcsRepoState.h>
-#define BUILD_REVISION VCS_REPO_STATE_REVISION
-#endif
-
 #if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
 #include "../vmisc/compatibility.h"
 #endif
@@ -111,6 +109,59 @@ Q_GLOBAL_STATIC_WITH_ARGS(const QString, LONG_OPTION_TEST, ("test"_L1)) // NOLIN
 QT_WARNING_POP
 } // namespace
 
+//---------------------------------------------------------------------------------------------------------------------
+inline void LogMessageDetails(QtMsgType type, const QMessageLogContext &context, const QString &msg)
+{
+    QString debugdate = "["_L1 + QDateTime::currentDateTime().toString(QStringLiteral("yyyy.MM.dd hh:mm:ss"));
+    QString const file = VAbstractApplication::ReduceLogContextFilePath(context.file);
+
+    switch (type)
+    {
+        case QtDebugMsg:
+            debugdate += QStringLiteral(":DEBUG:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdOut() << QApplication::translate("mNoisyHandler", "DEBUG:") << msg << "\n";
+            break;
+        case QtWarningMsg:
+            debugdate += QStringLiteral(":WARNING:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdErr() << QApplication::translate("mNoisyHandler", "WARNING:") << msg << "\n";
+            break;
+        case QtCriticalMsg:
+            debugdate += QStringLiteral(":CRITICAL:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdErr() << QApplication::translate("mNoisyHandler", "CRITICAL:") << msg << "\n";
+            break;
+        case QtFatalMsg:
+            debugdate += QStringLiteral(":FATAL:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdErr() << QApplication::translate("mNoisyHandler", "FATAL:") << msg << "\n";
+            break;
+        case QtInfoMsg:
+            debugdate += QStringLiteral(":INFO:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdOut() << QApplication::translate("mNoisyHandler", "INFO:") << msg << "\n";
+            break;
+        default:
+            break;
+    }
+
+    vStdOut().flush();
+    vStdErr().flush();
+
+    (*MApplication::VApp()->LogFile()) << debugdate << Qt::endl;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg)
 {
@@ -194,56 +245,7 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
         logMsg = logMsg.remove(VAbstractApplication::warningMessageSignature);
     }
 
-    {
-        QString debugdate = "["_L1 + QDateTime::currentDateTime().toString(QStringLiteral("yyyy.MM.dd hh:mm:ss"));
-        QString const file = VAbstractApplication::ReduceLogContextFilePath(context.file);
-
-        switch (type)
-        {
-            case QtDebugMsg:
-                debugdate += QStringLiteral(":DEBUG:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, logMsg);
-                vStdOut() << QApplication::translate("mNoisyHandler", "DEBUG:") << logMsg << "\n";
-                break;
-            case QtWarningMsg:
-                debugdate += QStringLiteral(":WARNING:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, logMsg);
-                vStdErr() << QApplication::translate("mNoisyHandler", "WARNING:") << logMsg << "\n";
-                break;
-            case QtCriticalMsg:
-                debugdate += QStringLiteral(":CRITICAL:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, logMsg);
-                vStdErr() << QApplication::translate("mNoisyHandler", "CRITICAL:") << logMsg << "\n";
-                break;
-            case QtFatalMsg:
-                debugdate += QStringLiteral(":FATAL:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, logMsg);
-                vStdErr() << QApplication::translate("mNoisyHandler", "FATAL:") << logMsg << "\n";
-                break;
-            case QtInfoMsg:
-                debugdate += QStringLiteral(":INFO:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, logMsg);
-                vStdOut() << QApplication::translate("mNoisyHandler", "INFO:") << logMsg << "\n";
-                break;
-            default:
-                break;
-        }
-
-        vStdOut().flush();
-        vStdErr().flush();
-
-        (*MApplication::VApp()->LogFile()) << debugdate << Qt::endl;
-    }
+    LogMessageDetails(type, context, logMsg);
 
     if (isGuiThread)
     {
@@ -341,10 +343,7 @@ MApplication::~MApplication()
     qDeleteAll(m_kmMainWindows);
 
     delete m_trVars;
-    if (not m_dataBase.isNull())
-    {
-        delete m_dataBase;
-    }
+    delete m_dataBase.data();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -472,7 +471,7 @@ void MApplication::InitOptions()
     StartLogging();
 
     qCDebug(mApp, "Version: %s", qUtf8Printable(AppVersionStr()));
-    qCDebug(mApp, "Build revision: %s", BUILD_REVISION);
+    qCDebug(mApp, "Build revision: %s", VCS_REPO_STATE_REVISION);
     qCDebug(mApp, "%s", qUtf8Printable(buildCompatibilityString()));
     qCDebug(mApp, "Built on %s at %s", __DATE__, __TIME__);
     qCDebug(mApp, "Command-line arguments: %s", qUtf8Printable(arguments().join(QStringLiteral(", "))));
@@ -486,9 +485,9 @@ void MApplication::InitOptions()
                        []()
                        {
                            QString const country = VGAnalytics::CountryCode();
-                           if (country == "ru"_L1 || country == "by"_L1)
+                           if (country == "ru"_L1 || country == "by"_L1 || country == "ir"_L1)
                            {
-                               qFatal("country not detected");
+                               QCoreApplication::exit();
                            }
                        });
 
@@ -755,7 +754,18 @@ void MApplication::RestartKnownMeasurementsDatabaseWatcher()
     {
         delete m_knownMeasurementsDatabaseWatcher;
         m_knownMeasurementsDatabaseWatcher = new QFileSystemWatcher({settings->GetPathKnownMeasurements()}, this);
-        connect(m_knownMeasurementsDatabaseWatcher, &QFileSystemWatcher::directoryChanged, this,
+
+        QDirIterator it(settings->GetPathKnownMeasurements(),
+                        QDir::Dirs | QDir::NoDotAndDotDot,
+                        QDirIterator::Subdirectories);
+        while (it.hasNext())
+        {
+            m_knownMeasurementsDatabaseWatcher->addPath(it.next());
+        }
+
+        connect(m_knownMeasurementsDatabaseWatcher,
+                &QFileSystemWatcher::directoryChanged,
+                this,
                 &MApplication::RepopulateMeasurementsDatabase);
     }
 }
@@ -795,11 +805,28 @@ void MApplication::BeginLogging()
 //---------------------------------------------------------------------------------------------------------------------
 auto MApplication::NewMainTapeWindow() -> TMainWindow *
 {
+    CleanTapeWindows();
+    int maxIndex = 1;
+    QSet<int> occupiedIndices;
+    for (const auto &window : m_mainWindows)
+    {
+        if (window->IsUntitled())
+        {
+            occupiedIndices.insert(window->GetUntitledIndex());
+        }
+    }
+
+    while (occupiedIndices.contains(maxIndex))
+    {
+        ++maxIndex;
+    }
+
     auto *tape = new TMainWindow();
     m_mainWindows.prepend(tape);
     if (not MApplication::VApp()->IsTestMode())
     {
         tape->show();
+        tape->SetUntitledIndex(maxIndex);
         tape->UpdateWindowTitle();
     }
     return tape;
@@ -832,11 +859,28 @@ auto MApplication::MainKMWindows() -> QList<TKMMainWindow *>
 //---------------------------------------------------------------------------------------------------------------------
 auto MApplication::NewMainKMWindow() -> TKMMainWindow *
 {
+    CleanKMWindows();
+    int maxIndex = 1;
+    QSet<int> occupiedIndices;
+    for (const auto &window : m_kmMainWindows)
+    {
+        if (window->IsUntitled())
+        {
+            occupiedIndices.insert(window->GetUntitledIndex());
+        }
+    }
+
+    while (occupiedIndices.contains(maxIndex))
+    {
+        ++maxIndex;
+    }
+
     auto *known = new TKMMainWindow();
     m_kmMainWindows.prepend(known);
     if (not MApplication::VApp()->IsTestMode())
     {
         known->show();
+        known->SetUntitledIndex(maxIndex);
         known->UpdateWindowTitle();
     }
     return known;
@@ -852,6 +896,17 @@ void MApplication::ProcessCMD()
         // Set feed URL before doing anything else
         FvUpdater::sharedUpdater()->SetFeedURL(FvUpdater::CurrentFeedURL());
 
+        QWidget *mainWindow = nullptr;
+        if (!m_knownMeasurementsMode)
+        {
+            mainWindow = MainTapeWindow();
+        }
+        else
+        {
+            mainWindow = MainKMWindow();
+        }
+        FvUpdater::sharedUpdater()->SetMainWindow(mainWindow);
+
         // Check for updates automatically
         FvUpdater::sharedUpdater()->CheckForUpdatesSilent();
     }
@@ -883,7 +938,18 @@ void MApplication::RepopulateMeasurementsDatabase(const QString &path)
     Q_UNUSED(path)
     if (m_knownMeasurementsDatabase != nullptr)
     {
-        connect(qApp, &QCoreApplication::aboutToQuit, m_knownMeasurementsRepopulateWatcher,
+        if (QFileInfo f(path); f.isDir() && f.exists())
+        {
+            QDirIterator it(path, QDir::Dirs | QDir::NoDotAndDotDot, QDirIterator::Subdirectories);
+            while (it.hasNext())
+            {
+                m_knownMeasurementsDatabaseWatcher->addPath(it.next());
+            }
+        }
+
+        connect(qApp,
+                &QCoreApplication::aboutToQuit,
+                m_knownMeasurementsRepopulateWatcher,
                 [this]()
                 {
                     m_knownMeasurementsRepopulateWatcher->cancel();
