@@ -46,6 +46,7 @@
 #include "knownmeasurements/vknownmeasurements.h"
 #include "mapplication.h" // Should be last because of definning qApp
 #include "ui_tkmmainwindow.h"
+#include <qmimedata.h>
 
 #include <QAbstractButton>
 #include <QCloseEvent>
@@ -116,10 +117,16 @@ TKMMainWindow::TKMMainWindow(QWidget *parent)
 
     ui->lineEditFind->installEventFilter(this);
     ui->plainTextEditFormula->installEventFilter(this);
+    ui->listWidget->installEventFilter(this);
+    // QListView::setViewMode overwriting the acceptDrops property
+    // https://forum.qt.io/post/688467
+    ui->listWidget->setDragDropMode(QAbstractItemView::DropOnly);
 
     m_search = QSharedPointer<VTableSearch>(new VTableSearch(ui->tableWidget));
     ui->tabWidget->setVisible(false);
 
+    connect(ui->tabWidget, &QTabWidget::currentChanged, this, &TKMMainWindow::RefreshMeasurementImagePreview);
+
     ui->toolBar->setContextMenuPolicy(Qt::PreventContextMenu);
 
     m_recentFileActs.fill(nullptr);
@@ -210,7 +217,7 @@ auto TKMMainWindow::LoadFile(const QString &path) -> bool
         m_m = new VKnownMeasurementsDocument();
         m_m->setXMLContent(converter.Convert());
 
-        if (VCommonSettings *settings = VAbstractApplication::VApp()->Settings(); settings->IsCollectStatistic())
+        if (const VCommonSettings *settings = VAbstractApplication::VApp()->Settings(); settings->IsCollectStatistic())
         {
             auto *statistic = VGAnalytics::Instance();
 
@@ -293,14 +300,7 @@ void TKMMainWindow::UpdateWindowTitle()
     }
     else
     {
-        if (auto index = MApplication::VApp()->MainKMWindows().indexOf(this); index != -1)
-        {
-            showName = tr("untitled %1").arg(index + 1);
-        }
-        else
-        {
-            showName = tr("untitled");
-        }
+        showName = untitledIndex > 0 ? tr("untitled %1").arg(untitledIndex) : tr("untitled");
         showName += ".vkm"_L1;
     }
 
@@ -338,6 +338,24 @@ void TKMMainWindow::UpdateWindowTitle()
 #endif // defined(Q_OS_MAC)
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto TKMMainWindow::IsUntitled() const -> bool
+{
+    return m_curFile.isEmpty();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto TKMMainWindow::GetUntitledIndex() const -> int
+{
+    return untitledIndex;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void TKMMainWindow::SetUntitledIndex(int newUntitledIndex)
+{
+    untitledIndex = newUntitledIndex;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void TKMMainWindow::closeEvent(QCloseEvent *event)
 {
@@ -393,6 +411,11 @@ void TKMMainWindow::changeEvent(QEvent *event)
         InitIcons();
     }
 
+    if (event->type() == QEvent::ThemeChange)
+    {
+        VTheme::Instance()->ResetColorScheme();
+    }
+
     // remember to call base class implementation
     QMainWindow::changeEvent(event);
 }
@@ -402,47 +425,133 @@ auto TKMMainWindow::eventFilter(QObject *object, QEvent *event) -> bool
 {
     if (auto *plainTextEdit = qobject_cast<QPlainTextEdit *>(object))
     {
-        if (event->type() == QEvent::KeyPress)
-        {
-            auto *keyEvent = static_cast<QKeyEvent *>(event); // NOLINT(cppcoreguidelines-pro-type-static-cast-downcast)
-            if ((keyEvent->key() == Qt::Key_Period) && ((keyEvent->modifiers() & Qt::KeypadModifier) != 0U))
-            {
-                if (VAbstractApplication::VApp()->Settings()->GetOsSeparator())
-                {
-                    plainTextEdit->insertPlainText(LocaleDecimalPoint(QLocale()));
-                }
-                else
-                {
-                    plainTextEdit->insertPlainText(LocaleDecimalPoint(QLocale::c()));
-                }
-                return true;
-            }
-        }
+        return HandleKeyPress(plainTextEdit, event);
     }
-    else if (auto *textEdit = qobject_cast<QLineEdit *>(object))
+
+    if (auto *textEdit = qobject_cast<QLineEdit *>(object))
     {
-        if (event->type() == QEvent::KeyPress)
-        {
-            auto *keyEvent = static_cast<QKeyEvent *>(event); // NOLINT(cppcoreguidelines-pro-type-static-cast-downcast)
-            if ((keyEvent->key() == Qt::Key_Period) && ((keyEvent->modifiers() & Qt::KeypadModifier) != 0U))
-            {
-                if (VAbstractApplication::VApp()->Settings()->GetOsSeparator())
-                {
-                    textEdit->insert(LocaleDecimalPoint(QLocale()));
-                }
-                else
-                {
-                    textEdit->insert(LocaleDecimalPoint(QLocale::c()));
-                }
-                return true;
-            }
-        }
+        return HandleKeyPress(textEdit, event);
+    }
+
+    if (const auto *listWidget = qobject_cast<QListWidget *>(object))
+    {
+        return HandleListWidgetEvent(listWidget, event);
     }
 
     // pass the event on to the parent class
     return QMainWindow::eventFilter(object, event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto TKMMainWindow::HandleKeyPress(QWidget *widget, QEvent *event) -> bool
+{
+    if (event->type() != QEvent::KeyPress)
+    {
+        return false;
+    }
+
+    // NOLINTNEXTLINE(cppcoreguidelines-pro-type-static-cast-downcast)
+    if (const auto *keyEvent = static_cast<QKeyEvent *>(event);
+        keyEvent->key() != Qt::Key_Period || !(keyEvent->modifiers() & Qt::KeypadModifier))
+    {
+        return false;
+    }
+
+    const QString decimalSeparator = VAbstractApplication::VApp()->Settings()->GetOsSeparator()
+                                         ? LocaleDecimalPoint(QLocale())
+                                         : LocaleDecimalPoint(QLocale::c());
+
+    if (auto *plainTextEdit = qobject_cast<QPlainTextEdit *>(widget))
+    {
+        plainTextEdit->insertPlainText(decimalSeparator);
+        return true;
+    }
+
+    if (auto *lineEdit = qobject_cast<QLineEdit *>(widget))
+    {
+        lineEdit->insert(decimalSeparator);
+        return true;
+    }
+
+    return false;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto TKMMainWindow::HandleListWidgetEvent(const QListWidget *listWidget, QEvent *event) -> bool
+{
+    if (listWidget != ui->listWidget)
+    {
+        return false;
+    }
+
+    if (event->type() == QEvent::DragEnter || event->type() == QEvent::DragMove)
+    {
+        // NOLINTNEXTLINE(cppcoreguidelines-pro-type-static-cast-downcast)
+        return HandleDragEnterMove(static_cast<QDragEnterEvent *>(event));
+    }
+
+    if (event->type() == QEvent::Drop)
+    {
+        // NOLINTNEXTLINE(cppcoreguidelines-pro-type-static-cast-downcast)
+        return HandleDrop(static_cast<QDropEvent *>(event));
+    }
+
+    return false;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto TKMMainWindow::HandleDragEnterMove(QDragEnterEvent *dragEvent) -> bool
+{
+    if (!dragEvent->mimeData()->hasUrls())
+    {
+        return false;
+    }
+
+    const QStringList formats = SupportedFormats();
+    if (const auto urls = dragEvent->mimeData()->urls();
+        std::all_of(urls.begin(),
+                    urls.end(),
+                    [formats](const QUrl &url)
+                    { return url.isLocalFile() && formats.contains(QFileInfo(url.toLocalFile()).suffix().toLower()); }))
+    {
+        dragEvent->acceptProposedAction();
+        return true;
+    }
+    return false;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto TKMMainWindow::HandleDrop(QDropEvent *dropEvent) -> bool
+{
+    if (!dropEvent->mimeData()->hasUrls())
+    {
+        return false;
+    }
+
+    const QStringList formats = SupportedFormats();
+    const auto urls = dropEvent->mimeData()->urls();
+    QStringList imagePaths;
+    imagePaths.reserve(urls.size());
+    for (const QUrl &url : urls)
+    {
+        if (url.isLocalFile())
+        {
+            if (const QString filePath = url.toLocalFile(); formats.contains(QFileInfo(filePath).suffix().toLower()))
+            {
+                imagePaths.append(filePath);
+            }
+        }
+    }
+
+    if (imagePaths.size() == urls.size())
+    {
+        AddMeasurementImages(imagePaths);
+        dropEvent->acceptProposedAction();
+        return true;
+    }
+    return false;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void TKMMainWindow::ExportToCSVData(const QString &fileName, bool withHeader, int mib, const QChar &separator)
 {
@@ -452,7 +561,7 @@ void TKMMainWindow::ExportToCSVData(const QString &fileName, bool withHeader, in
     int colCount = 0;
     for (int column = 0; column <= columns; ++column)
     {
-        csv.insertColumn(colCount++);
+        csv.insertSingleColumn(colCount++);
     }
 
     if (withHeader)
@@ -469,7 +578,7 @@ void TKMMainWindow::ExportToCSVData(const QString &fileName, bool withHeader, in
     {
         const VKnownMeasurement &m = iMap.value();
 
-        csv.insertRow(row);
+        csv.insertSingleRow(row);
         csv.setText(row, 0, m.name);
         csv.setText(row, 1, m.fullName);
         csv.setText(row, 2, m.group);
@@ -488,6 +597,41 @@ auto TKMMainWindow::RecentFileList() const -> QStringList
     return MApplication::VApp()->TapeSettings()->GetRecentKMFileList();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void TKMMainWindow::AddMeasurementImages(const QStringList &imagePaths)
+{
+    if (imagePaths.isEmpty())
+    {
+        return;
+    }
+
+    const VTapeSettings *settings = MApplication::VApp()->TapeSettings();
+
+    for (const auto &filePath : imagePaths)
+    {
+        if (QFileInfo f(filePath); f.exists())
+        {
+            settings->SetPathCustomImage(f.absolutePath());
+        }
+
+        VPatternImage const image = VPatternImage::FromFile(filePath);
+        if (not image.IsValid())
+        {
+            qCritical() << tr("Invalid image. Error: %1").arg(image.ErrorString());
+            continue;
+        }
+
+        m_m->AddImage(image);
+
+        MeasurementsWereSaved(false);
+    }
+
+    m_known = VKnownMeasurements();
+    RefreshImages();
+
+    ShowImageData();
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void TKMMainWindow::FileNew()
 {
@@ -887,36 +1031,15 @@ void TKMMainWindow::MoveBottom()
 //---------------------------------------------------------------------------------------------------------------------
 void TKMMainWindow::AddImage()
 {
-    VTapeSettings *settings = MApplication::VApp()->TapeSettings();
+    const VTapeSettings *settings = MApplication::VApp()->TapeSettings();
+    const QStringList filePaths = QFileDialog::getOpenFileNames(this,
+                                                                tr("Measurement images"),
+                                                                settings->GetPathCustomImage(),
+                                                                PrepareImageFilters(),
+                                                                nullptr,
+                                                                VAbstractApplication::VApp()->NativeFileDialog());
 
-    const QString filePath =
-        QFileDialog::getOpenFileName(this, tr("Measurement image"), settings->GetPathCustomImage(),
-                                     PrepareImageFilters(), nullptr, VAbstractApplication::VApp()->NativeFileDialog());
-
-    if (!filePath.isEmpty())
-    {
-        if (QFileInfo::exists(filePath))
-        {
-            settings->SetPathCustomImage(QFileInfo(filePath).absolutePath());
-        }
-
-        VPatternImage const image = VPatternImage::FromFile(filePath);
-
-        if (not image.IsValid())
-        {
-            qCritical() << tr("Invalid image. Error: %1").arg(image.ErrorString());
-            return;
-        }
-
-        m_m->AddImage(image);
-
-        MeasurementsWereSaved(false);
-
-        m_known = VKnownMeasurements();
-        RefreshImages();
-
-        ShowImageData();
-    }
+    AddMeasurementImages(filePaths);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1021,23 +1144,44 @@ void TKMMainWindow::SaveImage()
 //---------------------------------------------------------------------------------------------------------------------
 void TKMMainWindow::ShowImage()
 {
-    auto *item = ui->listWidget->currentItem();
+    VPatternImage image;
 
-    if (item == nullptr)
+    if (lastSelectedTab == ui->tabWidget->indexOf(ui->tabMeasurements)
+        || ui->tabWidget->currentIndex() == ui->tabWidget->indexOf(ui->tabMeasurements))
+    {
+        const QTableWidgetItem *nameField = ui->tableWidget->item(ui->tableWidget->currentRow(), ColumnName); // name
+        if (nameField == nullptr)
+        {
+            return;
+        }
+
+        VKnownMeasurement const m = m_known.Measurement(nameField->data(Qt::UserRole).toString());
+        image = m_known.Image(m.diagram);
+    }
+    else if (lastSelectedTab == ui->tabWidget->indexOf(ui->tabImages)
+             || ui->tabWidget->currentIndex() == ui->tabWidget->indexOf(ui->tabImages))
+    {
+        const QListWidgetItem *item = ui->listWidget->currentItem();
+        if (item == nullptr)
+        {
+            return;
+        }
+
+        QMap<QUuid, VPatternImage> const images = m_known.Images();
+
+        QUuid const id = item->data(Qt::UserRole).toUuid();
+        if (!images.contains(id))
+        {
+            return;
+        }
+
+        image = images.value(id);
+    }
+    else
     {
         return;
     }
 
-    QMap<QUuid, VPatternImage> const images = m_known.Images();
-
-    QUuid const id = item->data(Qt::UserRole).toUuid();
-    if (!images.contains(id))
-    {
-        return;
-    }
-
-    const VPatternImage image = images.value(id);
-
     if (not image.IsValid())
     {
         qCritical() << tr("Unable to show image. Error: %1").arg(image.ErrorString());
@@ -1052,7 +1196,7 @@ void TKMMainWindow::ShowImage()
         name += '.'_L1 + suffixes.at(0);
     }
 
-    delete m_tmpImage;
+    delete m_tmpImage.data();
     m_tmpImage = new QTemporaryFile(name, this);
     if (m_tmpImage->open())
     {
@@ -1127,9 +1271,9 @@ void TKMMainWindow::ShowMData()
     ui->plainTextEditDescription->blockSignals(false);
 
     // Don't block all signal for QLineEdit. Need for correct handle with clear button.
-    disconnect(ui->lineEditName, &QLineEdit::editingFinished, this, &TKMMainWindow::SaveMName);
+    disconnect(ui->lineEditName, &QLineEdit::textEdited, this, &TKMMainWindow::SaveMName);
     ui->lineEditName->setText(m.name);
-    connect(ui->lineEditName, &QLineEdit::editingFinished, this, &TKMMainWindow::SaveMName);
+    connect(ui->lineEditName, &QLineEdit::textEdited, this, &TKMMainWindow::SaveMName);
 
     disconnect(ui->lineEditFullName, &QLineEdit::editingFinished, this, &TKMMainWindow::SaveMFullName);
     ui->lineEditFullName->setText(m.fullName);
@@ -1176,6 +1320,8 @@ void TKMMainWindow::ShowImageData()
     QUuid const imageId = activeImage->data(Qt::UserRole).toUuid();
     VPatternImage const image = m_known.Image(imageId);
 
+    ShowMDiagram(image);
+
     // Don't block all signal for QLineEdit. Need for correct handle with clear button.
     disconnect(ui->lineEditImageTitle, &QLineEdit::editingFinished, this, &TKMMainWindow::SaveImageTitle);
     ui->lineEditImageTitle->setText(image.Title());
@@ -1547,6 +1693,32 @@ void TKMMainWindow::UpdateShortcuts()
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void TKMMainWindow::RefreshMeasurementImagePreview(int index)
+{
+    if (index == -1)
+    {
+        return;
+    }
+
+    if (index == ui->tabWidget->indexOf(ui->tabMeasurements))
+    {
+        ShowMData();
+        lastSelectedTab = ui->tabWidget->indexOf(ui->tabMeasurements);
+        ui->actionAddKnown->setEnabled(true);
+    }
+    else if (index == ui->tabWidget->indexOf(ui->tabImages))
+    {
+        ShowImageData();
+        lastSelectedTab = ui->tabWidget->indexOf(ui->tabImages);
+        ui->actionAddKnown->setEnabled(false);
+    }
+    else if (index == ui->tabWidget->indexOf(ui->tabInformation))
+    {
+        ui->actionAddKnown->setEnabled(false);
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void TKMMainWindow::SetupMenu()
 {
@@ -1621,6 +1793,10 @@ void TKMMainWindow::SetupMenu()
     AboutToShowWindowMenu();
 
     // Help
+    connect(ui->actionSettingsDirectory,
+            &QAction::triggered,
+            this,
+            []() { ShowInGraphicalShell(MApplication::VApp()->TapeSettings()->fileName()); });
     connect(ui->actionAboutQt, &QAction::triggered, this, [this]() { QMessageBox::aboutQt(this, tr("About Qt")); });
     connect(ui->actionAboutTape, &QAction::triggered, this,
             [this]()
@@ -1641,7 +1817,6 @@ void TKMMainWindow::InitWindow()
     ui->labelToolTip->setVisible(false);
     ui->tabWidget->setVisible(true);
     ui->tabWidget->setCurrentIndex(0); // measurements
-    ui->tableWidget->resizeColumnsToContents();
     ui->tableWidget->resizeRowsToContents();
     ui->tableWidget->horizontalHeader()->setStretchLastSection(true);
 
@@ -1666,7 +1841,7 @@ void TKMMainWindow::InitWindow()
     connect(ui->toolButtonBottom, &QToolButton::clicked, this, &TKMMainWindow::MoveBottom);
 
     connect(ui->pushButtonGrow, &QPushButton::clicked, this, &TKMMainWindow::DeployFormula);
-    connect(ui->lineEditName, &QLineEdit::editingFinished, this, &TKMMainWindow::SaveMName);
+    connect(ui->lineEditName, &QLineEdit::textEdited, this, &TKMMainWindow::SaveMName);
     connect(ui->plainTextEditDescription, &QPlainTextEdit::textChanged, this, &TKMMainWindow::SaveMDescription);
     connect(ui->lineEditFullName, &QLineEdit::editingFinished, this, &TKMMainWindow::SaveMFullName);
     connect(ui->lineEditGroup, &QLineEdit::editingFinished, this, &TKMMainWindow::SaveMGroup);
@@ -1985,7 +2160,7 @@ auto TKMMainWindow::AddCell(const QString &text, int row, int column, int aligme
 //---------------------------------------------------------------------------------------------------------------------
 void TKMMainWindow::ReadSettings()
 {
-    const VTapeSettings *settings = MApplication::VApp()->TapeSettings();
+    VTapeSettings *settings = MApplication::VApp()->TapeSettings();
 
     if (settings->status() == QSettings::NoError)
     {
@@ -1995,6 +2170,8 @@ void TKMMainWindow::ReadSettings()
         // Text under tool buton icon
         ToolBarStyles();
 
+        settings->RestoreKMMainWindowColumnWidths(ui->tableWidget);
+
         // Stack limit
         // VAbstractApplication::VApp()->getUndoStack()->setUndoLimit(settings->GetUndoCount());
 
@@ -2021,6 +2198,8 @@ void TKMMainWindow::WriteSettings()
     settings->SetKMSearchOptionRegexp(m_search->IsMatchRegexp());
     settings->SetKMSearchOptionUseUnicodeProperties(m_search->IsUseUnicodePreperties());
 
+    settings->SaveKMMainWindowColumnWidths(ui->tableWidget);
+
     settings->sync();
     if (settings->status() == QSettings::AccessError)
     {
@@ -2298,14 +2477,15 @@ void TKMMainWindow::RefreshImages()
 //---------------------------------------------------------------------------------------------------------------------
 void TKMMainWindow::ShowMDiagram(const VPatternImage &image)
 {
-    ui->labelDiagram->setPixmap(QPixmap());
+    ui->labelDiagram->setResizedPixmap(QPixmap());
     ui->labelDiagram->setCursor(QCursor());
-    ui->labelDiagram->disconnect();
+
+    disconnect(ui->labelDiagram, &VAspectRatioPixmapLabel::clicked, this, &TKMMainWindow::ShowImage);
 
     if (image.IsValid())
     {
         ui->labelDiagram->setCursor(Qt::PointingHandCursor);
-        ui->labelDiagram->setPixmap(image.GetPixmap());
+        ui->labelDiagram->setResizedPixmap(image.GetPixmap());
         connect(ui->labelDiagram, &VAspectRatioPixmapLabel::clicked, this, &TKMMainWindow::ShowImage,
                 Qt::UniqueConnection);
     }
