@@ -45,6 +45,7 @@
 #include "vvalentinashortcutmanager.h"
 
 #include "QtConcurrent/qtconcurrentrun.h"
+#include <vcsRepoState.h>
 #include <QDateTime>
 #include <QDir>
 #include <QEvent>
@@ -69,11 +70,6 @@
 #include <QtXmlPatterns>
 #endif
 
-#if !defined(BUILD_REVISION) && defined(QBS_BUILD)
-#include <vcsRepoState.h>
-#define BUILD_REVISION VCS_REPO_STATE_REVISION
-#endif
-
 #if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
 #include "../vmisc/compatibility.h"
 #endif
@@ -113,7 +109,7 @@ auto AppFilePath(const QString &appName) -> QString
     }
 #endif // defined(APPIMAGE) && defined(Q_OS_LINUX)
 
-#if defined(Q_OS_MACOS) && defined(QBS_BUILD) && defined(MULTI_BUNDLE)
+#if defined(Q_OS_MACOS) && defined(MULTI_BUNDLE)
     QFileInfo multiBundleFile(
         QStringLiteral("%1/../../../%2.app/Contents/MacOS/%2").arg(QCoreApplication::applicationDirPath(), appName));
     if (multiBundleFile.exists())
@@ -122,15 +118,6 @@ auto AppFilePath(const QString &appName) -> QString
     }
 #endif
 
-#if !defined(QBS_BUILD)
-    QFileInfo debugFile(QStringLiteral("%1/../../%2/bin/%3")
-                            .arg(QCoreApplication::applicationDirPath(), appName, appName + executableSuffix));
-    if (debugFile.exists())
-    {
-        return debugFile.absoluteFilePath();
-    }
-#endif
-
 #if !defined(Q_OS_MACOS)
     return appName + executableSuffix;
 #else
@@ -139,6 +126,71 @@ auto AppFilePath(const QString &appName) -> QString
 }
 } // namespace
 
+//---------------------------------------------------------------------------------------------------------------------
+inline void LogMessageDetails(QtMsgType type, const QMessageLogContext &context, const QString &msg)
+{
+    QString debugdate = "["_L1 + QDateTime::currentDateTime().toString(QStringLiteral("yyyy.MM.dd hh:mm:ss"));
+    QString const file = VAbstractApplication::ReduceLogContextFilePath(context.file);
+    const bool isPatternMessage = VAbstractApplication::VApp()->IsWarningMessage(msg);
+
+    switch (type)
+    {
+        case QtDebugMsg:
+            debugdate += QStringLiteral(":DEBUG:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdOut() << QApplication::translate("vNoisyHandler", "DEBUG:") << msg << "\n";
+            break;
+        case QtWarningMsg:
+            if (isPatternMessage)
+            {
+                VAbstractValApplication::VApp()->PostWarningMessage(msg, type);
+            }
+            debugdate += QStringLiteral(":WARNING:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdErr() << QApplication::translate("vNoisyHandler", "WARNING:") << msg << "\n";
+            break;
+        case QtCriticalMsg:
+            if (isPatternMessage)
+            {
+                VAbstractValApplication::VApp()->PostWarningMessage(msg, type);
+            }
+            debugdate += QStringLiteral(":CRITICAL:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdErr() << QApplication::translate("vNoisyHandler", "CRITICAL:") << msg << "\n";
+            break;
+        case QtFatalMsg:
+            debugdate += QStringLiteral(":FATAL:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdErr() << QApplication::translate("vNoisyHandler", "FATAL:") << msg << "\n";
+            break;
+        case QtInfoMsg:
+            if (isPatternMessage)
+            {
+                VAbstractValApplication::VApp()->PostWarningMessage(msg, type);
+            }
+            debugdate += QStringLiteral(":INFO:%1(%2)] %3: %4: %5")
+                             .arg(file)
+                             .arg(context.line)
+                             .arg(context.function, context.category, msg);
+            vStdOut() << QApplication::translate("vNoisyHandler", "INFO:") << msg << "\n";
+            break;
+        default:
+            break;
+    }
+    vStdOut().flush();
+    vStdErr().flush();
+
+    (*VApplication::VApp()->LogFile()) << debugdate << Qt::endl;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg)
 {
@@ -223,67 +275,7 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
         logMsg = logMsg.remove(VAbstractValApplication::warningMessageSignature);
     }
 
-    {
-        QString debugdate = "["_L1 + QDateTime::currentDateTime().toString(QStringLiteral("yyyy.MM.dd hh:mm:ss"));
-        QString const file = VAbstractApplication::ReduceLogContextFilePath(context.file);
-
-        switch (type)
-        {
-            case QtDebugMsg:
-                debugdate += QStringLiteral(":DEBUG:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, logMsg);
-                vStdOut() << QApplication::translate("vNoisyHandler", "DEBUG:") << logMsg << "\n";
-                break;
-            case QtWarningMsg:
-                if (isPatternMessage)
-                {
-                    VAbstractValApplication::VApp()->PostWarningMessage(logMsg, type);
-                }
-                debugdate += QStringLiteral(":WARNING:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, logMsg);
-                vStdErr() << QApplication::translate("vNoisyHandler", "WARNING:") << logMsg << "\n";
-                break;
-            case QtCriticalMsg:
-                if (isPatternMessage)
-                {
-                    VAbstractValApplication::VApp()->PostWarningMessage(logMsg, type);
-                }
-                debugdate += QStringLiteral(":CRITICAL:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, logMsg);
-                vStdErr() << QApplication::translate("vNoisyHandler", "CRITICAL:") << logMsg << "\n";
-                break;
-            case QtFatalMsg:
-                debugdate += QStringLiteral(":FATAL:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, logMsg);
-                vStdErr() << QApplication::translate("vNoisyHandler", "FATAL:") << logMsg << "\n";
-                break;
-            case QtInfoMsg:
-                if (isPatternMessage)
-                {
-                    VAbstractValApplication::VApp()->PostWarningMessage(logMsg, type);
-                }
-                debugdate += QStringLiteral(":INFO:%1(%2)] %3: %4: %5")
-                                 .arg(file)
-                                 .arg(context.line)
-                                 .arg(context.function, context.category, logMsg);
-                vStdOut() << QApplication::translate("vNoisyHandler", "INFO:") << logMsg << "\n";
-                break;
-            default:
-                break;
-        }
-        vStdOut().flush();
-        vStdErr().flush();
-
-        (*VApplication::VApp()->LogFile()) << debugdate << Qt::endl;
-    }
+    LogMessageDetails(type, context, msg);
 
     if (isGuiThread)
     {
@@ -573,7 +565,7 @@ void VApplication::InitOptions()
     StartLogging();
 
     qDebug() << "Version:" << AppVersionStr();
-    qDebug() << "Build revision:" << BUILD_REVISION;
+    qDebug() << "Build revision:" << VCS_REPO_STATE_REVISION;
     qDebug() << buildCompatibilityString();
     qDebug() << "Built on" << __DATE__ << "at" << __TIME__;
     qDebug() << "Command-line arguments:" << arguments();
@@ -590,9 +582,9 @@ void VApplication::InitOptions()
                        []()
                        {
                            QString const country = VGAnalytics::CountryCode();
-                           if (country == "ru"_L1 || country == "by"_L1)
+                           if (country == "ru"_L1 || country == "by"_L1 || country == "ir"_L1)
                            {
-                               qFatal("country not detected");
+                               QCoreApplication::exit();
                            }
                        });
 
