@@ -28,23 +28,24 @@
 
 #include "vformulapropertyeditor.h"
 
-#include <QHBoxLayout>
-#include <QFileDialog>
-#include <QKeyEvent>
 #include <QApplication>
 #include <QColorDialog>
 #include <QDebug>
+#include <QFileDialog>
+#include <QHBoxLayout>
+#include <QKeyEvent>
 #include <QRegularExpression>
 #include <QSpacerItem>
 
+#include "../vmisc/theme/vtheme.h"
+#include "../vmisc/vabstractvalapplication.h"
 #include "../vpropertyexplorer/vproperty.h"
 #include "../vtools/dialogs/support/dialogeditwrongformula.h"
-#include "../vmisc/vabstractvalapplication.h"
 
 // VFormulaPropertyEditor
 //---------------------------------------------------------------------------------------------------------------------
 VFormulaPropertyEditor::VFormulaPropertyEditor(QWidget *parent)
-    : QWidget(parent)
+  : QWidget(parent)
 {
     setAutoFillBackground(true);
 
@@ -52,11 +53,11 @@ VFormulaPropertyEditor::VFormulaPropertyEditor(QWidget *parent)
     m_ToolButton = new QToolButton(this);
     m_ToolButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     m_ToolButton->setText(QStringLiteral("..."));
-    m_ToolButton->setIcon(QIcon("://icon/16x16/fx.png"));
+    m_ToolButton->setIcon(VTheme::GetIconResource(QStringLiteral("icon"), QStringLiteral("16x16/fx.png")));
     m_ToolButton->setIconSize(QSize(16, 16));
     m_ToolButton->setFixedSize(24, 24);
     m_ToolButton->installEventFilter(this);
-    setFocusProxy(m_ToolButton);  // Make the ToolButton the focus proxy
+    setFocusProxy(m_ToolButton); // Make the ToolButton the focus proxy
     setFocusPolicy(m_ToolButton->focusPolicy());
     connect(m_ToolButton, &QToolButton::clicked, this, &VFormulaPropertyEditor::onToolButtonClicked);
 
@@ -66,9 +67,9 @@ VFormulaPropertyEditor::VFormulaPropertyEditor(QWidget *parent)
     m_TextLabel->setText(m_formula.getStringValue());
 
     // The layout (a horizontal layout)
-    auto* layout = new QHBoxLayout(this);
+    auto *layout = new QHBoxLayout(this);
     layout->setSpacing(3);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(m_TextLabel);
     // Spacer (this is needed for proper display of the label and button)
     layout->addSpacerItem(new QSpacerItem(1000000000, 0, QSizePolicy::Expanding, QSizePolicy::Preferred));
@@ -76,7 +77,7 @@ VFormulaPropertyEditor::VFormulaPropertyEditor(QWidget *parent)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VFormulaPropertyEditor::SetFormula(const VFormula& formula)
+void VFormulaPropertyEditor::SetFormula(const VFormula &formula)
 {
     if (this->m_formula != formula)
     {
@@ -88,9 +89,8 @@ void VFormulaPropertyEditor::SetFormula(const VFormula& formula)
 //---------------------------------------------------------------------------------------------------------------------
 void VFormulaPropertyEditor::onToolButtonClicked()
 {
-    QScopedPointer<DialogEditWrongFormula> tmpWidget(
-                new DialogEditWrongFormula(m_formula.getData(), m_formula.getToolId(),
-                                           VAbstractValApplication::VApp()->getMainWindow()));
+    QScopedPointer<DialogEditWrongFormula> const tmpWidget(new DialogEditWrongFormula(
+        m_formula.getData(), m_formula.getToolId(), VAbstractValApplication::VApp()->getMainWindow()));
     tmpWidget->setCheckZero(m_formula.getCheckZero());
     tmpWidget->setPostfix(m_formula.getPostfix());
     tmpWidget->SetFormula(m_formula.GetFormula(FormulaType::FromUser));
