@@ -184,7 +184,12 @@ PreferencesConfigurationPage::PreferencesConfigurationPage(QWidget *parent)
     ui->lineEditCrashUserEmail->setText(QString());
 #else
     ui->checkBoxSendCrashReports->setChecked(settings->IsSendCrashReport());
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+    connect(ui->checkBoxSendCrashReports, &QCheckBox::checkStateChanged, this,
+#else
     connect(ui->checkBoxSendCrashReports, &QCheckBox::stateChanged, this,
+#endif
             [this]() { m_sendCrashReportsChanged = true; });
 
     QRegularExpression const rx(QStringLiteral("\\b[A-Z0-9._%+-]+@[A-Z0-9.-]+\\.[A-Z]{2,4}\\b"),
