@@ -29,12 +29,12 @@
 #ifndef PREFERENCESPATTERNPAGE_H
 #define PREFERENCESPATTERNPAGE_H
 
-#include <QWidget>
 #include "../vmisc/def.h"
+#include <QWidget>
 
 namespace Ui
 {
-    class PreferencesPatternPage;
+class PreferencesPatternPage;
 }
 
 class QComboBox;
@@ -51,7 +51,7 @@ public:
     void InitDefaultSeamAllowance();
 
 protected:
-    void changeEvent(QEvent* event) override;
+    void changeEvent(QEvent *event) override;
 
 private slots:
     void EditDateTimeFormats();
@@ -65,6 +65,8 @@ private:
     Unit m_oldLineUnit{Unit::Mm};
 
     void InitLabelDateTimeFormats();
+    void InitLabelFontSizes();
+    void InitSingleLineFonts();
     static void InitComboBoxFormats(QComboBox *box, const QStringList &items, const QString &currentFormat);
     void InitUnits();
     void RetranslateUi();
