@@ -170,8 +170,9 @@ auto DialogFinalMeasurements::eventFilter(QObject *object, QEvent *event) -> boo
     {
         if (event->type() == QEvent::KeyPress)
         {
-            auto *keyEvent = static_cast<QKeyEvent *>(event); // NOLINT(cppcoreguidelines-pro-type-static-cast-downcast)
-            if ((keyEvent->key() == Qt::Key_Period) && (keyEvent->modifiers() & Qt::KeypadModifier))
+            // NOLINTNEXTLINE(cppcoreguidelines-pro-type-static-cast-downcast)
+            if (const auto *keyEvent = static_cast<QKeyEvent *>(event);
+                (keyEvent->key() == Qt::Key_Period) && (keyEvent->modifiers() & Qt::KeypadModifier))
             {
                 if (VAbstractApplication::VApp()->Settings()->GetOsSeparator())
                 {
@@ -390,7 +391,7 @@ void DialogFinalMeasurements::SaveFormula()
     // Replace line return character with spaces for calc if exist
     QString const text = ui->plainTextEditFormula->toPlainText();
 
-    if (QTableWidgetItem *formulaField = ui->tableWidget->item(row, 2); formulaField->text() == text)
+    if (const QTableWidgetItem *formulaField = ui->tableWidget->item(row, 2); formulaField->text() == text)
     {
         QTableWidgetItem *result = ui->tableWidget->item(row, 1);
         // Show unit in dialog lable (cm, mm or inch)
