@@ -33,11 +33,9 @@
 #include <QElapsedTimer>
 #include <QTimer>
 
-#include "../vmisc/defglobal.h"
-
 namespace Ui
 {
-    class DialogLayoutProgress;
+class DialogLayoutProgress;
 }
 
 class DialogLayoutProgress : public QDialog
@@ -64,7 +62,7 @@ private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(DialogLayoutProgress) // NOLINT
     Ui::DialogLayoutProgress *ui;
-    QMovie *m_movie;
+    QMovie *m_movie{nullptr};
     QElapsedTimer m_timer;
     qint64 m_timeout;
     bool m_isInitialized{false};
