@@ -116,7 +116,11 @@ DialogLayoutSettings::DialogLayoutSettings(VLayoutGenerator *generator, QWidget
     connect(ui->doubleSpinBoxPaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
             &DialogLayoutSettings::CorrectMaxFileds);
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+    connect(ui->checkBoxIgnoreFileds, &QCheckBox::checkStateChanged, this, &DialogLayoutSettings::IgnoreAllFields);
+#else
     connect(ui->checkBoxIgnoreFileds, &QCheckBox::stateChanged, this, &DialogLayoutSettings::IgnoreAllFields);
+#endif
 
     connect(ui->toolButtonPortrait, &QToolButton::toggled, this, &DialogLayoutSettings::Swap);
     connect(ui->toolButtonLandscape, &QToolButton::toggled, this, &DialogLayoutSettings::Swap);
