@@ -101,9 +101,7 @@ DialogPatternProperties::DialogPatternProperties(VPattern *doc, VContainer *patt
         ui->comboBoxLabelLanguage->addItem(QLocale(name).nativeLanguageName(), name);
     }
 
-    if (int const index = ui->comboBoxLabelLanguage->findData(
-            VAbstractValApplication::VApp()->ValentinaSettings()->GetLabelLanguage());
-        index != -1)
+    if (int const index = ui->comboBoxLabelLanguage->findData(m_doc->GetLabelPrefix()); index != -1)
     {
         ui->comboBoxLabelLanguage->setCurrentIndex(index);
     }
@@ -216,8 +214,9 @@ auto DialogPatternProperties::eventFilter(QObject *object, QEvent *event) -> boo
     {
         if (event->type() == QEvent::KeyPress)
         {
-            auto *keyEvent = static_cast<QKeyEvent *>(event); // NOLINT(cppcoreguidelines-pro-type-static-cast-downcast)
-            if ((keyEvent->key() == Qt::Key_Space) && ((keyEvent->modifiers() & Qt::ControlModifier) != 0U))
+            // NOLINTNEXTLINE(cppcoreguidelines-pro-type-static-cast-downcast)
+            if (const auto *keyEvent = static_cast<QKeyEvent *>(event);
+                (keyEvent->key() == Qt::Key_Space) && ((keyEvent->modifiers() & Qt::ControlModifier) != 0U))
             {
                 m_completerLength->complete();
                 return true;
@@ -231,8 +230,9 @@ auto DialogPatternProperties::eventFilter(QObject *object, QEvent *event) -> boo
     {
         if (event->type() == QEvent::KeyPress)
         {
-            auto *keyEvent = static_cast<QKeyEvent *>(event); // NOLINT(cppcoreguidelines-pro-type-static-cast-downcast)
-            if ((keyEvent->key() == Qt::Key_Space) && ((keyEvent->modifiers() & Qt::ControlModifier) != 0U))
+            // NOLINTNEXTLINE(cppcoreguidelines-pro-type-static-cast-downcast)
+            if (const auto *keyEvent = static_cast<QKeyEvent *>(event);
+                (keyEvent->key() == Qt::Key_Space) && ((keyEvent->modifiers() & Qt::ControlModifier) != 0U))
             {
                 m_completerWidth->complete();
                 return true;
@@ -514,7 +514,7 @@ void DialogPatternProperties::ShowImage()
         name += '.'_L1 + suffixes.at(0);
     }
 
-    delete m_tmpImage;
+    delete m_tmpImage.data();
     m_tmpImage = new QTemporaryFile(name, this);
     if (m_tmpImage->open())
     {
