@@ -61,9 +61,6 @@ Q_GLOBAL_STATIC_WITH_ARGS(const QString, baseFilenameRegExp, ("^[^\\:?\"*|\\/<>]
 QT_WARNING_POP
 } // namespace
 
-bool DialogSaveLayout::havePdf = false; // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
-bool DialogSaveLayout::tested = false;  // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
-
 //---------------------------------------------------------------------------------------------------------------------
 DialogSaveLayout::DialogSaveLayout(int count, Draw mode, const QString &fileName, QWidget *parent)
   : VAbstractLayoutDialog(parent),
@@ -88,16 +85,15 @@ DialogSaveLayout::DialogSaveLayout(int count, Draw mode, const QString &fileName
 
     ui->lineEditFileName->setValidator(new QRegularExpressionValidator(QRegularExpression(*baseFilenameRegExp), this));
 
-    const QString mask = fileName + '_'_L1;
     if (VApplication::IsGUIMode())
     {
-        ui->lineEditFileName->setText(mask);
+        ui->lineEditFileName->setText(fileName);
     }
     else
     {
-        if (QRegularExpression(*baseFilenameRegExp).match(mask).hasMatch())
+        if (QRegularExpression(*baseFilenameRegExp).match(fileName).hasMatch())
         {
-            ui->lineEditFileName->setText(mask);
+            ui->lineEditFileName->setText(fileName);
         }
         else
         {
@@ -105,36 +101,39 @@ DialogSaveLayout::DialogSaveLayout(int count, Draw mode, const QString &fileName
         }
     }
 
-    for (auto &[first, second] : InitFormats())
-    {
-        ui->comboBoxFormat->addItem(first, QVariant(static_cast<int>(second)));
-    }
-#ifdef V_NO_ASSERT // Temporarily unavailable
-    RemoveFormatFromList(LayoutExportFormats::OBJ);
-#endif
+    InitFileFormats();
+    connect(ui->comboBoxFormatType,
+            QOverload<int>::of(&QComboBox::currentIndexChanged),
+            this,
+            &DialogSaveLayout::ShowExample);
+    connect(ui->comboBoxFormat,
+            QOverload<int>::of(&QComboBox::currentIndexChanged),
+            this,
+            [this](int index)
+            {
+                if (index == -1)
+                {
+                    ui->comboBoxFormatType->clear();
+                    return;
+                }
 
-    //    RemoveFormatFromList(LayoutExportFormats::NC); // No support for now
+                ui->comboBoxFormatType->blockSignals(true);
+                InitFileFormatTypes(static_cast<LayoutExportFileFormat>(ui->comboBoxFormat->currentData().toInt()));
+                ui->comboBoxFormatType->setCurrentIndex(-1);
+                ui->comboBoxFormatType->blockSignals(false);
 
-    if (m_mode != Draw::Layout)
-    {
-        RemoveFormatFromList(LayoutExportFormats::PDFTiled);
-    }
-    else
-    {
-        RemoveFormatFromList(LayoutExportFormats::RLD);
-    }
+                ui->comboBoxFormatType->setCurrentIndex(0);
+            });
 
     InitDxfCompatibility();
 
     connect(bOk, &QPushButton::clicked, this, &DialogSaveLayout::Save);
     connect(ui->lineEditFileName, &QLineEdit::textChanged, this, &DialogSaveLayout::ShowExample);
-    connect(ui->comboBoxFormat, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
-            &DialogSaveLayout::ShowExample);
     connect(ui->pushButtonBrowse, &QPushButton::clicked, this,
             [this]()
             {
                 VValentinaSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
-                const QString dirPath = settings->GetPathLayout();
+                const QString dirPath = settings->GetPathLayoutExport();
 
                 const QString dir = QFileDialog::getExistingDirectory(
                     this, tr("Select folder"), dirPath,
@@ -144,12 +143,12 @@ DialogSaveLayout::DialogSaveLayout(int count, Draw mode, const QString &fileName
                 { // If paths equal the signal will not be called, we will do this manually
                     dir == ui->lineEditPath->text() ? PathChanged(dir) : ui->lineEditPath->setText(dir);
 
-                    settings->SetPathLayout(dir);
+                    settings->SetPathLayoutExport(dir);
                 }
             });
     connect(ui->lineEditPath, &QLineEdit::textChanged, this, &DialogSaveLayout::PathChanged);
 
-    ui->lineEditPath->setText(VAbstractValApplication::VApp()->ValentinaSettings()->GetPathLayout());
+    ui->lineEditPath->setText(VAbstractValApplication::VApp()->ValentinaSettings()->GetPathLayoutExport());
 
     InitTileTemplates(ui->comboBoxTemplates);
 
@@ -171,15 +170,32 @@ void DialogSaveLayout::SelectFormat(LayoutExportFormats format)
 {
     if (static_cast<int>(format) < 0 || format >= LayoutExportFormats::COUNT)
     {
-        throw VException(tr("Tried to use out of range format number."));
+        throw VException(tr("Tried to use out of range file format type number."));
     }
 
-    const int i = ui->comboBoxFormat->findData(static_cast<int>(format));
+    const LayoutExportFileFormat fileFormat = VLayoutExporter::LayoutExportFileFormat(format);
+
+    int i = ui->comboBoxFormat->findData(static_cast<int>(fileFormat));
     if (i < 0)
     {
-        throw VException(tr("Selected not present format."));
+        throw VException(tr("Selected not present file format."));
     }
+
+    ui->comboBoxFormat->blockSignals(true);
     ui->comboBoxFormat->setCurrentIndex(i);
+    ui->comboBoxFormat->blockSignals(false);
+
+    ui->comboBoxFormatType->blockSignals(true);
+    InitFileFormatTypes(fileFormat);
+    ui->comboBoxFormatType->setCurrentIndex(-1);
+    ui->comboBoxFormatType->blockSignals(false);
+
+    i = ui->comboBoxFormatType->findData(static_cast<int>(format));
+    if (i < 0)
+    {
+        throw VException(tr("Selected not present file format type."));
+    }
+    ui->comboBoxFormatType->setCurrentIndex(i);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -290,6 +306,8 @@ void DialogSaveLayout::SetShowGrainline(bool show)
         case LayoutExportFormats::TIF:
         case LayoutExportFormats::HPGL:
         case LayoutExportFormats::HPGL2:
+        case LayoutExportFormats::HPGL_PLT:
+        case LayoutExportFormats::HPGL2_PLT:
             ui->checkBoxShowGrainline->setChecked(show);
             break;
         default:
@@ -321,6 +339,8 @@ auto DialogSaveLayout::IsShowGrainline() const -> bool
         case LayoutExportFormats::TIF:
         case LayoutExportFormats::HPGL:
         case LayoutExportFormats::HPGL2:
+        case LayoutExportFormats::HPGL_PLT:
+        case LayoutExportFormats::HPGL2_PLT:
             return ui->checkBoxShowGrainline->isChecked();
         default:
             return true;
@@ -331,10 +351,11 @@ auto DialogSaveLayout::IsShowGrainline() const -> bool
 auto DialogSaveLayout::MakeHelpFormatList() -> QString
 {
     auto out = QStringLiteral("\n");
-    const auto formats = InitFormats();
+    const auto formats = VLayoutExporter::AllLayoutExportFormats();
     for (int i = 0; i < formats.size(); ++i)
     {
-        out += "\t* "_L1 + formats.at(i).first + " = "_L1 + QString::number(static_cast<int>(formats.at(i).second));
+        out += "\t* "_L1 + VLayoutExporter::ExportFormatDescription(formats.at(i)) + " = "_L1
+               + QString::number(static_cast<int>(formats.at(i)));
 
         if (i < formats.size() - 1)
         {
@@ -358,6 +379,7 @@ auto DialogSaveLayout::MakeHelpDxfApparelCompatibilityList() -> QString
     out += QStringLiteral("\t* Richpeace CAD V8 = %1,\n").arg(static_cast<int>(DXFApparelCompatibility::RPCADV08));
     out += QStringLiteral("\t* Richpeace CAD V9 = %1,\n").arg(static_cast<int>(DXFApparelCompatibility::RPCADV09));
     out += QStringLiteral("\t* Richpeace CAD V10 = %1.\n").arg(static_cast<int>(DXFApparelCompatibility::RPCADV10));
+    out += QStringLiteral("\t* Clo3D = %1.\n").arg(static_cast<int>(DXFApparelCompatibility::CLO3D));
 
     return out;
 }
@@ -409,13 +431,14 @@ auto DialogSaveLayout::Path() const -> QString
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogSaveLayout::FileName() const -> QString
 {
-    return ui->lineEditFileName->text();
+    const QString fileName = ui->lineEditFileName->text();
+    return m_count > 1 && Format() != LayoutExportFormats::PDFTiled ? fileName + '_'_L1 : fileName;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogSaveLayout::Format() const -> LayoutExportFormats
 {
-    return static_cast<LayoutExportFormats>(ui->comboBoxFormat->currentData().toInt());
+    return static_cast<LayoutExportFormats>(ui->comboBoxFormatType->currentData().toInt());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -425,8 +448,17 @@ void DialogSaveLayout::Save()
 
     for (int i = 0; i < m_count; ++i)
     {
-        const QString name =
-            Path() + '/' + FileName() + QString::number(i + 1) + VLayoutExporter::ExportFormatSuffix(Format());
+        QString name;
+
+        if (m_count > 1)
+        {
+            name = Path() + '/' + FileName() + QString::number(i + 1) + VLayoutExporter::ExportFormatSuffix(Format());
+        }
+        else
+        {
+            name = Path() + '/' + FileName() + VLayoutExporter::ExportFormatSuffix(Format());
+        }
+
         if (QFile::exists(name))
         {
             if (QMessageBox::StandardButton const res = QMessageBox::question(
@@ -445,7 +477,7 @@ void DialogSaveLayout::Save()
 
     if (QFile::exists(Path()))
     {
-        VAbstractValApplication::VApp()->ValentinaSettings()->SetPathLayout(Path());
+        VAbstractValApplication::VApp()->ValentinaSettings()->SetPathLayoutExport(Path());
     }
 
     accept();
@@ -478,9 +510,33 @@ void DialogSaveLayout::PathChanged(const QString &text)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveLayout::ShowExample()
 {
+    const bool hasValues = ui->comboBoxFormatType->currentIndex() != -1;
+    ui->groupBoxFormatOptions->setEnabled(hasValues);
+    ui->groupBoxScale->setEnabled(hasValues);
+    ui->groupBoxMargins->setEnabled(hasValues);
+    ui->groupBoxPaperFormat->setEnabled(hasValues);
+
+    QPushButton *bOk = ui->buttonBox->button(QDialogButtonBox::Ok);
+    SCASSERT(bOk != nullptr)
+    bOk->setEnabled(hasValues);
+
+    if (!hasValues)
+    {
+        return;
+    }
+
     const LayoutExportFormats currentFormat = Format();
-    ui->labelExample->setText(tr("Example:") + FileName() + '1'_L1 +
-                              VLayoutExporter::ExportFormatSuffix(currentFormat));
+    QString example;
+
+    if (m_count > 1 && currentFormat != LayoutExportFormats::PDFTiled)
+    {
+        example = tr("Example:") + FileName() + '1'_L1 + VLayoutExporter::ExportFormatSuffix(currentFormat);
+    }
+    else
+    {
+        example = tr("Example:") + FileName() + VLayoutExporter::ExportFormatSuffix(currentFormat);
+    }
+    ui->labelExample->setText(example);
 
     ui->groupBoxPaperFormat->setEnabled(false);
     ui->groupBoxMargins->setEnabled(false);
@@ -519,6 +575,8 @@ void DialogSaveLayout::ShowExample()
             break;
         case LayoutExportFormats::HPGL:
         case LayoutExportFormats::HPGL2:
+        case LayoutExportFormats::HPGL_PLT:
+        case LayoutExportFormats::HPGL2_PLT:
             ui->checkBoxShowGrainline->setVisible(true);
             ui->checkBoxTogetherWithNotches->setVisible(true);
             break;
@@ -734,65 +792,6 @@ void DialogSaveLayout::showEvent(QShowEvent *event)
     m_isInitialized = true; // first show windows are held
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-auto DialogSaveLayout::SupportPSTest() -> bool
-{
-    if (!tested)
-    {
-        havePdf = VLayoutExporter::SupportPDFConversion();
-        tested = true;
-    }
-    return havePdf;
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-auto DialogSaveLayout::InitFormats() -> QVector<std::pair<QString, LayoutExportFormats>>
-{
-    QVector<std::pair<QString, LayoutExportFormats>> list;
-
-    auto InitFormat = [&list](LayoutExportFormats format)
-    { list.append(std::make_pair(VLayoutExporter::ExportFormatDescription(format), format)); };
-
-    InitFormat(LayoutExportFormats::SVG);
-    InitFormat(LayoutExportFormats::PDF);
-    InitFormat(LayoutExportFormats::PNG);
-    InitFormat(LayoutExportFormats::OBJ);
-    if (SupportPSTest())
-    {
-        InitFormat(LayoutExportFormats::PS);
-        InitFormat(LayoutExportFormats::EPS);
-    }
-    InitFormat(LayoutExportFormats::DXF_AC1006_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1009_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1012_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1014_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1015_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1018_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1021_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1024_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1027_Flat);
-    InitFormat(LayoutExportFormats::DXF_AAMA);
-    InitFormat(LayoutExportFormats::DXF_ASTM);
-    InitFormat(LayoutExportFormats::PDFTiled);
-    //    InitFormat(LayoutExportFormats::NC);
-    InitFormat(LayoutExportFormats::RLD);
-    InitFormat(LayoutExportFormats::TIF);
-    InitFormat(LayoutExportFormats::HPGL);
-    InitFormat(LayoutExportFormats::HPGL2);
-
-    return list;
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-void DialogSaveLayout::RemoveFormatFromList(LayoutExportFormats format)
-{
-    const int index = ui->comboBoxFormat->findData(static_cast<int>(format));
-    if (index != -1)
-    {
-        ui->comboBoxFormat->removeItem(index);
-    }
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief ReadSettings reads the values of the variables needed for the save layout dialog, for instance
@@ -931,4 +930,65 @@ void DialogSaveLayout::InitDxfCompatibility()
                                           QVariant(static_cast<int>(DXFApparelCompatibility::RPCADV09)));
     ui->comboBoxDxfCompatibility->addItem("Richpeace CAD V10"_L1,
                                           QVariant(static_cast<int>(DXFApparelCompatibility::RPCADV10)));
+    ui->comboBoxDxfCompatibility->addItem("Clo3D"_L1, QVariant(static_cast<int>(DXFApparelCompatibility::CLO3D)));
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSaveLayout::InitFileFormats()
+{
+    auto AddItem = [this](const QString &label, LayoutExportFileFormat format)
+    { ui->comboBoxFormat->addItem(label, QVariant(static_cast<int>(format))); };
+
+    Q_STATIC_ASSERT_X(static_cast<int>(LayoutExportFileFormat::COUNT) == 10, "Update to cover all cases.");
+
+    AddItem("PDF"_L1, LayoutExportFileFormat::PDF);
+    AddItem("SVG"_L1, LayoutExportFileFormat::SVG);
+    AddItem("PNG"_L1, LayoutExportFileFormat::PNG);
+    // AddItem("OBJ"_L1, LayoutExportFileFormat::OBJ); // Temporarily unavailable
+    AddItem("DXF"_L1, LayoutExportFileFormat::DXF);
+    // AddItem("NC"_L1, LayoutExportFileFormat::NC);// No support for now
+    if (m_mode != Draw::Layout)
+    {
+        AddItem("RLD"_L1, LayoutExportFileFormat::RLD);
+    }
+    AddItem("PLT"_L1, LayoutExportFileFormat::PLT);
+    AddItem("HPGL"_L1, LayoutExportFileFormat::HPGL);
+    AddItem("TIF"_L1, LayoutExportFileFormat::TIF);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSaveLayout::InitFileFormatTypes(LayoutExportFileFormat format)
+{
+    ui->comboBoxFormatType->clear();
+    const QVector<LayoutExportFormats> types = VLayoutExporter::MapLayoutExportFormats(format);
+
+    for (const auto &type : types)
+    {
+        ui->comboBoxFormatType->addItem(VLayoutExporter::ExportFormatDescription(type),
+                                        QVariant(static_cast<int>(type)));
+    }
+
+    auto RemoveFormatFromList = [this](LayoutExportFormats exportFormat)
+    {
+        const int index = ui->comboBoxFormatType->findData(static_cast<int>(exportFormat));
+        if (index != -1)
+        {
+            ui->comboBoxFormatType->removeItem(index);
+        }
+    };
+
+    //    RemoveFormatFromList(LayoutExportFormats::NC); // No support for now
+
+#ifdef V_NO_ASSERT // Temporarily unavailable
+    RemoveFormatFromList(LayoutExportFormats::OBJ);
+#endif
+
+    if (m_mode != Draw::Layout)
+    {
+        RemoveFormatFromList(LayoutExportFormats::PDFTiled);
+    }
+    else
+    {
+        RemoveFormatFromList(LayoutExportFormats::RLD);
+    }
 }
