@@ -356,7 +356,7 @@ void VWidgetBackgroundImages::ContextMenu(const QPoint &pos)
     QAction *actionReset = menu.addAction(tr("Reset transformation"));
     actionReset->setEnabled(not image.Hold());
 
-    QAction *actionDelete = menu.addAction(FromTheme(VThemeIcon::EditDelete), tr("Delete"));
+    const QAction *actionDelete = menu.addAction(FromTheme(VThemeIcon::EditDelete), tr("Delete"));
 
     menu.addSeparator();
     QAction *actionHoldAll = menu.addAction(tr("Hold All"));
