@@ -48,29 +48,32 @@
 // Fix bug in Qt. Deprecation warning in QMessageBox::critical.
 #if QT_VERSION >= QT_VERSION_CHECK(6, 2, 0) && QT_VERSION < QT_VERSION_CHECK(6, 6, 0)
 #undef QT_REQUIRE_VERSION
-#define QT_REQUIRE_VERSION(argc, argv, str)                                                                            \
-    {                                                                                                                  \
-        QString s = QString::fromLatin1(str);                                                                          \
-        QString sq = QString::fromLatin1(qVersion());                                                                  \
-        if ((sq.section(QChar::fromLatin1('.'), 0, 0).toInt() << 16) +                                                 \
-                (sq.section(QChar::fromLatin1('.'), 1, 1).toInt() << 8) +                                              \
-                sq.section(QChar::fromLatin1('.'), 2, 2).toInt() <                                                     \
-            (s.section(QChar::fromLatin1('.'), 0, 0).toInt() << 16) +                                                  \
-                (s.section(QChar::fromLatin1('.'), 1, 1).toInt() << 8) +                                               \
-                s.section(QChar::fromLatin1('.'), 2, 2).toInt())                                                       \
-        {                                                                                                              \
-            if (!qApp)                                                                                                 \
-            {                                                                                                          \
-                new QApplication(argc, argv);                                                                          \
-            }                                                                                                          \
-            QString s = QApplication::tr("Executable '%1' requires Qt %2, found Qt %3.")                               \
-                            .arg(qAppName())                                                                           \
-                            .arg(QString::fromLatin1(str))                                                             \
-                            .arg(QString::fromLatin1(qVersion()));                                                     \
-            QMessageBox::critical(0, QApplication::tr("Incompatible Qt Library Error"), s, QMessageBox::Abort,         \
-                                  static_cast<QMessageBox::StandardButton>(0));                                        \
-            qFatal("%s", s.toLatin1().data());                                                                         \
-        }                                                                                                              \
+#define QT_REQUIRE_VERSION(argc, argv, str) \
+    { \
+        QString s = QString::fromLatin1(str); \
+        QString sq = QString::fromLatin1(qVersion()); \
+        if ((sq.section(QChar::fromLatin1('.'), 0, 0).toInt() << 16) \
+                + (sq.section(QChar::fromLatin1('.'), 1, 1).toInt() << 8) \
+                + sq.section(QChar::fromLatin1('.'), 2, 2).toInt() \
+            < (s.section(QChar::fromLatin1('.'), 0, 0).toInt() << 16) \
+                  + (s.section(QChar::fromLatin1('.'), 1, 1).toInt() << 8) \
+                  + s.section(QChar::fromLatin1('.'), 2, 2).toInt()) \
+        { \
+            if (!qApp) \
+            { \
+                new QApplication(argc, argv); \
+            } \
+            QString s = QApplication::tr("Executable '%1' requires Qt %2, found Qt %3.") \
+                            .arg(qAppName()) \
+                            .arg(QString::fromLatin1(str)) \
+                            .arg(QString::fromLatin1(qVersion())); \
+            QMessageBox::critical(nullptr, \
+                                  QApplication::tr("Incompatible Qt Library Error"), \
+                                  s, \
+                                  QMessageBox::Abort, \
+                                  static_cast<QMessageBox::StandardButton>(0)); \
+            qFatal("%s", s.toLatin1().data()); \
+        } \
     }
 #endif
 
@@ -94,7 +97,7 @@ auto main(int argc, char *argv[]) -> int
     Q_INIT_RESOURCE(win_dark_theme);  // NOLINT
 
 #ifdef CRASH_REPORTING
-    InitializeCrashpad(QStringLiteral(VER_PRODUCTNAME_STR).toLower());
+    InitializeCrashpad(QStringLiteral(VER_PRODUCTNAME_STR));
 #endif
 
 #if defined(Q_OS_WIN)
@@ -131,21 +134,23 @@ auto main(int argc, char *argv[]) -> int
 
     VApplication::setDesktopFileName(QStringLiteral("ua.com.smart-pattern.valentina.desktop"));
 
-    if (VApplication::IsGUIMode() && VAbstractApplication::VApp()->Settings()->IsAutomaticallyCheckUpdates())
-    {
-        // Set feed URL before doing anything else
-        FvUpdater::sharedUpdater()->SetFeedURL(FvUpdater::CurrentFeedURL());
-
-        // Check for updates automatically
-        FvUpdater::sharedUpdater()->CheckForUpdatesSilent();
-    }
-
     MainWindow w;
 #if !defined(Q_OS_MAC)
     VApplication::setWindowIcon(QIcon(":/icon/64x64/icon64x64.png"));
 #endif // !defined(Q_OS_MAC)
     app.setMainWindow(&w);
 
+    if (VApplication::IsGUIMode() && VAbstractApplication::VApp()->Settings()->IsAutomaticallyCheckUpdates())
+    {
+        // Set feed URL before doing anything else
+        FvUpdater::sharedUpdater()->SetFeedURL(FvUpdater::CurrentFeedURL());
+
+        FvUpdater::sharedUpdater()->SetMainWindow(&w);
+
+        // Check for updates automatically
+        FvUpdater::sharedUpdater()->CheckForUpdatesSilent();
+    }
+
     int msec = 0;
     // Before we load pattern show window.
     if (VApplication::IsGUIMode())
