@@ -121,6 +121,10 @@ protected:
     void CleanLayout() override;
     void PrepareSceneList(PreviewQuatilty quality) override;
     void ExportToCSVData(const QString &fileName, bool withHeader, int mib, const QChar &separator) override;
+    void dragEnterEvent(QDragEnterEvent *event) override;
+    void dragMoveEvent(QDragMoveEvent *event) override;
+    void dragLeaveEvent(QDragLeaveEvent *event) override;
+    void dropEvent(QDropEvent *event) override;
 #if defined(Q_OS_MAC)
     void ToolBarStyle(QToolBar *bar) const override;
 #endif
@@ -268,8 +272,6 @@ private:
     /** @brief ui keeps information about user interface */
     Ui::MainWindow *ui;
 
-    QFileSystemWatcher *m_watcher;
-
     /** @brief tool current tool */
     Tool m_currentTool{Tool::Arrow};
 
@@ -419,8 +421,8 @@ private:
 
     void InitScenes();
 
-    auto LoadMeasurements(const QString &path) -> bool;
-    auto UpdateMeasurements(const QString &path, qreal baseA, qreal baseB, qreal baseC) -> bool;
+    auto LoadMeasurements(const QString &patternPath, QString &path) -> bool;
+    auto UpdateMeasurements(const QString &patternPath, QString &path, qreal baseA, qreal baseB, qreal baseC) -> bool;
     auto UpdateMeasurements(const QSharedPointer<VMeasurements> &mFile, qreal baseA, qreal baseB, qreal baseC) -> bool;
 
     void ReadMeasurements(qreal baseA, qreal baseB, qreal baseC);
@@ -475,6 +477,8 @@ private:
     auto SavePatternAs(const QString &fileName) -> bool;
 
     auto FullParsePattern() -> bool;
+
+    void RefreshPieceGeometry();
 };
 
 #endif // MAINWINDOW_H
