@@ -133,7 +133,9 @@ void InsertGlobalContours(const QList<QGraphicsScene *> &scenes, const QList<QGr
 //---------------------------------------------------------------------------------------------------------------------
 MainWindowsNoGUI::MainWindowsNoGUI(QWidget *parent)
   : VAbstractMainWindow(parent),
-    pattern(new VContainer(VAbstractApplication::VApp()->TrVars(), VAbstractValApplication::VApp()->patternUnitsP(),
+    m_watcher(new QFileSystemWatcher(this)),
+    pattern(new VContainer(VAbstractApplication::VApp()->TrVars(),
+                           VAbstractValApplication::VApp()->patternUnitsP(),
                            valentinaNamespace))
 #if defined(Q_OS_WIN32) && QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     ,
@@ -154,8 +156,8 @@ MainWindowsNoGUI::MainWindowsNoGUI(QWidget *parent)
 //---------------------------------------------------------------------------------------------------------------------
 MainWindowsNoGUI::~MainWindowsNoGUI()
 {
-    delete m_unreadPatternMessage;
-    delete m_mouseCoordinate;
+    delete m_unreadPatternMessage.data();
+    delete m_mouseCoordinate.data();
     delete tempSceneLayout;
     delete pattern;
 }
@@ -507,15 +509,16 @@ void MainWindowsNoGUI::ExportData(const QVector<VLayoutPiece> &listDetails)
     if (const LayoutExportFormats format = m_dialogSaveLayout->Format();
         format == LayoutExportFormats::DXF_AAMA || format == LayoutExportFormats::DXF_ASTM ||
         format == LayoutExportFormats::RLD || format == LayoutExportFormats::HPGL ||
-        format == LayoutExportFormats::HPGL2)
+        format == LayoutExportFormats::HPGL2 || format == LayoutExportFormats::HPGL_PLT ||
+        format == LayoutExportFormats::HPGL2_PLT)
     {
         if (m_dialogSaveLayout->Mode() == Draw::Layout)
         {
             for (int i = 0; i < detailsOnLayout.size(); ++i)
             {
-                const QString name = m_dialogSaveLayout->Path() + '/'_L1 + m_dialogSaveLayout->FileName() +
-                                     QString::number(i + 1) +
-                                     VLayoutExporter::ExportFormatSuffix(m_dialogSaveLayout->Format());
+                const QString index = detailsOnLayout.size() > 1 ? QString::number(i + 1) : QString();
+                const QString name = m_dialogSaveLayout->Path() + '/'_L1 + m_dialogSaveLayout->FileName() + index
+                                     + VLayoutExporter::ExportFormatSuffix(m_dialogSaveLayout->Format());
 
                 auto *paper = qgraphicsitem_cast<QGraphicsRectItem *>(m_layoutSettings->LayoutPapers().at(i));
                 SCASSERT(paper != nullptr)
@@ -557,12 +560,12 @@ void MainWindowsNoGUI::ExportFlatLayout(const QList<QGraphicsScene *> &scenes, c
         return;
     }
 
-    VAbstractValApplication::VApp()->ValentinaSettings()->SetPathLayout(path);
+    VAbstractValApplication::VApp()->ValentinaSettings()->SetPathLayoutExport(path);
 
     if (const LayoutExportFormats format = m_dialogSaveLayout->Format();
         format == LayoutExportFormats::PDFTiled && m_dialogSaveLayout->Mode() == Draw::Layout)
     {
-        const QString name = path + '/'_L1 + m_dialogSaveLayout->FileName() + '1'_L1;
+        const QString name = path + '/'_L1 + m_dialogSaveLayout->FileName();
         PdfTiledFile(name);
     }
     else
@@ -662,7 +665,7 @@ void MainWindowsNoGUI::ExportApparelLayout(const QVector<VLayoutPiece> &details,
     }
 
     VValentinaSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
-    settings->SetPathLayout(path);
+    settings->SetPathLayoutExport(path);
     const LayoutExportFormats format = m_dialogSaveLayout->Format();
 
     QT_WARNING_PUSH
@@ -696,12 +699,14 @@ void MainWindowsNoGUI::ExportApparelLayout(const QVector<VLayoutPiece> &details,
             exporter.ExportToRLD(details);
             break;
         case LayoutExportFormats::HPGL:
+        case LayoutExportFormats::HPGL_PLT:
             exporter.SetSingleLineFont(settings->GetSingleLineFonts());
             exporter.SetSingleStrokeOutlineFont(settings->GetSingleStrokeOutlineFont());
             exporter.SetPenWidth(qCeil(settings->WidthHairLine()));
             exporter.ExportToHPGL(details);
             break;
         case LayoutExportFormats::HPGL2:
+        case LayoutExportFormats::HPGL2_PLT:
             exporter.SetSingleLineFont(settings->GetSingleLineFonts());
             exporter.SetSingleStrokeOutlineFont(settings->GetSingleStrokeOutlineFont());
             exporter.SetPenWidth(qCeil(settings->WidthHairLine()));
@@ -792,8 +797,8 @@ void MainWindowsNoGUI::ExportDetailsAsApparelLayout(QVector<VLayoutPiece> listDe
         listDetails[i].SetMatrix(moveMatrix);
     }
 
-    const QString name = m_dialogSaveLayout->Path() + '/' + m_dialogSaveLayout->FileName() + QString::number(1) +
-                         VLayoutExporter::ExportFormatSuffix(m_dialogSaveLayout->Format());
+    const QString name = m_dialogSaveLayout->Path() + '/' + m_dialogSaveLayout->FileName()
+                         + VLayoutExporter::ExportFormatSuffix(m_dialogSaveLayout->Format());
 
     ExportApparelLayout(listDetails, name, rect.size());
 }
@@ -905,8 +910,7 @@ auto MainWindowsNoGUI::PrepareDetailsForLayout(const QVector<DetailForLayout> &d
     layoutDetails.reserve(details.size());
     const QFuture<VLayoutPiece> future = futureWatcher.future();
 
-    QFuture<VLayoutPiece>::const_iterator i;
-    for (i = future.constBegin(); i != future.constEnd(); ++i)
+    for (auto i = future.constBegin(); i != future.constEnd(); ++i)
     {
         layoutDetails.append(*i);
     }
@@ -1083,9 +1087,9 @@ void MainWindowsNoGUI::ExportScene(const QList<QGraphicsScene *> &scenes, const
         auto *paper = qgraphicsitem_cast<QGraphicsRectItem *>(papers.at(i));
         if (paper != nullptr)
         {
-            const QString name = m_dialogSaveLayout->Path() + '/' + m_dialogSaveLayout->FileName() +
-                                 QString::number(i + 1) +
-                                 VLayoutExporter::ExportFormatSuffix(m_dialogSaveLayout->Format());
+            const QString index = scenes.size() > 1 ? QString::number(i + 1) : QString();
+            const QString name = m_dialogSaveLayout->Path() + '/' + m_dialogSaveLayout->FileName() + index
+                                 + VLayoutExporter::ExportFormatSuffix(m_dialogSaveLayout->Format());
             auto *brush = new QBrush();
             brush->setColor(QColor(Qt::white));
             QGraphicsScene *scene = scenes.at(i);
@@ -1217,9 +1221,9 @@ auto MainWindowsNoGUI::ExportFMeasurementsToCSVData(const QString &fileName, boo
 {
     QxtCsvModel csv;
 
-    csv.insertColumn(0);
-    csv.insertColumn(1);
-    csv.insertColumn(2);
+    csv.insertSingleColumn(0);
+    csv.insertSingleColumn(1);
+    csv.insertSingleColumn(2);
 
     if (withHeader)
     {
@@ -1236,7 +1240,7 @@ auto MainWindowsNoGUI::ExportFMeasurementsToCSVData(const QString &fileName, boo
     {
         const VFinalMeasurement &m = measurements.at(i);
 
-        csv.insertRow(i);
+        csv.insertSingleRow(i);
         csv.setText(i, 0, m.name); // name
 
         if (not m.formula.isEmpty())
@@ -1293,103 +1297,199 @@ auto MainWindowsNoGUI::ExportFMeasurementsToCSVData(const QString &fileName, boo
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto MainWindowsNoGUI::OpenMeasurementFile(const QString &path) const -> QSharedPointer<VMeasurements>
+auto MainWindowsNoGUI::OpenMeasurementFile(const QString &patternPath, QString &path) -> QSharedPointer<VMeasurements>
 {
-    QSharedPointer<VMeasurements> m;
     if (path.isEmpty())
     {
-        return m;
+        return {};
     }
 
+    const QStringList patternMeasurements = doc->ListMeasurements();
+    QString currentPath = path;
+    while (true)
+    {
+        QSharedPointer<VMeasurements> m = LoadMeasurements(patternPath, currentPath, path);
+        if (!m || m->Type() == MeasurementsType::Unknown)
+        {
+            return {};
+        }
+
+        const QSet<QString> missingMeasurements = ConvertToSet<QString>(patternMeasurements)
+                                                      .subtract(ConvertToSet<QString>(m->ListAll()));
+        if (missingMeasurements.isEmpty())
+        {
+            path = currentPath;
+            return m;
+        }
+
+        if (!HandleMissingMeasurements(m, missingMeasurements, currentPath))
+        {
+            return {};
+        }
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto MainWindowsNoGUI::LoadMeasurements(const QString &patternPath, const QString &currentPath, const QString &oldPath)
+    -> QSharedPointer<VMeasurements>
+{
     try
     {
-        m = QSharedPointer<VMeasurements>(new VMeasurements(pattern));
-        m->setXMLContent(path);
+        auto m = QSharedPointer<VMeasurements>(new VMeasurements(pattern));
+        m->setXMLContent(currentPath);
 
         if (m->Type() == MeasurementsType::Unknown)
         {
             throw VException(QCoreApplication::translate("MainWindowsNoGUI", "Measurement file has unknown format."));
         }
 
-        if (m->Type() == MeasurementsType::Multisize)
+        if (currentPath != oldPath)
         {
-            VVSTConverter converter(path);
-            m->setXMLContent(converter.Convert()); // Read again after conversion
-
-            VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
-            if (settings->IsCollectStatistic())
+            VAbstractValApplication::VApp()->SetMeasurementsType(m->Type());
+            if (not doc->MPath().isEmpty())
             {
-                auto *statistic = VGAnalytics::Instance();
-
-                if (QString clientID = settings->GetClientID(); clientID.isEmpty())
-                {
-                    clientID = QUuid::createUuid().toString();
-                    settings->SetClientID(clientID);
-                    statistic->SetClientID(clientID);
-                }
-
-                statistic->Enable(true);
-
-                const qint64 uptime = VAbstractApplication::VApp()->AppUptime();
-                statistic->SendMultisizeMeasurementsFormatVersion(uptime, converter.GetFormatVersionStr());
-            }
-        }
-        else
-        {
-            VVITConverter converter(path);
-            m->setXMLContent(converter.Convert()); // Read again after conversion
-
-            VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
-            if (settings->IsCollectStatistic())
-            {
-                auto *statistic = VGAnalytics::Instance();
-
-                if (QString clientID = settings->GetClientID(); clientID.isEmpty())
-                {
-                    clientID = QUuid::createUuid().toString();
-                    settings->SetClientID(clientID);
-                    statistic->SetClientID(clientID);
-                }
-
-                statistic->Enable(true);
-
-                const qint64 uptime = VAbstractApplication::VApp()->AppUptime();
-                statistic->SendIndividualMeasurementsFormatVersion(uptime, converter.GetFormatVersionStr());
+                m_watcher->removePath(AbsoluteMPath(patternPath, doc->MPath()));
             }
+            doc->SetMPath(RelativeMPath(patternPath, currentPath));
+            m_watcher->addPath(currentPath);
         }
 
-        CheckRequiredMeasurements(m.data());
+        const QString formatVersion = ApplyConverter(m, currentPath);
+        CollectStatistics(m->Type(), formatVersion);
+
+        return m;
     }
-    catch (VException &e)
+    catch (const VException &e)
     {
-        qCCritical(vMainNoGUIWindow, "%s\n\n%s\n\n%s",
+        qCCritical(vMainNoGUIWindow,
+                   "%s\n\n%s\n\n%s",
                    qUtf8Printable(QCoreApplication::translate("MainWindowsNoGUI", "File error.")),
-                   qUtf8Printable(e.ErrorMessage()), qUtf8Printable(e.DetailedInformation()));
-        if (not m.isNull())
-        {
-            m->clear();
-        }
+                   qUtf8Printable(e.ErrorMessage()),
+                   qUtf8Printable(e.DetailedInformation()));
 
-        if (not VApplication::IsGUIMode())
+        if (!VApplication::IsGUIMode())
         {
             QCoreApplication::exit(V_EX_NOINPUT);
         }
-        return m;
+
+        return {};
     }
-    return m;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void MainWindowsNoGUI::CheckRequiredMeasurements(const VMeasurements *m) const
+auto MainWindowsNoGUI::ApplyConverter(const QSharedPointer<VMeasurements> &m, const QString &path) const -> QString
 {
-    const QSet<QString> match =
-        ConvertToSet<QString>(doc->ListMeasurements()).subtract(ConvertToSet<QString>(m->ListAll()));
-
-    if (not match.isEmpty())
+    std::unique_ptr<VAbstractMConverter> converter;
+    if (m->Type() == MeasurementsType::Multisize)
     {
-        QStringList const list = ConvertToList(match);
-        VException e(tr("Measurement file doesn't include all required measurements."));
-        e.AddMoreInformation(tr("Please, additionally provide: %1").arg(list.join(", "_L1)));
-        throw e;
+        converter = std::make_unique<VVSTConverter>(path);
+    }
+    else
+    {
+        converter = std::make_unique<VVITConverter>(path);
+    }
+
+    m->setXMLContent(converter->Convert());
+    return converter->GetFormatVersionStr();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void MainWindowsNoGUI::CollectStatistics(MeasurementsType measurementsType, const QString &formatVersion) const
+{
+    const VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
+    if (!settings->IsCollectStatistic())
+    {
+        return;
+    }
+
+    auto *statistic = VGAnalytics::Instance();
+    if (settings->GetClientID().isEmpty())
+    {
+        const QString clientID = QUuid::createUuid().toString();
+        settings->SetClientID(clientID);
+        statistic->SetClientID(clientID);
+    }
+    statistic->Enable(true);
+    qint64 uptime = VAbstractApplication::VApp()->AppUptime();
+    if (measurementsType == MeasurementsType::Multisize)
+    {
+        statistic->SendMultisizeMeasurementsFormatVersion(uptime, formatVersion);
+    }
+    else
+    {
+        statistic->SendIndividualMeasurementsFormatVersion(uptime, formatVersion);
     }
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto MainWindowsNoGUI::HandleMissingMeasurements(const QSharedPointer<VMeasurements> &m,
+                                                 const QSet<QString> &missing,
+                                                 QString &currentPath) -> bool
+{
+    const QStringList missingList = ConvertToList(missing);
+
+    if (!VApplication::IsGUIMode())
+    {
+        qCCritical(vMainNoGUIWindow,
+                   "%s\n\n%s\n\n%s",
+                   qUtf8Printable(QCoreApplication::translate("MainWindowsNoGUI", "File error.")),
+                   qUtf8Printable(tr("Measurement file doesn't include all required measurements.")),
+                   qUtf8Printable(tr("Please, additionally provide: %1").arg(missingList.join(", "_L1))));
+        return false;
+    }
+
+    if (const QString message
+        = tr("Measurement file doesn't include all required measurements.\n\nMissing: %1\n\nWould you like "
+             "to select another file?")
+              .arg(missingList.join(", "));
+        QMessageBox::question(this, tr("Missing Measurements"), message) != QMessageBox::Yes)
+    {
+        m->clear();
+        return false;
+    }
+
+    return SelectNewFile(m, currentPath);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto MainWindowsNoGUI::SelectNewFile(const QSharedPointer<VMeasurements> &m, QString &currentPath) -> bool
+{
+    QString filter;
+    if (m->Type() == MeasurementsType::Multisize)
+    {
+        filter = tr("Multisize measurements") + " (*.vst);;"_L1 + tr("Individual measurements") + " (*.vit)"_L1;
+    }
+    else
+    {
+        filter = tr("Individual measurements") + " (*.vit);;"_L1 + tr("Multisize measurements") + " (*.vst)"_L1;
+    }
+
+    const QString dirPath = QFileInfo(currentPath).absolutePath();
+    QFileDialog dialog(this, tr("Select Measurement File"), dirPath, filter);
+    dialog.selectFile(QFileInfo(currentPath).fileName());
+    dialog.setFileMode(QFileDialog::ExistingFile);
+    dialog.setOption(QFileDialog::DontUseNativeDialog,
+                     VAbstractApplication::VApp()->Settings()->IsDontUseNativeDialog());
+
+    if (dialog.exec() == QDialog::Accepted)
+    {
+        currentPath = dialog.selectedFiles().value(0);
+
+        if (const VValentinaSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
+            m->Type() == MeasurementsType::Multisize)
+        {
+            settings->SetPathMultisizeMeasurements(currentPath);
+        }
+        else
+        {
+            settings->SetPathIndividualMeasurements(currentPath);
+        }
+    }
+    else
+    {
+        m->clear();
+        return false;
+    }
+
+    return true;
+}
