@@ -101,6 +101,8 @@ protected:
 
     QGraphicsScene *tempSceneLayout{nullptr}; // NOLINT(misc-non-private-member-variables-in-classes)
 
+    QFileSystemWatcher *m_watcher; // NOLINT(misc-non-private-member-variables-in-classes)
+
     /** @brief pattern container with data (points, arcs, splines, spline paths, variables) */
     VContainer *pattern; // NOLINT(misc-non-private-member-variables-in-classes)
 
@@ -147,9 +149,7 @@ protected:
     auto ExportFMeasurementsToCSVData(const QString &fileName, bool withHeader, int mib, const QChar &separator) const
         -> bool;
 
-    auto OpenMeasurementFile(const QString &path) const -> QSharedPointer<VMeasurements>;
-
-    void CheckRequiredMeasurements(const VMeasurements *m) const;
+    auto OpenMeasurementFile(const QString &patternPath, QString &path) -> QSharedPointer<VMeasurements>;
 
 private:
     Q_DISABLE_COPY_MOVE(MainWindowsNoGUI) // NOLINT
@@ -175,6 +175,15 @@ private:
     void ExportDetailsAsFlatLayout(const QVector<VLayoutPiece> &listDetails);
 
     void ShowLayoutError(const LayoutErrors &state);
+
+    auto LoadMeasurements(const QString &patternPath, const QString &currentPath, const QString &oldPath)
+        -> QSharedPointer<VMeasurements>;
+    auto ApplyConverter(const QSharedPointer<VMeasurements> &m, const QString &path) const -> QString;
+    void CollectStatistics(MeasurementsType measurementsType, const QString &formatVersion) const;
+    auto HandleMissingMeasurements(const QSharedPointer<VMeasurements> &m,
+                                   const QSet<QString> &missing,
+                                   QString &currentPath) -> bool;
+    auto SelectNewFile(const QSharedPointer<VMeasurements> &m, QString &currentPath) -> bool;
 };
 
 #endif // MAINWINDOWSNOGUI_H
