@@ -28,31 +28,30 @@
 #include <QUrl>
 #include <QtGlobal>
 
-#include "../vmisc/defglobal.h"
-
 class FvAvailableUpdate final : public QObject
 {
     Q_OBJECT // NOLINT
+
 public:
     explicit FvAvailableUpdate(QObject *parent = nullptr);
 
-    QUrl GetEnclosureUrl() const;
+    auto GetEnclosureUrl() const -> QUrl;
     void SetEnclosureUrl(const QUrl &enclosureUrl);
     void SetEnclosureUrl(const QString &enclosureUrl);
 
-    QString GetEnclosureVersion() const;
+    auto GetEnclosureVersion() const -> QString;
     void SetEnclosureVersion(const QString &enclosureVersion);
 
-    QString GetEnclosurePlatform() const;
+    auto GetEnclosurePlatform() const -> QString;
     void SetEnclosurePlatform(const QString &enclosurePlatform);
 
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(FvAvailableUpdate) // NOLINT
 
-    QUrl          m_enclosureUrl;
-    QString       m_enclosureVersion;
-    QString       m_enclosurePlatform;
+    QUrl m_enclosureUrl;
+    QString m_enclosureVersion;
+    QString m_enclosurePlatform;
 };
 
 #endif // FVAVAILABLEUPDATE_H
