@@ -29,7 +29,6 @@
 #ifndef VEXCEPTION_H
 #define VEXCEPTION_H
 
-#include <qcompilerdetection.h>
 #include <QCoreApplication>
 #include <QException>
 #include <QString>
@@ -46,31 +45,35 @@ QT_WARNING_DISABLE_GCC("-Wsuggest-final-methods")
 class VException : public QException
 {
     Q_DECLARE_TR_FUNCTIONS(VException) // NOLINT
-public:
-    explicit VException(const QString &error) V_NOEXCEPT_EXPR (true);
-    VException(const VException &e) V_NOEXCEPT_EXPR (true);
-    VException &operator=(const VException &e) V_NOEXCEPT_EXPR (true);
-    virtual ~VException() V_NOEXCEPT_EXPR (true) = default;
 
-    Q_NORETURN virtual void raise() const override;
+public:
+    explicit VException(const QString &error) V_NOEXCEPT_EXPR(true);
+    VException(const VException &e) V_NOEXCEPT_EXPR(true);
+    auto operator=(const VException &e) V_NOEXCEPT_EXPR(true) -> VException &;
+    ~VException() V_NOEXCEPT_EXPR(true) override = default;
+
+    VException(VException &&) noexcept = default;
+    auto operator=(VException &&) noexcept -> VException & = default;
+
+    Q_NORETURN void raise() const override;
 
     // cppcheck-suppress unusedFunction
-    Q_REQUIRED_RESULT virtual VException *clone() const override;
+    Q_REQUIRED_RESULT auto clone() const -> VException * override;
 
-    virtual QString ErrorMessage() const;
-    virtual QString DetailedInformation() const;
-    QString         WhatUtf8() const V_NOEXCEPT_EXPR (true);
-    void            AddMoreInformation(const QString &info);
-    QString         MoreInformation() const;
+    virtual auto ErrorMessage() const -> QString;
+    virtual auto DetailedInformation() const -> QString;
+    auto WhatUtf8() const V_NOEXCEPT_EXPR(true) -> QString;
+    void AddMoreInformation(const QString &info);
+    auto MoreInformation() const -> QString;
 
 protected:
     /** @brief error string with error */
-    QString         error;
+    QString error;
 
     /** @brief moreInfo more information about error */
-    QString         moreInfo {};
+    QString moreInfo{};
 
-    QString         MoreInfo(const QString &detInfo) const;
+    auto MoreInfo(const QString &detInfo) const -> QString;
 };
 
 QT_WARNING_POP
@@ -80,7 +83,7 @@ QT_WARNING_POP
  * @brief What return string with error
  * @return string with error
  */
-inline QString VException::WhatUtf8() const V_NOEXCEPT_EXPR (true)
+inline auto VException::WhatUtf8() const V_NOEXCEPT_EXPR(true) -> QString
 {
     return error;
 }
@@ -90,7 +93,7 @@ inline QString VException::WhatUtf8() const V_NOEXCEPT_EXPR (true)
  * @brief MoreInformation return more information for error
  * @return information
  */
-inline QString VException::MoreInformation() const
+inline auto VException::MoreInformation() const -> QString
 {
     return moreInfo;
 }
@@ -99,15 +102,16 @@ inline QString VException::MoreInformation() const
 class VExceptionToolWasDeleted : public VException
 {
     Q_DECLARE_TR_FUNCTIONS(VExceptionToolDeleted) // NOLINT
+
 public:
-    explicit VExceptionToolWasDeleted(const QString &error) V_NOEXCEPT_EXPR (true);
-    VExceptionToolWasDeleted(const VExceptionToolWasDeleted &e) V_NOEXCEPT_EXPR (true);
-    VExceptionToolWasDeleted &operator=(const VExceptionToolWasDeleted &e) V_NOEXCEPT_EXPR (true);
-    virtual ~VExceptionToolWasDeleted() V_NOEXCEPT_EXPR (true) = default;
+    explicit VExceptionToolWasDeleted(const QString &error) V_NOEXCEPT_EXPR(true);
+    VExceptionToolWasDeleted(const VExceptionToolWasDeleted &e) V_NOEXCEPT_EXPR(true);
+    auto operator=(const VExceptionToolWasDeleted &e) V_NOEXCEPT_EXPR(true) -> VExceptionToolWasDeleted &;
+    virtual ~VExceptionToolWasDeleted() V_NOEXCEPT_EXPR(true) = default;
 
     Q_NORETURN virtual void raise() const override;
     // cppcheck-suppress unusedFunction
-    virtual VExceptionToolWasDeleted *clone() const override;
+    virtual auto clone() const -> VExceptionToolWasDeleted * override;
 };
 
 #endif // VEXCEPTION_H
