@@ -29,7 +29,7 @@
 #ifndef VEXCEPTIONWRONGID_H
 #define VEXCEPTIONWRONGID_H
 
-#include <qcompilerdetection.h>
+
 #include <QString>
 #include <QtGlobal>
 
@@ -46,18 +46,22 @@ class VExceptionWrongId : public VException
 public:
     VExceptionWrongId(const QString &what, const QDomElement &domElement) V_NOEXCEPT_EXPR (true);
     VExceptionWrongId(const VExceptionWrongId &e) V_NOEXCEPT_EXPR (true);
-    VExceptionWrongId &operator=(const VExceptionWrongId &e) V_NOEXCEPT_EXPR (true);
+    auto operator=(const VExceptionWrongId &e) V_NOEXCEPT_EXPR(true) -> VExceptionWrongId &;
     virtual ~VExceptionWrongId() V_NOEXCEPT_EXPR (true) = default;
 
     Q_NORETURN virtual void raise() const override { throw *this; }
 
-    Q_REQUIRED_RESULT virtual VExceptionWrongId *clone() const override { return new VExceptionWrongId(*this); }
+    Q_REQUIRED_RESULT virtual auto clone() const -> VExceptionWrongId * override
+    {
+        return new VExceptionWrongId(*this);
+    }
+
+    virtual auto ErrorMessage() const -> QString override;
+    virtual auto DetailedInformation() const -> QString override;
+    auto TagText() const -> QString;
+    auto TagName() const -> QString;
+    auto LineNumber() const -> qint32;
 
-    virtual QString ErrorMessage() const override;
-    virtual QString DetailedInformation() const override;
-    QString         TagText() const;
-    QString         TagName() const;
-    qint32          LineNumber() const;
 protected:
     /** @brief tagText tag text */
     QString         tagText;
@@ -74,7 +78,7 @@ protected:
  * @brief TagText return tag text
  * @return tag text
  */
-inline QString VExceptionWrongId::TagText() const
+inline auto VExceptionWrongId::TagText() const -> QString
 {
     return tagText;
 }
@@ -84,7 +88,7 @@ inline QString VExceptionWrongId::TagText() const
  * @brief TagName return tag name
  * @return tag name
  */
-inline QString VExceptionWrongId::TagName() const
+inline auto VExceptionWrongId::TagName() const -> QString
 {
     return tagName;
 }
@@ -94,7 +98,7 @@ inline QString VExceptionWrongId::TagName() const
  * @brief LineNumber return line number in file
  * @return line number
  */
-inline qint32 VExceptionWrongId::LineNumber() const
+inline auto VExceptionWrongId::LineNumber() const -> qint32
 {
     return lineNumber;
 }
