@@ -36,7 +36,7 @@
 #include <QSvgRenderer>
 
 // Header <ciso646> is removed in C++20.
-#if __cplusplus <= 201703L
+#if defined(Q_CC_MSVC) && __cplusplus <= 201703L
 #include <ciso646> // and, not, or
 #endif
 
@@ -78,9 +78,7 @@ auto MimeTypeFromByteArray(const QByteArray &data) -> QMimeType
     QSet<QString> aliases = ConvertToSet<QString>(mime.aliases());
     aliases.insert(mime.name());
 
-    QSet<QString> const gzipMime{"application/gzip", "application/x-gzip"};
-
-    if (gzipMime.contains(aliases))
+    if (QSet<QString> const gzipMime{"application/gzip", "application/x-gzip"}; gzipMime.contains(aliases))
     {
         QSvgRenderer const render(data);
         if (render.isValid())
@@ -93,18 +91,31 @@ auto MimeTypeFromByteArray(const QByteArray &data) -> QMimeType
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto PrepareImageFilters() -> QString
+auto SupportedFormats() -> QStringList
 {
     const QList<QByteArray> supportedFormats = QImageReader::supportedImageFormats();
     const QSet<QString> filterFormats{"bmp", "jpeg", "jpg", "png", "svg", "svgz", "tif", "tiff", "webp"};
-    QStringList sufixes;
+    QStringList formats;
     for (const auto &format : supportedFormats)
     {
         if (filterFormats.contains(format))
         {
-            sufixes.append(QStringLiteral("*.%1").arg(QString(format)));
+            formats.append(format);
         }
     }
+    return formats;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto PrepareImageFilters() -> QString
+{
+    const QStringList supportedFormats = SupportedFormats();
+    QStringList sufixes;
+    sufixes.reserve(supportedFormats.size());
+    for (const auto &format : supportedFormats)
+    {
+        sufixes.append("*."_L1 + format);
+    }
 
     QStringList filters;
 
