@@ -29,15 +29,12 @@
 #include "vabstractmconverter.h"
 
 #include <QDomElement>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
 
 #include "vabstractconverter.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 VAbstractMConverter::VAbstractMConverter(const QString &fileName)
-    :VAbstractConverter(fileName)
+  : VAbstractConverter(fileName)
 {
     m_ver = GetFormatVersion(GetFormatVersionStr());
 }
@@ -58,15 +55,14 @@ auto VAbstractMConverter::Units() const -> Unit
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractMConverter::AddRootComment()
 {
-    const QString rootComment =
-            QStringLiteral("Measurements created with Valentina (https://smart-pattern.com.ua/).");
+    const auto rootComment = QStringLiteral("Measurements created with Valentina (https://smart-pattern.com.ua/).");
 
     QDomElement rootElement = this->documentElement();
     rootElement.insertBefore(createComment(rootComment), rootElement.firstChild());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QMultiMap<QString, QString> VAbstractMConverter::OldNamesToNewNames_InV0_3_0()
+auto VAbstractMConverter::OldNamesToNewNames_InV0_3_0() -> QMultiMap<QString, QString>
 {
     // new name, old name
     QMultiMap<QString, QString> names;
@@ -82,7 +78,7 @@ QMultiMap<QString, QString> VAbstractMConverter::OldNamesToNewNames_InV0_3_0()
     names.insert(QStringLiteral("height_waist_front"), QStringLiteral("front_waist_to_floor"));
     names.insert(QStringLiteral("height_bustpoint"), QStringLiteral("height_nipple_point"));
 
-    QString name = QStringLiteral("height_shoulder_tip");
+    auto name = QStringLiteral("height_shoulder_tip");
     names.insert(name, QStringLiteral("shoulder_height"));
     names.insert(name, QStringLiteral("height_shoulder_point"));
 
@@ -253,7 +249,7 @@ QMultiMap<QString, QString> VAbstractMConverter::OldNamesToNewNames_InV0_3_0()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QMap<QString, QString> VAbstractMConverter::OldNamesToNewNames_InV0_3_3()
+auto VAbstractMConverter::OldNamesToNewNames_InV0_3_3() -> QMap<QString, QString>
 {
     // new name, old name
     QMap<QString, QString> names;
