@@ -88,8 +88,7 @@ void SaveNodeCanonically(QXmlStreamWriter &stream, const QDomNode &domNode)
 
     if (domNode.isElement())
     {
-        const QDomElement domElement = domNode.toElement();
-        if (not domElement.isNull())
+        if (const QDomElement domElement = domNode.toElement(); not domElement.isNull())
         {
             stream.writeStartElement(domElement.tagName());
 
@@ -169,10 +168,8 @@ auto LessThen(const QDomNode &element1, const QDomNode &element2) -> bool
     }
 
     QString const tag1 = element1.nodeName();
-    QString const tag2 = element2.nodeName();
 
-    // qDebug() << tag1 <<tag2;
-    if (tag1 != tag2)
+    if (QString const tag2 = element2.nodeName(); tag1 != tag2)
     {
         return tag1 < tag2;
     }
@@ -292,17 +289,16 @@ VDomDocument::~VDomDocument()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VDomDocument::elementById(quint32 id, const QString &tagName, bool updateCache) -> QDomElement
+auto VDomDocument::FindElementById(quint32 id, const QString &tagName, bool updateCache) -> QDomElement
 {
     if (id == 0)
     {
-        return QDomElement();
+        return {};
     }
 
     if (m_elementIdCache.contains(id))
     {
-        const QDomElement e = m_elementIdCache.value(id);
-        if (e.parentNode().nodeType() != QDomNode::BaseNode)
+        if (const QDomElement e = m_elementIdCache.value(id); e.parentNode().nodeType() != QDomNode::BaseNode)
         {
             if (not tagName.isEmpty())
             {
@@ -326,8 +322,7 @@ auto VDomDocument::elementById(quint32 id, const QString &tagName, bool updateCa
     if (tagName.isEmpty())
     {
         // Because VDomDocument::find checks for unique id we must use temp cache
-        QHash<quint32, QDomElement> tmpCache;
-        if (VDomDocument::find(tmpCache, this->documentElement(), id))
+        if (QHash<quint32, QDomElement> tmpCache; VDomDocument::find(tmpCache, this->documentElement(), id))
         {
             return tmpCache.value(id);
         }
@@ -337,12 +332,10 @@ auto VDomDocument::elementById(quint32 id, const QString &tagName, bool updateCa
         const QDomNodeList list = elementsByTagName(tagName);
         for (int i = 0; i < list.size(); ++i)
         {
-            const QDomElement domElement = list.at(i).toElement();
-            if (not domElement.isNull() && domElement.hasAttribute(AttrId))
+            if (const QDomElement domElement = list.at(i).toElement();
+                not domElement.isNull() && domElement.hasAttribute(AttrId))
             {
-                const quint32 elementId = GetParametrUInt(domElement, AttrId, NULL_ID_STR);
-
-                if (elementId == id)
+                if (const quint32 elementId = GetParametrUInt(domElement, AttrId, NULL_ID_STR); elementId == id)
                 {
                     return domElement;
                 }
@@ -350,7 +343,7 @@ auto VDomDocument::elementById(quint32 id, const QString &tagName, bool updateCa
         }
     }
 
-    return QDomElement();
+    return {};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -542,8 +535,7 @@ auto VDomDocument::GetParametrBool(const QDomElement &domElement, const QString
 //---------------------------------------------------------------------------------------------------------------------
 auto VDomDocument::GetParametrUsage(const QDomElement &domElement, const QString &name) -> NodeUsage
 {
-    const bool value = GetParametrBool(domElement, name, trueStr);
-    if (value)
+    if (const bool value = GetParametrBool(domElement, name, trueStr); value)
     {
         return NodeUsage::InUse;
     }
@@ -663,8 +655,7 @@ auto VDomDocument::GetParametrId(const QDomElement &domElement) -> quint32
 //---------------------------------------------------------------------------------------------------------------------
 auto VDomDocument::UniqueTagText(const QString &tagName, const QString &defVal) const -> QString
 {
-    QDomElement const domElement = UniqueTag(tagName);
-    if (not domElement.isNull())
+    if (QDomElement const domElement = UniqueTag(tagName); not domElement.isNull())
     {
         QString text = domElement.text();
         if (text.isEmpty())
@@ -742,23 +733,37 @@ void VDomDocument::CacheRefreshed()
 void VDomDocument::setXMLContent(const QString &fileName)
 {
     QFile file(fileName);
-    if (file.open(QIODevice::ReadOnly) == false)
+    if (!file.open(QIODevice::ReadOnly))
     {
         const QString errorMsg(tr("Can't open file %1:\n%2.").arg(fileName, file.errorString()));
         throw VException(errorMsg);
     }
 
+    auto HandleParsingError = [fileName](const QString &errorMsg, int errorLine, int errorColumn)
+    {
+        VException e(errorMsg);
+        e.AddMoreInformation(
+            tr("Parsing error in file %3 at line %1, column %2").arg(errorLine).arg(errorColumn).arg(fileName));
+        throw e;
+    };
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+    if (const QDomDocument::ParseResult result = QDomDocument::setContent(&file); !result)
+    {
+        file.close();
+        HandleParsingError(result.errorMessage, static_cast<int>(result.errorLine),
+                           static_cast<int>(result.errorColumn));
+    }
+#else
     QString errorMsg;
     int errorLine = -1;
     int errorColumn = -1;
-    if (QDomDocument::setContent(&file, &errorMsg, &errorLine, &errorColumn) == false)
+    if (!QDomDocument::setContent(&file, &errorMsg, &errorLine, &errorColumn))
     {
         file.close();
-        VException e(errorMsg);
-        e.AddMoreInformation(
-            tr("Parsing error file %3 in line %1 column %2").arg(errorLine).arg(errorColumn).arg(fileName));
-        throw e;
+        HandleParsingError(errorMsg, errorLine, errorColumn);
     }
+#endif // QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
 
     RefreshElementIdCache();
 }
@@ -799,8 +804,7 @@ auto VDomDocument::SaveDocument(const QString &fileName, QString &error) -> bool
     if (file.open(QIODevice::WriteOnly))
     {
         // See issue #666. QDomDocument produces random attribute order.
-        const int indent = 4;
-        if (not SaveCanonicalXML(&file, indent, error))
+        if (const int indent = 4; not SaveCanonicalXML(&file, indent, error))
         {
             return false;
         }
@@ -879,8 +883,7 @@ auto VDomDocument::GetFormatVersionStr() const -> QString
         throw VException(errorMsg);
     }
 
-    const QDomNode domNode = nodeList.at(0);
-    if (domNode.isNull() == false && domNode.isElement())
+    if (const QDomNode domNode = nodeList.at(0); domNode.isNull() == false && domNode.isElement())
     {
         const QDomElement domElement = domNode.toElement();
         if (domElement.isNull() == false)
@@ -925,15 +928,13 @@ auto VDomDocument::GetFormatVersion(const QString &version) -> unsigned
 //---------------------------------------------------------------------------------------------------------------------
 auto VDomDocument::setTagText(const QString &tag, const QString &text) -> bool
 {
-    const QDomNodeList nodeList = this->elementsByTagName(tag);
-    if (nodeList.isEmpty())
+    if (const QDomNodeList nodeList = this->elementsByTagName(tag); nodeList.isEmpty())
     {
         qDebug() << "Can't save tag " << tag << Q_FUNC_INFO;
     }
     else
     {
-        QDomNode const domNode = nodeList.at(0);
-        if (not domNode.isNull() && domNode.isElement())
+        if (QDomNode const domNode = nodeList.at(0); not domNode.isNull() && domNode.isElement())
         {
             QDomElement domElement = domNode.toElement();
             return setTagText(domElement, text);
@@ -981,11 +982,9 @@ auto VDomDocument::UniqueTag(const QString &tagName) const -> QDomElement
         return {};
     }
 
-    const QDomNode domNode = nodeList.at(0);
-    if (not domNode.isNull() && domNode.isElement())
+    if (const QDomNode domNode = nodeList.at(0); not domNode.isNull() && domNode.isElement())
     {
-        const QDomElement domElement = domNode.toElement();
-        if (not domElement.isNull())
+        if (const QDomElement domElement = domNode.toElement(); not domElement.isNull())
         {
             return domElement;
         }
@@ -1026,7 +1025,7 @@ auto VDomDocument::CloneNodeById(const quint32 &nodeId) -> QDomElement
 //---------------------------------------------------------------------------------------------------------------------
 auto VDomDocument::NodeById(const quint32 &nodeId, const QString &tagName) -> QDomElement
 {
-    QDomElement const domElement = elementById(nodeId, tagName);
+    QDomElement const domElement = FindElementById(nodeId, tagName);
     if (domElement.isNull() || domElement.isElement() == false)
     {
         throw VExceptionBadId(tr("Couldn't get node"), nodeId);
@@ -1156,11 +1155,10 @@ void VDomDocument::SetLabelTemplate(QDomElement &element, const QVector<VLabelTe
 //---------------------------------------------------------------------------------------------------------------------
 void VDomDocument::ValidateVersion(const QString &version)
 {
-    static const QRegularExpression rx(
-        QStringLiteral("^([0-9]|[1-9][0-9]|[1-2][0-5][0-5]).([0-9]|[1-9][0-9]|[1-2][0-5][0-5])"
-                       ".([0-9]|[1-9][0-9]|[1-2][0-5][0-5])$"));
-
-    if (!rx.match(version).hasMatch())
+    if (static const QRegularExpression rx(
+            QStringLiteral("^([0-9]|[1-9][0-9]|[1-2][0-5][0-5]).([0-9]|[1-9][0-9]|[1-2][0-5][0-5])"
+                           ".([0-9]|[1-9][0-9]|[1-2][0-5][0-5])$"));
+        !rx.match(version).hasMatch())
     {
         const QString errorMsg(tr("Version \"%1\" invalid.").arg(version));
         throw VException(errorMsg);
