@@ -52,43 +52,40 @@ VLabelTemplateConverter::VLabelTemplateConverter(const QString &fileName)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-unsigned VLabelTemplateConverter::MinVer() const
+auto VLabelTemplateConverter::XSDSchemas() -> QHash<unsigned int, QString>
+{
+    static const auto schemas = QHash <unsigned, QString>
+    {
+        std::make_pair(FormatVersion(1, 0, 0), CurrentSchema)
+    };
+
+    return schemas;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VLabelTemplateConverter::MinVer() const -> unsigned
 {
     return LabelTemplateMinVer;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-unsigned VLabelTemplateConverter::MaxVer() const
+auto VLabelTemplateConverter::MaxVer() const -> unsigned
 {
     return LabelTemplateMaxVer;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VLabelTemplateConverter::MinVerStr() const
+auto VLabelTemplateConverter::MinVerStr() const -> QString
 {
     return LabelTemplateMinVerStr;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VLabelTemplateConverter::MaxVerStr() const
+auto VLabelTemplateConverter::MaxVerStr() const -> QString
 {
     return LabelTemplateMaxVerStr;
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-QString VLabelTemplateConverter::XSDSchema(unsigned ver) const
-{
-    switch (ver)
-    {
-        case (FormatVersion(1, 0, 0)):
-            return CurrentSchema;
-        default:
-            InvalidVersion(ver);
-            break;
-    }
-    return QString();//unreachable code
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 void VLabelTemplateConverter::ApplyPatches()
 {
@@ -108,3 +105,9 @@ void VLabelTemplateConverter::DowngradeToCurrentMaxVersion()
     SetVersion(LabelTemplateMaxVerStr);
     Save();
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VLabelTemplateConverter::Schemas() const -> QHash<unsigned int, QString>
+{
+    return XSDSchemas();
+}
