@@ -28,6 +28,7 @@
 #ifndef VLAYOUTCONVERTER_H
 #define VLAYOUTCONVERTER_H
 
+#include "../vmisc/projectversion.h"
 #include "vabstractconverter.h"
 
 class QDomElement;
@@ -35,16 +36,20 @@ class QString;
 
 class VLayoutConverter : public VAbstractConverter
 {
+    Q_OBJECT // NOLINT
+
 public:
     explicit VLayoutConverter(const QString &fileName);
-    ~VLayoutConverter() override =default;
+    ~VLayoutConverter() override = default;
 
     auto GetFormatVersionStr() const -> QString override;
 
     static const QString LayoutMaxVerStr;
     static const QString CurrentSchema;
-    static Q_DECL_CONSTEXPR const unsigned LayoutMinVer = FormatVersion(0, 1, 0);
-    static Q_DECL_CONSTEXPR const unsigned LayoutMaxVer = FormatVersion(0, 1, 2);
+    static constexpr const unsigned LayoutMinVer = FormatVersion(0, 1, 0);
+    static constexpr const unsigned LayoutMaxVer = FormatVersion(0, 2, 0);
+
+    static auto XSDSchemas() -> QHash<unsigned, QString>;
 
 protected:
     void SetVersion(const QString &version) override;
@@ -55,13 +60,24 @@ protected:
     auto MinVerStr() const -> QString override;
     auto MaxVerStr() const -> QString override;
 
-    auto XSDSchema(unsigned ver) const -> QString override;
     void ApplyPatches() override;
     void DowngradeToCurrentMaxVersion() override;
 
     auto IsReadOnly() const -> bool override;
 
-    void ToV0_1_2();
+    auto Schemas() const -> QHash<unsigned, QString> override;
+
+    void ConvertPiecesToV0_1_3();
+    void ConvertPathToV0_1_3(QDomElement &node);
+
+    void ConvertPiecesToV0_1_5();
+
+    void ConvertPiecesToV0_1_7();
+
+    void ToV0_1_3();
+    void ToV0_1_5();
+    void ToV0_1_7();
+    void ToV0_2_0();
 
 private:
     Q_DISABLE_COPY_MOVE(VLayoutConverter) // NOLINT
