@@ -54,7 +54,7 @@ public:
     static const QString PatternMaxVerStr;
     static const QString CurrentSchema;
     static constexpr const unsigned PatternMinVer = FormatVersion(0, 1, 4);
-    static constexpr const unsigned PatternMaxVer = FormatVersion(0, 9, 6);
+    static constexpr const unsigned PatternMaxVer = FormatVersion(0, 9, 8);
 
     static auto XSDSchemas() -> QHash<unsigned, QString>;
 
@@ -92,6 +92,8 @@ private:
     void ToV0_9_1();
     void ToV0_9_2();
     void ToV0_9_6();
+    void ToV0_9_7();
+    void ToV0_9_8();
 
     void TagUnitToV0_2_0();
     void TagIncrementToV0_2_0();
@@ -154,7 +156,9 @@ private:
 
     void ConvertPathAttributesToV0_9_2();
 
-    void ConvertGrainlineToV0_9_6();
+    void ConvertGrainlineToV0_9_6() const;
+
+    void ConvertMirrorLineToV0_9_7() const;
 };
 
 //---------------------------------------------------------------------------------------------------------------------
