@@ -28,8 +28,8 @@
 #ifndef VPATTERNIMAGE_H
 #define VPATTERNIMAGE_H
 
-#include <QString>
 #include <QCoreApplication>
+#include <QString>
 
 class QPixmap;
 class QMimeType;
@@ -37,6 +37,7 @@ class QMimeType;
 class VPatternImage
 {
     Q_DECLARE_TR_FUNCTIONS(VPatternImage) // NOLINT
+
 public:
     VPatternImage() = default;
 
@@ -45,12 +46,14 @@ public:
     auto ContentType() const -> const QString &;
 
     auto ContentData() const -> const QByteArray &;
-    void SetContentData(const QByteArray &newContentData, const QString & newContentType);
+    void SetContentData(const QByteArray &newContentData, const QString &newContentType);
 
     auto IsNull() const -> bool;
     auto IsValid() const -> bool;
 
+    auto GetPixmap() const -> QPixmap;
     auto GetPixmap(int width, int height) const -> QPixmap;
+    auto GetPixmap(const QSize &size) const -> QPixmap;
 
     auto ErrorString() const -> const QString &;
 
@@ -58,10 +61,18 @@ public:
 
     auto Size() const -> QSize;
 
+    auto Title() const -> QString;
+    void SetTitle(const QString &newTitle);
+
+    qreal GetSizeScale() const;
+    void SetSizeScale(qreal newSizeScale);
+
 private:
-    QString         m_contentType{};
-    QByteArray      m_contentData{};
+    QString m_contentType{};
+    QByteArray m_contentData{};
     mutable QString m_errorString{};
+    QString m_title{};
+    qreal m_sizeScale{100};
 };
 
 #endif // VPATTERNIMAGE_H
