@@ -55,8 +55,8 @@ using namespace Qt::Literals::StringLiterals;
  */
 
 const QString VVITConverter::MeasurementMinVerStr = QStringLiteral("0.2.0");
-const QString VVITConverter::MeasurementMaxVerStr = QStringLiteral("0.6.1");
-const QString VVITConverter::CurrentSchema = QStringLiteral("://schema/individual_measurements/v0.6.1.xsd");
+const QString VVITConverter::MeasurementMaxVerStr = QStringLiteral("0.6.2");
+const QString VVITConverter::CurrentSchema = QStringLiteral("://schema/individual_measurements/v0.6.2.xsd");
 
 // VVITConverter::MeasurementMinVer; // <== DON'T FORGET TO UPDATE TOO!!!!
 // VVITConverter::MeasurementMaxVer; // <== DON'T FORGET TO UPDATE TOO!!!!
@@ -98,7 +98,8 @@ auto VVITConverter::XSDSchemas() -> QHash<unsigned int, QString>
         std::make_pair(FormatVersion(0, 5, 1), QStringLiteral("://schema/individual_measurements/v0.5.1.xsd")),
         std::make_pair(FormatVersion(0, 5, 2), QStringLiteral("://schema/individual_measurements/v0.5.2.xsd")),
         std::make_pair(FormatVersion(0, 6, 0), QStringLiteral("://schema/individual_measurements/v0.6.0.xsd")),
-        std::make_pair(FormatVersion(0, 6, 1), CurrentSchema),
+        std::make_pair(FormatVersion(0, 6, 1), QStringLiteral("://schema/individual_measurements/v0.6.1.xsd")),
+        std::make_pair(FormatVersion(0, 6, 2), CurrentSchema),
     };
 
     return schemas;
@@ -130,9 +131,12 @@ void VVITConverter::ApplyPatches()
         case (FormatVersion(0, 5, 2)):
         case (FormatVersion(0, 6, 0)):
             ToV0_6_1();
-            ValidateXML(CurrentSchema);
             Q_FALLTHROUGH();
         case (FormatVersion(0, 6, 1)):
+            ToV0_6_2();
+            ValidateXML(CurrentSchema);
+            Q_FALLTHROUGH();
+        case (FormatVersion(0, 6, 2)):
             break;
         default:
             InvalidVersion(m_ver);
@@ -151,7 +155,7 @@ void VVITConverter::DowngradeToCurrentMaxVersion()
 auto VVITConverter::IsReadOnly() const -> bool
 {
     // Check if attribute read-only was not changed in file format
-    Q_STATIC_ASSERT_X(VVITConverter::MeasurementMaxVer == FormatVersion(0, 6, 1), "Check attribute read-only.");
+    Q_STATIC_ASSERT_X(VVITConverter::MeasurementMaxVer == FormatVersion(0, 6, 2), "Check attribute read-only.");
 
     // Possibly in future attribute read-only will change position etc.
     // For now position is the same for all supported format versions.
@@ -320,8 +324,7 @@ void VVITConverter::ConvertCustomerNameToV0_4_0()
 
     // Given name
     QString givenName;
-    const QDomNodeList givenNameList = this->elementsByTagName(*strGivenName);
-    if (not givenNameList.isEmpty())
+    if (const QDomNodeList givenNameList = this->elementsByTagName(*strGivenName); not givenNameList.isEmpty())
     {
         QDomNode const givenNameNode = givenNameList.at(0);
         givenName = givenNameNode.toElement().text();
@@ -330,8 +333,7 @@ void VVITConverter::ConvertCustomerNameToV0_4_0()
 
     // Family name
     QString familyName;
-    const QDomNodeList familyNameList = this->elementsByTagName(*strFamilyName);
-    if (not familyNameList.isEmpty())
+    if (const QDomNodeList familyNameList = this->elementsByTagName(*strFamilyName); not familyNameList.isEmpty())
     {
         QDomNode const familyNameNode = familyNameList.at(0);
         familyName = familyNameNode.toElement().text();
@@ -429,3 +431,13 @@ void VVITConverter::ToV0_6_1()
     ConvertPMSystemToV0_6_1();
     Save();
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+void VVITConverter::ToV0_6_2()
+{
+    // TODO. Delete if minimal supported version is 0.6.2
+    Q_STATIC_ASSERT_X(VVITConverter::MeasurementMinVer < FormatVersion(0, 6, 2), "Time to refactor the code.");
+
+    SetVersion(QStringLiteral("0.6.2"));
+    Save();
+}
