@@ -130,7 +130,7 @@ QmuParserBase::~QmuParserBase()
  * Implemented by calling Assign(a_Parser). Self assignement is suppressed.
  * @param a_Parser Object to copy to this.
  * @return *this
- * @throw nothrow
+ * @throw None No exceptions are thrown.
  */
 auto QmuParserBase::operator=(const QmuParserBase &a_Parser) -> QmuParserBase &
 {
@@ -205,7 +205,7 @@ void QmuParserBase::ResetLocale()
  * @brief Reset parser to string parsing mode and clear internal buffers.
  *
  * Clear bytecode, reset the token reader.
- * @throw nothrow
+ * @throw None No exceptions are thrown.
  */
 void QmuParserBase::ReInit() const
 {
@@ -429,8 +429,8 @@ void QmuParserBase::CheckName(const QString &a_sName, const QString &a_szCharSet
 void QmuParserBase::SetExpr(const QString &a_sExpr)
 {
     // Check locale compatibility
-    std::locale const loc;
-    if (m_pTokenReader->GetArgSep() == QChar(std::use_facet<std::numpunct<char_type>>(loc).decimal_point()))
+    if (std::locale const loc;
+        m_pTokenReader->GetArgSep() == QChar(std::use_facet<std::numpunct<char_type>>(loc).decimal_point()))
     {
         Error(ecLOCALE);
     }
@@ -1136,6 +1136,8 @@ auto QmuParserBase::ParseCmdCodeBulk(int nOffset, int nThreadID) const -> qreal
                 QT_WARNING_PUSH
                 QT_WARNING_DISABLE_GCC("-Wcast-function-type")
                 QT_WARNING_DISABLE_CLANG("-Wundefined-reinterpret-cast")
+                QT_WARNING_DISABLE_CLANG("-Wunknown-warning-option")
+                QT_WARNING_DISABLE_CLANG("-Wcast-function-type-mismatch") // Since Clang 19
                 QT_WARNING_DISABLE_MSVC(4191)
 
                 // switch according to argument count
@@ -1644,7 +1646,7 @@ Q_NORETURN void QmuParserBase::Error(EErrorCodes a_iErrc, qmusizetype a_iPos, co
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief Clear all user defined variables.
- * @throw nothrow
+ * @throw None No exceptions are thrown.
  *
  * Resets the parser to string parsing mode by calling #ReInit.
  */
@@ -1658,7 +1660,7 @@ void QmuParserBase::ClearVar()
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief Remove a variable from internal storage.
- * @throw nothrow
+ * @throw None No exceptions are thrown.
  *
  * Removes a variable if it exists. If the Variable does not exist nothing will be done.
  */
@@ -1676,7 +1678,7 @@ void QmuParserBase::RemoveVar(const QString &a_strVarName)
 /**
  * @brief Clear all functions.
  * @post Resets the parser to string parsing mode.
- * @throw nothrow
+ * @throw None No exceptions are thrown.
  */
 // cppcheck-suppress unusedFunction
 void QmuParserBase::ClearFun()
@@ -1691,7 +1693,7 @@ void QmuParserBase::ClearFun()
  *
  * Both numeric and string constants will be removed from the internal storage.
  * @post Resets the parser to string parsing mode.
- * @throw nothrow
+ * @throw None No exceptions are thrown.
  */
 void QmuParserBase::ClearConst()
 {
@@ -1704,7 +1706,7 @@ void QmuParserBase::ClearConst()
 /**
  * @brief Clear all user defined postfix operators.
  * @post Resets the parser to string parsing mode.
- * @throw nothrow
+ * @throw None No exceptions are thrown.
  */
 void QmuParserBase::ClearPostfixOprt()
 {
@@ -1716,7 +1718,7 @@ void QmuParserBase::ClearPostfixOprt()
 /**
  * @brief Clear all user defined binary operators.
  * @post Resets the parser to string parsing mode.
- * @throw nothrow
+ * @throw None No exceptions are thrown.
  */
 // cppcheck-suppress unusedFunction
 void QmuParserBase::ClearOprt()
@@ -1729,7 +1731,7 @@ void QmuParserBase::ClearOprt()
 /**
  * @brief Clear the user defined Prefix operators.
  * @post Resets the parser to string parser mode.
- * @throw nothrow
+ * @throw None No exceptions are thrown.
  */
 // cppcheck-suppress unusedFunction
 void QmuParserBase::ClearInfixOprt()
@@ -1742,7 +1744,7 @@ void QmuParserBase::ClearInfixOprt()
 /**
  * @brief Enable or disable the formula optimization feature.
  * @post Resets the parser to string parser mode.
- * @throw nothrow
+ * @throw None No exceptions are thrown.
  */
 void QmuParserBase::EnableOptimizer(bool a_bIsOn)
 {
@@ -1768,7 +1770,7 @@ void QmuParserBase::EnableDebugDump(bool bDumpCmd, bool bDumpStack)
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief Enable or disable the built in binary operators.
- * @throw nothrow
+ * @throw None No exceptions are thrown.
  * @sa m_bBuiltInOp, ReInit()
  *
  * If you disable the built in binary operators there will be no binary operators defined. Thus you must add them
@@ -1827,8 +1829,7 @@ void QmuParserBase::StackDump(const QStack<token_type> &a_stVal, const QStack<to
 
     while (stOprt.empty() == false)
     {
-        const token_type &topToken = stOprt.top();
-        if (topToken.GetCode() <= cmASSIGN)
+        if (const token_type &topToken = stOprt.top(); topToken.GetCode() <= cmASSIGN)
         {
             qDebug() << "OPRT_INTRNL \"" << QmuParserBase::GetOprtDef()[topToken.GetCode()] << "\" \n";
         }
@@ -1910,8 +1911,6 @@ void QmuParserBase::Eval(qreal *results, int nBulkSize) const
 {
     CreateRPN();
 
-    int i = 0;
-
 #ifdef QMUP_USE_OPENMP
 // #define DEBUG_OMP_STUFF
 #ifdef DEBUG_OMP_STUFF
@@ -1924,7 +1923,7 @@ void QmuParserBase::Eval(qreal *results, int nBulkSize) const
     omp_set_num_threads(nMaxThreads);
 
 #pragma omp parallel for schedule(static, nBulkSize / nMaxThreads) private(nThreadID)
-    for (i = 0; i < nBulkSize; ++i)
+    for (int i = 0; i < nBulkSize; ++i)
     {
         int nThreadID = omp_get_thread_num();
         results[i] = ParseCmdCodeBulk(i, nThreadID);
@@ -1953,7 +1952,7 @@ void QmuParserBase::Eval(qreal *results, int nBulkSize) const
 #endif
 
 #else
-    for (i = 0; i < nBulkSize; ++i)
+    for (int i = 0; i < nBulkSize; ++i)
     {
         results[i] = ParseCmdCodeBulk(i, 0);
     }
