@@ -25,47 +25,44 @@
 #ifndef QMUPARSERCALLBACK_P_H
 #define QMUPARSERCALLBACK_P_H
 
-#include <QSharedData>
+#include "qmudef.h"
 #include "qmuparserdef.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/diagnostic.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/defglobal.h"
+#include <QSharedData>
+
+namespace qmu
+{
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Weffc++")
 QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")
 
-namespace qmu
-{
-
 class QmuParserCallbackData : public QSharedData
 {
 public:
     QmuParserCallbackData();
-    QmuParserCallbackData(fun_type0  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(fun_type1  a_pFun, bool a_bAllowOpti, int a_iPrec = -1, ECmdCode a_iCode=cmFUNC);
-    QmuParserCallbackData(fun_type2  a_pFun, bool a_bAllowOpti, int a_iPrec, EOprtAssociativity a_eOprtAsct);
-    QmuParserCallbackData(fun_type2  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(fun_type3  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(fun_type4  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(fun_type5  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(fun_type6  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(fun_type7  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(fun_type8  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(fun_type9  a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(fun_type0 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(fun_type1 a_pFun, bool a_bAllowOpti, int a_iPrec = -1, ECmdCode a_iCode = cmFUNC);
+    QmuParserCallbackData(fun_type2 a_pFun, bool a_bAllowOpti, int a_iPrec, EOprtAssociativity a_eOprtAsct);
+    QmuParserCallbackData(fun_type2 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(fun_type3 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(fun_type4 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(fun_type5 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(fun_type6 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(fun_type7 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(fun_type8 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(fun_type9 a_pFun, bool a_bAllowOpti);
     QmuParserCallbackData(fun_type10 a_pFun, bool a_bAllowOpti);
 
-    QmuParserCallbackData(bulkfun_type0  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(bulkfun_type1  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(bulkfun_type2  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(bulkfun_type3  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(bulkfun_type4  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(bulkfun_type5  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(bulkfun_type6  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(bulkfun_type7  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(bulkfun_type8  a_pFun, bool a_bAllowOpti);
-    QmuParserCallbackData(bulkfun_type9  a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(bulkfun_type0 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(bulkfun_type1 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(bulkfun_type2 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(bulkfun_type3 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(bulkfun_type4 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(bulkfun_type5 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(bulkfun_type6 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(bulkfun_type7 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(bulkfun_type8 a_pFun, bool a_bAllowOpti);
+    QmuParserCallbackData(bulkfun_type9 a_pFun, bool a_bAllowOpti);
     QmuParserCallbackData(bulkfun_type10 a_pFun, bool a_bAllowOpti);
 
     QmuParserCallbackData(multfun_type a_pFun, bool a_bAllowOpti);
@@ -73,9 +70,9 @@ public:
     QmuParserCallbackData(strfun_type2 a_pFun, bool a_bAllowOpti);
     QmuParserCallbackData(strfun_type3 a_pFun, bool a_bAllowOpti);
     QmuParserCallbackData(const QmuParserCallbackData &a_Fun);
-    virtual ~QmuParserCallbackData();
+    ~QmuParserCallbackData() = default;
 
-    void *m_pFun;                   ///< Pointer to the callback function, casted to void
+    void *m_pFun; ///< Pointer to the callback function, casted to void
 
     /**
      * @brief Number of numeric function arguments
@@ -83,16 +80,18 @@ public:
      * This number is negative for functions with variable number of arguments. in this cases
      * they represent the actual number of arguments found.
      */
-    int   m_iArgc;
-    int   m_iPri;                   ///< Valid only for binary and infix operators; Operator precedence.
+    int m_iArgc;
+    int m_iPri;                     ///< Valid only for binary and infix operators; Operator precedence.
     EOprtAssociativity m_eOprtAsct; ///< Operator associativity; Valid only for binary operators
-    ECmdCode  m_iCode;
+    ECmdCode m_iCode;
     ETypeCode m_iType;
-    bool  m_bAllowOpti;             ///< Flag indication optimizeability
+    bool m_bAllowOpti; ///< Flag indication optimizeability
 
 private:
-    Q_DISABLE_ASSIGN(QmuParserCallbackData)
+    Q_DISABLE_ASSIGN_MOVE(QmuParserCallbackData) // NOLINT
 };
 
-}
+QT_WARNING_POP
+
+} // namespace qmu
 #endif // QMUPARSERCALLBACK_P_H
