@@ -33,7 +33,7 @@
 #include <QtGlobal>
 
 // Header <ciso646> is removed in C++20.
-#if __cplusplus <= 201703L
+#if defined(Q_CC_MSVC) && __cplusplus <= 201703L
 #include <ciso646> // and, not, or
 #endif
 
@@ -57,7 +57,8 @@ enum class DXFApparelCompatibility : qint8
     RPCADV08 = 1, // Richpeace CAD V8
     RPCADV09 = 2, // Richpeace CAD V9
     RPCADV10 = 3, // Richpeace CAD V10
-    COUNT         /*Use only for validation*/
+    CLO3D = 4,    // Clo3D
+    COUNT = 5     // Use only for validation
 };
 
 // Helps mark end of string. See VDxfEngine::drawTextItem for more details
