@@ -94,7 +94,7 @@ public:
 
 protected:
     virtual auto parseCode(int code, const std::unique_ptr<dxfReader> &reader) -> bool;
-    void reset()
+    virtual void reset()
     {
         flags = 0;
         for (auto it = extData.begin(); it != extData.end(); ++it)
@@ -198,10 +198,10 @@ public:
         dimlwd(),
         dimlwe()
     {
-        reset();
+        DRW_Dimstyle::reset();
     }
 
-    void reset()
+    void reset() override
     {
         tType = DRW::DIMSTYLE;
         dimasz = dimtxt = dimcen = 2.5;
@@ -326,10 +326,10 @@ public:
         path(),
         pathIdx()
     {
-        reset();
+        DRW_LType::reset();
     }
 
-    void reset()
+    void reset() override
     {
         tType = DRW::LTYPE;
         desc = "";
@@ -374,10 +374,10 @@ public:
         handlePlotS(),
         handleMaterialS()
     {
-        reset();
+        DRW_Layer::reset();
     }
 
-    void reset()
+    void reset() override
     {
         tType = DRW::LAYER;
         lineType = "CONTINUOUS";
@@ -388,10 +388,6 @@ public:
         DRW_TableEntry::reset();
     }
 
-protected:
-    auto parseCode(int code, const std::unique_ptr<dxfReader> &reader) -> bool override;
-
-public:
     UTF8STRING lineType;            /*!< line type, code 6 */
     int color;                      /*!< layer color, code 62 */
     int color24;                    /*!< 24-bit color, code 420 */
@@ -399,6 +395,9 @@ public:
     DRW_LW_Conv::lineWidth lWeight; /*!< layer lineweight, code 370 */
     std::string handlePlotS;        /*!< Hard-pointer ID/handle of plotstyle, code 390 */
     std::string handleMaterialS;    /*!< Hard-pointer ID/handle of materialstyle, code 347 */
+
+private:
+    auto parseCode(int code, const std::unique_ptr<dxfReader> &reader) -> bool override;
 };
 
 //! Class to handle block record entries
@@ -414,10 +413,10 @@ public:
     DRW_Block_Record()
       : insUnits()
     {
-        reset();
+        DRW_Block_Record::reset();
     }
 
-    void reset()
+    void reset() override
     {
         tType = DRW::BLOCK_RECORD;
         flags = 0;
@@ -432,6 +431,80 @@ public:
     int insUnits; /*!< block insertion units, code 70 of block_record*/
 };
 
+class DRW_View : public DRW_TableEntry
+{
+    SETOBJFRIENDS
+
+public:
+    DRW_View() { DRW_View::reset(); }
+
+    void reset() override
+    {
+        size.x = size.y = size.z = 0.0;
+        center.x = center.y = center.z = 0.0;
+        viewDirectionFromTarget.x = viewDirectionFromTarget.y = viewDirectionFromTarget.z = 0.0;
+        targetPoint.x = targetPoint.y = targetPoint.z = 0.0;
+        lensLen = 0.0;
+        frontClippingPlaneOffset = 0.0;
+        backClippingPlaneOffset = 0.0;
+        twistAngle = 0.0;
+        viewMode = 0;
+        renderMode = 0;
+        hasUCS = false;
+        cameraPlottable = false;
+
+        ucsOrigin.x = ucsOrigin.y = ucsOrigin.z = 0.0;
+        ucsXAxis.x = ucsXAxis.y = ucsXAxis.z = 0.0;
+        ucsYAxis.x = ucsYAxis.y = ucsYAxis.z = 0.0;
+        ucsOrthoType = 1;
+        ucsElevation = 0.0;
+        namedUCS_ID = 0;
+        baseUCS_ID = 0;
+        DRW_TableEntry::reset();
+    }
+
+protected:
+    bool parseCode(int code, const std::unique_ptr<dxfReader> &reader) override;
+
+public:
+    DRW_Coord size{};                    // view width/height in DCS, codes 40 & 41
+    DRW_Coord center{};                  // View center point (in DCS) code 10 & 20
+    DRW_Coord viewDirectionFromTarget{}; //View direction from target (in WCS), code 11, 21, 31
+    DRW_Coord targetPoint{};             //Target point (in WCS), code 12, 22, 32
+    double lensLen{0};                   // Lens length, code 42
+    double frontClippingPlaneOffset{0};  // Front clipping plane (offset from target point), code 43
+    double backClippingPlaneOffset{0};   // Back clipping plane (offset from target point), code 44
+    double twistAngle{0};                // Twist angle, code 50
+    int viewMode{0};                     //(?? type) View mode (see VIEWMODE system variable), code 71
+    unsigned int renderMode{0};          // Render mode: code 281.
+    // 0 = 2D Optimized (classic 2D)
+    //    1 = Wireframe
+    //    2 = Hidden line
+    //    3 = Flat shaded
+    //    4 = Gouraud shaded
+    //    5 = Flat shaded with wireframe
+    //    6 = Gouraud shaded with wireframe
+    //    All rendering modes other than 2D Optimized engage the new 3D graphics pipeline. These values directly
+    // correspond to the SHADEMODE command and the AcDbAbstractViewTableRecord::RenderMode enum
+
+    bool hasUCS{false};          // 72, 1 if there is a UCS associated to this view; 0 otherwise
+    bool cameraPlottable{false}; // 73, 1 if the camera is plottable
+
+    DRW_Coord ucsOrigin{}; // UCS origin, 110, 120, 130
+    DRW_Coord ucsXAxis{};  // UCS X-axis, 111, 121, 131
+    DRW_Coord ucsYAxis{};  // UCS Y-axis, 112, 122, 132
+    // Orthographic type of UCS, 0 = UCS is not orthographic, 1 = Top; 2 = Bottom, 3 = Front; 4 = Back, 5 = Left;
+    // 6 = Right, code 79
+    int ucsOrthoType{1};
+    double ucsElevation{0}; // UCS elevation, code 146
+    /*dwgHandle*/
+    // ID/handle of AcDbUCSTableRecord if UCS is a named UCS. If not present, then UCS is unnamed, code 345
+    duint32 namedUCS_ID{0};
+    // ID/handle of AcDbUCSTableRecord of base UCS if UCS is orthographic, If not present and 79 code is non-zero,
+    // then base UCS is taken to be WORLD, code 346
+    duint32 baseUCS_ID{0};
+};
+
 //! Class to handle text style entries
 /*!
  *  Class to handle text style symbol table entries
@@ -452,10 +525,10 @@ public:
         bigFont(),
         fontFamily()
     {
-        reset();
+        DRW_Textstyle::reset();
     }
 
-    void reset()
+    void reset() override
     {
         tType = DRW::STYLE;
         height = oblique = 0.0;
@@ -516,10 +589,10 @@ public:
         snapIsopair(),
         gridBehavior()
     {
-        reset();
+        DRW_Vport::reset();
     }
 
-    void reset()
+    void reset() override
     {
         tType = DRW::VPORT;
         UpperRight.x = UpperRight.y = 1.0;
@@ -597,10 +670,10 @@ public:
         resolution(),
         reactors()
     {
-        reset();
+        DRW_ImageDef::reset();
     }
 
-    void reset()
+    void reset() override
     {
         tType = DRW::IMAGEDEF;
         imgVersion = 0;
@@ -634,9 +707,9 @@ class DRW_PlotSettings : public DRW_TableEntry
     SETOBJFRIENDS
 
 public:
-    DRW_PlotSettings() { reset(); }
+    DRW_PlotSettings() { DRW_PlotSettings::reset(); }
 
-    void reset()
+    void reset() override
     {
         tType = DRW::PLOTSETTINGS;
         marginLeft = 0.0;
@@ -667,13 +740,14 @@ class DRW_AppId final : public DRW_TableEntry
     SETOBJFRIENDS
 
 public:
-    DRW_AppId() { reset(); }
+    DRW_AppId() { DRW_AppId::reset(); }
 
-    void reset()
+    void reset() override
     {
         tType = DRW::APPID;
         flags = 0;
         name = "";
+        DRW_TableEntry::reset();
     }
 };
 
