@@ -5,19 +5,19 @@
 #include "drw_cptable949.h"
 #include "drw_cptable950.h"
 #include "drw_cptables.h"
-#include <QDebug>
-#include <QSet>
-#include <QString>
 #include <algorithm>
 #include <cstddef>
 #include <cstring>
 #include <iomanip>
 #include <memory>
 #include <sstream>
+#include <QDebug>
+#include <QSet>
+#include <QString>
 
 DRW_TextCodec::DRW_TextCodec()
   : version(DRW::AC1021),
-    conv(new DRW_Converter())
+    conv(std::make_unique<DRW_Converter>())
 {
 }
 
@@ -83,7 +83,7 @@ void DRW_TextCodec::setVersion(const std::string &v, bool dxfFormat)
     version = DRW::UNKNOWNV;
     for (auto [first, second] : DRW::dwgVersionStrings)
     {
-        if (std::strcmp(v.c_str(), first) == 0)
+        if (std::strncmp(v.c_str(), first, 32) == 0)
         {
             version = second;
             setVersion(second, dxfFormat);
@@ -234,8 +234,7 @@ auto DRW_Converter::toUtf8(const std::string &s) -> std::string
 {
     std::string result;
     unsigned int j = 0;
-    unsigned int i = 0;
-    for (i = 0; i < s.length(); i++)
+    for (unsigned int i = 0; i < s.length(); i++)
     {
         auto c = static_cast<unsigned char>(s.at(i));
         if (c < 0x80)
@@ -310,8 +309,7 @@ auto DRW_ConvTable::toUtf8(const std::string &s) -> std::string
     std::string res;
     for (auto it = s.begin(); it < s.end(); ++it)
     {
-        auto c = static_cast<unsigned char>(*it);
-        if (c < 0x80)
+        if (auto c = static_cast<unsigned char>(*it); c < 0x80)
         {
             // check for \U+ encoded text
             if (c == '\\')
@@ -402,31 +400,39 @@ auto DRW_Converter::encodeNum(int c) -> std::string
 }
 
 /** 's' is a string with at least 4 bytes length
-** returned 'b' is byte length of encoded char: 2,3 or 4
+** returned 'b' is byte length of encoded char: 2, 3 or 4
 **/
 auto DRW_Converter::decodeNum(const std::string &s, unsigned int *b) -> int
 {
     int code = 0;
-    auto c = static_cast<unsigned char>(s.at(0));
-    if ((c & 0xE0) == 0xC0)
+
+    auto to_int = [](std::byte byte) { return std::to_integer<unsigned char>(byte); };
+
+    if (const auto c = static_cast<std::byte>(s.at(0)); (c & std::byte{0xE0}) == std::byte{0xC0})
     { // 2 bytes
-        code = (c & 0x1F) << 6;
-        code = (s.at(1) & 0x3F) | code;
+        const auto c1 = static_cast<std::byte>(s.at(1));
+        code = to_int(c & std::byte{0x1F}) << 6;
+        code = to_int(c1 & std::byte{0x3F}) | code;
         *b = 2;
     }
-    else if ((c & 0xF0) == 0xE0)
+    else if ((c & std::byte{0xF0}) == std::byte{0xE0})
     { // 3 bytes
-        code = (c & 0x0F) << 12;
-        code = ((s.at(1) & 0x3F) << 6) | code;
-        code = (s.at(2) & 0x3F) | code;
+        const auto c1 = static_cast<std::byte>(s.at(1));
+        const auto c2 = static_cast<std::byte>(s.at(2));
+        code = to_int(c & std::byte{0x0F}) << 12;
+        code = (to_int(c1 & std::byte{0x3F}) << 6) | code;
+        code = to_int(c2 & std::byte{0x3F}) | code;
         *b = 3;
     }
-    else if ((c & 0xF8) == 0xF0)
+    else if ((c & std::byte{0xF8}) == std::byte{0xF0})
     { // 4 bytes
-        code = (c & 0x07) << 18;
-        code = ((s.at(1) & 0x3F) << 12) | code;
-        code = ((s.at(2) & 0x3F) << 6) | code;
-        code = (s.at(3) & 0x3F) | code;
+        const auto c1 = static_cast<std::byte>(s.at(1));
+        const auto c2 = static_cast<std::byte>(s.at(2));
+        const auto c3 = static_cast<std::byte>(s.at(3));
+        code = to_int(c & std::byte{0x07}) << 18;
+        code = (to_int(c1 & std::byte{0x3F}) << 12) | code;
+        code = (to_int(c2 & std::byte{0x3F}) << 6) | code;
+        code = to_int(c3 & std::byte{0x3F}) | code;
         *b = 4;
     }
 
@@ -483,8 +489,7 @@ template <size_t DoubleTableSize> auto DRW_ConvDBCSTable<DoubleTableSize>::toUtf
     for (auto it = s.begin(); it < s.end(); ++it)
     {
         bool notFound = true;
-        auto c = static_cast<unsigned char>(*it);
-        if (c < 0x80)
+        if (auto c = static_cast<unsigned char>(*it); c < 0x80)
         {
             notFound = false;
             // check for \U+ encoded text
@@ -594,8 +599,7 @@ auto DRW_Conv932Table::toUtf8(const std::string &s) -> std::string
     for (auto it = s.begin(); it < s.end(); ++it)
     {
         bool notFound = true;
-        auto c = static_cast<unsigned char>(*it);
-        if (c < 0x80)
+        if (auto c = static_cast<unsigned char>(*it); c < 0x80)
         {
             notFound = false;
             // check for \U+ encoded text
