@@ -54,13 +54,28 @@ auto VAbstartMeasurementDimension::IsValid() -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VAbstartMeasurementDimension::RangeMin() const -> int
+auto VAbstartMeasurementDimension::Decimals() const -> int
+{
+    if (m_units == Unit::Mm)
+    {
+        return 2;
+    }
+    else if (m_units == Unit::Inch)
+    {
+        return 5;
+    }
+
+    return 3;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VAbstartMeasurementDimension::RangeMin() const -> qreal
 {
     if (m_measurement)
     {
-        const int rangeMinCm = 20;
-        const int rangeMinMm = 200;
-        const int rangeMinInch = 8;
+        const qreal rangeMinCm = 1;
+        const qreal rangeMinMm = 10;
+        const qreal rangeMinInch = 2.54;
 
         switch (Units())
         {
@@ -79,13 +94,13 @@ auto VAbstartMeasurementDimension::RangeMin() const -> int
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VAbstartMeasurementDimension::RangeMax() const -> int
+auto VAbstartMeasurementDimension::RangeMax() const -> qreal
 {
     if (m_measurement)
     {
-        const int rangeMaxCm = 272;
-        const int rangeMaxMm = 2720;
-        const int rangeMaxInch = 107;
+        const qreal rangeMaxCm = 272;
+        const qreal rangeMaxMm = 2720;
+        const qreal rangeMaxInch = 107.09;
 
         switch (Units())
         {
@@ -100,7 +115,7 @@ auto VAbstartMeasurementDimension::RangeMax() const -> int
         }
     }
 
-    return 100;
+    return 272;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -112,32 +127,37 @@ auto VAbstartMeasurementDimension::Name() const -> QString
 //---------------------------------------------------------------------------------------------------------------------
 auto VAbstartMeasurementDimension::ValidSteps() const -> QVector<qreal>
 {
-    const qreal stepBarrier = 50;
-    const qreal s = 0.1;
-
     QVector<qreal> steps;
-    steps.reserve(qRound((stepBarrier - s) * 2 - 1));
 
-    const qreal diff = m_maxValue - m_minValue;
-    if (qFuzzyIsNull(diff))
+    if (const qreal diff = m_maxValue - m_minValue; qFuzzyIsNull(diff))
     {
         steps.append(0); // only one possible value
     }
     else if (diff > 0)
     {
-        qreal candidate = 1;
-        int i = 1;
-        do
+        qreal step = 0.01;
+        if (m_units == Unit::Mm)
         {
-            const qreal step = (m_units == Unit::Mm ? candidate * 10 : candidate);
-            qreal intpart;
-            if (qFuzzyIsNull(std::modf(diff / step, &intpart)))
+            step = 0.1;
+        }
+        else if (m_units == Unit::Inch)
+        {
+            step = 0.03937;
+        }
+
+        const int stepsCount = qRound(diff / step);
+        steps.reserve(stepsCount);
+
+        for (int i = 1; i <= stepsCount; ++i)
+        {
+            const qreal currentStep = i * step;
+
+            qreal intpart = NAN;
+            if (qFuzzyIsNull(std::modf(diff / currentStep, &intpart)))
             {
-                steps.append(step);
+                steps.append(currentStep);
             }
-            candidate = 1 + s * i;
-            ++i;
-        } while (candidate < stepBarrier);
+        }
     }
 
     return steps;
