@@ -28,6 +28,7 @@
 #include "vganalytics.h"
 #include "vganalyticsworker.h"
 
+#include <vcsRepoState.h>
 #include <QDataStream>
 #include <QDebug>
 #include <QGuiApplication>
@@ -60,11 +61,6 @@
 #include "../vmisc/compatibility.h"
 #endif
 
-#if !defined(BUILD_REVISION) && defined(QBS_BUILD)
-#include <vcsRepoState.h>
-#define BUILD_REVISION VCS_REPO_STATE_REVISION
-#endif
-
 #include "../vmisc/vcommonsettings.h"
 #include "def.h"
 
@@ -116,8 +112,7 @@ auto GetSystemMemorySize() -> qint64
 //---------------------------------------------------------------------------------------------------------------------
 auto GetSystemMemorySizeGB() -> double
 {
-    qint64 const totalMemoryBytes = GetSystemMemorySize();
-    if (totalMemoryBytes != -1)
+    if (qint64 const totalMemoryBytes = GetSystemMemorySize(); totalMemoryBytes != -1)
     {
         return static_cast<double>(totalMemoryBytes) / (1024 * 1024 * 1024); // Convert bytes to gigabytes
     }
@@ -159,7 +154,7 @@ auto VGAnalytics::Instance() -> VGAnalytics *
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VGAnalytics::Init(VCommonSettings *settings)
+void VGAnalytics::Init(const VCommonSettings *settings)
 {
     SCASSERT(settings != nullptr)
 
@@ -174,7 +169,7 @@ void VGAnalytics::Init(VCommonSettings *settings)
     statistic->SetGUILanguage(settings->GetLocale());
     statistic->SetMeasurementId(GA_MEASUREMENT_ID);
     statistic->SetApiSecret(GA_API_SECRET);
-    statistic->SetRepoRevision(QLatin1String(BUILD_REVISION));
+    statistic->SetRepoRevision(QLatin1String(VCS_REPO_STATE_REVISION));
     statistic->Enable(settings->IsCollectStatistic());
 }
 
