@@ -31,28 +31,28 @@
 #include <QJsonObject>
 #include <QLineF>
 
+#include "../vmisc/vmath.h"
 #include "vabstractcurve.h"
 #include "vspline_p.h"
-#include "../vmisc/vmath.h"
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief VSpline default constructor
  */
 VSpline::VSpline()
-    : VAbstractCubicBezier(GOType::Spline),
-      d(new VSplineData)
-{}
+  : VAbstractCubicBezier(GOType::Spline),
+    d(new VSplineData)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-/**
- * @brief VSpline constructor.
- * @param spline spline from which the copy.
- */
-VSpline::VSpline(const VSpline &spline) // NOLINT(modernize-use-equals-default)
-    : VAbstractCubicBezier(spline),
-      d(spline.d)
-{}
+COPY_CONSTRUCTOR_IMPL_2(VSpline, VAbstractCubicBezier)
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -65,10 +65,10 @@ VSpline::VSpline(const VSpline &spline) // NOLINT(modernize-use-equals-default)
  * @param kAsm1 coefficient of length first control line.
  * @param kAsm2 coefficient of length second control line.
  */
-VSpline::VSpline (const VPointF &p1, const VPointF &p4, qreal angle1, qreal angle2, qreal kAsm1, qreal kAsm2,
-                  qreal kCurve, quint32 idObject, Draw mode)
-    : VAbstractCubicBezier(GOType::Spline, idObject, mode),
-      d(new VSplineData(p1, p4, angle1, angle2, kAsm1, kAsm2, kCurve))
+VSpline::VSpline(const VPointF &p1, const VPointF &p4, qreal angle1, qreal angle2, qreal kAsm1, qreal kAsm2,
+                 qreal kCurve, quint32 idObject, Draw mode)
+  : VAbstractCubicBezier(GOType::Spline, idObject, mode),
+    d(new VSplineData(p1, p4, angle1, angle2, kAsm1, kAsm2, kCurve))
 {
     CreateName();
 }
@@ -81,14 +81,14 @@ VSpline::VSpline (const VPointF &p1, const VPointF &p4, qreal angle1, qreal angl
  * @param p3 second control point.
  * @param p4 second point spline.
  */
-VSpline::VSpline (const VPointF &p1, const QPointF &p2, const QPointF &p3, const VPointF &p4, quint32 idObject,
-                  Draw mode)
-    :VAbstractCubicBezier(GOType::Spline, idObject, mode), d(new VSplineData(p1, p2, p3, p4))
+VSpline::VSpline(const VPointF &p1, const QPointF &p2, const QPointF &p3, const VPointF &p4, quint32 idObject,
+                 Draw mode)
+  : VAbstractCubicBezier(GOType::Spline, idObject, mode),
+    d(new VSplineData(p1, p2, p3, p4))
 {
     CreateName();
 }
 
-
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief VSpline constructor
@@ -106,9 +106,9 @@ VSpline::VSpline (const VPointF &p1, const QPointF &p2, const QPointF &p3, const
 VSpline::VSpline(const VPointF &p1, const VPointF &p4, qreal angle1, const QString &angle1Formula, qreal angle2,
                  const QString &angle2Formula, qreal c1Length, const QString &c1LengthFormula, qreal c2Length,
                  const QString &c2LengthFormula, quint32 idObject, Draw mode)
-    : VAbstractCubicBezier(GOType::Spline, idObject, mode),
-      d(new VSplineData(p1, p4, angle1, angle1Formula, angle2, angle2Formula, c1Length, c1LengthFormula, c2Length,
-                        c2LengthFormula))
+  : VAbstractCubicBezier(GOType::Spline, idObject, mode),
+    d(new VSplineData(p1, p4, angle1, angle1Formula, angle2, angle2Formula, c1Length, c1LengthFormula, c2Length,
+                      c2LengthFormula))
 {
     CreateName();
 }
@@ -183,18 +183,17 @@ auto VSpline::Move(qreal length, qreal angle, const QString &prefix) const -> VS
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VSpline::~VSpline() // NOLINT(hicpp-use-equals-default, modernize-use-equals-default)
-{}
+VSpline::~VSpline() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief GetLength return length of spline.
  * @return length.
  */
-auto VSpline::GetLength () const -> qreal
+auto VSpline::GetLength() const -> qreal
 {
-    return LengthBezier ( static_cast<QPointF>(GetP1()), static_cast<QPointF>(GetP2()), static_cast<QPointF>(GetP3()),
-                          static_cast<QPointF>(GetP4()), GetApproximationScale());
+    return LengthBezier(static_cast<QPointF>(GetP1()), static_cast<QPointF>(GetP2()), static_cast<QPointF>(GetP3()),
+                        static_cast<QPointF>(GetP4()), GetApproximationScale());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -219,7 +218,7 @@ auto VSpline::CutSpline(qreal length, VSpline &spl1, VSpline &spl2, const QStrin
  * @brief GetPoints return list with spline points.
  * @return list of points.
  */
-auto VSpline::GetPoints () const -> QVector<QPointF>
+auto VSpline::GetPoints() const -> QVector<QPointF>
 {
     return GetCubicBezierPoints(static_cast<QPointF>(GetP1()), static_cast<QPointF>(GetP2()),
                                 static_cast<QPointF>(GetP3()), static_cast<QPointF>(GetP4()), GetApproximationScale());
@@ -238,27 +237,27 @@ auto VSpline::GetPoints () const -> QVector<QPointF>
  * @return list with spline points.
  */
 // cppcheck-suppress unusedFunction
-auto VSpline::SplinePoints(const QPointF &p1, const QPointF &p4, qreal angle1, qreal angle2, qreal kAsm1,
-                           qreal kAsm2, qreal kCurve, qreal approximationScale) -> QVector<QPointF>
+auto VSpline::SplinePoints(const QPointF &p1, const QPointF &p4, qreal angle1, qreal angle2, qreal kAsm1, qreal kAsm2,
+                           qreal kCurve, qreal approximationScale) -> QVector<QPointF>
 {
     QLineF p1pX(p1.x(), p1.y(), p1.x() + 100, p1.y());
-    p1pX.setAngle( angle1 );
+    p1pX.setAngle(angle1);
     qreal L = 0, radius = 0, angle = 90;
     radius = QLineF(QPointF(p1.x(), p4.y()), p4).length();
-    L = kCurve * radius * 4 / 3 * tan( angle * M_PI_4 / 180.0 );
+    L = kCurve * radius * 4 / 3 * tan(angle * M_PI_4 / 180.0);
     QLineF p1p2(p1.x(), p1.y(), p1.x() + L * kAsm1, p1.y());
     p1p2.setAngle(angle1);
     QLineF p4p3(p4.x(), p4.y(), p4.x() + L * kAsm2, p4.y());
     p4p3.setAngle(angle2);
-    QPointF p2 = p1p2.p2();
-    QPointF p3 = p4p3.p2();
+    QPointF const p2 = p1p2.p2();
+    QPointF const p3 = p4p3.p2();
     return GetCubicBezierPoints(p1, p2, p3, p4, approximationScale);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VSpline::operator =(const VSpline &spline) -> VSpline &
+auto VSpline::operator=(const VSpline &spline) -> VSpline &
 {
-    if ( &spline == this )
+    if (&spline == this)
     {
         return *this;
     }
@@ -267,21 +266,20 @@ auto VSpline::operator =(const VSpline &spline) -> VSpline &
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VSpline::VSpline(VSpline &&spline) Q_DECL_NOTHROW
-    : VAbstractCubicBezier(std::move(spline)),
-      d(std::move(spline.d))
-{}
+VSpline::VSpline(VSpline &&spline) noexcept
+  : VAbstractCubicBezier(std::move(spline)),
+    d(std::move(spline.d)) // NOLINT(bugprone-use-after-move)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VSpline::operator=(VSpline &&spline) Q_DECL_NOTHROW -> VSpline &
+auto VSpline::operator=(VSpline &&spline) noexcept -> VSpline &
 {
     VAbstractCubicBezier::operator=(spline);
     std::swap(d, spline.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -431,7 +429,7 @@ void VSpline::SetC2Length(qreal length, const QString &formula)
 auto VSpline::GetKasm1() const -> qreal
 {
     return QLineF(static_cast<QPointF>(d->p1), static_cast<QPointF>(GetP2())).length() /
-            VSplineData::GetL(static_cast<QPointF>(d->p1), static_cast<QPointF>(d->p4), d->kCurve);
+           VSplineData::GetL(static_cast<QPointF>(d->p1), static_cast<QPointF>(d->p4), d->kCurve);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -442,7 +440,7 @@ auto VSpline::GetKasm1() const -> qreal
 auto VSpline::GetKasm2() const -> qreal
 {
     return QLineF(static_cast<QPointF>(d->p4), static_cast<QPointF>(GetP3())).length() /
-            VSplineData::GetL(static_cast<QPointF>(d->p1), static_cast<QPointF>(d->p4), d->kCurve);
+           VSplineData::GetL(static_cast<QPointF>(d->p1), static_cast<QPointF>(d->p4), d->kCurve);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -458,11 +456,11 @@ auto VSpline::GetKcurve() const -> qreal
 //---------------------------------------------------------------------------------------------------------------------
 auto VSpline::Sign(long double ld) -> int
 {
-    if (qAbs(ld)<0.00000000001)
+    if (qAbs(ld) < 0.00000000001)
     {
         return 0;
     }
-    return (ld>0) ? 1 : -1;
+    return (ld > 0) ? 1 : -1;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -486,50 +484,50 @@ auto VSpline::Sign(long double ld) -> int
  */
 auto VSpline::Cubic(QVector<qreal> &x, qreal a, qreal b, qreal c) -> qint32
 {
-    //To find cubic equation roots in the case of real coefficients, calculated at the beginning
-    const qreal q = (pow(a, 2) - 3*b)/9.;
-    const qreal r = (2*pow(a, 3) - 9*a*b + 27.*c)/54.;
+    // To find cubic equation roots in the case of real coefficients, calculated at the beginning
+    const qreal q = (pow(a, 2) - 3 * b) / 9.;
+    const qreal r = (2 * pow(a, 3) - 9 * a * b + 27. * c) / 54.;
     if (pow(r, 2) < pow(q, 3))
     { // equation has three real roots, use formula Vieta
-        const qreal t = acos(r/sqrt(pow(q, 3)))/3.;
-        x.insert(0, -2.*sqrt(q)*cos(t)-a/3);
-        x.insert(1, -2.*sqrt(q)*cos(t + (2*M_2PI/3.)) - a/3.);
-        x.insert(2, -2.*sqrt(q)*cos(t - (2*M_2PI/3.)) - a/3.);
-        return(3);
+        const qreal t = acos(r / sqrt(pow(q, 3))) / 3.;
+        x.insert(0, -2. * sqrt(q) * cos(t) - a / 3);
+        x.insert(1, -2. * sqrt(q) * cos(t + (2 * M_2PI / 3.)) - a / 3.);
+        x.insert(2, -2. * sqrt(q) * cos(t - (2 * M_2PI / 3.)) - a / 3.);
+        return (3);
     }
 
     // 1 real root + 2 complex
-    //Formula Cardano
-    const qreal aa = -Sign(r)*pow(fabs(r)+sqrt(pow(r, 2)-pow(q, 3)), 1./3.);
-    const qreal bb = Sign(aa) == 0 ? 0 : q/aa;
+    // Formula Cardano
+    const qreal aa = -Sign(r) * pow(fabs(r) + sqrt(pow(r, 2) - pow(q, 3)), 1. / 3.);
+    const qreal bb = Sign(aa) == 0 ? 0 : q / aa;
 
-    x.insert(0, aa+bb-a/3.); // Real root
-    x.insert(1, (-0.5)*(aa+bb)-a/3.); //Complex root
-    x.insert(2, (sqrt(3.)*0.5)*fabs(aa-bb)); // Complex root
+    x.insert(0, aa + bb - a / 3.);                 // Real root
+    x.insert(1, (-0.5) * (aa + bb) - a / 3.);      // Complex root
+    x.insert(2, (sqrt(3.) * 0.5) * fabs(aa - bb)); // Complex root
     if (qFuzzyIsNull(x.at(2)))
     {
-        return(2);
+        return (2);
     }
-    return(1);
+    return (1);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VSpline::CalcT(qreal curveCoord1, qreal curveCoord2, qreal curveCoord3, qreal curveCoord4,
-                    qreal pointCoord) -> QVector<qreal>
+auto VSpline::CalcT(qreal curveCoord1, qreal curveCoord2, qreal curveCoord3, qreal curveCoord4, qreal pointCoord)
+    -> QVector<qreal>
 {
-    const qreal a = -curveCoord1 + 3*curveCoord2 - 3*curveCoord3 + curveCoord4;
-    const qreal b = 3*curveCoord1 - 6*curveCoord2 + 3*curveCoord3;
-    const qreal c = -3*curveCoord1 + 3*curveCoord2;
+    const qreal a = -curveCoord1 + 3 * curveCoord2 - 3 * curveCoord3 + curveCoord4;
+    const qreal b = 3 * curveCoord1 - 6 * curveCoord2 + 3 * curveCoord3;
+    const qreal c = -3 * curveCoord1 + 3 * curveCoord2;
     const qreal d = -pointCoord + curveCoord1;
 
-    QVector<qreal> t = QVector<qreal>(3, -1);
-    Cubic(t, b/a, c/a, d/a);
+    auto t = QVector<qreal>(3, -1);
+    Cubic(t, b / a, c / a, d / a);
 
     QVector<qreal> retT;
     retT.reserve(t.size());
     for (auto i : qAsConst(t))
     {
-        if (i >= 0 && i <= 1 )
+        if (i >= 0 && i <= 1)
         {
             retT.append(i);
         }
@@ -547,12 +545,12 @@ auto VSpline::CalcT(qreal curveCoord1, qreal curveCoord2, qreal curveCoord3, qre
  * @param pBt point on curve
  * @return t coeffient that reprezent this point on curve. Return -1 if point doesn't belongs to curve.
  */
-auto VSpline::ParamT (const QPointF &pBt) const -> qreal
+auto VSpline::ParamT(const QPointF &pBt) const -> qreal
 {
     QVector<qreal> ts;
     // Calculate t coefficient for each axis
-    ts += CalcT (GetP1().x(), GetP2().x(), GetP3().x(), GetP4().x(), pBt.x());
-    ts += CalcT (GetP1().y(), GetP2().y(), GetP3().y(), GetP4().y(), pBt.y());
+    ts += CalcT(GetP1().x(), GetP2().x(), GetP3().x(), GetP4().x(), pBt.x());
+    ts += CalcT(GetP1().y(), GetP2().y(), GetP3().y(), GetP4().y(), pBt.y());
 
     if (ts.isEmpty())
     {
@@ -566,19 +564,21 @@ auto VSpline::ParamT (const QPointF &pBt) const -> qreal
     // Here we try find closest to our point.
     for (auto t : qAsConst(ts))
     {
-        const QPointF p0 = static_cast<QPointF>(GetP1());
-        const QPointF p1 = static_cast<QPointF>(GetP2());
-        const QPointF p2 = static_cast<QPointF>(GetP3());
-        const QPointF p3 = static_cast<QPointF>(GetP4());
-        //The explicit form of the Cubic Bézier curve
-        const qreal pointX = pow(1-t, 3)*p0.x() + 3*pow(1-t, 2)*t*p1.x() + 3*(1-t)*pow(t, 2)*p2.x() + pow(t, 3)*p3.x();
-        const qreal pointY = pow(1-t, 3)*p0.y() + 3*pow(1-t, 2)*t*p1.y() + 3*(1-t)*pow(t, 2)*p2.y() + pow(t, 3)*p3.y();
+        const auto p0 = static_cast<QPointF>(GetP1());
+        const auto p1 = static_cast<QPointF>(GetP2());
+        const auto p2 = static_cast<QPointF>(GetP3());
+        const auto p3 = static_cast<QPointF>(GetP4());
+        // The explicit form of the Cubic Bézier curve
+        const qreal pointX = pow(1 - t, 3) * p0.x() + 3 * pow(1 - t, 2) * t * p1.x() +
+                             3 * (1 - t) * pow(t, 2) * p2.x() + pow(t, 3) * p3.x();
+        const qreal pointY = pow(1 - t, 3) * p0.y() + 3 * pow(1 - t, 2) * t * p1.y() +
+                             3 * (1 - t) * pow(t, 2) * p2.y() + pow(t, 3) * p3.y();
 
         const QLineF line(pBt, QPointF(pointX, pointY));
         if (line.length() <= eps)
         {
             tx = t;
-            eps = line.length(); //Next point should be even closest
+            eps = line.length(); // Next point should be even closest
         }
     }
 
@@ -589,30 +589,30 @@ auto VSpline::ParamT (const QPointF &pBt) const -> qreal
 auto VSpline::ToJson() const -> QJsonObject
 {
     QJsonObject object = VAbstractCubicBezier::ToJson();
-    object[QLatin1String("aScale")] = GetApproximationScale();
-    object[QLatin1String("p1")] = GetP1().ToJson();
-    object[QLatin1String("p4")] = GetP4().ToJson();
-    object[QLatin1String("angle1")] = GetStartAngle();
-    object[QLatin1String("angle1Formula")] = GetStartAngleFormula();
-    object[QLatin1String("angle2")] = GetEndAngle();
-    object[QLatin1String("angle2Formula")] = GetEndAngleFormula();
-    object[QLatin1String("c1Length")] = GetC1Length();
-    object[QLatin1String("c1LengthFormula")] = GetC1LengthFormula();
-    object[QLatin1String("c2Length")] = GetC2Length();
-    object[QLatin1String("c2LengthFormula")] = GetC2LengthFormula();
+    object["aScale"_L1] = GetApproximationScale();
+    object["p1"_L1] = GetP1().ToJson();
+    object["p4"_L1] = GetP4().ToJson();
+    object["angle1"_L1] = GetStartAngle();
+    object["angle1Formula"_L1] = GetStartAngleFormula();
+    object["angle2"_L1] = GetEndAngle();
+    object["angle2Formula"_L1] = GetEndAngleFormula();
+    object["c1Length"_L1] = GetC1Length();
+    object["c1LengthFormula"_L1] = GetC1LengthFormula();
+    object["c2Length"_L1] = GetC2Length();
+    object["c2LengthFormula"_L1] = GetC2LengthFormula();
     return object;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VSpline::GetControlPoint1() const -> QPointF
 {
-    return static_cast<QPointF>(GetP2 ());
+    return static_cast<QPointF>(GetP2());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VSpline::GetControlPoint2() const -> QPointF
 {
-    return static_cast<QPointF>(GetP3 ());
+    return static_cast<QPointF>(GetP3());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
