@@ -51,27 +51,27 @@ public:
     VFSplinePoint(const VFSplinePoint &point);
     ~VFSplinePoint();
 
-    VFSplinePoint &operator=(const VFSplinePoint &point);
-#ifdef Q_COMPILER_RVALUE_REFS
-    VFSplinePoint(VFSplinePoint &&point) Q_DECL_NOTHROW;
-    VFSplinePoint &operator=(VFSplinePoint &&point) Q_DECL_NOTHROW;
-#endif
+    auto operator=(const VFSplinePoint &point) -> VFSplinePoint &;
+
+    VFSplinePoint(VFSplinePoint &&point) noexcept;
+    auto operator=(VFSplinePoint &&point) noexcept -> VFSplinePoint &;
+
+    auto P() const -> VPointF;
+    void SetP(const VPointF &value);
+    auto Angle1() const -> qreal;
+    void SetAngle1(const qreal &value);
+    void SetAngle2(const qreal &value);
+    auto Angle2() const -> qreal;
+    auto KAsm1() const -> qreal;
+    void SetKAsm1(const qreal &value);
+    auto KAsm2() const -> qreal;
+    void SetKAsm2(const qreal &value);
 
-    VPointF P() const;
-    void    SetP(const VPointF &value);
-    qreal   Angle1() const;
-    void    SetAngle1(const qreal &value);
-    void    SetAngle2(const qreal &value);
-    qreal   Angle2() const;
-    qreal   KAsm1() const;
-    void    SetKAsm1(const qreal &value);
-    qreal   KAsm2() const;
-    void    SetKAsm2(const qreal &value);
 protected:
     QSharedDataPointer<VFSplinePointData> d;
 };
 
-Q_DECLARE_METATYPE(VFSplinePoint)
+Q_DECLARE_METATYPE(VFSplinePoint)                  // NOLINT
 Q_DECLARE_TYPEINFO(VFSplinePoint, Q_MOVABLE_TYPE); // NOLINT
 
 class VSplinePointData;
@@ -89,39 +89,39 @@ public:
     VSplinePoint(const VSplinePoint &point);
     ~VSplinePoint();
 
-    VSplinePoint &operator=(const VSplinePoint &point);
-#ifdef Q_COMPILER_RVALUE_REFS
-    VSplinePoint(VSplinePoint &&point) Q_DECL_NOTHROW;
-    VSplinePoint &operator=(VSplinePoint &&point) Q_DECL_NOTHROW;
-#endif
+    auto operator=(const VSplinePoint &point) -> VSplinePoint &;
 
-    VPointF P() const;
-    void    SetP(const VPointF &value);
+    VSplinePoint(VSplinePoint &&point) noexcept;
+    auto operator=(VSplinePoint &&point) noexcept -> VSplinePoint &;
 
-    qreal   Angle1() const;
-    QString Angle1Formula() const;
-    void    SetAngle1(const qreal &value, const QString &angle1F);
+    auto P() const -> VPointF;
+    void SetP(const VPointF &value);
 
-    qreal   Angle2() const;
-    QString Angle2Formula() const;
-    void    SetAngle2(const qreal &value, const QString &angle2F);
+    auto Angle1() const -> qreal;
+    auto Angle1Formula() const -> QString;
+    void SetAngle1(const qreal &value, const QString &angle1F);
 
-    qreal   Length1() const;
-    QString Length1Formula() const;
-    void    SetLength1(const qreal &value, const QString &length1F);
+    auto Angle2() const -> qreal;
+    auto Angle2Formula() const -> QString;
+    void SetAngle2(const qreal &value, const QString &angle2F);
 
-    qreal   Length2() const;
-    QString Length2Formula() const;
-    void    SetLength2(const qreal &value, const QString &length2F);
+    auto Length1() const -> qreal;
+    auto Length1Formula() const -> QString;
+    void SetLength1(const qreal &value, const QString &length1F);
 
-    bool    IsMovable() const;
+    auto Length2() const -> qreal;
+    auto Length2Formula() const -> QString;
+    void SetLength2(const qreal &value, const QString &length2F);
+
+    auto IsMovable() const -> bool;
+
+    auto ToJson() const -> QJsonObject;
 
-    QJsonObject ToJson() const;
 protected:
     QSharedDataPointer<VSplinePointData> d;
 };
 
-Q_DECLARE_METATYPE(VSplinePoint)
+Q_DECLARE_METATYPE(VSplinePoint)                  // NOLINT
 Q_DECLARE_TYPEINFO(VSplinePoint, Q_MOVABLE_TYPE); // NOLINT
 
 #endif // VSPLINEPOINT_H
