@@ -32,10 +32,11 @@
 #include <QLineF>
 #include <QSharedData>
 #include <QtDebug>
+#include <QtGlobal>
 
-#include "vpointf.h"
-#include "../vmisc/def.h"
 #include "../qmuparser/qmutokenparser.h"
+#include "../vmisc/def.h"
+#include "vpointf.h"
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Weffc++")
@@ -44,158 +45,108 @@ QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")
 class VFSplinePointData final : public QSharedData
 {
 public:
-
-    VFSplinePointData()
-        : pSpline(VPointF()),
-          angle1(0),
-          angle2(180),
-          kAsm1(1),
-          kAsm2(1)
-    {}
-
-    VFSplinePointData(VPointF pSpline, qreal kAsm1, qreal angle1, qreal kAsm2, qreal angle2)
-        : pSpline(pSpline),
-          angle1(angle1),
-          angle2(angle2),
-          kAsm1(kAsm1),
-          kAsm2(kAsm2)
-    {
-        if (VFuzzyComparePossibleNulls(angle1, angle2) || not qFuzzyCompare(qAbs(angle1-angle2), 180) )
-        {
-            this->angle2 = this->angle1 + 180;
-        }
-    }
-
-    VFSplinePointData(const VFSplinePointData &point)
-        : QSharedData(point),
-          pSpline(point.pSpline),
-          angle1(point.angle1),
-          angle2(point.angle2),
-          kAsm1(point.kAsm1),
-          kAsm2(point.kAsm2)
-    {}
-
-    virtual ~VFSplinePointData();
+    VFSplinePointData() = default;
+    VFSplinePointData(const VPointF &pSpline, qreal kAsm1, qreal angle1, qreal kAsm2, qreal angle2);
+    VFSplinePointData(const VFSplinePointData &point) = default;
+    ~VFSplinePointData() = default;
 
     /** @brief pSpline point. */
-    VPointF pSpline;
+    VPointF pSpline{}; // NOLINT(misc-non-private-member-variables-in-classes)
 
     /** @brief angle1 first angle spline. */
-    qreal   angle1;
+    qreal angle1{0}; // NOLINT(misc-non-private-member-variables-in-classes)
 
     /** @brief angle2 second angle spline. */
-    qreal   angle2;
+    qreal angle2{180}; // NOLINT(misc-non-private-member-variables-in-classes)
 
     /** @brief kAsm1 coefficient of length first control line. */
-    qreal   kAsm1;
+    qreal kAsm1{1}; // NOLINT(misc-non-private-member-variables-in-classes)
 
     /** @brief kAsm2 coefficient of length second control line. */
-    qreal   kAsm2;
+    qreal kAsm2{1}; // NOLINT(misc-non-private-member-variables-in-classes)
 
 private:
-    Q_DISABLE_ASSIGN(VFSplinePointData)
+    Q_DISABLE_ASSIGN_MOVE(VFSplinePointData) // NOLINT
 };
 
-VFSplinePointData::~VFSplinePointData()
-{}
+//---------------------------------------------------------------------------------------------------------------------
+inline VFSplinePointData::VFSplinePointData(const VPointF &pSpline, qreal kAsm1, qreal angle1, qreal kAsm2,
+                                            qreal angle2)
+  : pSpline(pSpline),
+    angle1(angle1),
+    angle2(angle2),
+    kAsm1(kAsm1),
+    kAsm2(kAsm2)
+{
+    if (VFuzzyComparePossibleNulls(angle1, angle2) || not qFuzzyCompare(qAbs(angle1 - angle2), 180))
+    {
+        this->angle2 = this->angle1 + 180;
+    }
+}
 
 //--------------------------------------VSplinePointData---------------------------------------------------------------
 
 class VSplinePointData final : public QSharedData
 {
 public:
-    VSplinePointData()
-        : pSpline(),
-          angle1(0),
-          angle1F('0'),
-          angle2(180),
-          angle2F("180"),
-          length1(ToPixel(0.01, Unit::Mm)),
-          length1F('0'),
-          length2(ToPixel(0.01, Unit::Mm)),
-          length2F('0')
-    {}
-
-    VSplinePointData(VPointF pSpline, qreal angle1, const QString &angle1F, qreal angle2, const QString &angle2F,
+    VSplinePointData() = default;
+    VSplinePointData(const VPointF &pSpline, qreal angle1, const QString &angle1F, qreal angle2, const QString &angle2F,
                      qreal length1, const QString &length1F, qreal length2, const QString &length2F);
-
-    VSplinePointData(const VSplinePointData &point)
-        : QSharedData(point),
-          pSpline(point.pSpline),
-          angle1(point.angle1),
-          angle1F(point.angle1F),
-          angle2(point.angle2),
-          angle2F(point.angle2F),
-          length1(point.length1),
-          length1F(point.length1F),
-          length2(point.length2),
-          length2F(point.length2F)
-    {
-        if (qFuzzyIsNull(this->length1))
-        {
-            this->length1 = ToPixel(0.01, Unit::Mm);
-        }
-
-        if (qFuzzyIsNull(this->length2))
-        {
-            this->length2 = ToPixel(0.01, Unit::Mm);
-        }
-    }
-
-    virtual ~VSplinePointData();
+    VSplinePointData(const VSplinePointData &point);
+    ~VSplinePointData() = default;
 
     /** @brief pSpline point. */
-    VPointF pSpline;
+    VPointF pSpline{}; // NOLINT(misc-non-private-member-variables-in-classes)
 
     /** @brief angle1 first angle spline. */
-    qreal   angle1;
-    QString angle1F;
+    qreal angle1{0};      // NOLINT(misc-non-private-member-variables-in-classes)
+    QString angle1F{'0'}; // NOLINT(misc-non-private-member-variables-in-classes)
 
     /** @brief angle2 second angle spline. */
-    qreal   angle2;
-    QString angle2F;
+    qreal angle2{180};                      // NOLINT(misc-non-private-member-variables-in-classes)
+    QString angle2F{QStringLiteral("180")}; // NOLINT(misc-non-private-member-variables-in-classes)
 
     /** @brief length1 length a first control line. */
-    qreal   length1;
-    QString length1F;
+    qreal length1{ToPixel(0.01, Unit::Mm)}; // NOLINT(misc-non-private-member-variables-in-classes)
+    QString length1F{'0'};                  // NOLINT(misc-non-private-member-variables-in-classes)
 
     /** @brief length2 length a second control line. */
-    qreal   length2;
-    QString length2F;
+    qreal length2{ToPixel(0.01, Unit::Mm)}; // NOLINT(misc-non-private-member-variables-in-classes)
+    QString length2F{'0'};                  // NOLINT(misc-non-private-member-variables-in-classes)
 
 private:
-    Q_DISABLE_ASSIGN(VSplinePointData)
+    Q_DISABLE_ASSIGN_MOVE(VSplinePointData) // NOLINT
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-VSplinePointData::VSplinePointData(VPointF pSpline, qreal angle1, const QString &angle1F, qreal angle2,
-                                   const QString &angle2F, qreal length1, const QString &length1F, qreal length2,
-                                   const QString &length2F)
-    : pSpline(pSpline),
-      angle1(angle1),
-      angle1F(angle1F),
-      angle2(angle2),
-      angle2F(angle2F),
-      length1(length1),
-      length1F(length1F),
-      length2(length2),
-      length2F(length2F)
+inline VSplinePointData::VSplinePointData(const VPointF &pSpline, qreal angle1, const QString &angle1F, qreal angle2,
+                                          const QString &angle2F, qreal length1, const QString &length1F, qreal length2,
+                                          const QString &length2F)
+  : pSpline(pSpline),
+    angle1(angle1),
+    angle1F(angle1F),
+    angle2(angle2),
+    angle2F(angle2F),
+    length1(length1),
+    length1F(length1F),
+    length2(length2),
+    length2F(length2F)
 {
-    if (not VFuzzyComparePossibleNulls(qAbs(angle1-angle2), 180))
+    if (not VFuzzyComparePossibleNulls(qAbs(angle1 - angle2), 180))
     {
-        QLineF line (0, 0, 100, 0);
+        QLineF line(0, 0, 100, 0);
 
         if (not qmu::QmuTokenParser::IsSingle(angle1F) || qmu::QmuTokenParser::IsSingle(angle2F))
         {
             line.setAngle(angle1 + 180);
             this->angle2 = line.angle();
-            this->angle2F = QString().number(line.angle());
+            this->angle2F = QString::number(line.angle());
         }
         else
         {
             line.setAngle(angle2 + 180);
             this->angle1 = line.angle();
-            this->angle1F = QString().number(line.angle());
+            this->angle1F = QString::number(line.angle());
         }
     }
 
@@ -211,8 +162,28 @@ VSplinePointData::VSplinePointData(VPointF pSpline, qreal angle1, const QString
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VSplinePointData::~VSplinePointData()
-{}
+inline VSplinePointData::VSplinePointData(const VSplinePointData &point)
+  : QSharedData(point),
+    pSpline(point.pSpline),
+    angle1(point.angle1),
+    angle1F(point.angle1F),
+    angle2(point.angle2),
+    angle2F(point.angle2F),
+    length1(point.length1),
+    length1F(point.length1F),
+    length2(point.length2),
+    length2F(point.length2F)
+{
+    if (qFuzzyIsNull(this->length1))
+    {
+        this->length1 = ToPixel(0.01, Unit::Mm);
+    }
+
+    if (qFuzzyIsNull(this->length2))
+    {
+        this->length2 = ToPixel(0.01, Unit::Mm);
+    }
+}
 
 QT_WARNING_POP
 
