@@ -138,9 +138,8 @@ auto AngleByLength(QVector<VRawSAPoint> points, QPointF p1, QPointF p2, QPointF
     {
         QLineF const edge1(p2, p1);
         QLineF const edge2(p2, p3);
-        const qreal angle = edge1.angleTo(edge2);
 
-        if (angle > 180 && p.GetAngleType() != PieceNodeAngle::ByLengthCurve)
+        if (const qreal angle = edge1.angleTo(edge2); angle > 180 && p.GetAngleType() != PieceNodeAngle::ByLengthCurve)
         {
             if (VGObject::IsPointOnLineSegment(sp2, bigLine2.p1(), bigLine2.p2()))
             {
@@ -227,9 +226,8 @@ auto AngleByIntersection(const QVector<VRawSAPoint> &points, QPointF p1, QPointF
     {
         QLineF const edge1(p2, p1);
         QLineF const edge2(p2, p3);
-        const qreal angle = edge1.angleTo(edge2);
 
-        if (angle > 180)
+        if (const qreal angle = edge1.angleTo(edge2); angle > 180)
         {
             return AngleByLength(points, p1, p2, p3, bigLine1, sp2, bigLine2, p, width, needRollback);
         }
@@ -314,9 +312,8 @@ auto AngleByFirstSymmetry(const QVector<VRawSAPoint> &points, QPointF p1, QPoint
     {
         QLineF const edge1(p2, p1);
         QLineF const edge2(p2, p3);
-        const qreal angle = edge1.angleTo(edge2);
 
-        if (angle > 180)
+        if (const qreal angle = edge1.angleTo(edge2); angle > 180)
         {
             return AngleByLength(points, p1, p2, p3, bigLine1, sp2, bigLine2, p, width, needRollback);
         }
@@ -395,9 +392,8 @@ auto AngleBySecondSymmetry(const QVector<VRawSAPoint> &points, QPointF p1, QPoin
     {
         QLineF const edge1(p2, p1);
         QLineF const edge2(p2, p3);
-        const qreal angle = edge1.angleTo(edge2);
 
-        if (angle > 180)
+        if (const qreal angle = edge1.angleTo(edge2); angle > 180)
         {
             return AngleByLength(points, p1, p2, p3, bigLine1, sp2, bigLine2, p, width, needRollback);
         }
@@ -478,9 +474,8 @@ auto AngleByFirstRightAngle(const QVector<VRawSAPoint> &points, QPointF p1, QPoi
     {
         QLineF const edge1(p2, p1);
         QLineF const edge2(p2, p3);
-        const qreal angle = edge1.angleTo(edge2);
 
-        if (angle > 270)
+        if (const qreal angle = edge1.angleTo(edge2); angle > 270)
         {
             return AngleByLength(points, p1, p2, p3, bigLine1, sp2, bigLine2, p, width, needRollback);
         }
@@ -491,9 +486,8 @@ auto AngleByFirstRightAngle(const QVector<VRawSAPoint> &points, QPointF p1, QPoi
     QLineF const edge(p1, p2);
 
     QPointF px;
-    QLineF::IntersectType const type = edge.intersects(bigLine2, &px);
 
-    if (type == QLineF::NoIntersection)
+    if (QLineF::IntersectType const type = edge.intersects(bigLine2, &px); type == QLineF::NoIntersection)
     {
         return AngleByLength(points, p1, p2, p3, bigLine1, sp2, bigLine2, p, width, needRollback);
     }
@@ -515,9 +509,8 @@ auto AngleByFirstRightAngle(const QVector<VRawSAPoint> &points, QPointF p1, QPoi
     {
         QLineF const edge1(p2, p1);
         QLineF const edge2(p2, p3);
-        const qreal angle = edge1.angleTo(edge2);
 
-        if (angle > 180)
+        if (const qreal angle = edge1.angleTo(edge2); angle > 180)
         {
             return AngleByLength(points, p1, p2, p3, bigLine1, sp2, bigLine2, p, width, needRollback);
         }
@@ -546,9 +539,8 @@ auto AngleBySecondRightAngle(QVector<VRawSAPoint> points, QPointF p1, QPointF p2
     {
         QLineF const edge1(p2, p1);
         QLineF const edge2(p2, p3);
-        const qreal angle = edge1.angleTo(edge2);
 
-        if (angle > 270)
+        if (const qreal angle = edge1.angleTo(edge2); angle > 270)
         {
             return AngleByLength(points, p1, p2, p3, bigLine1, sp2, bigLine2, p, width, needRollback);
         }
@@ -563,9 +555,8 @@ auto AngleBySecondRightAngle(QVector<VRawSAPoint> points, QPointF p1, QPointF p2
     QLineF const edge(p2, p3);
 
     QPointF px;
-    QLineF::IntersectType const type = edge.intersects(bigLine1, &px);
 
-    if (type == QLineF::NoIntersection)
+    if (QLineF::IntersectType const type = edge.intersects(bigLine1, &px); type == QLineF::NoIntersection)
     {
         return AngleByLength(points, p1, p2, p3, bigLine1, sp2, bigLine2, p, width, needRollback);
     }
@@ -592,9 +583,8 @@ auto AngleBySecondRightAngle(QVector<VRawSAPoint> points, QPointF p1, QPointF p2
     {
         QLineF const edge1(p2, p1);
         QLineF const edge2(p2, p3);
-        const qreal angle = edge1.angleTo(edge2);
 
-        if (angle > 180)
+        if (const qreal angle = edge1.angleTo(edge2); angle > 180)
         {
             return AngleByLength(points, p1, p2, p3, bigLine1, sp2, bigLine2, p, width, needRollback);
         }
@@ -647,9 +637,8 @@ auto BisectorLine(const QPointF &p1, const QPointF &p2, const QPointF &p3) -> QL
     QLineF bLine;
 
     const qreal angle1 = line1.angleTo(line2);
-    const qreal angle2 = line2.angleTo(line1);
 
-    if (angle1 <= angle2)
+    if (const qreal angle2 = line2.angleTo(line1); angle1 <= angle2)
     {
         bLine = line1;
         bLine.setAngle(bLine.angle() + angle1 / 2.0);
@@ -793,9 +782,8 @@ void RollbackByPointsIntersection(QVector<VRawSAPoint> &ekvPoints, const QVector
     const QLineF bigLine1 = VAbstractPiece::ParallelLine(points.at(points.size() - 2), points.at(0), width);
     QVector<VRawSAPoint> temp = ekvPoints;
     temp.insert(ekvPoints.size() - 1, VRawSAPoint(bigLine1.p2(), points.at(0).CurvePoint(), points.at(0).TurnPoint()));
-    bool const success = Rollback(temp, QLineF(points.constLast(), points.at(1)));
 
-    if (success)
+    if (bool const success = Rollback(temp, QLineF(points.constLast(), points.at(1))); success)
     {
         ekvPoints = temp;
     }
@@ -869,6 +857,62 @@ void RollbackBySecondEdgeRightAngle(QVector<VRawSAPoint> &ekvPoints, const QVect
         }
     }
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto FoundProng(const QLineF &bigLine1, const QLineF &bigLine2, const VSAPoint &ekvPoint, qreal width, qreal caseAngle,
+                QPointF crosPoint, QVector<VRawSAPoint> &points) -> bool
+{
+    if (not VFuzzyComparePossibleNulls(ekvPoint.GetSABefore(width), ekvPoint.GetSAAfter(width)) &&
+        ekvPoint.GetAngleType() == PieceNodeAngle::ByLength)
+    {
+        if (VFuzzyComparePossibleNulls(caseAngle, 180))
+        {
+            points.append(VRawSAPoint(bigLine1.p2(), ekvPoint.CurvePoint(), ekvPoint.TurnPoint()));
+            points.append(VRawSAPoint(bigLine2.p1(), ekvPoint.CurvePoint(), ekvPoint.TurnPoint()));
+            return true;
+        }
+        else if (caseAngle > 180 && caseAngle <= 225)
+        {
+            QPointF intersectPoint;
+            QLineF::IntersectType type = bigLine1.intersects(QLineF(ekvPoint, bigLine2.p1()), &intersectPoint);
+            if (type == QLineF::BoundedIntersection)
+            {
+                points.append(VRawSAPoint(intersectPoint, ekvPoint.CurvePoint(), ekvPoint.TurnPoint()));
+                points.append(VRawSAPoint(bigLine2.p1(), ekvPoint.CurvePoint(), ekvPoint.TurnPoint()));
+                return true;
+            }
+
+            type = bigLine2.intersects(QLineF(ekvPoint, bigLine1.p2()), &intersectPoint);
+            if (type == QLineF::BoundedIntersection)
+            {
+                points.append(VRawSAPoint(bigLine1.p2(), ekvPoint.CurvePoint(), ekvPoint.TurnPoint()));
+                points.append(VRawSAPoint(intersectPoint, ekvPoint.CurvePoint(), ekvPoint.TurnPoint()));
+                return true;
+            }
+        }
+        else
+        {
+            QPointF intersectPoint;
+            QLineF::IntersectType type =
+                QLineF(bigLine1.p2(), crosPoint).intersects(QLineF(ekvPoint, bigLine2.p1()), &intersectPoint);
+            if (type == QLineF::BoundedIntersection)
+            {
+                points.append(VRawSAPoint(intersectPoint, ekvPoint.CurvePoint(), ekvPoint.TurnPoint()));
+                points.append(VRawSAPoint(bigLine2.p1(), ekvPoint.CurvePoint(), ekvPoint.TurnPoint()));
+                return true;
+            }
+
+            type = QLineF(crosPoint, bigLine2.p1()).intersects(QLineF(bigLine1.p2(), ekvPoint), &intersectPoint);
+            if (type == QLineF::BoundedIntersection)
+            {
+                points.append(VRawSAPoint(bigLine1.p2(), ekvPoint.CurvePoint(), ekvPoint.TurnPoint()));
+                points.append(VRawSAPoint(intersectPoint, ekvPoint.CurvePoint(), ekvPoint.TurnPoint()));
+                return true;
+            }
+        }
+    }
+    return false;
+}
 } // namespace
 
 // Friend functions
@@ -968,6 +1012,18 @@ void VAbstractPiece::SetForceFlipping(bool value)
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VAbstractPiece::IsSymmetricalCopy() const -> bool
+{
+    return d->m_symmetricalCopy;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VAbstractPiece::SetSymmetricalCopy(bool value)
+{
+    d->m_symmetricalCopy = value;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VAbstractPiece::IsFollowGrainline() const -> bool
 {
@@ -1153,6 +1209,8 @@ auto VAbstractPiece::Equidistant(QVector<VSAPoint> points, qreal width, const QS
     cleaned = CorrectEquidistantPoints(cleaned, removeFirstAndLast);
     cleaned = CorrectPathDistortion(cleaned);
 
+    //    DumpVector(TurnPointList(cleaned), QStringLiteral("output.json.XXXXXX")); // Uncomment for dumping test data
+
     //    QVector<QPointF> dump;
     //    CastTo(cleaned, dump);
     //    DumpVector(dump, QStringLiteral("output.json.XXXXXX")); // Uncomment for dumping test data
@@ -1164,9 +1222,8 @@ auto VAbstractPiece::SumTrapezoids(const QVector<QPointF> &points) -> qreal
 {
     // Calculation a polygon area through the sum of the areas of trapezoids
     qreal s, res = 0;
-    const auto n = points.size();
 
-    if (n > 2)
+    if (const auto n = points.size(); n > 2)
     {
         for (int i = 0; i < n; ++i)
         {
@@ -1252,6 +1309,18 @@ auto VAbstractPiece::EkvPoint(QVector<VRawSAPoint> points, const VSAPoint &p1Lin
         }
         return points;
     }
+    else if (VFuzzyComparePossibleNulls(a, 360))
+    {
+        QLineF ext1 = bigLine1;
+        ext1.setLength(ext1.length() + p2Line1.GetSABefore(width));
+        points.append(VRawSAPoint(ext1.p2(), p2Line1.CurvePoint(), p2Line1.TurnPoint()));
+
+        QLineF ext2(bigLine2.p2(), bigLine2.p1());
+        ext2.setLength(ext2.length() + p2Line2.GetSAAfter(width));
+        points.append(VRawSAPoint(ext2.p2(), p2Line1.CurvePoint(), p2Line1.TurnPoint()));
+
+        return points;
+    }
     else if (a > 345)
     {
         points.append(VRawSAPoint(bigLine1.p2(), p2Line1.CurvePoint(), p2Line1.TurnPoint()));
@@ -1260,9 +1329,8 @@ auto VAbstractPiece::EkvPoint(QVector<VRawSAPoint> points, const VSAPoint &p1Lin
     }
 
     QPointF crosPoint;
-    const QLineF::IntersectType type = bigLine1.intersects(bigLine2, &crosPoint);
 
-    switch (type)
+    switch (const QLineF::IntersectType type = bigLine1.intersects(bigLine2, &crosPoint); type)
     { // There are at least three big cases
         case (QLineF::BoundedIntersection):
             // The easiest, real intersection
@@ -1272,25 +1340,8 @@ auto VAbstractPiece::EkvPoint(QVector<VRawSAPoint> points, const VSAPoint &p1Lin
         { // Most common case
             /* Case when a path has point on line (both segments lie on the same line) and seam allowance creates
              * prong. */
-            auto IsOnLine = [](const QPointF &base, const QPointF &sp1, const QPointF &sp2, qreal accuracy)
+            if (FoundProng(bigLine1, bigLine2, p2Line1, width, a, crosPoint, points))
             {
-                if (not VFuzzyComparePoints(base, sp1))
-                {
-                    return VGObject::IsPointOnLineviaPDP(sp2, base, sp1, accuracy);
-                }
-
-                if (not VFuzzyComparePoints(base, sp2))
-                {
-                    return VGObject::IsPointOnLineviaPDP(sp1, base, sp2, accuracy);
-                }
-                return true;
-            };
-            if (VGObject::IsPointOnLineSegment(p2Line1, p1Line1, p1Line2, ToPixel(0.5, Unit::Mm)) &&
-                IsOnLine(p2Line1, bigLine1.p2(), bigLine2.p1(), ToPixel(0.5, Unit::Mm)) &&
-                p2Line1.GetAngleType() == PieceNodeAngle::ByLength)
-            {
-                points.append(VRawSAPoint(bigLine1.p2(), p2Line1.CurvePoint(), p2Line1.TurnPoint()));
-                points.append(VRawSAPoint(bigLine2.p1(), p2Line1.CurvePoint(), p2Line1.TurnPoint()));
                 return points;
             }
 
@@ -1301,10 +1352,9 @@ auto VAbstractPiece::EkvPoint(QVector<VRawSAPoint> points, const VSAPoint &p1Lin
             const QLineF b1 = BisectorLine(p1Line1, p2Line1, p1Line2);
             const QLineF b2 = BisectorLine(bigLine1.p1(), crosPoint, bigLine2.p2());
 
-            const qreal angle = AngleBetweenBisectors(b1, b2);
-
             // Comparison bisector angles helps to find direction
-            if (angle < 135 || VFuzzyComparePossibleNulls(angle, 135.0)) // Go in a same direction
+            if (const qreal angle = AngleBetweenBisectors(b1, b2);
+                angle < 135 || VFuzzyComparePossibleNulls(angle, 135.0)) // Go in a same direction
             {                                                            // Regular equdistant case
                 QT_WARNING_PUSH
                 QT_WARNING_DISABLE_GCC("-Wswitch-default")
@@ -1351,15 +1401,16 @@ auto VAbstractPiece::EkvPoint(QVector<VRawSAPoint> points, const VSAPoint &p1Lin
                 QLineF bisector(p2Line1, p1Line1);
                 bisector.setAngle(b1.angle());
 
-                const qreal result1 = PointPosition(bisector.p2(), QLineF(p1Line1, p2Line1));
-                const qreal result2 = PointPosition(bisector.p2(), QLineF(p2Line2, p1Line2));
+                qreal result1 = PointPosition(bisector.p2(), QLineF(p1Line1, p2Line1));
+                qreal result2 = PointPosition(bisector.p2(), QLineF(p2Line2, p1Line2));
 
                 if ((result1 < 0 || qFuzzyIsNull(result1)) && (result2 < 0 || qFuzzyIsNull(result2)))
                 { // Dart case. A bisector watches outside.
-                    QLineF const edge1(p1Line1, p2Line1);
-                    QLineF const edge2(p1Line2, p2Line2);
+                    QLineF const bisectorEdge1(p1Line1, p2Line1);
+                    QLineF const bisectorEdge2(p1Line2, p2Line2);
 
-                    if (qAbs(edge1.length() - edge2.length()) <= qMax(edge1.length(), edge2.length()) * 0.2)
+                    if (qAbs(bisectorEdge1.length() - bisectorEdge2.length()) <=
+                        qMax(bisectorEdge1.length(), bisectorEdge2.length()) * 0.2)
                     {
                         // Classic dart must be symmetrical.
                         // In some cases a point still valid, but ignore if going outside of an equdistant.
@@ -1377,15 +1428,13 @@ auto VAbstractPiece::EkvPoint(QVector<VRawSAPoint> points, const VSAPoint &p1Lin
                     { // Just an acute angle with big seam allowance
                         if (IsSameDirection(bigLine2.p1(), bigLine2.p2(), crosPoint))
                         {
-                            QLineF loop(crosPoint, bigLine1.p1());
+                            points.append(VRawSAPoint(bigLine1.p2(), p2Line1.CurvePoint(), p2Line1.TurnPoint()));
+                            points.append(VRawSAPoint(bigLine2.p1(), p2Line1.CurvePoint(), p2Line1.TurnPoint()));
+
+                            QLineF loop(crosPoint, bigLine2.p1());
                             loop.setAngle(loop.angle() + 180);
                             loop.setLength(accuracyPointOnLine * 2.);
                             points.append(VRawSAPoint(loop.p2(), p2Line1.CurvePoint(), p2Line1.TurnPoint()));
-                            points.append(VRawSAPoint(crosPoint, p2Line1.CurvePoint(), p2Line1.TurnPoint()));
-
-                            loop = QLineF(crosPoint, bigLine1.p1());
-                            loop.setLength(loop.length() + localWidth * 2.);
-                            points.append(VRawSAPoint(loop.p2(), p2Line1.CurvePoint(), p2Line1.TurnPoint(), true));
                         }
 
                         return points;
@@ -1393,10 +1442,10 @@ auto VAbstractPiece::EkvPoint(QVector<VRawSAPoint> points, const VSAPoint &p1Lin
                 }
                 else
                 { // New subcase. This is not a dart. An angle is acute and bisector watch inside.
-                    const qreal result1 = PointPosition(crosPoint, QLineF(p1Line1, p2Line1));
-                    const qreal result2 = PointPosition(crosPoint, QLineF(p2Line2, p1Line2));
+                    result1 = PointPosition(crosPoint, QLineF(p1Line1, p2Line1));
 
-                    if ((result1 < 0 || qFuzzyIsNull(result1)) && (result2 < 0 || qFuzzyIsNull(result2)))
+                    if (result2 = PointPosition(crosPoint, QLineF(p2Line2, p1Line2));
+                        (result1 < 0 || qFuzzyIsNull(result1)) && (result2 < 0 || qFuzzyIsNull(result2)))
                     { // The cross point is still outside of a piece
                         if (line.length() >= localWidth)
                         {
@@ -1451,9 +1500,8 @@ auto VAbstractPiece::IsAllowanceValid(const QVector<QPointF> &base, const QVecto
 
     // First check direction
     const qreal baseDirection = VPiece::SumTrapezoids(base);
-    const qreal allowanceDirection = VPiece::SumTrapezoids(allowance);
 
-    if (baseDirection >= 0 || allowanceDirection >= 0)
+    if (const qreal allowanceDirection = VPiece::SumTrapezoids(allowance); baseDirection >= 0 || allowanceDirection >= 0)
     {
         return false; // Wrong direction
     }
@@ -1779,8 +1827,7 @@ auto VAbstractPiece::IsItemContained(const QRectF &parentBoundingRect, const QVe
 auto VAbstractPiece::CorrectPosition(const QRectF &parentBoundingRect, QVector<QPointF> points) -> QVector<QPointF>
 {
     qreal dX = 0;
-    qreal dY = 0;
-    if (not IsItemContained(parentBoundingRect, points, dX, dY))
+    if (qreal dY = 0; not IsItemContained(parentBoundingRect, points, dX, dY))
     {
         for (auto &point : points)
         {
@@ -1797,9 +1844,8 @@ auto VAbstractPiece::FindGrainlineGeometry(const VGrainlineData &geom, const VCo
     SCASSERT(pattern != nullptr)
 
     const quint32 topPin = geom.TopPin();
-    const quint32 bottomPin = geom.BottomPin();
 
-    if (topPin != NULL_ID && bottomPin != NULL_ID)
+    if (const quint32 bottomPin = geom.BottomPin(); topPin != NULL_ID && bottomPin != NULL_ID)
     {
         try
         {
@@ -1842,8 +1888,7 @@ auto VAbstractPiece::FindGrainlineGeometry(const VGrainlineData &geom, const VCo
         return false;
     }
 
-    const quint32 centerPin = geom.CenterPin();
-    if (centerPin != NULL_ID)
+    if (const quint32 centerPin = geom.CenterPin(); centerPin != NULL_ID)
     {
         try
         {
@@ -1902,8 +1947,7 @@ auto VAbstractPiece::GrainlineMainLine(const VGrainlineData &geom, const VContai
     }
 
     qreal dX = 0;
-    qreal dY = 0;
-    if (not IsItemContained(boundingRect, v, dX, dY))
+    if (qreal dY = 0; not IsItemContained(boundingRect, v, dX, dY))
     {
         pt1.rx() += dX;
         pt1.ry() += dY;
@@ -2134,3 +2178,39 @@ auto VAbstractPiece::LabelShapePath(const PlaceLabelImg &shape) -> QPainterPath
     }
     return path;
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VAbstractPiece::SeamAllowanceMirrorLine(const QLineF &seamMirrorLine,
+                                             const QVector<QPointF> &seamAllowancePoints) const -> QLineF
+{
+    if (!IsSeamAllowance() || (IsSeamAllowance() && IsSeamAllowanceBuiltIn()) || seamMirrorLine.isNull())
+    {
+        return seamMirrorLine;
+    }
+
+    auto rec = QRectF(0, 0, INT_MAX, INT_MAX);
+    rec.translate(-INT_MAX / 2.0, -INT_MAX / 2.0);
+
+    auto axis =
+        QLineF(seamMirrorLine.center(), VGObject::BuildRay(seamMirrorLine.center(), seamMirrorLine.angle() + 180, rec));
+
+    QVector<QPointF> points = seamAllowancePoints;
+
+    QVector<QPointF> intersections = VAbstractCurve::CurveIntersectLine(points, axis);
+    if (intersections.isEmpty())
+    {
+        return {};
+    }
+
+    const QPointF startPoint = intersections.constFirst();
+
+    std::reverse(points.begin(), points.end());
+    axis = QLineF(seamMirrorLine.center(), VGObject::BuildRay(seamMirrorLine.center(), seamMirrorLine.angle(), rec));
+    intersections = VAbstractCurve::CurveIntersectLine(points, axis);
+    if (intersections.isEmpty())
+    {
+        return {};
+    }
+
+    return {startPoint, intersections.constFirst()};
+}
