@@ -54,6 +54,26 @@ QT_WARNING_POP
 
 namespace
 {
+//---------------------------------------------------------------------------------------------------------------------
+auto HandleSymmetricalCopy(const VLayoutPiece &piece, int copyIndex) -> VLayoutPiece
+{
+    VLayoutPiece copy = piece;
+
+    if (copyIndex % 2 == 1) // Flip every even-numbered copy
+    {
+        if (piece.IsForceFlipping())
+        {
+            copy.SetForbidFlipping(true);
+        }
+        else if (piece.IsForbidFlipping())
+        {
+            copy.SetForceFlipping(true);
+        }
+    }
+
+    return copy;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto PrepareQuantity(const QVector<VLayoutPiece> &details) -> QVector<VLayoutPiece>
 {
@@ -61,7 +81,21 @@ auto PrepareQuantity(const QVector<VLayoutPiece> &details) -> QVector<VLayoutPie
     withQuantity.reserve(details.size());
     for (const auto &piece : details)
     {
-        for (int i = 0; i < piece.GetQuantity(); ++i)
+        if (const int quantity = piece.GetQuantity(); quantity > 1)
+        {
+            for (int i = 0; i < quantity; ++i)
+            {
+                if (piece.IsSymmetricalCopy() && (piece.IsForceFlipping() || piece.IsForbidFlipping()))
+                {
+                    withQuantity.append(HandleSymmetricalCopy(piece, i));
+                }
+                else
+                {
+                    withQuantity.append(piece);
+                }
+            }
+        }
+        else
         {
             withQuantity.append(piece);
         }
@@ -96,7 +130,7 @@ template <typename T> auto CountDetails(const T &container) -> vsizetype
 auto NotArrangedDetail(QMap<uint, QHash<int, qint64>> &container, QMap<uint, QHash<int, qint64>> &unsorted, int i)
     -> bool
 {
-    QMutableMapIterator<uint, QHash<int, qint64>> iterator(container);
+    QMutableMapIterator iterator(container);
     while (iterator.hasNext())
     {
         iterator.next();
@@ -124,7 +158,7 @@ auto NotArrangedDetail(QMap<uint, QHash<int, qint64>> &container, QMap<uint, QHa
 auto NotArrangedDetail(QMap<uint, QMultiMap<qint64, int>> &container, QMap<uint, QHash<int, qint64>> &unsorted, int i)
     -> bool
 {
-    QMutableMapIterator<uint, QMultiMap<qint64, int>> iterator(container);
+    QMutableMapIterator iterator(container);
     while (iterator.hasNext())
     {
         iterator.next();
@@ -152,8 +186,7 @@ auto NotArrangedDetail(QMap<uint, QMultiMap<qint64, int>> &container, QMap<uint,
 //---------------------------------------------------------------------------------------------------------------------
 auto TakeFirstForPriority(const QMap<uint, QHash<int, qint64>> &container, uint priority) -> int
 {
-    const QHash<int, qint64> priorityGroup = container.value(priority);
-    if (not priorityGroup.isEmpty())
+    if (const QHash<int, qint64> priorityGroup = container.value(priority); not priorityGroup.isEmpty())
     {
         return priorityGroup.constBegin().key();
     }
@@ -452,7 +485,7 @@ auto VBank::GetBiggestDiagonal() const -> qreal
 //---------------------------------------------------------------------------------------------------------------------
 void VBank::PrepareGroup()
 {
-    QMutableMapIterator<uint, QHash<int, qint64>> i(unsorted);
+    QMutableMapIterator i(unsorted);
     while (i.hasNext())
     {
         i.next();
@@ -583,9 +616,9 @@ auto VBank::GetNextDescGroup(uint priority) const -> int
 {
     auto descGroup = desc.value(priority);
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-    QMultiMapIterator<qint64, int> i(descGroup);
+    QMultiMapIterator i(descGroup);
 #else
-    QMapIterator<qint64, int> i(descGroup);
+    QMapIterator i(descGroup);
 #endif
     i.toBack();
     if (i.hasPrevious())
@@ -622,7 +655,7 @@ void VBank::SqMaxMin(qint64 &sMax, qint64 &sMin, uint priority) const
 //---------------------------------------------------------------------------------------------------------------------
 auto VBank::ArrangedDetail(QMap<uint, QHash<int, qint64>> &container, int i) -> bool
 {
-    QMutableMapIterator<uint, QHash<int, qint64>> iterator(container);
+    QMutableMapIterator iterator(container);
     while (iterator.hasNext())
     {
         iterator.next();
@@ -648,7 +681,7 @@ auto VBank::ArrangedDetail(QMap<uint, QHash<int, qint64>> &container, int i) ->
 //---------------------------------------------------------------------------------------------------------------------
 auto VBank::ArrangedDetail(QMap<uint, QMultiMap<qint64, int>> &container, int i) -> bool
 {
-    QMutableMapIterator<uint, QMultiMap<qint64, int>> iterator(container);
+    QMutableMapIterator iterator(container);
     while (iterator.hasNext())
     {
         iterator.next();
