@@ -30,60 +30,62 @@
 #define VBANK_H
 
 #include <QHash>
+#include <QLoggingCategory>
 #include <QMap>
 #include <QRectF>
 #include <QVector>
 #include <QtGlobal>
-#include <QLoggingCategory>
 
 #include "../vmisc/typedef.h"
-#include "vlayoutpiece.h"
 #include "vlayoutdef.h"
+#include "vlayoutpiece.h"
 
 // An annoying char define, from the Windows team in <rpcndr.h>
 // #define small char
 // http://stuartjames.info/Journal/c--visual-studio-2012-vs2012--win8--converting-projects-up-some-conflicts-i-found.aspx
-#if defined (Q_OS_WIN) && defined (Q_CC_MSVC)
+#if defined(Q_OS_WIN) && defined(Q_CC_MSVC)
 #pragma push_macro("small")
 #undef small
 #endif
 
-Q_DECLARE_LOGGING_CATEGORY(lBank)
+Q_DECLARE_LOGGING_CATEGORY(lBank) // NOLINT
 
 class VBank
 {
     Q_DECLARE_TR_FUNCTIONS(VBank) // NOLINT
+
 public:
     VBank();
+    ~VBank() = default;
 
-    qreal GetLayoutWidth() const;
+    auto GetLayoutWidth() const -> qreal;
     void SetLayoutWidth(qreal value);
 
-    bool GetManualPriority() const;
+    auto GetManualPriority() const -> bool;
     void SetManualPriority(bool value);
 
-    bool IsNestQuantity() const;
+    auto IsNestQuantity() const -> bool;
     void SetNestQuantity(bool value);
 
     void SetDetails(const QVector<VLayoutPiece> &details);
-    int  GetNext();
-    VLayoutPiece GetDetail(int i) const;
+    auto GetNext() -> int;
+    auto GetDetail(int i) const -> VLayoutPiece;
 
     void Arranged(int i);
     void NotArranged(int i);
 
-    bool PrepareUnsorted();
-    bool PrepareDetails();
+    auto PrepareUnsorted() -> bool;
+    auto PrepareDetails(bool togetherWithNotches) -> bool;
     void Reset();
     void SetCaseType(Cases caseType);
 
-    int AllDetailsCount() const;
-    int LeftToArrange() const;
-    int FailedToArrange() const;
+    auto AllDetailsCount() const -> vsizetype;
+    auto LeftToArrange() const -> vsizetype;
+    auto FailedToArrange() const -> vsizetype;
 
-    qreal GetBiggestDiagonal() const;
+    auto GetBiggestDiagonal() const -> qreal;
 
-    bool IsRotationNeeded() const;
+    auto IsRotationNeeded() const -> bool;
 
 private:
     Q_DISABLE_COPY_MOVE(VBank) // NOLINT
@@ -112,17 +114,17 @@ private:
     void PrepareTwoGroups(uint priority);
     void PrepareDescGroup(uint priority);
 
-    int GetNextThreeGroups(uint priority) const;
-    int GetNextTwoGroups(uint priority) const;
-    int GetNextDescGroup(uint priority) const;
+    auto GetNextThreeGroups(uint priority) const -> int;
+    auto GetNextTwoGroups(uint priority) const -> int;
+    auto GetNextDescGroup(uint priority) const -> int;
 
     void SqMaxMin(qint64 &sMax, qint64 &sMin, uint priority) const;
 
-    bool ArrangedDetail(QMap<uint, QHash<int, qint64>> &container, int i);
-    bool ArrangedDetail(QMap<uint, QMultiMap<qint64, int>> &container, int i);
+    auto ArrangedDetail(QMap<uint, QHash<int, qint64>> &container, int i) -> bool;
+    auto ArrangedDetail(QMap<uint, QMultiMap<qint64, int>> &container, int i) -> bool;
 };
 
-#if defined (Q_OS_WIN) && defined (Q_CC_MSVC)
+#if defined(Q_OS_WIN) && defined(Q_CC_MSVC)
 #pragma pop_macro("small")
 #endif
 
