@@ -27,43 +27,40 @@
  *************************************************************************/
 
 #include "vbestsquare.h"
-#include "vbestsquare_p.h"
 #include "../vgeometry/vgeometrydef.h"
-
-#include <QMatrix>
+#include "vbestsquare_p.h"
 
 namespace
 {
 //---------------------------------------------------------------------------------------------------------------------
-Q_DECL_CONSTEXPR inline qint64 Square(QSizeF size)
+constexpr auto Square(QSizeF size) -> qint64
 {
-    return static_cast<qint64>(size.width()*size.height());
+    return static_cast<qint64>(size.width() * size.height());
 }
 } // anonymous namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 VBestSquare::VBestSquare()
-    : d(new VBestSquareData())
-{}
+  : d(new VBestSquareData())
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 VBestSquare::VBestSquare(QSizeF sheetSize, bool saveLength, bool isPortrait)
-    : d(new VBestSquareData(sheetSize, saveLength, isPortrait))
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-VBestSquare::VBestSquare(const VBestSquare &res)
-    : d(res.d)
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-VBestSquare::~VBestSquare()
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-VBestSquare &VBestSquare::operator=(const VBestSquare &res)
+  : d(new VBestSquareData(sheetSize, saveLength, isPortrait))
 {
-    if ( &res == this )
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+COPY_CONSTRUCTOR_IMPL(VBestSquare)
+
+//---------------------------------------------------------------------------------------------------------------------
+VBestSquare::~VBestSquare() = default;
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VBestSquare::operator=(const VBestSquare &res) -> VBestSquare &
+{
+    if (&res == this)
     {
         return *this;
     }
@@ -71,24 +68,23 @@ VBestSquare &VBestSquare::operator=(const VBestSquare &res)
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VBestSquare::VBestSquare(VBestSquare &&res) Q_DECL_NOTHROW
-    : d(std::move(res.d))
-{}
+VBestSquare::VBestSquare(VBestSquare &&res) noexcept
+  : d(std::move(res.d))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-VBestSquare &VBestSquare::operator=(VBestSquare &&res) Q_DECL_NOTHROW
+auto VBestSquare::operator=(VBestSquare &&res) noexcept -> VBestSquare &
 {
     std::swap(d, res.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
 void VBestSquare::NewResult(const VBestSquareResData &data)
 {
-    auto SaveResult = [this, data]()
+    auto SaveResult = [this, &data]()
     {
         d->valideResult = true;
         d->data = data;
@@ -106,12 +102,9 @@ void VBestSquare::NewResult(const VBestSquareResData &data)
         {
             if (d->saveLength)
             {
-                if (VFuzzyOnAxis(data.depthPosition, d->data.depthPosition)
-                        && IsImprovedSidePosition(data.sidePosition))
-                {
-                    SaveResult();
-                }
-                else if (data.depthPosition < d->data.depthPosition)
+                if ((VFuzzyOnAxis(data.depthPosition, d->data.depthPosition) &&
+                     IsImprovedSidePosition(data.sidePosition)) ||
+                    data.depthPosition < d->data.depthPosition)
                 {
                     SaveResult();
                 }
@@ -137,55 +130,55 @@ void VBestSquare::NewResult(const VBestSquare &best)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QSizeF VBestSquare::BestSize() const
+auto VBestSquare::BestSize() const -> QSizeF
 {
     return d->data.bestSize;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VBestSquare::GContourEdge() const
+auto VBestSquare::GContourEdge() const -> int
 {
     return d->data.globalI;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VBestSquare::DetailEdge() const
+auto VBestSquare::DetailEdge() const -> int
 {
     return d->data.detJ;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QTransform VBestSquare::Matrix() const
+auto VBestSquare::Matrix() const -> QTransform
 {
     return d->data.resMatrix;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VBestSquare::HasValidResult() const
+auto VBestSquare::HasValidResult() const -> bool
 {
     return d->valideResult;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VBestSquare::Mirror() const
+auto VBestSquare::Mirror() const -> bool
 {
     return d->data.resMirror;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-BestFrom VBestSquare::Type() const
+auto VBestSquare::Type() const -> BestFrom
 {
     return d->data.type;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VBestSquare::IsTerminatedByException() const
+auto VBestSquare::IsTerminatedByException() const -> bool
 {
     return d->terminatedByException;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VBestSquare::ReasonTerminatedByException() const
+auto VBestSquare::ReasonTerminatedByException() const -> QString
 {
     return d->exceptionReason;
 }
@@ -199,28 +192,28 @@ void VBestSquare::TerminatedByException(const QString &reason)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VBestSquareResData VBestSquare::BestResultData() const
+auto VBestSquare::BestResultData() const -> VBestSquareResData
 {
     return d->data;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VBestSquare::IsSaveLength() const
+auto VBestSquare::IsSaveLength() const -> bool
 {
     return d->saveLength;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VBestSquare::IsImprovedSidePosition(qreal sidePosition) const
+auto VBestSquare::IsImprovedSidePosition(qreal sidePosition) const -> bool
 {
     const bool lessThan = d->data.sidePosition < sidePosition;
     const bool greaterThan = d->data.sidePosition > sidePosition;
 
-    return IsPortrait() ?  greaterThan : lessThan;
+    return IsPortrait() ? greaterThan : lessThan;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VBestSquare::IsPortrait() const
+auto VBestSquare::IsPortrait() const -> bool
 {
     return d->isPortrait;
 }
