@@ -28,6 +28,12 @@
 
 #include "vgraphicsfillitem.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
+#include "../vmisc/backport/qpainterstateguard.h"
+#else
+#include <QPainterStateGuard>
+#endif
+
 //---------------------------------------------------------------------------------------------------------------------
 VGraphicsFillItem::VGraphicsFillItem(QGraphicsItem *parent)
   : QGraphicsPathItem(parent)
@@ -45,26 +51,31 @@ void VGraphicsFillItem::paint(QPainter *painter, const QStyleOptionGraphicsItem
 {
     Q_UNUSED(option)
     Q_UNUSED(widget)
-    painter->save();
-
-    QPen pen;
+    QPainterStateGuard const guard(painter);
 
     if (m_customPen)
     {
-        pen = this->pen();
+        painter->setPen(this->pen());
     }
     else
     {
-        pen = painter->pen();
+        QPen pen = painter->pen();
         pen.setWidthF(width);
         pen.setCapStyle(Qt::RoundCap);
         pen.setJoinStyle(Qt::RoundJoin);
+        painter->setPen(pen);
+    }
+
+    if (m_noBrush)
+    {
+        painter->setBrush(QBrush(Qt::NoBrush));
+    }
+    else
+    {
+        painter->setBrush(painter->pen().color());
     }
-    painter->setPen(pen);
 
-    painter->setBrush(painter->pen().color());
     painter->drawPath(path());
-    painter->restore();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
