@@ -28,12 +28,13 @@
 #ifndef VLAYOUTEXPORTER_H
 #define VLAYOUTEXPORTER_H
 
+#include <QCoreApplication>
 #include <QMargins>
 #include <QPen>
 #include <QRectF>
 #include <QString>
-#include <QCoreApplication>
 
+#include "../vdxf/dxfdef.h"
 #include "../vlayout/vlayoutdef.h"
 
 class QGraphicsScene;
@@ -43,6 +44,7 @@ class VLayoutPiece;
 class VLayoutExporter
 {
     Q_DECLARE_TR_FUNCTIONS(VLayoutExporter) // NOLINT
+
 public:
     VLayoutExporter() = default;
 
@@ -76,46 +78,77 @@ public:
     auto BinaryDxfFormat() const -> bool;
     void SetBinaryDxfFormat(bool binaryFormat);
 
+    auto DxfApparelCompatibility() const -> DXFApparelCompatibility;
+    void SetDxfApparelCompatibility(DXFApparelCompatibility mode);
+
+    auto IsShowGrainline() const -> bool;
+    void SetShowGrainline(bool show);
+
     auto DxfVersion() const -> int;
     void SetDxfVersion(int dxfVersion);
 
-    void ExportToSVG(QGraphicsScene *scene) const;
-    void ExportToPNG(QGraphicsScene *scene) const;
-    void ExportToTIF(QGraphicsScene *scene) const;
-    void ExportToPDF(QGraphicsScene *scene) const;
+    void SetBoundaryTogetherWithNotches(bool value);
+    auto IsBoundaryTogetherWithNotches() const -> bool;
+
+    void ExportToSVG(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const;
+    void ExportToPNG(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const;
+    void ExportToTIF(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const;
+    void ExportToPDF(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const;
     void ExportToOBJ(QGraphicsScene *scene) const;
-    void ExportToPS(QGraphicsScene *scene) const;
-    void ExportToEPS(QGraphicsScene *scene) const;
+    void ExportToPS(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const;
+    void ExportToEPS(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const;
     void ExportToFlatDXF(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const;
     void ExportToAAMADXF(const QVector<VLayoutPiece> &details) const;
     void ExportToASTMDXF(const QVector<VLayoutPiece> &details) const;
     void ExportToRLD(const QVector<VLayoutPiece> &details) const;
+    void ExportToHPGL(const QVector<VLayoutPiece> &details) const;
+    void ExportToHPGL2(const QVector<VLayoutPiece> &details) const;
 
     static auto SupportPDFConversion() -> bool;
 
-
-    static QString ExportFormatDescription(LayoutExportFormats format);
-    static QString ExportFormatSuffix(LayoutExportFormats format);
+    static auto ExportFormatDescription(LayoutExportFormats format) -> QString;
+    static auto ExportFormatSuffix(LayoutExportFormats format) -> QString;
     static void PdfToPs(const QStringList &params);
+    static void PrepareGrainlineForExport(const QList<QGraphicsItem *> &items, bool showGrainline);
+    static void RestoreGrainlineAfterExport(const QList<QGraphicsItem *> &items);
+
+    static auto LayoutExportFileFormat(LayoutExportFormats format) -> LayoutExportFileFormat;
+    static auto MapLayoutExportFormats(enum LayoutExportFileFormat format) -> QVector<LayoutExportFormats>;
+    static auto AllLayoutExportFormats() -> QVector<LayoutExportFormats>;
 
     auto offset() const -> QPointF;
     void SetOffset(const QPointF &newOffset);
 
-private:
-    QString   m_fileName{};
-    QMarginsF m_margins{};
-    QRectF    m_imageRect{};
-    qreal     m_xScale{1.0};
-    qreal     m_yScale{1.0};
-    QString   m_title{};
-    QString   m_description{};
-    QPen      m_pen{};
-    bool      m_ignorePrinterMargins{false};
-    bool      m_binaryDxfFormat{false};
-    int       m_dxfVersion{0};
-    QPointF   m_offset{};
+    auto GetSingleLineFont() const -> bool;
+    void SetSingleLineFont(bool newSingleLineFont);
 
-    void ExportToPDF(QGraphicsScene *scene, const QString &filename) const;
+    auto GetSingleStrokeOutlineFont() const -> bool;
+    void SetSingleStrokeOutlineFont(bool newSingleStrokeOutlineFont);
+
+    auto GetPenWidth() const -> int;
+    void SetPenWidth(int newPenWidth);
+
+private:
+    QString m_fileName{};
+    QMarginsF m_margins{};
+    QRectF m_imageRect{};
+    qreal m_xScale{1.0};
+    qreal m_yScale{1.0};
+    QString m_title{};
+    QString m_description{};
+    QPen m_pen{};
+    bool m_ignorePrinterMargins{false};
+    bool m_binaryDxfFormat{false};
+    bool m_showGrainline{true};
+    int m_dxfVersion{0};
+    QPointF m_offset{};
+    bool m_singleLineFont{false};
+    bool m_singleStrokeOutlineFont{false};
+    int m_penWidth{1};
+    bool m_togetherWithNotches{false};
+    DXFApparelCompatibility m_dxfCompatibility{DXFApparelCompatibility::STANDARD};
+
+    void ExportToPDF(QGraphicsScene *scene, const QList<QGraphicsItem *> &details, const QString &filename) const;
 };
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -250,4 +283,64 @@ inline void VLayoutExporter::SetDxfVersion(int dxfVersion)
     m_dxfVersion = dxfVersion;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+inline void VLayoutExporter::SetBoundaryTogetherWithNotches(bool value)
+{
+    m_togetherWithNotches = value;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+inline auto VLayoutExporter::IsBoundaryTogetherWithNotches() const -> bool
+{
+    return m_togetherWithNotches;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+inline auto VLayoutExporter::offset() const -> QPointF
+{
+    return m_offset;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+inline void VLayoutExporter::SetOffset(const QPointF &newOffset)
+{
+    m_offset = newOffset;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+inline auto VLayoutExporter::GetSingleLineFont() const -> bool
+{
+    return m_singleLineFont;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+inline void VLayoutExporter::SetSingleLineFont(bool newSingleLineFont)
+{
+    m_singleLineFont = newSingleLineFont;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+inline auto VLayoutExporter::GetSingleStrokeOutlineFont() const -> bool
+{
+    return m_singleStrokeOutlineFont;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+inline void VLayoutExporter::SetSingleStrokeOutlineFont(bool newSingleStrokeOutlineFont)
+{
+    m_singleStrokeOutlineFont = newSingleStrokeOutlineFont;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+inline int VLayoutExporter::GetPenWidth() const
+{
+    return m_penWidth;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+inline void VLayoutExporter::SetPenWidth(int newPenWidth)
+{
+    m_penWidth = newPenWidth;
+}
+
 #endif // VLAYOUTEXPORTER_H
