@@ -32,43 +32,19 @@
 #include <QGraphicsRectItem>
 #include <QRectF>
 #include <QThreadPool>
+#include <QtMath>
 
-#include "../vmisc/def.h"
-#include "../vmisc/vmath.h"
-#include "../vmisc/compatibility.h"
-#include "vlayoutpiece.h"
-#include "vlayoutpaper.h"
 #include "../ifc/exception/vexceptionterminatedposition.h"
+#include "../vmisc/compatibility.h"
+#include "../vmisc/def.h"
+#include "vlayoutpaper.h"
+#include "vlayoutpiece.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 VLayoutGenerator::VLayoutGenerator(QObject *parent)
-    : QObject(parent),
-      papers(),
-      bank(new VBank()),
-      paperHeight(0),
-      paperWidth(0),
-      margins(),
-      usePrinterFields(true),
-#ifdef Q_CC_MSVC
-      // See https://stackoverflow.com/questions/15750917/initializing-stdatomic-bool
-      stopGeneration(ATOMIC_VAR_INIT(false)),
-#else
-      stopGeneration(false),
-#endif
-      state(LayoutErrors::NoError),
-      shift(0),
-      rotate(true),
-      followGrainline(false),
-      rotationNumber(2),
-      autoCropLength(false),
-      autoCropWidth(false),
-      saveLength(false),
-      unitePages(false),
-      stripOptimizationEnabled(false),
-      multiplier(1),
-      stripOptimization(false),
-      textAsPaths(false)
-{}
+  : QObject(parent)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 VLayoutGenerator::~VLayoutGenerator()
@@ -96,7 +72,7 @@ void VLayoutGenerator::SetCaseType(Cases caseType)
 
 //---------------------------------------------------------------------------------------------------------------------
 // cppcheck-suppress unusedFunction
-int VLayoutGenerator::DetailsCount()
+auto VLayoutGenerator::DetailsCount() -> vsizetype
 {
     return bank->AllDetailsCount();
 }
@@ -133,7 +109,7 @@ void VLayoutGenerator::Generate(const QElapsedTimer &timer, qint64 timeout, Layo
 
     if (VFuzzyComparePossibleNulls(shift, -1))
     {
-        if (bank->PrepareDetails())
+        if (bank->PrepareDetails(togetherWithNotches))
         {
             SetShift(ToPixel(1, Unit::Cm));
         }
@@ -149,10 +125,10 @@ void VLayoutGenerator::Generate(const QElapsedTimer &timer, qint64 timeout, Layo
 
             auto SetStrip = [this, b](int &side)
             {
-                if (side >= b*2)
+                if (side >= b * 2)
                 {
                     stripOptimizationEnabled = true;
-                    side = qFloor(side / qFloor(side/b));
+                    side = qFloor(side / qFloor(side / b));
                 }
             };
 
@@ -213,8 +189,6 @@ void VLayoutGenerator::Generate(const QElapsedTimer &timer, qint64 timeout, Layo
                     return;
                 }
 
-                QCoreApplication::processEvents();
-
                 if (stopGeneration.load())
                 {
                     break;
@@ -224,7 +198,7 @@ void VLayoutGenerator::Generate(const QElapsedTimer &timer, qint64 timeout, Layo
                 {
                     return;
                 }
-            } while(bank->LeftToArrange() > 0);
+            } while (bank->LeftToArrange() > 0);
 
             if (stopGeneration.load())
             {
@@ -280,7 +254,7 @@ void VLayoutGenerator::Generate(const QElapsedTimer &timer, qint64 timeout, Layo
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VLayoutGenerator::LayoutEfficiency() const
+auto VLayoutGenerator::LayoutEfficiency() const -> qreal
 {
     qreal efficiency = 0;
     if (not papers.isEmpty())
@@ -291,27 +265,36 @@ qreal VLayoutGenerator::LayoutEfficiency() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-LayoutErrors VLayoutGenerator::State() const
+auto VLayoutGenerator::State() const -> LayoutErrors
 {
     return state;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QList<QGraphicsItem *> VLayoutGenerator::GetPapersItems() const
+auto VLayoutGenerator::PapersCount() const -> vsizetype
+{
+    return papers.size();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VLayoutGenerator::GetPapersItems() const -> QList<QGraphicsItem *>
 {
     QList<QGraphicsItem *> list;
-    for (auto &paper : papers)
+    list.reserve(papers.count());
+    for (const auto &paper : papers)
     {
-        list.append(paper.GetPaperItem(autoCropLength, autoCropWidth, IsTestAsPaths()));
+        list.append(
+            paper.GetPaperItem(autoCropLength, autoCropWidth, textAsPaths, togetherWithNotches, showLayoutAllowance));
     }
     return list;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QList<QGraphicsItem *> VLayoutGenerator::GetGlobalContours() const
+auto VLayoutGenerator::GetGlobalContours() const -> QList<QGraphicsItem *>
 {
     QList<QGraphicsItem *> list;
-    for (auto &paper : papers)
+    list.reserve(papers.count());
+    for (const auto &paper : papers)
     {
         list.append(paper.GetGlobalContour());
     }
@@ -319,21 +302,23 @@ QList<QGraphicsItem *> VLayoutGenerator::GetGlobalContours() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QList<QList<QGraphicsItem *> > VLayoutGenerator::GetAllDetailsItems() const
+auto VLayoutGenerator::GetAllDetailsItems() const -> QList<QList<QGraphicsItem *>>
 {
-    QList<QList<QGraphicsItem *> > list;
-    for (auto &paper : papers)
+    QList<QList<QGraphicsItem *>> list;
+    list.reserve(papers.count());
+    for (const auto &paper : papers)
     {
-        list.append(paper.GetItemDetails(IsTestAsPaths()));
+        list.append(paper.GetItemDetails(textAsPaths, togetherWithNotches, showLayoutAllowance));
     }
     return list;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<QVector<VLayoutPiece> > VLayoutGenerator::GetAllDetails() const
+auto VLayoutGenerator::GetAllDetails() const -> QVector<QVector<VLayoutPiece>>
 {
-    QVector<QVector<VLayoutPiece> > list;
-    for (auto &paper : papers)
+    QVector<QVector<VLayoutPiece>> list;
+    list.reserve(papers.count());
+    for (const auto &paper : papers)
     {
         list.append(paper.GetDetails());
     }
@@ -358,7 +343,7 @@ void VLayoutGenerator::Timeout()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::IsStripOptimization() const
+auto VLayoutGenerator::IsStripOptimization() const -> bool
 {
     return stripOptimization;
 }
@@ -370,7 +355,7 @@ void VLayoutGenerator::SetStripOptimization(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::IsTestAsPaths() const
+auto VLayoutGenerator::IsTestAsPaths() const -> bool
 {
     return textAsPaths;
 }
@@ -382,20 +367,42 @@ void VLayoutGenerator::SetTextAsPaths(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::IsRotationNeeded() const
+auto VLayoutGenerator::IsBoundaryTogetherWithNotches() const -> bool
+{
+    return togetherWithNotches;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutGenerator::SetBoundaryTogetherWithNotches(bool value)
+{
+    togetherWithNotches = value;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VLayoutGenerator::IsShowLayoutAllowance() const -> bool
+{
+    return showLayoutAllowance;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutGenerator::SetShowLayoutAllowance(bool value)
+{
+    showLayoutAllowance = value;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VLayoutGenerator::IsRotationNeeded() const -> bool
 {
     if (followGrainline)
     {
         return bank->IsRotationNeeded();
     }
-    else
-    {
-        return true;
-    }
+
+    return true;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint8 VLayoutGenerator::GetMultiplier() const
+auto VLayoutGenerator::GetMultiplier() const -> quint8
 {
     return multiplier;
 }
@@ -418,19 +425,19 @@ void VLayoutGenerator::SetMultiplier(quint8 value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VLayoutGenerator::PageHeight() const
+auto VLayoutGenerator::PageHeight() const -> int
 {
     return static_cast<int>(paperHeight - (margins.top() + margins.bottom()));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VLayoutGenerator::PageWidth() const
+auto VLayoutGenerator::PageWidth() const -> int
 {
     return static_cast<int>(paperWidth - (margins.left() + margins.right()));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::IsPortrait() const
+auto VLayoutGenerator::IsPortrait() const -> bool
 {
     return PageHeight() >= PageWidth();
 }
@@ -449,9 +456,9 @@ void VLayoutGenerator::GatherPages()
         {
             int paperHeight = qRound(rec.y() + rec.height());
 
-            if (i != papers.size()-1)
+            if (i != papers.size() - 1)
             {
-                paperHeight += qRound(bank->GetLayoutWidth()*2);
+                paperHeight += qRound(bank->GetLayoutWidth() * 2);
             }
 
             if (length + paperHeight <= PageHeight())
@@ -462,7 +469,7 @@ void VLayoutGenerator::GatherPages()
             else
             {
                 length = 0; // Start new paper
-                ++j;// New paper
+                ++j;        // New paper
                 UniteDetails(j, nDetails, length, i);
                 length += paperHeight;
             }
@@ -471,9 +478,9 @@ void VLayoutGenerator::GatherPages()
         {
             int paperWidth = qRound(rec.x() + rec.width());
 
-            if (i != papers.size()-1)
+            if (i != papers.size() - 1)
             {
-                paperWidth += qRound(bank->GetLayoutWidth()*2);
+                paperWidth += qRound(bank->GetLayoutWidth() * 2);
             }
 
             if (length + paperWidth <= PageWidth())
@@ -484,7 +491,7 @@ void VLayoutGenerator::GatherPages()
             else
             {
                 length = 0; // Start new paper
-                ++j;// New paper
+                ++j;        // New paper
                 UniteDetails(j, nDetails, length, i);
                 length += paperWidth;
             }
@@ -524,7 +531,7 @@ void VLayoutGenerator::OptimizeWidth()
         newDetails.reserve(details.size());
         for (auto &d : details)
         {
-            IsPortrait() ? d.Translate(-rec.x()+1, 0) : d.Translate(0, -rec.y()+1);
+            IsPortrait() ? d.Translate(-rec.x() + 1, 0) : d.Translate(0, -rec.y() + 1);
             newDetails.append(d);
         }
 
@@ -541,7 +548,7 @@ void VLayoutGenerator::UnitePages()
     }
 
     QList<qreal> papersLength;
-    QList<QList<VLayoutPiece> > nDetails;
+    QList<QList<VLayoutPiece>> nDetails;
     qreal length = 0;
     int j = 0; // papers count
 
@@ -560,9 +567,9 @@ void VLayoutGenerator::UnitePages()
                 paperHeight = papers.at(i).GetHeight();
             }
 
-            if (i != papers.size()-1)
+            if (i != papers.size() - 1)
             {
-                paperHeight = qRound(paperHeight + bank->GetLayoutWidth()*2);
+                paperHeight = qRound(paperHeight + bank->GetLayoutWidth() * 2);
             }
 
             if (length + paperHeight <= QIMAGE_MAX)
@@ -574,7 +581,7 @@ void VLayoutGenerator::UnitePages()
             else
             {
                 length = 0; // Start new paper
-                ++j;// New paper
+                ++j;        // New paper
                 UniteDetails(j, nDetails, length, i);
                 length += paperHeight;
                 UnitePapers(j, papersLength, length);
@@ -593,9 +600,9 @@ void VLayoutGenerator::UnitePages()
                 paperWidth = papers.at(i).GetWidth();
             }
 
-            if (i != papers.size()-1)
+            if (i != papers.size() - 1)
             {
-                paperWidth = qRound(paperWidth + bank->GetLayoutWidth()*2);
+                paperWidth = qRound(paperWidth + bank->GetLayoutWidth() * 2);
             }
 
             if (length + paperWidth <= QIMAGE_MAX)
@@ -607,7 +614,7 @@ void VLayoutGenerator::UnitePages()
             else
             {
                 length = 0; // Start new paper
-                ++j;// New paper
+                ++j;        // New paper
                 UniteDetails(j, nDetails, length, i);
                 length += paperWidth;
                 UnitePapers(j, papersLength, length);
@@ -619,8 +626,8 @@ void VLayoutGenerator::UnitePages()
     nPapers.reserve(nDetails.size());
     for (int i = 0; i < nDetails.size(); ++i)
     {
-        const int height = IsPortrait() ? qRound(papersLength.at(i)+accuracyPointOnLine*4) : PageHeight();
-        const int width = IsPortrait() ? PageWidth() : qRound(papersLength.at(i)+accuracyPointOnLine*4);
+        const int height = IsPortrait() ? qRound(papersLength.at(i) + accuracyPointOnLine * 4) : PageHeight();
+        const int width = IsPortrait() ? PageWidth() : qRound(papersLength.at(i) + accuracyPointOnLine * 4);
 
         VLayoutPaper paper(height, width, bank->GetLayoutWidth());
         paper.SetShift(shift);
@@ -639,10 +646,10 @@ void VLayoutGenerator::UnitePages()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VLayoutGenerator::UniteDetails(int j, QList<QList<VLayoutPiece> > &nDetails, qreal length, int i) const
+void VLayoutGenerator::UniteDetails(int j, QList<QList<VLayoutPiece>> &nDetails, qreal length, int i) const
 {
     if ((j == 0 && nDetails.isEmpty()) || j >= nDetails.size())
-    {//First or new details in paper
+    { // First or new details in paper
         nDetails.insert(j, MoveDetails(length, papers.at(i).GetDetails()));
     }
     else
@@ -665,7 +672,7 @@ void VLayoutGenerator::UnitePapers(int j, QList<qreal> &papersLength, qreal leng
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QList<VLayoutPiece> VLayoutGenerator::MoveDetails(qreal length, const QVector<VLayoutPiece> &details) const
+auto VLayoutGenerator::MoveDetails(qreal length, const QVector<VLayoutPiece> &details) const -> QList<VLayoutPiece>
 {
     if (qFuzzyIsNull(length))
     {
@@ -673,6 +680,7 @@ QList<VLayoutPiece> VLayoutGenerator::MoveDetails(qreal length, const QVector<VL
     }
 
     QList<VLayoutPiece> newDetails;
+    newDetails.reserve(details.size());
     for (auto d : details)
     {
         IsPortrait() ? d.Translate(0, length) : d.Translate(length, 0);
@@ -691,14 +699,14 @@ QList<VLayoutPiece> VLayoutGenerator::MoveDetails(qreal length, const QVector<VL
  *
  * @return master page
  */
-VLayoutPaper VLayoutGenerator::MasterPage() const
+auto VLayoutGenerator::MasterPage() const -> VLayoutPaper
 {
     if (papers.size() < 2)
     {
-        return ConstFirst(papers);
+        return papers.constFirst();
     }
 
-    QList<QList<VLayoutPiece> > nDetails;
+    QList<QList<VLayoutPiece>> nDetails;
     qreal length = 0;
     const int j = 0; // papers count. Always 1.
 
@@ -717,9 +725,9 @@ VLayoutPaper VLayoutGenerator::MasterPage() const
                 paperHeight = papers.at(i).GetHeight();
             }
 
-            if (i != papers.size()-1)
+            if (i != papers.size() - 1)
             {
-                paperHeight = qRound(paperHeight + bank->GetLayoutWidth()*2);
+                paperHeight = qRound(paperHeight + bank->GetLayoutWidth() * 2);
             }
 
             UniteDetails(j, nDetails, length, i);
@@ -738,9 +746,9 @@ VLayoutPaper VLayoutGenerator::MasterPage() const
                 paperWidth = papers.at(i).GetWidth();
             }
 
-            if (i != papers.size()-1)
+            if (i != papers.size() - 1)
             {
-                paperWidth = qRound(paperWidth + bank->GetLayoutWidth()*2);
+                paperWidth = qRound(paperWidth + bank->GetLayoutWidth() * 2);
             }
 
             UniteDetails(j, nDetails, length, i);
@@ -748,8 +756,8 @@ VLayoutPaper VLayoutGenerator::MasterPage() const
         }
     }
 
-    const int height = IsPortrait() ? qRound(length+accuracyPointOnLine*4) : PageHeight();
-    const int width = IsPortrait() ? PageWidth() : qRound(length+accuracyPointOnLine*4);
+    const int height = IsPortrait() ? qRound(length + accuracyPointOnLine * 4) : PageHeight();
+    const int width = IsPortrait() ? PageWidth() : qRound(length + accuracyPointOnLine * 4);
 
     VLayoutPaper paper(height, width, bank->GetLayoutWidth());
     paper.SetShift(shift);
@@ -764,7 +772,7 @@ VLayoutPaper VLayoutGenerator::MasterPage() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::IsUnitePages() const
+auto VLayoutGenerator::IsUnitePages() const -> bool
 {
     return unitePages;
 }
@@ -776,7 +784,7 @@ void VLayoutGenerator::SetUnitePages(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::IsSaveLength() const
+auto VLayoutGenerator::IsSaveLength() const -> bool
 {
     return saveLength;
 }
@@ -788,7 +796,7 @@ void VLayoutGenerator::SetSaveLength(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::IsPreferOneSheetSolution() const
+auto VLayoutGenerator::IsPreferOneSheetSolution() const -> bool
 {
     return preferOneSheetSolution;
 }
@@ -800,7 +808,7 @@ void VLayoutGenerator::SetPreferOneSheetSolution(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::GetAutoCropLength() const
+auto VLayoutGenerator::GetAutoCropLength() const -> bool
 {
     return autoCropLength;
 }
@@ -812,7 +820,7 @@ void VLayoutGenerator::SetAutoCropLength(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::GetAutoCropWidth() const
+auto VLayoutGenerator::GetAutoCropWidth() const -> bool
 {
     return autoCropWidth;
 }
@@ -825,7 +833,7 @@ void VLayoutGenerator::SetAutoCropWidth(bool value)
 
 //---------------------------------------------------------------------------------------------------------------------
 // cppcheck-suppress unusedFunction
-int VLayoutGenerator::GetRotationNumber() const
+auto VLayoutGenerator::GetRotationNumber() const -> int
 {
     return rotationNumber;
 }
@@ -842,7 +850,7 @@ void VLayoutGenerator::SetRotationNumber(int value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::GetRotate() const
+auto VLayoutGenerator::GetRotate() const -> bool
 {
     return rotate;
 }
@@ -854,7 +862,7 @@ void VLayoutGenerator::SetRotate(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::GetFollowGrainline() const
+auto VLayoutGenerator::GetFollowGrainline() const -> bool
 {
     return followGrainline;
 }
@@ -866,7 +874,7 @@ void VLayoutGenerator::SetFollowGrainline(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::GetManualPriority() const
+auto VLayoutGenerator::GetManualPriority() const -> bool
 {
     return bank->GetManualPriority();
 }
@@ -878,7 +886,7 @@ void VLayoutGenerator::SetManualPriority(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::IsNestQuantity() const
+auto VLayoutGenerator::IsNestQuantity() const -> bool
 {
     return bank->IsNestQuantity();
 }
@@ -890,7 +898,7 @@ void VLayoutGenerator::SetNestQuantity(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VLayoutGenerator::GetPaperWidth() const
+auto VLayoutGenerator::GetPaperWidth() const -> qreal
 {
     return paperWidth;
 }
@@ -902,13 +910,13 @@ void VLayoutGenerator::SetPaperWidth(qreal value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VLayoutGenerator::GetNestingTime() const
+auto VLayoutGenerator::GetNestingTime() const -> int
 {
     return nestingTime;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VLayoutGenerator::GetNestingTimeMSecs() const
+auto VLayoutGenerator::GetNestingTimeMSecs() const -> int
 {
     return nestingTime * 60000;
 }
@@ -920,7 +928,7 @@ void VLayoutGenerator::SetNestingTime(int value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VLayoutGenerator::GetEfficiencyCoefficient() const
+auto VLayoutGenerator::GetEfficiencyCoefficient() const -> qreal
 {
     return efficiencyCoefficient;
 }
@@ -932,13 +940,13 @@ void VLayoutGenerator::SetEfficiencyCoefficient(qreal coefficient)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutGenerator::IsUsePrinterFields() const
+auto VLayoutGenerator::IsUsePrinterFields() const -> bool
 {
     return usePrinterFields;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QMarginsF VLayoutGenerator::GetPrinterFields() const
+auto VLayoutGenerator::GetPrinterFields() const -> QMarginsF
 {
     return margins;
 }
@@ -951,7 +959,7 @@ void VLayoutGenerator::SetPrinterFields(bool usePrinterFields, const QMarginsF &
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VLayoutGenerator::GetShift() const
+auto VLayoutGenerator::GetShift() const -> qreal
 {
     return shift;
 }
@@ -963,7 +971,7 @@ void VLayoutGenerator::SetShift(qreal shift)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VLayoutGenerator::GetPaperHeight() const
+auto VLayoutGenerator::GetPaperHeight() const -> qreal
 {
     return paperHeight;
 }
