@@ -85,14 +85,22 @@ public:
     auto GetUniqueID() const -> QString override;
 
     auto GetMappedContourPoints() const -> QVector<VLayoutPoint>;
-    auto GetMappedFullContourPoints() const -> QVector<VLayoutPoint>;
-    auto GetFullContourPoints() const -> QVector<VLayoutPoint>;
+    auto GetMappedFullContourPoints(bool togetherWithNotches = false,
+                                    bool drawMode = false,
+                                    bool layoutAllowance = false) const -> QVector<VLayoutPoint>;
+    auto GetFullContourPoints(bool togetherWithNotches = false,
+                              bool drawMode = false,
+                              bool layoutAllowance = false) const -> QVector<VLayoutPoint>;
     auto GetContourPoints() const -> QVector<VLayoutPoint>;
     void SetContourPoints(const QVector<VLayoutPoint> &points, bool hideMainPath = false);
 
     auto GetMappedSeamAllowancePoints() const -> QVector<VLayoutPoint>;
-    auto GetMappedFullSeamAllowancePoints() const -> QVector<VLayoutPoint>;
-    auto GetFullSeamAllowancePoints() const -> QVector<VLayoutPoint>;
+    auto GetMappedFullSeamAllowancePoints(bool togetherWithNotches = false,
+                                          bool drawMode = false,
+                                          bool layoutAllowance = false) const -> QVector<VLayoutPoint>;
+    auto GetFullSeamAllowancePoints(bool togetherWithNotches = false,
+                                    bool drawMode = false,
+                                    bool layoutAllowance = false) const -> QVector<VLayoutPoint>;
     auto GetSeamAllowancePoints() const -> QVector<VLayoutPoint>;
     void SetSeamAllowancePoints(const QVector<VLayoutPoint> &points, bool seamAllowance = true,
                                 bool seamAllowanceBuiltIn = false);
@@ -116,11 +124,11 @@ public:
     void SetInternalPaths(const QVector<VLayoutPiecePath> &internalPaths);
 
     auto GetPieceText() const -> QStringList;
-    void SetPieceText(VAbstractPattern *pDoc, const QString &qsName, const VPieceLabelData &data, const QFont &font,
-                      const QString &SVGFontFamily, const VContainer *pattern);
+    void SetPieceText(const VAbstractPattern *pDoc, const QString &qsName, const VPieceLabelData &data,
+                      const QFont &font, const QString &SVGFontFamily, const VContainer *pattern);
 
     auto GetPatternText() const -> QStringList;
-    void SetPatternInfo(VAbstractPattern *pDoc, const VPatternLabelData &geom, const QFont &font,
+    void SetPatternInfo(const VAbstractPattern *pDoc, const VPatternLabelData &geom, const QFont &font,
                         const QString &SVGFontFamily, const VContainer *pattern);
 
     void SetGrainline(const VGrainlineData &geom, const VContainer *pattern);
@@ -172,6 +180,9 @@ public:
     auto GetPatternLabelData() const -> VTextManager;
     void SetPatternLabelData(const VTextManager &data);
 
+    auto GetMappedCorrectedMirrorLine(bool togetherWithNotches = false) const -> QLineF;
+    auto GetCorrectedMirrorLine(bool togetherWithNotches = false) const -> QLineF;
+
     auto GetMappedSeamMirrorLine() const -> QLineF;
     auto GetSeamMirrorLine() const -> QLineF;
     void SetSeamMirrorLine(const QLineF &line);
@@ -254,7 +265,7 @@ private:
     auto DetailPath() const -> QVector<VLayoutPoint>;
 
     Q_REQUIRED_RESULT auto GetMainItem(bool togetherWithNotches, bool showLayoutAllowance) const -> QGraphicsPathItem *;
-    Q_REQUIRED_RESULT auto GetMainPathItem() const -> QGraphicsPathItem *;
+    Q_REQUIRED_RESULT auto GetExternalContourPathItem() const -> QGraphicsPathItem *;
 
     void LabelStringsSVGFont(QGraphicsItem *parent, const QVector<QPointF> &labelShape, const VTextManager &tm,
                              bool textAsPaths) const;
@@ -271,6 +282,8 @@ private:
 
     auto Edge(const QVector<QPointF> &path, int i) const -> QLineF;
     auto EdgeByPoint(const QVector<QPointF> &path, const QPointF &p1) const -> EdgeIndex;
+
+    auto CorrectSeamAllowanceMirrorLine() const -> QLineF;
 };
 
 QT_WARNING_POP
