@@ -28,23 +28,19 @@
 
 #include "vlayoutpiecepath.h"
 #include "vlayoutpiecepath_p.h"
-#include "vlayoutdef.h"
 
 #include <QPainterPath>
 
-const quint32 VLayoutPiecePathData::streamHeader = 0xA53F0225; // CRC-32Q string "VLayoutPiecePathData"
-const quint16 VLayoutPiecePathData::classVersion = 1;
-
 // Friend functions
 //---------------------------------------------------------------------------------------------------------------------
-QDataStream &operator<<(QDataStream &dataStream, const VLayoutPiecePath &path)
+auto operator<<(QDataStream &dataStream, const VLayoutPiecePath &path) -> QDataStream &
 {
     dataStream << *path.d;
     return dataStream;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDataStream &operator>>(QDataStream &dataStream, VLayoutPiecePath &path)
+auto operator>>(QDataStream &dataStream, VLayoutPiecePath &path) -> QDataStream &
 {
     dataStream >> *path.d;
     return dataStream;
@@ -52,26 +48,23 @@ QDataStream &operator>>(QDataStream &dataStream, VLayoutPiecePath &path)
 
 //---------------------------------------------------------------------------------------------------------------------
 VLayoutPiecePath::VLayoutPiecePath()
-    : d(new VLayoutPiecePathData)
+  : d(new VLayoutPiecePathData)
 {
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VLayoutPiecePath::VLayoutPiecePath(const QVector<QPointF> &points)
-    : d(new VLayoutPiecePathData(points))
+VLayoutPiecePath::VLayoutPiecePath(const QVector<VLayoutPoint> &points)
+  : d(new VLayoutPiecePathData(points))
 {
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VLayoutPiecePath::VLayoutPiecePath(const VLayoutPiecePath &path)
-    : d(path.d)
-{
-}
+COPY_CONSTRUCTOR_IMPL(VLayoutPiecePath)
 
 //---------------------------------------------------------------------------------------------------------------------
-VLayoutPiecePath &VLayoutPiecePath::operator=(const VLayoutPiecePath &path)
+auto VLayoutPiecePath::operator=(const VLayoutPiecePath &path) -> VLayoutPiecePath &
 {
-    if ( &path == this )
+    if (&path == this)
     {
         return *this;
     }
@@ -79,51 +72,50 @@ VLayoutPiecePath &VLayoutPiecePath::operator=(const VLayoutPiecePath &path)
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VLayoutPiecePath::VLayoutPiecePath(VLayoutPiecePath &&path) Q_DECL_NOTHROW
-    : d(std::move(path.d))
-{}
+VLayoutPiecePath::VLayoutPiecePath(VLayoutPiecePath &&path) noexcept
+  : d(std::move(path.d))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-VLayoutPiecePath &VLayoutPiecePath::operator=(VLayoutPiecePath &&path) Q_DECL_NOTHROW
+auto VLayoutPiecePath::operator=(VLayoutPiecePath &&path) noexcept -> VLayoutPiecePath &
 {
     std::swap(d, path.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
-VLayoutPiecePath::~VLayoutPiecePath()
-{
-}
+VLayoutPiecePath::~VLayoutPiecePath() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
-QPainterPath VLayoutPiecePath::GetPainterPath() const
+auto VLayoutPiecePath::GetPainterPath() const -> QPainterPath
 {
     QPainterPath path;
     if (not d->m_points.isEmpty())
     {
-        path.addPolygon(QPolygonF(d->m_points));
+        QVector<QPointF> points;
+        CastTo(d->m_points, points);
+        path.addPolygon(QPolygonF(points));
         path.setFillRule(Qt::WindingFill);
     }
     return path;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<QPointF> VLayoutPiecePath::Points() const
+auto VLayoutPiecePath::Points() const -> QVector<VLayoutPoint>
 {
     return d->m_points;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VLayoutPiecePath::SetPoints(const QVector<QPointF> &points)
+void VLayoutPiecePath::SetPoints(const QVector<VLayoutPoint> &points)
 {
     d->m_points = points;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-Qt::PenStyle VLayoutPiecePath::PenStyle() const
+auto VLayoutPiecePath::PenStyle() const -> Qt::PenStyle
 {
     return d->m_penStyle;
 }
@@ -135,7 +127,7 @@ void VLayoutPiecePath::SetPenStyle(const Qt::PenStyle &penStyle)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLayoutPiecePath::IsCutPath() const
+auto VLayoutPiecePath::IsCutPath() const -> bool
 {
     return d->m_cut;
 }
@@ -145,3 +137,15 @@ void VLayoutPiecePath::SetCutPath(bool cut)
 {
     d->m_cut = cut;
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VLayoutPiecePath::IsNotMirrored() const -> bool
+{
+    return d->m_notMirrored;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiecePath::SetNotMirrored(bool value)
+{
+    d->m_notMirrored = value;
+}
