@@ -27,31 +27,30 @@
  *************************************************************************/
 #include "vprintlayout.h"
 
-#include <QPrinterInfo>
-#include <QMessageBox>
-#include <QSpacerItem>
-#include <QGridLayout>
-#include <QPrintDialog>
-#include <QGuiApplication>
-#include <QDir>
 #include <QDebug>
+#include <QDir>
 #include <QGraphicsRectItem>
+#include <QGraphicsScene>
+#include <QGridLayout>
+#include <QGuiApplication>
+#include <QMessageBox>
+#include <QPageSize>
 #include <QPainter>
 #include <QPixmapCache>
-#include <QGraphicsScene>
+#include <QPrintDialog>
 #include <QPrintPreviewDialog>
-#include <QPageSize>
+#include <QPrinterInfo>
+#include <QSpacerItem>
+#include <QtMath>
 
-#include "dialogs/dialoglayoutscale.h"
+#include "../ifc/exception/vexception.h"
+#include "../ifc/xml/vwatermarkconverter.h"
+#include "../vformat/vwatermark.h"
 #include "../vmisc/vabstractvalapplication.h"
+#include "../vpropertyexplorer/checkablemessagebox.h"
+#include "dialogs/dialoglayoutscale.h"
 #include "dialogs/vabstractlayoutdialog.h"
 #include "vposter.h"
-#include "../vformat/vwatermark.h"
-#include "../ifc/xml/vwatermarkconverter.h"
-#include "../ifc/exception/vexception.h"
-#include "../vmisc/vmath.h"
-#include "../vpropertyexplorer/checkablemessagebox.h"
-#include "../vmisc/compatibility.h"
 
 namespace
 {
@@ -59,9 +58,7 @@ namespace
 auto FindPageSizeId(QSizeF size) -> QPageSize::PageSizeId
 {
     auto TestSize = [size](float width, float height)
-    {
-        return size == QSizeF(width, height) || size == QSizeF(height, width);
-    };
+    { return size == QSizeF(width, height) || size == QSizeF(height, width); };
 
     constexpr int A0Width = 841;
     constexpr int A0Height = 1189;
@@ -116,32 +113,33 @@ auto FindPageSizeId(QSizeF size) -> QPageSize::PageSizeId
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-Q_REQUIRED_RESULT auto PreparePrinter(
-        const QPrinterInfo &info, QPrinter::PrinterMode mode = QPrinter::ScreenResolution) -> QSharedPointer<QPrinter>;
+Q_REQUIRED_RESULT auto PreparePrinter(const QPrinterInfo &info, QPrinter::PrinterMode mode = QPrinter::ScreenResolution)
+    -> QSharedPointer<QPrinter>;
 auto PreparePrinter(const QPrinterInfo &info, QPrinter::PrinterMode mode) -> QSharedPointer<QPrinter>
 {
     QPrinterInfo tmpInfo = info;
-    if(tmpInfo.isNull() || tmpInfo.printerName().isEmpty())
+    if (tmpInfo.isNull() || tmpInfo.printerName().isEmpty())
     {
         const QStringList list = QPrinterInfo::availablePrinterNames();
-        if(list.isEmpty())
+        if (list.isEmpty())
         {
             return {};
         }
 
-        tmpInfo = QPrinterInfo::printerInfo(ConstFirst<QString>(list));
+        tmpInfo = QPrinterInfo::printerInfo(list.constFirst());
     }
 
     auto printer = QSharedPointer<QPrinter>(new QPrinter(tmpInfo, mode));
     printer->setResolution(static_cast<int>(PrintDPI));
     return printer;
 }
-}  // namespace
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 VPrintLayout::VPrintLayout(QObject *parent)
-    : QObject(parent)
-{}
+  : QObject(parent)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 VPrintLayout::~VPrintLayout()
@@ -161,7 +159,7 @@ void VPrintLayout::PrintOrigin()
 {
     if (not IsPagesUniform())
     {
-        qCritical()<<tr("For printing multipages document all sheet should have the same size.");
+        qCritical() << tr("For printing multipages document all sheet should have the same size.");
         return;
     }
 
@@ -181,7 +179,7 @@ void VPrintLayout::PrintPreviewOrigin()
 {
     if (not IsPagesUniform())
     {
-        qCritical()<<tr("For previewing multipage document all sheet should have the same size.");
+        qCritical() << tr("For previewing multipage document all sheet should have the same size.");
         return;
     }
 
@@ -194,12 +192,9 @@ void VPrintLayout::PdfTiledFile(const QString &name)
 {
     m_isTiled = true;
 
-    if (m_isLayoutStale)
+    if (m_isLayoutStale && ContinueIfLayoutStale(m_parentWidget) == QMessageBox::No)
     {
-        if (ContinueIfLayoutStale(m_parentWidget) == QMessageBox::No)
-        {
-            return;
-        }
+        return;
     }
     QPrinter printer;
     SetPrinterSettings(&printer, PrintType::PrintPDF, name);
@@ -207,7 +202,7 @@ void VPrintLayout::PdfTiledFile(const QString &name)
     // Call IsPagesFit after setting a printer settings and check if pages is not bigger than printer's paper size
     if (not m_isTiled && not IsPagesFit(printer.pageLayout().paintRectPixels(printer.resolution()).size()))
     {
-        qWarning()<<tr("Pages will be cropped because they do not fit printer paper size.");
+        qWarning() << tr("Pages will be cropped because they do not fit printer paper size.");
     }
 
     printer.setResolution(static_cast<int>(PrintDPI));
@@ -226,20 +221,17 @@ void VPrintLayout::CleanLayout()
 //---------------------------------------------------------------------------------------------------------------------
 void VPrintLayout::PrintLayout()
 {
-    if (m_isLayoutStale)
+    if (m_isLayoutStale && ContinueIfLayoutStale(m_parentWidget) == QMessageBox::No)
     {
-        if (ContinueIfLayoutStale(m_parentWidget) == QMessageBox::No)
-        {
-            return;
-        }
+        return;
     }
     // display print dialog and if accepted print
     QPrinterInfo info = QPrinterInfo::printerInfo(m_layoutPrinterName);
-    if(info.isNull() || info.printerName().isEmpty())
+    if (info.isNull() || info.printerName().isEmpty())
     {
         info = QPrinterInfo::defaultPrinter();
     }
-    QSharedPointer<QPrinter> printer = PreparePrinter(info, QPrinter::HighResolution);
+    QSharedPointer<QPrinter> const printer = PreparePrinter(info, QPrinter::HighResolution);
     if (printer.isNull())
     {
         qCritical("%s\n\n%s", qUtf8Printable(tr("Print error")),
@@ -271,20 +263,17 @@ void VPrintLayout::PrintLayout()
 //---------------------------------------------------------------------------------------------------------------------
 void VPrintLayout::PrintPreview()
 {
-    if (m_isLayoutStale)
+    if (m_isLayoutStale && ContinueIfLayoutStale(m_parentWidget) == QMessageBox::No)
     {
-        if (ContinueIfLayoutStale(m_parentWidget) == QMessageBox::No)
-        {
-            return;
-        }
+        return;
     }
 
     QPrinterInfo info = QPrinterInfo::printerInfo(m_layoutPrinterName);
-    if(info.isNull() || info.printerName().isEmpty())
+    if (info.isNull() || info.printerName().isEmpty())
     {
         info = QPrinterInfo::defaultPrinter();
     }
-    QSharedPointer<QPrinter> printer = PreparePrinter(info);
+    QSharedPointer<QPrinter> const printer = PreparePrinter(info);
     if (printer.isNull())
     {
         qCritical("%s\n\n%s", qUtf8Printable(tr("Print error")),
@@ -324,9 +313,9 @@ void VPrintLayout::PrintPages(QPrinter *printer)
     painter.setRenderHint(QPainter::Antialiasing, true);
     painter.setPen(QPen(Qt::black, VAbstractApplication::VApp()->Settings()->WidthMainLine(), Qt::SolidLine,
                         Qt::RoundCap, Qt::RoundJoin));
-    painter.setBrush ( QBrush ( Qt::NoBrush ) );
+    painter.setBrush(QBrush(Qt::NoBrush));
 
-    int count = 0;
+    vsizetype count = 0;
     QSharedPointer<QVector<PosterData>> poster;
     QSharedPointer<VPoster> posterazor;
 
@@ -334,7 +323,7 @@ void VPrintLayout::PrintPages(QPrinter *printer)
     {
         // when isTiled, the landscape tiles have to be rotated, because the pages
         // stay portrait in the pdf
-        if(m_tiledPDFOrientation == PageOrientation::Landscape)
+        if (m_tiledPDFOrientation == PageOrientation::Landscape)
         {
             const int angle = -90;
             painter.rotate(angle);
@@ -344,13 +333,13 @@ void VPrintLayout::PrintPages(QPrinter *printer)
         poster = QSharedPointer<QVector<PosterData>>(new QVector<PosterData>());
         posterazor = QSharedPointer<VPoster>(new VPoster(printer));
 
-        for (int i=0; i < m_layoutScenes.size(); ++i)
+        for (int i = 0; i < m_layoutScenes.size(); ++i)
         {
             auto *paper = qgraphicsitem_cast<QGraphicsRectItem *>(m_layoutPapers.at(i));
             if (paper != nullptr)
             {
-                QRectF paperRect = paper->rect();
-                QSizeF image(paperRect.width() * m_xscale, paperRect.height() * m_yscale);
+                QRectF const paperRect = paper->rect();
+                QSizeF const image(paperRect.width() * m_xscale, paperRect.height() * m_yscale);
                 *poster += posterazor->Calc(image.toSize(), i, m_tiledPDFOrientation);
             }
         }
@@ -363,7 +352,7 @@ void VPrintLayout::PrintPages(QPrinter *printer)
     }
 
     // Handle the fromPage(), toPage(), supportsMultipleCopies(), and numCopies() values from QPrinter.
-    int firstPage = printer->fromPage() - 1;
+    vsizetype firstPage = printer->fromPage() - 1;
     if (firstPage >= count)
     {
         return;
@@ -373,34 +362,31 @@ void VPrintLayout::PrintPages(QPrinter *printer)
         firstPage = 0;
     }
 
-    int lastPage = printer->toPage() - 1;
+    vsizetype lastPage = printer->toPage() - 1;
     if (lastPage == -1 || lastPage >= count)
     {
         lastPage = count - 1;
     }
 
-    const int numPages = lastPage - firstPage + 1;
+    const vsizetype numPages = lastPage - firstPage + 1;
     int copyCount = 1;
     if (not printer->supportsMultipleCopies())
     {
         copyCount = printer->copyCount();
     }
 
-    VWatermarkData data = WatermarkData();
+    VWatermarkData const data = WatermarkData();
 
     for (int i = 0; i < copyCount; ++i)
     {
         for (int j = 0; j < numPages; ++j)
         {
-            if (i != 0 || j != 0)
+            if ((i != 0 || j != 0) && not printer->newPage())
             {
-                if (not printer->newPage())
-                {
-                    qCritical() << tr("Failed in flushing page to disk, disk full?");
-                    return;
-                }
+                qCritical() << tr("Failed in flushing page to disk, disk full?");
+                return;
             }
-            int index;
+            vsizetype index;
             if (printer->pageOrder() == QPrinter::FirstPageFirst)
             {
                 index = firstPage + j;
@@ -410,7 +396,7 @@ void VPrintLayout::PrintPages(QPrinter *printer)
                 index = lastPage - j;
             }
 
-            int paperIndex = -1;
+            vsizetype paperIndex = -1;
             m_isTiled ? paperIndex = static_cast<int>(poster->at(index).index) : paperIndex = index;
 
             auto *paper = qgraphicsitem_cast<QGraphicsRectItem *>(m_layoutPapers.at(paperIndex));
@@ -421,8 +407,8 @@ void VPrintLayout::PrintPages(QPrinter *printer)
                 if (m_isTiled)
                 {
                     // Draw tile
-                    posterData = posterazor->Tile(paper, poster->at(index), m_layoutScenes.size(), data,
-                                                  m_watermarkPath);
+                    posterData =
+                        posterazor->Tile(paper, poster->at(index), m_layoutScenes.size(), data, m_watermarkPath);
                 }
 
                 PreparePaper(paperIndex);
@@ -431,8 +417,8 @@ void VPrintLayout::PrintPages(QPrinter *printer)
                 QRectF source;
                 m_isTiled ? source = poster->at(index).rect : source = paper->rect();
 
-                m_layoutScenes.at(paperIndex)->render(&painter, VPrintLayout::SceneTargetRect(printer, source), source,
-                                                      Qt::IgnoreAspectRatio);
+                m_layoutScenes.at(paperIndex)
+                    ->render(&painter, VPrintLayout::SceneTargetRect(printer, source), source, Qt::IgnoreAspectRatio);
 
                 if (m_isTiled)
                 {
@@ -475,12 +461,12 @@ void VPrintLayout::SetPrinterPrinterMargins(QPrinter *printer)
     }
     else
     {
-        if(m_tiledPDFOrientation == PageOrientation::Landscape)
+        if (m_tiledPDFOrientation == PageOrientation::Landscape)
         {
             // because when painting we have a -90rotation in landscape mode,
             // see function PrintPages.
-            printerMargins = QMarginsF(m_tiledMargins.bottom(), m_tiledMargins.left(), m_tiledMargins.top(),
-                                       m_tiledMargins.right());
+            printerMargins =
+                QMarginsF(m_tiledMargins.bottom(), m_tiledMargins.left(), m_tiledMargins.top(), m_tiledMargins.right());
         }
         else
         {
@@ -500,12 +486,12 @@ void VPrintLayout::SetPrinterOutputFileName(QPrinter *printer, PrintType printTy
 {
     SCASSERT(printer != nullptr)
 
-    switch(printType)
+    switch (printType)
     {
         case PrintType::PrintPDF:
         {
-            const QString outputFileName = filePath.isEmpty() ? QDir::homePath() + QDir::separator() + DocName()
-                                                              : filePath;
+            const QString outputFileName =
+                filePath.isEmpty() ? QDir::homePath() + QDir::separator() + DocName() : filePath;
             printer->setOutputFileName(outputFileName + QStringLiteral(".pdf"));
 
 #ifdef Q_OS_MAC
@@ -516,7 +502,7 @@ void VPrintLayout::SetPrinterOutputFileName(QPrinter *printer, PrintType printTy
             break;
         }
         case PrintType::PrintNative:
-            printer->setOutputFileName(QString());//Disable printing to file if was enabled.
+            printer->setOutputFileName(QString()); // Disable printing to file if was enabled.
             printer->setOutputFormat(QPrinter::NativeFormat);
             break;
         case PrintType::PrintPreview: /*do nothing*/
@@ -542,13 +528,13 @@ void VPrintLayout::SetPrinterPageSize(QPrinter *printer)
             {
                 if (m_isLayoutPortrait)
                 {
-                    height = FromPixel(paper->rect().height() + m_layoutMargins.top() + m_layoutMargins.bottom(),
-                                       Unit::Mm);
+                    height =
+                        FromPixel(paper->rect().height() + m_layoutMargins.top() + m_layoutMargins.bottom(), Unit::Mm);
                 }
                 else
                 {
-                    width = FromPixel(paper->rect().width() + m_layoutMargins.left() + m_layoutMargins.right(),
-                                      Unit::Mm);
+                    width =
+                        FromPixel(paper->rect().width() + m_layoutMargins.left() + m_layoutMargins.right(), Unit::Mm);
                 }
             }
         }
@@ -560,18 +546,18 @@ void VPrintLayout::SetPrinterPageSize(QPrinter *printer)
             {
                 if (m_isLayoutPortrait)
                 {
-                    width = FromPixel(paper->rect().width() + m_layoutMargins.left() + m_layoutMargins.right(),
-                                      Unit::Mm);
+                    width =
+                        FromPixel(paper->rect().width() + m_layoutMargins.left() + m_layoutMargins.right(), Unit::Mm);
                 }
                 else
                 {
-                    height = FromPixel(paper->rect().height() + m_layoutMargins.top() + m_layoutMargins.bottom(),
-                                       Unit::Mm);
+                    height =
+                        FromPixel(paper->rect().height() + m_layoutMargins.top() + m_layoutMargins.bottom(), Unit::Mm);
                 }
             }
         }
 
-        QSizeF size = QSizeF(width, height);
+        auto size = QSizeF(width, height);
 
         if (not m_isLayoutPortrait)
         {
@@ -610,22 +596,22 @@ auto VPrintLayout::DocName() const -> QString
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPrintLayout::PreparePaper(int index) const
+void VPrintLayout::PreparePaper(vsizetype index) const
 {
     auto *paper = qgraphicsitem_cast<QGraphicsRectItem *>(m_layoutPapers.at(index));
     if (paper != nullptr)
     {
-        QBrush brush(Qt::white);
+        QBrush const brush(Qt::white);
         m_layoutScenes.at(index)->setBackgroundBrush(brush);
         m_layoutShadows.at(index)->setVisible(false);
         const float thinPen = 0.1F;
-        paper->setPen(QPen(Qt::white, thinPen, Qt::NoPen));// border
+        paper->setPen(QPen(Qt::white, thinPen, Qt::NoPen)); // border
     }
 
     QTransform matrix;
     matrix.scale(m_xscale, m_yscale);
 
-    QList<QGraphicsItem *> paperDetails = m_layoutDetails.at(index);
+    QList<QGraphicsItem *> const paperDetails = m_layoutDetails.at(index);
     for (auto *detail : paperDetails)
     {
         QTransform m = detail->transform();
@@ -635,22 +621,22 @@ void VPrintLayout::PreparePaper(int index) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPrintLayout::RestorePaper(int index) const
+void VPrintLayout::RestorePaper(vsizetype index) const
 {
     auto *paper = qgraphicsitem_cast<QGraphicsRectItem *>(m_layoutPapers.at(index));
     if (paper != nullptr)
     {
         // Restore
         paper->setPen(QPen(Qt::black, 1));
-        QBrush brush(Qt::gray);
+        QBrush const brush(Qt::gray);
         m_layoutScenes.at(index)->setBackgroundBrush(brush);
         m_layoutShadows.at(index)->setVisible(true);
     }
 
     QTransform matrix;
-    matrix.scale(1./m_xscale, 1./m_yscale);
+    matrix.scale(1. / m_xscale, 1. / m_yscale);
 
-    QList<QGraphicsItem *> paperDetails = m_layoutDetails.at(index);
+    QList<QGraphicsItem *> const paperDetails = m_layoutDetails.at(index);
     for (auto *detail : paperDetails)
     {
         QTransform m = detail->transform();
@@ -670,12 +656,13 @@ auto VPrintLayout::IsPagesUniform() const -> bool
     auto *paper = qgraphicsitem_cast<QGraphicsRectItem *>(m_layoutPapers.at(0));
     SCASSERT(paper != nullptr)
 
-    return std::all_of(m_layoutPapers.begin(), m_layoutPapers.end(), [paper](QGraphicsItem *paperItem)
-    {
-        auto *p = qgraphicsitem_cast<QGraphicsRectItem *>(paperItem);
-        SCASSERT(p != nullptr)
-        return paper->rect() == p->rect();
-    });
+    return std::all_of(m_layoutPapers.begin(), m_layoutPapers.end(),
+                       [paper](QGraphicsItem *paperItem)
+                       {
+                           auto *p = qgraphicsitem_cast<QGraphicsRectItem *>(paperItem);
+                           SCASSERT(p != nullptr)
+                           return paper->rect() == p->rect();
+                       });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -711,8 +698,9 @@ auto VPrintLayout::WatermarkData() const -> VWatermarkData
         catch (VException &e)
         {
             const QString errorMsg = tr("File error.\n\n%1\n\n%2").arg(e.ErrorMessage(), e.DetailedInformation());
-            VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+            VAbstractApplication::VApp()->IsPedantic()
+                ? throw VException(errorMsg)
+                : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
         }
     }
 
@@ -730,13 +718,13 @@ auto VPrintLayout::ContinueIfLayoutStale(QWidget *parent) -> int
         }
 
         Utils::CheckableMessageBox msgBox(parent);
-        msgBox.setIconPixmap(QApplication::style()->standardIcon(QStyle::SP_MessageBoxQuestion).pixmap(32, 32) );
+        msgBox.setIconPixmap(QApplication::style()->standardIcon(QStyle::SP_MessageBoxQuestion).pixmap(32, 32));
         msgBox.setWindowTitle(tr("The layout is stale."));
         msgBox.setText(tr("The layout was not updated since last pattern modification. Do you want to continue?"));
-        msgBox.setStandardButtons(QDialogButtonBox::Yes|QDialogButtonBox::No);
+        msgBox.setStandardButtons(QDialogButtonBox::Yes | QDialogButtonBox::No);
         msgBox.setDefaultButton(QDialogButtonBox::No);
 
-        int dialogResult = msgBox.exec();
+        int const dialogResult = msgBox.exec();
 
         if (msgBox.isChecked())
         {
@@ -756,22 +744,23 @@ auto VPrintLayout::SceneTargetRect(QPrinter *printer, const QRectF &source) -> Q
 
     qreal x;
     qreal y;
-    if(printer->fullPage())
+    if (printer->fullPage())
     {
         QPageLayout layout = printer->pageLayout();
         layout.setUnits(QPageLayout::Millimeter);
-        QMarginsF printerMargins = layout.margins();
+        QMarginsF const printerMargins = layout.margins();
         x = qFloor(ToPixel(printerMargins.left(), Unit::Mm));
         y = qFloor(ToPixel(printerMargins.top(), Unit::Mm));
     }
     else
     {
-        x = 0; y = 0;
+        x = 0;
+        y = 0;
     }
 
-    QPair<qreal, qreal> scaleDiff = PrinterScaleDiff(printer);
-    const double xscale = scaleDiff.first;
-    const double yscale = scaleDiff.second;
+    auto const [scaleDiffFirst, scaleDiffSecond] = PrinterScaleDiff(printer);
+    const double xscale = scaleDiffFirst;
+    const double yscale = scaleDiffSecond;
 
     return {x * xscale, y * yscale, source.width() * xscale, source.height() * yscale};
 }
