@@ -332,6 +332,7 @@ void PrepareMeasurementsPlaceholders(const VPieceLabelInfo &info, QMap<QString,
     while (i != measurements.constEnd())
     {
         AddPlaceholder(pl_measurement + i.key(), QString::number(*i.value()->GetValue()));
+        AddPlaceholder(pl_measurement + i.key() + pl_valueAlias, i.value()->GetValueAlias());
         ++i;
     }
 }
@@ -403,10 +404,42 @@ void PrepareUserMaterialsPlaceholders(const VPieceLabelInfo &info, QMap<QString,
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void PrepareFinalMeasurementsPlaceholders(bool pieceLabel, const VPieceLabelInfo &info,
-                                          QMap<QString, QString> &placeholders, const QSet<QString> &uniquePlaceholders)
+void AddMeasurementTokensToUniqueNames(const VFinalMeasurement &m, QSet<QString> &uniquePieceNames)
+{
+    QMap<vsizetype, QString> tokens;
+
+    try
+    {
+        QScopedPointer<qmu::QmuTokenParser> const cal(new qmu::QmuTokenParser(m.formula, false, false)); // Eval formula
+        tokens = cal->GetTokens(); // Tokens (variables, measurements)
+    }
+    catch (qmu::QmuParserError &)
+    {
+        // Skip formula errors
+    }
+
+    QMapIterator i(tokens);
+    while (i.hasNext())
+    {
+        i.next();
+        if (i.value().startsWith(pieceArea_))
+        {
+            QString name = i.value();
+            uniquePieceNames.insert(name.remove(0, pieceArea_.length()));
+        }
+        else if (i.value().startsWith(pieceSeamLineArea_))
+        {
+            QString name = i.value();
+            uniquePieceNames.insert(name.remove(0, pieceSeamLineArea_.length()));
+        }
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto ExtractUniquePieceNames(const VPieceLabelInfo &info, const QSet<QString> &uniquePlaceholders) -> QSet<QString>
 {
     QSet<QString> uniquePieceNames;
+
     if (uniquePlaceholders.contains('%' + pieceArea_ + info.labelData.GetAreaShortName() + '%') ||
         uniquePlaceholders.contains('%' + pieceSeamLineArea_ + info.labelData.GetAreaShortName() + '%'))
     {
@@ -418,38 +451,17 @@ void PrepareFinalMeasurementsPlaceholders(bool pieceLabel, const VPieceLabelInfo
     {
         if (uniquePlaceholders.contains('%' + pl_finalMeasurement + m.name + '%'))
         {
-            QMap<vsizetype, QString> tokens;
-            try
-            {
-                QScopedPointer<qmu::QmuTokenParser> const cal(
-                    new qmu::QmuTokenParser(m.formula, false, false)); // Eval formula
-                tokens = cal->GetTokens();                             // Tokens (variables, measurements)
-            }
-            catch (qmu::QmuParserError &)
-            {
-                // skip formula
-            }
-
-            QMapIterator<vsizetype, QString> i(tokens);
-            while (i.hasNext())
-            {
-                i.next();
-                if (i.value().startsWith(pieceArea_))
-                {
-                    QString name = i.value();
-                    uniquePieceNames.insert(name.remove(0, pieceArea_.length()));
-                }
-                else if (i.value().startsWith(pieceSeamLineArea_))
-                {
-                    QString name = i.value();
-                    uniquePieceNames.insert(name.remove(0, pieceSeamLineArea_.length()));
-                }
-            }
+            AddMeasurementTokensToUniqueNames(m, uniquePieceNames);
         }
     }
 
-    VContainer completeData = info.completeData;
-    QHash<quint32, VPiece> *pieces = completeData.DataPieces();
+    return uniquePieceNames;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void PopulatePieceData(VContainer &completeData, const QSet<QString> &uniquePieceNames)
+{
+    const QHash<quint32, VPiece> *pieces = completeData.DataPieces();
     Unit const patternUnits = VAbstractValApplication::VApp()->patternUnits();
     QSet<QString> processedNames;
 
@@ -466,87 +478,119 @@ void PrepareFinalMeasurementsPlaceholders(bool pieceLabel, const VPieceLabelInfo
         }
         ++i;
     }
+}
 
-    if (pieceLabel)
+//---------------------------------------------------------------------------------------------------------------------
+void InsertPlaceholderValue(const VContainer &completeData, const QString &formula,
+                            QMap<QString, QString> &placeholders, const QString &placeholderKey,
+                            const QString &errorMsg)
+{
+    QScopedPointer<Calculator> const cal(new Calculator());
+
+    try
+    {
+        const qreal result = cal->EvalFormula(completeData.DataVariables(), formula);
+        placeholders.insert(placeholderKey, QString::number(result));
+    }
+    catch (qmu::QmuParserError &e)
+    {
+        const QString error = QStringLiteral("%1 %2.").arg(errorMsg).arg(e.GetMsg());
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(error)
+            : qWarning() << VAbstractValApplication::warningMessageSignature + error;
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void PreparePieceLabelPlaceholders(const VContainer &completeData, const VPieceLabelInfo &info,
+                                   QMap<QString, QString> &placeholders, const QSet<QString> &uniquePlaceholders)
+{
+    if (uniquePlaceholders.contains('%' + pl_currentArea + '%'))
+    {
+        InsertPlaceholderValue(completeData, pieceArea_ + info.labelData.GetAreaShortName(), placeholders,
+                               pl_currentArea, "Failed to prepare full piece area placeholder.");
+    }
+
+    if (uniquePlaceholders.contains('%' + pl_currentSeamLineArea + '%'))
+    {
+        InsertPlaceholderValue(completeData, pieceSeamLineArea_ + info.labelData.GetAreaShortName(), placeholders,
+                               pl_currentSeamLineArea, "Failed to prepare piece seam line area placeholder.");
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void SetEmptyPieceLabelPlaceholders(QMap<QString, QString> &placeholders, const QSet<QString> &uniquePlaceholders)
+{
+    if (uniquePlaceholders.contains('%' + pl_currentArea + '%'))
+    {
+        placeholders.insert(pl_currentArea, QString());
+    }
+
+    if (uniquePlaceholders.contains('%' + pl_currentSeamLineArea + '%'))
+    {
+        placeholders.insert(pl_currentSeamLineArea, QString());
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void InsertMeasurementPlaceholder(const VContainer &completeData, const VFinalMeasurement &m, int index,
+                                  QMap<QString, QString> &placeholders)
+{
+    try
     {
         QScopedPointer<Calculator> const cal(new Calculator());
+        const qreal result = cal->EvalFormula(completeData.DataVariables(), m.formula);
 
-        if (uniquePlaceholders.contains('%' + pl_currentArea + '%'))
-        {
-            try
-            {
-                const QString formula = pieceArea_ + info.labelData.GetAreaShortName();
-                const qreal result = cal->EvalFormula(completeData.DataVariables(), formula);
-                placeholders.insert(pl_currentArea, QString::number(result));
-            }
-            catch (qmu::QmuParserError &e)
-            {
-                const QString errorMsg =
-                    QObject::tr("Failed to prepare full piece area placeholder. %1.").arg(e.GetMsg());
-                VAbstractApplication::VApp()->IsPedantic()
-                    ? throw VException(errorMsg)
-                    : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
-            }
-        }
-
-        if (uniquePlaceholders.contains('%' + pl_currentSeamLineArea + '%'))
-        {
-            try
-            {
-                const QString formula = pieceSeamLineArea_ + info.labelData.GetAreaShortName();
-                const qreal result = cal->EvalFormula(completeData.DataVariables(), formula);
-                placeholders.insert(pl_currentSeamLineArea, QString::number(result));
-            }
-            catch (qmu::QmuParserError &e)
-            {
-                const QString errorMsg =
-                    QObject::tr("Failed to prepare piece seam line area placeholder. %1.").arg(e.GetMsg());
-                VAbstractApplication::VApp()->IsPedantic()
-                    ? throw VException(errorMsg)
-                    : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
-            }
-        }
+        placeholders.insert(pl_finalMeasurement + m.name, QString::number(result));
     }
-    else
+    catch (qmu::QmuParserError &e)
     {
-        if (uniquePlaceholders.contains('%' + pl_currentArea + '%'))
-        {
-            placeholders.insert(pl_currentArea, QString());
-        }
-
-        if (uniquePlaceholders.contains('%' + pl_currentSeamLineArea + '%'))
-        {
-            placeholders.insert(pl_currentSeamLineArea, QString());
-        }
+        const QString errorMsg =
+            QObject::tr("Failed to prepare final measurement placeholder. Parser error at line %1: %2.")
+                .arg(index + 1)
+                .arg(e.GetMsg());
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
     }
+}
 
-    for (int i = 0; i < measurements.size(); ++i)
+//---------------------------------------------------------------------------------------------------------------------
+void PrepareFinalMeasurementPlaceholders(const VPieceLabelInfo &info, const VContainer &completeData,
+                                         QMap<QString, QString> &placeholders, const QSet<QString> &uniquePlaceholders)
+{
+    for (int i = 0; i < info.finalMeasurements.size(); ++i)
     {
-        const VFinalMeasurement &m = measurements.at(i);
+        const VFinalMeasurement &m = info.finalMeasurements.at(i);
 
         if (uniquePlaceholders.contains('%' + pl_finalMeasurement + m.name + '%'))
         {
-            try
-            {
-                QScopedPointer<Calculator> const cal(new Calculator());
-                const qreal result = cal->EvalFormula(completeData.DataVariables(), m.formula);
-
-                placeholders.insert(pl_finalMeasurement + m.name, QString::number(result));
-            }
-            catch (qmu::QmuParserError &e)
-            {
-                const QString errorMsg = QObject::tr("Failed to prepare final measurement placeholder. Parser error at "
-                                                     "line %1: %2.")
-                                             .arg(i + 1)
-                                             .arg(e.GetMsg());
-                VAbstractApplication::VApp()->IsPedantic()
-                    ? throw VException(errorMsg)
-                    : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
-            }
+            InsertMeasurementPlaceholder(completeData, m, i, placeholders);
         }
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void PrepareFinalMeasurementsPlaceholders(bool pieceLabel, const VPieceLabelInfo &info,
+                                          QMap<QString, QString> &placeholders, const QSet<QString> &uniquePlaceholders)
+{
+    QSet<QString> uniquePieceNames = ExtractUniquePieceNames(info, uniquePlaceholders);
+
+    VContainer completeData = info.completeData;
+    PopulatePieceData(completeData, uniquePieceNames);
+
+    if (pieceLabel)
+    {
+        PreparePieceLabelPlaceholders(completeData, info, placeholders, uniquePlaceholders);
+    }
+    else
+    {
+        SetEmptyPieceLabelPlaceholders(placeholders, uniquePlaceholders);
+    }
+
+    PrepareFinalMeasurementPlaceholders(info, completeData, placeholders, uniquePlaceholders);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto PreparePlaceholders(const VPieceLabelInfo &info, const QSet<QString> &uniquePlaceholders, bool pieceLabel = false)
     -> QMap<QString, QString>
@@ -815,12 +859,14 @@ auto VTextManager::GetLabelSourceLines(int width, const QFont &font) const -> QV
     for (const auto &tl : m_liLines)
     {
         fnt.setPointSize(qMax(fSize + tl.m_iFontSize, 1));
-        fnt.setBold(tl.m_bold);
+        if (!VAbstractApplication::VApp()->Settings()->GetSingleStrokeOutlineFont())
+        {
+            fnt.setBold(tl.m_bold);
+        }
         fnt.setItalic(tl.m_italic);
 
         QString const qsText = tl.m_qsText;
-        QFontMetrics const fm(fnt);
-        if (fm.horizontalAdvance(qsText) > width)
+        if (HorizontalAdvance(qsText, fnt) > width)
         {
             const QStringList brokeLines = BreakTextIntoLines(qsText, fnt, width);
             for (const auto &lineText : brokeLines)
@@ -969,17 +1015,16 @@ void VTextManager::UpdatePatternLabelInfo(const VPieceLabelInfo &info)
 //---------------------------------------------------------------------------------------------------------------------
 auto VTextManager::BreakTextIntoLines(const QString &text, const QFont &font, int maxWidth) -> QStringList
 {
-    QFontMetrics const fontMetrics(font);
     QStringList words = text.split(' ');
 
     QString currentLine;
     int currentLineWidth = 0;
-    const int spaceWidth = fontMetrics.horizontalAdvance(QChar(' '));
+    const int spaceWidth = HorizontalAdvance(QChar(' '), font);
     const float tolerance = 0.3F;
 
     QStringList lines;
     lines.reserve(words.size());
-    QMutableListIterator<QString> iterator(words);
+    QMutableListIterator iterator(words);
 
     auto AppendWord = [&currentLine, &currentLineWidth](const QString &word, int totalWidth)
     {
@@ -994,7 +1039,7 @@ auto VTextManager::BreakTextIntoLines(const QString &text, const QFont &font, in
     while (iterator.hasNext())
     {
         const QString &word = iterator.next();
-        int const wordWidth = fontMetrics.horizontalAdvance(word);
+        int const wordWidth = HorizontalAdvance(word, font);
         int const totalWidth = !currentLine.isEmpty() ? currentLineWidth + spaceWidth + wordWidth : wordWidth;
 
         if (totalWidth <= maxWidth)
@@ -1013,7 +1058,7 @@ auto VTextManager::BreakTextIntoLines(const QString &text, const QFont &font, in
         else
         {
             // Word is too long, force line break
-            if (currentLineWidth + spaceWidth + fontMetrics.horizontalAdvance(word.at(0)) > maxWidth)
+            if (currentLineWidth + spaceWidth + HorizontalAdvance(word.at(0), font) > maxWidth)
             {
                 lines.append(currentLine);
                 currentLine.clear();
@@ -1029,7 +1074,7 @@ auto VTextManager::BreakTextIntoLines(const QString &text, const QFont &font, in
             }
             else
             {
-                const int width = fontMetrics.horizontalAdvance(subWords.constFirst());
+                const int width = HorizontalAdvance(subWords.constFirst(), font);
                 const int tWidth = !currentLine.isEmpty() ? currentLineWidth + spaceWidth + width : width;
                 AppendWord(subWords.constFirst(), tWidth);
                 lines.append(currentLine);
@@ -1079,7 +1124,7 @@ auto VTextManager::BreakTextIntoLines(const QString &text, const VSvgFont &font,
 
     QStringList lines;
     lines.reserve(words.size());
-    QMutableListIterator<QString> iterator(words);
+    QMutableListIterator iterator(words);
 
     auto AppendWord = [&currentLine, &currentLineWidth](const QString &word, int totalWidth)
     {
@@ -1157,7 +1202,7 @@ auto VTextManager::BreakTextIntoLines(const QString &text, const VSvgFont &font,
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VTextManager::PrepareLabelInfo(VAbstractPattern *doc, const VContainer *pattern, bool pieceLabel)
+auto VTextManager::PrepareLabelInfo(const VAbstractPattern *doc, const VContainer *pattern, bool pieceLabel)
     -> VPieceLabelInfo
 {
     VPieceLabelInfo info(doc->GetCompleteData());
@@ -1204,3 +1249,23 @@ auto VTextManager::PrepareLabelInfo(VAbstractPattern *doc, const VContainer *pat
 
     return info;
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VTextManager::HorizontalAdvance(const QString &text, const QFont &font) -> int
+{
+    const VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
+    qreal const penWidth = VAbstractApplication::VApp()->Settings()->WidthHairLine();
+
+    QFontMetrics const fm(font);
+    if (settings->GetSingleStrokeOutlineFont())
+    {
+        int w = 0;
+        for (auto c : qAsConst(text))
+        {
+            w += fm.horizontalAdvance(c) + qRound(penWidth / 2.0);
+        }
+
+        return w;
+    }
+    return fm.horizontalAdvance(text);
+}
