@@ -29,13 +29,11 @@
 #ifndef CUSTOMEVENTS_H
 #define CUSTOMEVENTS_H
 
-#include <qcompilerdetection.h>
 #include <QEvent>
 #include <QString>
 
-#include "typedef.h"
-
-enum CustomEventType {
+enum CustomEventType
+{
     UndoEventType = 1,
     LiteParseEventType = 2,
     FitBestCurrentEventType = 3,
@@ -43,96 +41,86 @@ enum CustomEventType {
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_CLANG("-Wenum-enum-conversion")
-
 // Define undo event identifier
-const QEvent::Type UNDO_EVENT = static_cast<QEvent::Type>(QEvent::User + CustomEventType::UndoEventType);
-
-QT_WARNING_POP
+const QEvent::Type UNDO_EVENT =
+    static_cast<QEvent::Type>(QEvent::User + static_cast<int>(CustomEventType::UndoEventType));
 
 class UndoEvent : public QEvent
 {
 public:
-    UndoEvent()
-        : QEvent(UNDO_EVENT)
-    {}
-
-    virtual ~UndoEvent() =default;
+    UndoEvent();
+    ~UndoEvent() override = default;
 };
 
+inline UndoEvent::UndoEvent()
+  : QEvent(UNDO_EVENT)
+{
+}
+
 //---------------------------------------------------------------------------------------------------------------------
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_CLANG("-Wenum-enum-conversion")
-
-const QEvent::Type LITE_PARSE_EVENT = static_cast<QEvent::Type>(QEvent::User + CustomEventType::LiteParseEventType);
-
-QT_WARNING_POP
+const QEvent::Type LITE_PARSE_EVENT =
+    static_cast<QEvent::Type>(QEvent::User + static_cast<int>(CustomEventType::LiteParseEventType));
 
 class LiteParseEvent : public QEvent
 {
 public:
-    LiteParseEvent()
-        : QEvent(LITE_PARSE_EVENT)
-    {}
-
-    virtual ~LiteParseEvent() =default;
+    LiteParseEvent();
+    ~LiteParseEvent() override = default;
 };
 
+inline LiteParseEvent::LiteParseEvent()
+  : QEvent(LITE_PARSE_EVENT)
+{
+}
+
 //---------------------------------------------------------------------------------------------------------------------
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_CLANG("-Wenum-enum-conversion")
-
-const QEvent::Type FIT_BEST_CURRENT_EVENT = static_cast<QEvent::Type>(QEvent::User +
-                                                                      CustomEventType::FitBestCurrentEventType);
-
-QT_WARNING_POP
+const QEvent::Type FIT_BEST_CURRENT_EVENT =
+    static_cast<QEvent::Type>(QEvent::User + static_cast<int>(CustomEventType::FitBestCurrentEventType));
 
 class FitBestCurrentEvent : public QEvent
 {
 public:
-    FitBestCurrentEvent()
-        : QEvent(FIT_BEST_CURRENT_EVENT)
-    {}
-
-    virtual ~FitBestCurrentEvent() =default;
+    FitBestCurrentEvent();
+    ~FitBestCurrentEvent() override = default;
 };
 
+inline FitBestCurrentEvent::FitBestCurrentEvent()
+  : QEvent(FIT_BEST_CURRENT_EVENT)
+{
+}
+
 //---------------------------------------------------------------------------------------------------------------------
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_CLANG("-Wenum-enum-conversion")
-
-const QEvent::Type WARNING_MESSAGE_EVENT = static_cast<QEvent::Type>(QEvent::User +
-                                                                      CustomEventType::WarningMessageEventType);
-
-QT_WARNING_POP
+const QEvent::Type WARNING_MESSAGE_EVENT =
+    static_cast<QEvent::Type>(QEvent::User + static_cast<int>(CustomEventType::WarningMessageEventType));
 
 class WarningMessageEvent : public QEvent
 {
 public:
-    WarningMessageEvent(const QString &message, QtMsgType severity)
-        : QEvent(WARNING_MESSAGE_EVENT),
-          m_message(message),
-          m_severity(severity)
-    {}
+    WarningMessageEvent(const QString &message, QtMsgType severity);
+    ~WarningMessageEvent() override = default;
 
-    virtual ~WarningMessageEvent() =default;
+    auto Message() const -> QString;
 
-    QString Message() const;
-
-    QtMsgType Severity() const;
+    auto Severity() const -> QtMsgType;
 
 private:
     QString m_message;
     QtMsgType m_severity;
 };
 
-inline QString WarningMessageEvent::Message() const
+inline WarningMessageEvent::WarningMessageEvent(const QString &message, QtMsgType severity)
+  : QEvent(WARNING_MESSAGE_EVENT),
+    m_message(message),
+    m_severity(severity)
+{
+}
+
+inline auto WarningMessageEvent::Message() const -> QString
 {
     return m_message;
 }
 
-inline QtMsgType WarningMessageEvent::Severity() const
+inline auto WarningMessageEvent::Severity() const -> QtMsgType
 {
     return m_severity;
 }
