@@ -99,7 +99,7 @@ void InitLanguageList(QComboBox *combobox)
         locale.truncate(locale.lastIndexOf('.'_L1));  // "valentina_de_De"
         locale.remove(0, locale.indexOf('_'_L1) + 1); // "de_De"
 
-        if (locale.startsWith("ru"_L1) || !supportedLocales.contains(locale))
+        if (locale.startsWith("ru"_L1) || locale.startsWith("ir"_L1) || !supportedLocales.contains(locale))
         {
             continue;
         }
@@ -155,8 +155,25 @@ void SetItemOverrideCursor(QGraphicsItem *item, const QString &pixmapPath, int h
 //---------------------------------------------------------------------------------------------------------------------
 auto SupportedLocales() -> QStringList
 {
-    return QStringList{"uk_UA", "de_DE", "cs_CZ", "he_IL", "fr_FR", "it_IT", "nl_NL", "id_ID",
-                       "es_ES", "fi_FI", "ro_RO", "zh_CN", "pt_BR", "el_GR", "pl_PL"};
+    return QStringList{"uk_UA",
+                       "de_DE",
+                       "cs_CZ",
+                       "he_IL",
+                       "fr_FR",
+                       "it_IT",
+                       "nl_NL",
+                       "id_ID",
+                       "es_ES",
+                       "fi_FI",
+                       "ro_RO",
+                       "zh_CN",
+                       "pt_BR",
+                       "el_GR",
+                       "pl_PL",
+                       "hr_HR",
+                       "hu_HU",
+                       "pt_PT",
+                       "ja_JP"};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
