@@ -47,7 +47,7 @@
 template <class T> class QSharedPointer;
 
 // Header <ciso646> is removed in C++20.
-#if __cplusplus <= 201703L
+#if defined(Q_CC_MSVC) && __cplusplus <= 201703L
 #include <ciso646> // and, not, or
 #endif
 
@@ -396,6 +396,12 @@ enum class IMD : qint8 // Individual measurement dimension
     Z  // hip half circumference
 };
 
+struct VMeasurementCorrection
+{
+    qreal correction{0};
+    QString alias{};
+};
+
 /* QImage supports a maximum of 32768x32768 px images (signed short).
  * This follows from the condition: width * height * colordepth < INT_MAX (4 billion) -> 32768 * 32768 * 4 = 4 billion.
  * The second condition is of course that malloc is able to allocate the requested memory.
@@ -725,8 +731,8 @@ Q_REQUIRED_RESULT auto darkenPixmap(const QPixmap &pixmap) -> QPixmap;
 
 void ShowInGraphicalShell(const QString &filePath);
 
-Q_REQUIRED_RESULT constexpr static inline auto VFuzzyComparePossibleNulls(double p1, double p2) -> bool;
-constexpr static inline auto VFuzzyComparePossibleNulls(double p1, double p2) -> bool
+Q_REQUIRED_RESULT constexpr static auto VFuzzyComparePossibleNulls(double p1, double p2) -> bool;
+constexpr static auto VFuzzyComparePossibleNulls(double p1, double p2) -> bool
 {
     if (qFuzzyIsNull(p1))
     {
