@@ -399,7 +399,7 @@ auto QxtCsvModel::setData(const QModelIndex &index, const QVariant &data, int ro
 /*!
     \reimp
  */
-auto QxtCsvModel::insertRow(int row, const QModelIndex &parent) -> bool
+auto QxtCsvModel::insertSingleRow(int row, const QModelIndex &parent) -> bool
 {
     return insertRows(row, 1, parent);
 }
@@ -436,7 +436,7 @@ auto QxtCsvModel::insertRows(int row, int count, const QModelIndex &parent) -> b
 /*!
     \reimp
  */
-auto QxtCsvModel::removeRow(int row, const QModelIndex &parent) -> bool
+auto QxtCsvModel::removeSingleRow(int row, const QModelIndex &parent) -> bool
 {
     return removeRows(row, 1, parent);
 }
@@ -471,7 +471,7 @@ auto QxtCsvModel::removeRows(int row, int count, const QModelIndex &parent) -> b
 /*!
     \reimp
  */
-auto QxtCsvModel::insertColumn(int col, const QModelIndex &parent) -> bool
+auto QxtCsvModel::insertSingleColumn(int col, const QModelIndex &parent) -> bool
 {
     return insertColumns(col, 1, parent);
 }
@@ -511,7 +511,7 @@ auto QxtCsvModel::insertColumns(int col, int count, const QModelIndex &parent) -
 /*!
     \reimp
  */
-auto QxtCsvModel::removeColumn(int col, const QModelIndex &parent) -> bool
+auto QxtCsvModel::removeSingleColumn(int col, const QModelIndex &parent) -> bool
 {
     return removeColumns(col, 1, parent);
 }
@@ -601,9 +601,8 @@ auto QxtCsvModel::toCSV(QIODevice *dest, QString &error, bool withHeader, QChar
     -> bool
 {
     const QxtCsvModelPrivate &d_ptr = qxt_d();
-    int row, col, rows, cols;
-    rows = rowCount();
-    cols = columnCount();
+    int rows = rowCount();
+    int cols = columnCount();
     QString data;
     if (not dest->isOpen() && not dest->open(QIODevice::WriteOnly | QIODevice::Truncate))
     {
@@ -624,7 +623,7 @@ auto QxtCsvModel::toCSV(QIODevice *dest, QString &error, bool withHeader, QChar
     if (withHeader)
     {
         data = QString();
-        for (col = 0; col < cols; ++col)
+        for (int col = 0; col < cols; ++col)
         {
             if (col > 0)
             {
@@ -634,11 +633,11 @@ auto QxtCsvModel::toCSV(QIODevice *dest, QString &error, bool withHeader, QChar
         }
         stream << data << Qt::endl;
     }
-    for (row = 0; row < rows; ++row)
+    for (int row = 0; row < rows; ++row)
     {
         const QStringList &rowData = d_ptr.csvData[row];
         data = QString();
-        for (col = 0; col < cols; ++col)
+        for (int col = 0; col < cols; ++col)
         {
             if (col > 0)
             {
