@@ -40,8 +40,36 @@
 #include <QRegion>
 #include <QSet>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
+#include "../backport/qpainterstateguard.h"
+#else
+#include <QPainterStateGuard>
+#endif
+
 using namespace Qt::Literals::StringLiterals;
 
+namespace
+{
+//---------------------------------------------------------------------------------------------------------------------
+auto CalcOffset(const QPainterPath &path) -> QPointF
+{
+    const QRectF bounds = path.boundingRect();
+
+    // Shift path if top-left is positive
+    QPointF offset;
+    if (bounds.topLeft().x() > 0)
+    {
+        offset.setX(bounds.topLeft().x());
+    }
+    if (bounds.topLeft().y() > 0)
+    {
+        offset.setY(bounds.topLeft().y());
+    }
+
+    return offset;
+}
+} // namespace
+
 //---------------------------------------------------------------------------------------------------------------------
 VSvgFontEngine::VSvgFontEngine()
   : d(new VSvgFontEngineData())
@@ -167,7 +195,7 @@ void VSvgFontEngine::AddGlyph(QChar unicode, const QPainterPath &path, qreal hor
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VSvgFontEngine::DrawPath(const QPointF &point, const QString &str) const -> QPainterPath
+auto VSvgFontEngine::DrawPath(const QPointF &point, const QString &str, qreal penWidth) const -> QPainterPath
 {
     qreal const pixelSize = FontPixelSize();
 
@@ -194,7 +222,12 @@ auto VSvgFontEngine::DrawPath(const QPointF &point, const QString &str) const ->
             }
         }
         path.addPath(matrix.map(d->m_glyphs[unicode].Path()));
-        matrix.translate(d->m_glyphs[unicode].HorizAdvX(), 0);
+        matrix.translate(d->m_glyphs[unicode].HorizAdvX() + penWidth / 2.0, 0);
+    }
+
+    if (const QPointF offset = CalcOffset(path); !offset.isNull())
+    {
+        path.translate(-offset);
     }
 
     return path;
@@ -212,7 +245,7 @@ void VSvgFontEngine::Draw(QPainter *p, const QPointF &point, const QString &str)
 
     const qreal baseLine = FromFontUnits(d->m_font.Ascent());
 
-    p->save();
+    QPainterStateGuard const guard(p);
     p->translate(point.x(), point.y() + baseLine);
     p->scale(pixelSize / d->m_font.UnitsPerEm(), -pixelSize / d->m_font.UnitsPerEm());
 
@@ -236,7 +269,6 @@ void VSvgFontEngine::Draw(QPainter *p, const QPointF &point, const QString &str)
         p->drawPath(d->m_glyphs[unicode].Path());
         p->translate(d->m_glyphs[unicode].HorizAdvX(), 0);
     }
-    p->restore();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -253,7 +285,7 @@ void VSvgFontEngine::Draw(QPainter *p, const QRectF &rect, const QString &str, Q
 
     const qreal baseLine = FromFontUnits(d->m_font.Ascent());
 
-    p->save();
+    QPainterStateGuard const guard(p);
     p->setClipRect(rect);
     p->translate(rect.x() + p->pen().widthF(), rect.y() + baseLine + p->pen().widthF());
     p->scale(pixelSize / d->m_font.UnitsPerEm(), -pixelSize / d->m_font.UnitsPerEm());
@@ -295,7 +327,6 @@ void VSvgFontEngine::Draw(QPainter *p, const QRectF &rect, const QString &str, Q
         p->drawPath(d->m_glyphs[unicode].Path());
         p->translate(d->m_glyphs[unicode].HorizAdvX(), 0);
     }
-    p->restore();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -324,6 +355,25 @@ auto VSvgFontEngine::TextWidth(const QString &str, qreal penWidth) const -> qrea
     return FromFontUnits(TextHorizAdvX(str) + static_cast<int>(str.length()) * penWidth);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VSvgFontEngine::BoundingRect(const QString &str, qreal penWidth) const -> QRectF
+{
+    if (str.isEmpty() || str.trimmed().isEmpty())
+    {
+        return {}; // Mimic QFontMetrics behavior for space/empty
+    }
+
+    QPainterPath path = DrawPath(QPointF(), str, penWidth);
+
+    // Shift path if top-left is positive
+    if (QPointF offset = CalcOffset(path); !offset.isNull())
+    {
+        path.translate(-offset);
+    }
+
+    return path.boundingRect();
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VSvgFontEngine::InFont(QChar ch) const -> bool
 {
