@@ -43,6 +43,7 @@
 #include <QMessageLogger>
 #include <QScopeGuard>
 #include <QStandardPaths>
+#include <QTimeZone>
 #include <QTranslator>
 #include <QUndoStack>
 #include <QWidget>
@@ -77,7 +78,7 @@ auto FilterLocales(const QStringList &locales) -> QStringList
     QStringList filtered;
     for (const auto &locale : locales)
     {
-        if (not locale.startsWith("ru"_L1))
+        if (not locale.startsWith("ru"_L1) && not locale.startsWith("ir"_L1))
         {
             filtered.append(locale);
         }
@@ -168,7 +169,7 @@ VAbstractApplication::VAbstractApplication(int &argc, char **argv)
 VAbstractApplication::~VAbstractApplication()
 {
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-    QHashIterator<QStringConverter::Encoding, VTextCodec *> i(m_codecs);
+    QHashIterator i(m_codecs);
     while (i.hasNext())
     {
         i.next();
@@ -230,7 +231,6 @@ auto VAbstractApplication::translationsPath(const QString &locale) -> QString
         return dir.absolutePath();
     }
 
-#ifdef QBS_BUILD
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     dir.setPath(QCoreApplication::applicationDirPath() + "/../../.." + PKGDATADIR + trPath);
 #else
@@ -240,7 +240,6 @@ auto VAbstractApplication::translationsPath(const QString &locale) -> QString
     {
         return dir.absolutePath();
     }
-#endif // QBS_BUILD
 
 #if defined(APPIMAGE) && defined(Q_OS_LINUX)
     /* Fix path to translations when run inside AppImage. */
@@ -263,7 +262,6 @@ auto VAbstractApplication::QtTranslationsPath(const QString &locale) -> QString
         return dir.absolutePath();
     }
 
-#ifdef QBS_BUILD
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     dir.setPath(QCoreApplication::applicationDirPath() + "/../../.."_L1 + PKGDATADIR + trPath);
 #else
@@ -273,7 +271,6 @@ auto VAbstractApplication::QtTranslationsPath(const QString &locale) -> QString
     {
         return dir.absolutePath();
     }
-#endif // QBS_BUILD
 
 #if defined(APPIMAGE)
     Q_UNUSED(locale)
@@ -291,8 +288,7 @@ auto VAbstractApplication::QtTranslationsPath(const QString &locale) -> QString
 auto VAbstractApplication::ReduceLogContextFilePath(QString path) -> QString
 {
     // Find the position of the 'src' folder in the path
-    vsizetype const srcIndex = path.indexOf(QDir::toNativeSeparators(QStringLiteral("/src/")));
-    if (srcIndex != -1)
+    if (vsizetype const srcIndex = path.indexOf(QDir::toNativeSeparators(QStringLiteral("/src/"))); srcIndex != -1)
     {
         // Extract the substring starting from 'src' folder
         path = path.mid(srcIndex);
@@ -340,7 +336,7 @@ void VAbstractApplication::WinAttachConsole()
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractApplication::LoadTranslation(QString locale)
 {
-    if (locale.startsWith("ru"_L1))
+    if (locale.startsWith("ru"_L1) || locale.startsWith("ir"_L1))
     {
         locale = QString();
     }
@@ -371,7 +367,7 @@ void VAbstractApplication::LoadTranslation(QString locale)
     LoadQM(qtTranslator, QStringLiteral("qt_"), locale, qtQmDir);
     installTranslator(qtTranslator);
 
-#if (defined(Q_OS_WIN) && !defined(QBS_BUILD)) || defined(APPIMAGE)
+#if defined(APPIMAGE)
     qtxmlTranslator = new QTranslator(this);
     LoadQM(qtxmlTranslator, QStringLiteral("qtxmlpatterns_"), locale, qtQmDir);
     installTranslator(qtxmlTranslator);
@@ -379,7 +375,7 @@ void VAbstractApplication::LoadTranslation(QString locale)
     qtBaseTranslator = new QTranslator(this);
     LoadQM(qtBaseTranslator, QStringLiteral("qtbase_"), locale, qtQmDir);
     installTranslator(qtBaseTranslator);
-#endif // defined(Q_OS_WIN) && !defined(QBS_BUILD)
+#endif // defined(APPIMAGE)
 
     appTranslator = new QTranslator(this);
     LoadQM(appTranslator, QStringLiteral("valentina_"), locale, appQmDir);
@@ -394,27 +390,27 @@ void VAbstractApplication::ClearTranslation()
     if (not qtTranslator.isNull())
     {
         removeTranslator(qtTranslator);
-        delete qtTranslator;
+        delete qtTranslator.data();
     }
 
-#if (defined(Q_OS_WIN) && !defined(QBS_BUILD)) || defined(APPIMAGE)
+#if defined(APPIMAGE)
     if (not qtxmlTranslator.isNull())
     {
         removeTranslator(qtxmlTranslator);
-        delete qtxmlTranslator;
+        delete qtxmlTranslator.data();
     }
 
     if (not qtBaseTranslator.isNull())
     {
         removeTranslator(qtBaseTranslator);
-        delete qtBaseTranslator;
+        delete qtBaseTranslator.data();
     }
-#endif // defined(Q_OS_WIN) && !defined(QBS_BUILD)
+#endif // defined(APPIMAGE)
 
     if (not appTranslator.isNull())
     {
         removeTranslator(appTranslator);
-        delete appTranslator;
+        delete appTranslator.data();
     }
 }
 
@@ -521,7 +517,7 @@ auto VAbstractApplication::GetPlaceholderTranslator() -> QSharedPointer<VTransla
         pieceLabelLocale = settings->GetLocale();
     }
 
-    if (pieceLabelLocale.startsWith("ru"_L1))
+    if (pieceLabelLocale.startsWith("ru"_L1) || pieceLabelLocale.startsWith("ir"_L1))
     {
         return QSharedPointer<VTranslator>(new VTranslator);
     }
@@ -561,10 +557,11 @@ void VAbstractApplication::CacheTextCodec(QStringConverter::Encoding encoding, V
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractApplication::CheckSystemLocale()
 {
-    const QString defLocale = QLocale::system().name();
-    if (defLocale.startsWith("ru"_L1))
+    if (const QString defLocale = QLocale::system().name();
+        defLocale.startsWith("ru"_L1) || defLocale.startsWith("ir"_L1))
     {
-        qFatal("Incompatible locale \"%s\"", qPrintable(defLocale));
+        QCoreApplication::exit();
+        return;
     }
 
     auto CheckLanguage = [](QStandardPaths::StandardLocation type, const QStringList &test)
@@ -584,7 +581,46 @@ void VAbstractApplication::CheckSystemLocale()
 
     if (match >= 4)
     {
-        qFatal("russian language detected");
+        QCoreApplication::exit();
+        return;
+    }
+
+    QString const timeZoneId = QString::fromUtf8(QTimeZone::systemTimeZone().id());
+    QSet<QString> const timeZones{"Asia/Anadyr",
+                                  "Asia/Barnaul",
+                                  "Asia/Chita",
+                                  "Asia/Irkutsk",
+                                  "Asia/Kamchatka",
+                                  "Asia/Khandyga",
+                                  "Asia/Krasnoyarsk",
+                                  "Asia/Magadan",
+                                  "Asia/Novokuznetsk",
+                                  "Asia/Novosibirsk",
+                                  "Asia/Omsk",
+                                  "Asia/Sakhalin",
+                                  "Asia/Srednekolymsk",
+                                  "Asia/Tomsk",
+                                  "Asia/Ust-Nera",
+                                  "Asia/Vladivostok",
+                                  "Asia/Yakutsk",
+                                  "Asia/Yekaterinburg",
+                                  "Europe/Astrakhan",
+                                  "Europe/Kaliningrad",
+                                  "Europe/Kirov",
+                                  "Europe/Moscow",
+                                  "Europe/Samara",
+                                  "Europe/Saratov",
+                                  "Europe/Simferopol",
+                                  "Europe/Ulyanovsk",
+                                  "Europe/Volgograd",
+                                  "W-SU",
+                                  "Europe/Minsk",
+                                  "Asia/Tehran",
+                                  "Iran"};
+    if (timeZones.contains(timeZoneId))
+    {
+        QCoreApplication::exit();
+        return;
     }
 }
 
@@ -671,8 +707,7 @@ auto VAbstractApplication::LogDirPath() -> QString
 //---------------------------------------------------------------------------------------------------------------------
 auto VAbstractApplication::CreateLogDir() -> bool
 {
-    QDir const logDir(LogDirPath());
-    if (not logDir.exists())
+    if (QDir const logDir(LogDirPath()); not logDir.exists())
     {
         return logDir.mkpath(QChar('.')); // Create directory for log if need
     }
