@@ -29,21 +29,29 @@
 #include "customevents.h"
 #include "vvalentinasettings.h"
 
+#include <QTranslator>
 #include <QWidget>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
+
 //---------------------------------------------------------------------------------------------------------------------
 VAbstractValApplication::VAbstractValApplication(int &argc, char **argv)
-    : VAbstractApplication(argc, argv)
-{}
+  : VAbstractApplication(argc, argv)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-double VAbstractValApplication::toPixel(double val) const
+auto VAbstractValApplication::toPixel(double val) const -> double
 {
     return ToPixel(val, m_patternUnits);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-double VAbstractValApplication::fromPixel(double pix) const
+auto VAbstractValApplication::fromPixel(double pix) const -> double
 {
     return FromPixel(pix, m_patternUnits);
 }
@@ -63,19 +71,28 @@ void VAbstractValApplication::PostWarningMessage(const QString &message, QtMsgTy
  */
 void VAbstractValApplication::OpenSettings()
 {
+#if defined(Q_OS_WIN)
+    QString const docPath = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
+    if (!docPath.isEmpty())
+    {
+        QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, docPath);
+    }
+#endif
     settings = new VValentinaSettings(QSettings::IniFormat, QSettings::UserScope, QCoreApplication::organizationName(),
                                       QCoreApplication::applicationName(), this);
+    connect(settings, &VValentinaSettings::SVGFontsPathChanged, this, &VAbstractValApplication::SVGFontsPathChanged);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VValentinaSettings *VAbstractValApplication::ValentinaSettings()
+auto VAbstractValApplication::ValentinaSettings() -> VValentinaSettings *
 {
     SCASSERT(settings != nullptr)
-            return qobject_cast<VValentinaSettings *>(settings);
+
+    return qobject_cast<VValentinaSettings *>(settings);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VAbstractValApplication::VApp() -> VAbstractValApplication *
 {
-    return qobject_cast<VAbstractValApplication*>(QCoreApplication::instance());
+    return qobject_cast<VAbstractValApplication *>(QCoreApplication::instance());
 }
