@@ -92,6 +92,7 @@ Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingPathsIndividualMeasurements, ("p
 Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingPathsMultisizeMeasurements, ("paths/standard_measurements"_L1))
 Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingPathsPattern, ("paths/pattern"_L1))                         // NOLINT
 Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingPathsManualLayouts, ("paths/manualLayouts"_L1))             // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingPathsLayoutExport, ("paths/layoutExport"_L1))               // NOLINT
 Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingPathsCustomImage, ("paths/customImage"_L1))                 // NOLINT
 Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingPathsSVGFonts, ("paths/svgFonts"_L1))                       // NOLINT
 Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingPathsFontCorrections, ("paths/fontCorrections"_L1))         // NOLINT
@@ -220,6 +221,7 @@ int scrollingUpdateIntervalCached = -1;     // NOLINT(cppcoreguidelines-avoid-no
 qreal scrollingSensorMouseScaleCached = -1; // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
 qreal scrollingWheelMouseScaleCached = -1;  // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
 qreal scrollingAccelerationCached = -1;     // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
+int patternTranslateFormulaCached = -1;     // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
 
 //---------------------------------------------------------------------------------------------------------------------
 auto ClearFormats(const QStringList &predefinedFormats, QStringList formats) -> QStringList
@@ -277,7 +279,7 @@ auto VCommonSettings::GetPathIndividualMeasurements() const -> QString
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetPathIndividualMeasurements(const QString &value)
+void VCommonSettings::SetPathIndividualMeasurements(const QString &value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingPathsIndividualMeasurements, value);
@@ -292,7 +294,7 @@ auto VCommonSettings::GetPathMultisizeMeasurements() const -> QString
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetPathMultisizeMeasurements(const QString &value)
+void VCommonSettings::SetPathMultisizeMeasurements(const QString &value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingPathsMultisizeMeasurements, value);
@@ -307,7 +309,7 @@ auto VCommonSettings::GetPathPattern() const -> QString
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetPathPattern(const QString &value)
+void VCommonSettings::SetPathPattern(const QString &value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingPathsPattern, value);
@@ -322,13 +324,28 @@ auto VCommonSettings::GetPathManualLayouts() const -> QString
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetPathManualLayouts(const QString &value)
+void VCommonSettings::SetPathManualLayouts(const QString &value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingPathsManualLayouts, value);
     settings.sync();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VCommonSettings::GetPathLayoutExport() const -> QString
+{
+    QSettings const settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
+    return settings.value(*settingPathsLayoutExport, QDir::homePath()).toString();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VCommonSettings::SetPathLayoutExport(const QString &value) const
+{
+    QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
+    settings.setValue(*settingPathsLayoutExport, value);
+    settings.sync();
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VCommonSettings::GetPathCustomImage() const -> QString
 {
@@ -337,7 +354,7 @@ auto VCommonSettings::GetPathCustomImage() const -> QString
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetPathCustomImage(const QString &value)
+void VCommonSettings::SetPathCustomImage(const QString &value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingPathsCustomImage, value);
@@ -411,7 +428,7 @@ auto VCommonSettings::GetPathFontCorrections() const -> QString
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetPathFontCorrections(const QString &value)
+void VCommonSettings::SetPathFontCorrections(const QString &value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingPathsFontCorrections, value);
@@ -641,7 +658,7 @@ auto VCommonSettings::GetThemeMode() const -> VThemeMode
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetThemeMode(VThemeMode mode)
+void VCommonSettings::SetThemeMode(VThemeMode mode) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingConfigurationThemeMode, static_cast<int>(mode));
@@ -879,7 +896,7 @@ auto VCommonSettings::IsAutomaticallyCheckUpdates() const -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetAutomaticallyCheckUpdates(bool value)
+void VCommonSettings::SetAutomaticallyCheckUpdates(bool value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingAutomaticallyCheckUpdates, value);
@@ -894,7 +911,7 @@ auto VCommonSettings::GetLatestSkippedVersion() const -> unsigned
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetLatestSkippedVersion(unsigned value)
+void VCommonSettings::SetLatestSkippedVersion(unsigned value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingLatestSkippedVersion, value);
@@ -909,7 +926,7 @@ auto VCommonSettings::GetDateOfLastRemind() const -> QDate
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetDateOfLastRemind(const QDate &date)
+void VCommonSettings::SetDateOfLastRemind(const QDate &date) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingDateOfLastRemind, date);
@@ -987,7 +1004,7 @@ void VCommonSettings::SetDoublePassmark(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetCSVWithHeader(bool withHeader)
+void VCommonSettings::SetCSVWithHeader(bool withHeader) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingCSVWithHeader, withHeader);
@@ -1007,7 +1024,7 @@ auto VCommonSettings::GetDefCSVWithHeader() -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetCSVCodec(int mib)
+void VCommonSettings::SetCSVCodec(int mib) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingCSVCodec, mib);
@@ -1027,7 +1044,7 @@ auto VCommonSettings::GetDefCSVCodec() -> int
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetCSVSeparator(const QChar &separator)
+void VCommonSettings::SetCSVSeparator(const QChar &separator) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     switch (separator.toLatin1())
@@ -1413,7 +1430,7 @@ auto VCommonSettings::IsDontUseNativeDialog() const -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetDontUseNativeDialog(bool value)
+void VCommonSettings::SetDontUseNativeDialog(bool value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingConfigurationDontUseNativeDialog, value);
@@ -1460,7 +1477,7 @@ auto VCommonSettings::GetScrollingDuration() const -> int
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetScrollingDuration(int duration)
+void VCommonSettings::SetScrollingDuration(int duration) const
 {
     scrollingDurationCached = qBound(scrollingDurationMin, duration, scrollingDurationMax);
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
@@ -1477,7 +1494,7 @@ auto VCommonSettings::GetScrollingUpdateInterval() const -> int
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetScrollingUpdateInterval(int updateInterval)
+void VCommonSettings::SetScrollingUpdateInterval(int updateInterval) const
 {
     scrollingUpdateIntervalCached = qBound(scrollingUpdateIntervalMin, updateInterval, scrollingUpdateIntervalMax);
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
@@ -1494,7 +1511,7 @@ auto VCommonSettings::GetSensorMouseScale() const -> qreal
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetSensorMouseScale(qreal scale)
+void VCommonSettings::SetSensorMouseScale(qreal scale) const
 {
     scrollingSensorMouseScaleCached = qBound(sensorMouseScaleMin, scale, sensorMouseScaleMax);
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
@@ -1511,7 +1528,7 @@ auto VCommonSettings::GetWheelMouseScale() const -> qreal
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetWheelMouseScale(qreal scale)
+void VCommonSettings::SetWheelMouseScale(qreal scale) const
 {
     scrollingWheelMouseScaleCached = qBound(wheelMouseScaleMin, scale, wheelMouseScaleMax);
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
@@ -1528,7 +1545,7 @@ auto VCommonSettings::GetScrollingAcceleration() const -> qreal
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetScrollingAcceleration(qreal acceleration)
+void VCommonSettings::SetScrollingAcceleration(qreal acceleration) const
 {
     scrollingAccelerationCached = qBound(scrollingAccelerationMin, acceleration, scrollingAccelerationMax);
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
@@ -1544,7 +1561,7 @@ auto VCommonSettings::IsOpenGLRender() const -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetOpenGLRender(bool value)
+void VCommonSettings::SetOpenGLRender(bool value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingPatternUseOpenGLRender, value);
@@ -1559,7 +1576,7 @@ auto VCommonSettings::GetGraphicalOutput() const -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetGraphicalOutput(const bool &value)
+void VCommonSettings::SetGraphicalOutput(const bool &value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingPatternGraphicalOutput, value);
@@ -1646,7 +1663,7 @@ auto VCommonSettings::GetWatermarkCustomColors() const -> QVector<QColor>
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetWatermarkCustomColors(QVector<QColor> colors)
+void VCommonSettings::SetWatermarkCustomColors(QVector<QColor> colors) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
 
@@ -1675,7 +1692,7 @@ auto VCommonSettings::IsAskCollectStatistic() const -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetAskCollectStatistic(bool value)
+void VCommonSettings::SetAskCollectStatistic(bool value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingsStatistictAskCollect, value);
@@ -1690,7 +1707,7 @@ auto VCommonSettings::IsCollectStatistic() const -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetCollectStatistic(bool value)
+void VCommonSettings::SetCollectStatistic(bool value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingsStatistictCollect, value);
@@ -1705,7 +1722,7 @@ auto VCommonSettings::GetClientID() const -> QString
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetClientID(const QString &clientID)
+void VCommonSettings::SetClientID(const QString &clientID) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingsStatistictClientID, clientID);
@@ -1715,16 +1732,22 @@ void VCommonSettings::SetClientID(const QString &clientID)
 //---------------------------------------------------------------------------------------------------------------------
 auto VCommonSettings::IsTranslateFormula() const -> bool
 {
-    QSettings const settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
-    return settings.value(*settingsPatternTranslateFormula, 1).toBool();
+    if (patternTranslateFormulaCached < 0)
+    {
+        QSettings const settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
+        patternTranslateFormulaCached = settings.value(*settingsPatternTranslateFormula, 1).toBool();
+    }
+
+    return patternTranslateFormulaCached;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetTranslateFormula(bool value)
+void VCommonSettings::SetTranslateFormula(bool value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingsPatternTranslateFormula, value);
     settings.sync();
+    patternTranslateFormulaCached = value;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1736,7 +1759,7 @@ auto VCommonSettings::GetActionShortcuts(const QString &name, const QStringList
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetActionShortcuts(const QString &name, const QStringList &shortcuts)
+void VCommonSettings::SetActionShortcuts(const QString &name, const QStringList &shortcuts) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.beginGroup("shortcuts"_L1);
@@ -1752,7 +1775,7 @@ auto VCommonSettings::GetCrashEmail() const -> QString
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetCrashEmail(const QString &value)
+void VCommonSettings::SetCrashEmail(const QString &value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingsConfigurationCrashEmail, value);
@@ -1767,7 +1790,7 @@ auto VCommonSettings::IsSendCrashReport() const -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SeSendCrashReport(bool value)
+void VCommonSettings::SeSendCrashReport(bool value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingsConfigurationSendCrashReport, value);
@@ -1782,7 +1805,7 @@ auto VCommonSettings::IsAskSendCrashReport() const -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VCommonSettings::SetAskSendCrashReport(bool value)
+void VCommonSettings::SetAskSendCrashReport(bool value) const
 {
     QSettings settings(this->format(), this->scope(), this->organizationName(), *commonIniFilename);
     settings.setValue(*settingsConfigurationAskSendCrashReport, value);
