@@ -32,17 +32,15 @@
 #include <QStringBuilder>
 #include <QTableWidget>
 #include <QTableWidgetItem>
-#include <Qt>
 
 #include "../vmisc/def.h"
-#include "../vmisc/compatibility.h"
 
 const int VTableSearch::MaxHistoryRecords = 10;
 
 //---------------------------------------------------------------------------------------------------------------------
 VTableSearch::VTableSearch(QTableWidget *table, QObject *parent)
-    : QObject(parent),
-      table(table)
+  : QObject(parent),
+    table(table)
 {
 }
 
@@ -51,19 +49,19 @@ void VTableSearch::Clear()
 {
     SCASSERT(table != nullptr)
 
-    for(int i = 0; i < table->rowCount(); ++i)
+    for (int i = 0; i < table->rowCount(); ++i)
     {
-        for(int j = 0; j < table->columnCount(); ++j)
+        for (int j = 0; j < table->columnCount(); ++j)
         {
             if (QTableWidgetItem *item = table->item(i, j))
             {
                 if (item->row() % 2 != 0 && table->alternatingRowColors())
                 {
-                    item->setBackground(QPalette().alternateBase());
+                    item->setBackground(table->palette().alternateBase());
                 }
                 else
                 {
-                    item->setBackground(QPalette().base());
+                    item->setBackground(table->palette().base());
                 }
             }
         }
@@ -76,7 +74,7 @@ void VTableSearch::Clear()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VTableSearch::ShowNext(int newIndex)
+void VTableSearch::ShowNext(vsizetype newIndex)
 {
     if (not searchList.isEmpty())
     {
@@ -120,24 +118,24 @@ auto VTableSearch::FindTableItems(QString term) -> QList<QTableWidgetItem *>
         options |= QRegularExpression::UseUnicodePropertiesOption;
     }
 
-    QRegularExpression re(term, options);
+    QRegularExpression const re(term, options);
 
-    if(not re.isValid())
+    if (not re.isValid())
     {
         return {};
     }
 
     QList<QTableWidgetItem *> list;
 
-    for (int r=0; r<table->rowCount(); ++r)
+    for (int r = 0; r < table->rowCount(); ++r)
     {
-        for (int c=0; c<table->columnCount(); ++c)
+        for (int c = 0; c < table->columnCount(); ++c)
         {
             QTableWidgetItem *cell = table->item(r, c);
             if (cell != nullptr)
             {
-                QString text = cell->text();
-                QRegularExpressionMatch match = re.match(text);
+                QString const text = cell->text();
+                QRegularExpressionMatch const match = re.match(text);
                 if (match.hasMatch())
                 {
                     list.append(cell);
@@ -156,18 +154,18 @@ auto VTableSearch::FindCurrentMatchIndex() const -> int
         return 0;
     }
 
-    QList<QTableWidgetItem*> selectedItems = table->selectedItems();
+    QList<QTableWidgetItem *> const selectedItems = table->selectedItems();
     if (selectedItems.isEmpty())
     {
         return 0;
     }
 
-    QTableWidgetItem* selectedItem = ConstFirst(selectedItems);
+    QTableWidgetItem *selectedItem = selectedItems.constFirst();
 
-    for (int i=0; i<searchList.size(); ++i)
+    for (int i = 0; i < searchList.size(); ++i)
     {
-        QTableWidgetItem* item = searchList.at(i);
-        if (item->row()>= selectedItem->row() && item->column()>= selectedItem->column())
+        QTableWidgetItem *item = searchList.at(i);
+        if (item->row() >= selectedItem->row() && item->column() >= selectedItem->column())
         {
             return i;
         }
@@ -179,7 +177,7 @@ auto VTableSearch::FindCurrentMatchIndex() const -> int
 //---------------------------------------------------------------------------------------------------------------------
 void VTableSearch::Find(const QString &term)
 {
-    if(table == nullptr)
+    if (table == nullptr)
     {
         return;
     }
@@ -210,7 +208,7 @@ void VTableSearch::Find(const QString &term)
 //---------------------------------------------------------------------------------------------------------------------
 void VTableSearch::FindPrevious()
 {
-    int newIndex = searchIndex - 1;
+    vsizetype newIndex = searchIndex - 1;
 
     if (newIndex < 0)
     {
@@ -223,7 +221,7 @@ void VTableSearch::FindPrevious()
 //---------------------------------------------------------------------------------------------------------------------
 void VTableSearch::FindNext()
 {
-    int newIndex = searchIndex + 1;
+    vsizetype newIndex = searchIndex + 1;
 
     if (newIndex >= searchList.size())
     {
@@ -256,7 +254,7 @@ void VTableSearch::RemoveRow(int row)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VTableSearch::AddRow(int row)
+void VTableSearch::AddRow(vsizetype row)
 {
     if (searchIndex < 0 || searchIndex >= searchList.size())
     {
@@ -293,11 +291,11 @@ void VTableSearch::RefreshList(const QString &term)
 
         if (searchIndex < 0)
         {
-           searchIndex = searchList.size() - 1;
+            searchIndex = searchList.size() - 1;
         }
         else if (searchIndex >= searchList.size())
         {
-           searchIndex = 0;
+            searchIndex = 0;
         }
 
         QTableWidgetItem *item = searchList.at(searchIndex);
@@ -367,13 +365,13 @@ auto VTableSearch::IsUseUnicodePreperties() const -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VTableSearch::MatchIndex() const -> int
+auto VTableSearch::MatchIndex() const -> vsizetype
 {
     return searchIndex;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VTableSearch::MatchCount() const -> int
+auto VTableSearch::MatchCount() const -> vsizetype
 {
     return searchList.size();
 }
