@@ -27,22 +27,27 @@
  *************************************************************************/
 
 #include "vabstractfloatitemdata.h"
+#include "../vmisc/def.h"
 #include "vabstractfloatitemdata_p.h"
 
 //---------------------------------------------------------------------------------------------------------------------
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_GCC("-Wnoexcept")
+
 VAbstractFloatItemData::VAbstractFloatItemData()
-    : d(new VAbstractFloatItemDataPrivate())
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-VAbstractFloatItemData::VAbstractFloatItemData(const VAbstractFloatItemData &data)
-    : d (data.d)
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-VAbstractFloatItemData &VAbstractFloatItemData::operator=(const VAbstractFloatItemData &data)
+  : d(new VAbstractFloatItemDataPrivate())
 {
-    if ( &data == this )
+}
+
+QT_WARNING_POP
+
+//---------------------------------------------------------------------------------------------------------------------
+COPY_CONSTRUCTOR_IMPL(VAbstractFloatItemData)
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VAbstractFloatItemData::operator=(const VAbstractFloatItemData &data) -> VAbstractFloatItemData &
+{
+    if (&data == this)
     {
         return *this;
     }
@@ -50,26 +55,24 @@ VAbstractFloatItemData &VAbstractFloatItemData::operator=(const VAbstractFloatIt
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VAbstractFloatItemData::VAbstractFloatItemData(VAbstractFloatItemData &&data) Q_DECL_NOTHROW
-    : d (std::move(data.d))
-{}
+VAbstractFloatItemData::VAbstractFloatItemData(VAbstractFloatItemData &&data) noexcept
+  : d(std::move(data.d))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-VAbstractFloatItemData &VAbstractFloatItemData::operator=(VAbstractFloatItemData &&data) Q_DECL_NOTHROW
+auto VAbstractFloatItemData::operator=(VAbstractFloatItemData &&data) noexcept -> VAbstractFloatItemData &
 {
     std::swap(d, data.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
-VAbstractFloatItemData::~VAbstractFloatItemData()
-{}
+VAbstractFloatItemData::~VAbstractFloatItemData() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
-QPointF VAbstractFloatItemData::GetPos() const
+auto VAbstractFloatItemData::GetPos() const -> QPointF
 {
     return d->m_ptPos;
 }
@@ -81,13 +84,13 @@ void VAbstractFloatItemData::SetPos(const QPointF &ptPos)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VAbstractFloatItemData::IsVisible() const
+auto VAbstractFloatItemData::IsEnabled() const -> bool
 {
-    return d->m_bVisible;
+    return d->m_bEnabled;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VAbstractFloatItemData::SetVisible(bool bVisible)
+void VAbstractFloatItemData::SetEnabled(bool bEnabled)
 {
-    d->m_bVisible = bVisible;
+    d->m_bEnabled = bEnabled;
 }
