@@ -42,18 +42,17 @@ public:
 
     virtual ~VAbstractFloatItemData();
 
-    VAbstractFloatItemData &operator=(const VAbstractFloatItemData &data);
-#ifdef Q_COMPILER_RVALUE_REFS
-    VAbstractFloatItemData(VAbstractFloatItemData &&data) Q_DECL_NOTHROW;
-    VAbstractFloatItemData &operator=(VAbstractFloatItemData &&data) Q_DECL_NOTHROW;
-#endif
+    auto operator=(const VAbstractFloatItemData &data) -> VAbstractFloatItemData &;
+
+    VAbstractFloatItemData(VAbstractFloatItemData &&data) noexcept;
+    auto operator=(VAbstractFloatItemData &&data) noexcept -> VAbstractFloatItemData &;
 
     // methods, which set and return values of different parameters
-    QPointF GetPos() const;
-    void    SetPos(const QPointF& ptPos);
+    auto GetPos() const -> QPointF;
+    void SetPos(const QPointF &ptPos);
 
-    bool IsVisible() const;
-    void SetVisible(bool bVisible);
+    auto IsEnabled() const -> bool;
+    void SetEnabled(bool bEnabled);
 
 private:
     QSharedDataPointer<VAbstractFloatItemDataPrivate> d;
