@@ -33,9 +33,6 @@
 #include <QSharedData>
 
 #include "../vmisc/defglobal.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/diagnostic.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Weffc++")
@@ -44,29 +41,19 @@ QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")
 class VAbstractFloatItemDataPrivate : public QSharedData
 {
 public:
-    VAbstractFloatItemDataPrivate()
-        : m_ptPos(),
-          m_bVisible(false)
-    {}
-
-    VAbstractFloatItemDataPrivate(const VAbstractFloatItemDataPrivate &data)
-        : QSharedData(data),
-          m_ptPos(data.m_ptPos),
-          m_bVisible(data.m_bVisible)
-    {}
-
+    VAbstractFloatItemDataPrivate() = default;
+    VAbstractFloatItemDataPrivate(const VAbstractFloatItemDataPrivate &data) = default;
     ~VAbstractFloatItemDataPrivate() = default;
 
     /** @brief m_ptPos position of label's top left corner */
-    QPointF m_ptPos;
-    /** @brief m_bVisible visibility flag */
-    bool    m_bVisible;
+    QPointF m_ptPos{}; // NOLINT(misc-non-private-member-variables-in-classes)
+    /** @brief m_bEnabled activity flag */
+    bool m_bEnabled{false}; // NOLINT(misc-non-private-member-variables-in-classes)
 
 private:
-    Q_DISABLE_ASSIGN(VAbstractFloatItemDataPrivate)
+    Q_DISABLE_ASSIGN_MOVE(VAbstractFloatItemDataPrivate) // NOLINT
 };
 
 QT_WARNING_POP
 
 #endif // VABSTRACTFLOATITEMDATA_P_H
-
