@@ -28,25 +28,24 @@
 
 #include <QPointF>
 
+#include "../vmisc/def.h"
 #include "vgrainlinedata.h"
 #include "vgrainlinedata_p.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 VGrainlineData::VGrainlineData()
-    : VAbstractFloatItemData(),
-      d(new VGrainlineDataPrivate())
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-VGrainlineData::VGrainlineData(const VGrainlineData &data)
-    : VAbstractFloatItemData(data),
-      d (data.d)
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-VGrainlineData &VGrainlineData::operator=(const VGrainlineData &data)
+  : VAbstractFloatItemData(),
+    d(new VGrainlineDataPrivate())
 {
-    if ( &data == this )
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+COPY_CONSTRUCTOR_IMPL_2(VGrainlineData, VAbstractFloatItemData)
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VGrainlineData::operator=(const VGrainlineData &data) -> VGrainlineData &
+{
+    if (&data == this)
     {
         return *this;
     }
@@ -55,52 +54,50 @@ VGrainlineData &VGrainlineData::operator=(const VGrainlineData &data)
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VGrainlineData::VGrainlineData(VGrainlineData &&data) Q_DECL_NOTHROW
-    : VAbstractFloatItemData(std::move(data)),
-      d (std::move(data.d))
-{}
+VGrainlineData::VGrainlineData(VGrainlineData &&data) noexcept
+  : VAbstractFloatItemData(std::move(data)),
+    d(std::move(data.d)) // NOLINT(bugprone-use-after-move)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-VGrainlineData &VGrainlineData::operator=(VGrainlineData &&data) Q_DECL_NOTHROW
+auto VGrainlineData::operator=(VGrainlineData &&data) noexcept -> VGrainlineData &
 {
     VAbstractFloatItemData::operator=(data);
     std::swap(d, data.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
-VGrainlineData::~VGrainlineData()
-{}
+VGrainlineData::~VGrainlineData() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VGrainlineData::GetLength() const
+auto VGrainlineData::GetLength() const -> QString
 {
     return d->m_qsLength;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VGrainlineData::SetLength(const QString& qsLen)
+void VGrainlineData::SetLength(const QString &qsLen)
 {
     d->m_qsLength = qsLen;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VGrainlineData::GetRotation() const
+auto VGrainlineData::GetRotation() const -> QString
 {
     return d->m_dRotation;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VGrainlineData::SetRotation(const QString& qsRot)
+void VGrainlineData::SetRotation(const QString &qsRot)
 {
     d->m_dRotation = qsRot;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-GrainlineArrowDirection VGrainlineData::GetArrowType() const
+auto VGrainlineData::GetArrowType() const -> GrainlineArrowDirection
 {
     return d->m_eArrowType;
 }
@@ -112,7 +109,7 @@ void VGrainlineData::SetArrowType(GrainlineArrowDirection eAT)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 VGrainlineData::CenterPin() const
+auto VGrainlineData::CenterPin() const -> quint32
 {
     return d->m_centerPin;
 }
@@ -124,7 +121,7 @@ void VGrainlineData::SetCenterPin(quint32 centerPin)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 VGrainlineData::TopPin() const
+auto VGrainlineData::TopPin() const -> quint32
 {
     return d->m_topPin;
 }
@@ -136,7 +133,7 @@ void VGrainlineData::SetTopPin(quint32 topPin)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 VGrainlineData::BottomPin() const
+auto VGrainlineData::BottomPin() const -> quint32
 {
     return d->m_bottomPin;
 }
@@ -146,3 +143,15 @@ void VGrainlineData::SetBottomPin(quint32 bottomPin)
 {
     d->m_bottomPin = bottomPin;
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VGrainlineData::IsVisible() const -> bool
+{
+    return d->m_visible;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VGrainlineData::SetVisible(bool visible)
+{
+    d->m_visible = visible;
+}
