@@ -32,7 +32,6 @@
 #include <QString>
 
 #include "vpatternlabeldata.h"
-#include "floatitemdef.h"
 
 class VPieceLabelDataPrivate;
 struct VLabelTemplateLine;
@@ -47,43 +46,45 @@ public:
     VPieceLabelData();
     VPieceLabelData(const VPieceLabelData &data);
 
-    virtual ~VPieceLabelData();
+    ~VPieceLabelData() override;
 
-    VPieceLabelData &operator=(const VPieceLabelData &data);
-#ifdef Q_COMPILER_RVALUE_REFS
-    VPieceLabelData(VPieceLabelData &&data) Q_DECL_NOTHROW;
-    VPieceLabelData &operator=(VPieceLabelData &&data) Q_DECL_NOTHROW;
-#endif
+    auto operator=(const VPieceLabelData &data) -> VPieceLabelData &;
+
+    VPieceLabelData(VPieceLabelData &&data) noexcept;
+    auto operator=(VPieceLabelData &&data) noexcept -> VPieceLabelData &;
 
     void Clear();
 
     // methods, which operate on other members
-    QString GetLetter() const;
-    void    SetLetter(const QString &qsLetter);
+    auto GetLetter() const -> QString;
+    void SetLetter(const QString &qsLetter);
 
-    QString GetAnnotation() const;
-    void    SetAnnotation(const QString &val);
+    auto GetAnnotation() const -> QString;
+    void SetAnnotation(const QString &val);
 
-    QString GetOrientation() const;
-    void    SetOrientation(const QString &val);
+    auto GetOrientation() const -> QString;
+    void SetOrientation(const QString &val);
 
-    QString GetRotationWay() const;
-    void    SetRotationWay(const QString &val);
+    auto GetRotationWay() const -> QString;
+    void SetRotationWay(const QString &val);
 
-    QString GetTilt() const;
-    void    SetTilt(const QString &val);
+    auto GetTilt() const -> QString;
+    void SetTilt(const QString &val);
 
-    QString GetFoldPosition() const;
-    void    SetFoldPosition(const QString &val);
+    auto GetFoldPosition() const -> QString;
+    void SetFoldPosition(const QString &val);
 
-    quint16 GetQuantity() const;
-    void    SetQuantity(quint16 val);
+    auto GetQuantity() const -> quint16;
+    void SetQuantity(quint16 val);
 
-    bool IsOnFold() const;
+    auto IsOnFold() const -> bool;
     void SetOnFold(bool onFold);
 
-    QVector<VLabelTemplateLine> GetLabelTemplate() const;
-    void                        SetLabelTemplate(const QVector<VLabelTemplateLine> &lines);
+    auto GetAreaShortName() const -> QString;
+    void SetAreaShortName(const QString &val);
+
+    auto GetLabelTemplate() const -> QVector<VLabelTemplateLine>;
+    void SetLabelTemplate(const QVector<VLabelTemplateLine> &lines);
 
 private:
     QSharedDataPointer<VPieceLabelDataPrivate> d;
