@@ -29,19 +29,24 @@
 #include "testpassmark.h"
 #include "vpassmark.h"
 
+#include <QDir>
 #include <QJsonArray>
+#include <QJsonDocument>
+#include <QJsonObject>
+#include <QTemporaryFile>
+
+#include "../vmisc/testpath.h"
 
 #if !defined(V_NO_ASSERT)
 namespace
 {
 //---------------------------------------------------------------------------------------------------------------------
-QJsonArray PassmarkShapeToJson(const QVector<QLineF> &shape)
+auto PassmarkShapeToJson(const QVector<QLineF> &shape) -> QJsonArray
 {
     QJsonArray shapeArray;
-    for (auto line: shape)
+    for (const auto &line : shape)
     {
-        QJsonObject lineObject
-        {
+        QJsonObject const lineObject{
             {"type", "QLineF"},
             {"p1", PointToJson(line.p1())},
             {"p2", PointToJson(line.p2())},
@@ -52,12 +57,12 @@ QJsonArray PassmarkShapeToJson(const QVector<QLineF> &shape)
 
     return shapeArray;
 }
-}
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 void DumpPassmarkData(const VPiecePassmarkData &data, const QString &templateName)
 {
-    QTemporaryFile temp; // Go to tmp folder to find dump
+    QTemporaryFile temp;       // Go to tmp folder to find dump
     temp.setAutoRemove(false); // Remove dump manually
 
     if (not templateName.isEmpty())
@@ -68,20 +73,17 @@ void DumpPassmarkData(const VPiecePassmarkData &data, const QString &templateNam
     if (temp.open())
     {
 #if defined(Q_OS_LINUX)
-    #if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
-//        On Linux, QTemporaryFile will attempt to create unnamed temporary
-//        files. If that succeeds, open() will return true but exists() will be
-//        false. If you call fileName() or any function that calls it,
-//        QTemporaryFile will give the file a name, so most applications will
-//        not see a difference.
+        //        On Linux, QTemporaryFile will attempt to create unnamed temporary
+        //        files. If that succeeds, open() will return true but exists() will be
+        //        false. If you call fileName() or any function that calls it,
+        //        QTemporaryFile will give the file a name, so most applications will
+        //        not see a difference.
         temp.fileName(); // call to create a file on disk
-    #endif
 #endif
-        QJsonObject dataObject
-        {
+        QJsonObject const dataObject{
             {"data", data.toJson()},
         };
-        QJsonDocument vector(dataObject);
+        QJsonDocument const vector(dataObject);
 
         QTextStream out(&temp);
         out << vector.toJson();
@@ -92,7 +94,7 @@ void DumpPassmarkData(const VPiecePassmarkData &data, const QString &templateNam
 //---------------------------------------------------------------------------------------------------------------------
 void DumpPassmarkShape(const QVector<QLineF> &shape, const QString &templateName)
 {
-    QTemporaryFile temp; // Go to tmp folder to find dump
+    QTemporaryFile temp;       // Go to tmp folder to find dump
     temp.setAutoRemove(false); // Remove dump manually
 
     if (not templateName.isEmpty())
@@ -103,20 +105,17 @@ void DumpPassmarkShape(const QVector<QLineF> &shape, const QString &templateName
     if (temp.open())
     {
 #if defined(Q_OS_LINUX)
-    #if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
-//        On Linux, QTemporaryFile will attempt to create unnamed temporary
-//        files. If that succeeds, open() will return true but exists() will be
-//        false. If you call fileName() or any function that calls it,
-//        QTemporaryFile will give the file a name, so most applications will
-//        not see a difference.
+        //        On Linux, QTemporaryFile will attempt to create unnamed temporary
+        //        files. If that succeeds, open() will return true but exists() will be
+        //        false. If you call fileName() or any function that calls it,
+        //        QTemporaryFile will give the file a name, so most applications will
+        //        not see a difference.
         temp.fileName(); // call to create a file on disk
-    #endif
 #endif
-        QJsonObject shapeObject
-        {
+        QJsonObject const shapeObject{
             {"shape", PassmarkShapeToJson(shape)},
         };
-        QJsonDocument vector(shapeObject);
+        QJsonDocument const vector(shapeObject);
 
         QTextStream out(&temp);
         out << vector.toJson();
