@@ -29,7 +29,6 @@
 #ifndef VCURVEVARIABLE_H
 #define VCURVEVARIABLE_H
 
-#include <qcompilerdetection.h>
 #include <QSharedDataPointer>
 #include <QTypeInfo>
 #include <QtGlobal>
@@ -44,22 +43,21 @@ public:
     VCurveVariable();
     VCurveVariable(const quint32 &id, const quint32 &parentId);
     VCurveVariable(const VCurveVariable &var);
+    ~VCurveVariable() override;
 
-    virtual ~VCurveVariable() override;
+    auto operator=(const VCurveVariable &var) -> VCurveVariable &;
 
-    VCurveVariable &operator=(const VCurveVariable &var);
-#ifdef Q_COMPILER_RVALUE_REFS
-    VCurveVariable(VCurveVariable &&var) Q_DECL_NOTHROW;
-    VCurveVariable &operator=(VCurveVariable &&var) Q_DECL_NOTHROW;
-#endif
+    VCurveVariable(VCurveVariable &&var) noexcept;
+    auto operator=(VCurveVariable &&var) noexcept -> VCurveVariable &;
 
-    virtual bool Filter(quint32 id) override;
+    auto Filter(quint32 id) -> bool override;
 
-    quint32      GetId() const;
-    void         SetId(const quint32 &id);
+    auto GetId() const -> quint32;
+    void SetId(const quint32 &id);
+
+    auto GetParentId() const -> quint32;
+    void SetParentId(const quint32 &value);
 
-    quint32      GetParentId() const;
-    void         SetParentId(const quint32 &value);
 private:
     QSharedDataPointer<VCurveVariableData> d;
 };
