@@ -29,7 +29,6 @@
 #ifndef VINCREMENTTABLEROW_H
 #define VINCREMENTTABLEROW_H
 
-#include <qcompilerdetection.h>
 #include <QSharedDataPointer>
 #include <QString>
 #include <QTypeInfo>
@@ -43,35 +42,34 @@ class VContainer;
 /**
  * @brief The VIncrement class keep data row of increment table
  */
-class VIncrement :public VVariable
+class VIncrement : public VVariable
 {
 public:
     VIncrement();
     VIncrement(VContainer *data, const QString &name, IncrementType incrType = IncrementType::Increment);
     VIncrement(const VIncrement &incr);
 
-    virtual ~VIncrement() override;
+    ~VIncrement() override;
 
-    VIncrement &operator=(const VIncrement &incr);
-#ifdef Q_COMPILER_RVALUE_REFS
-    VIncrement(VIncrement &&incr) Q_DECL_NOTHROW;
-    VIncrement &operator=(VIncrement &&incr) Q_DECL_NOTHROW;
-#endif
+    auto operator=(const VIncrement &incr) -> VIncrement &;
 
-    void    SetFormula(qreal base, const QString &formula, bool ok);
-    QString GetFormula() const;
-    bool    IsFormulaOk() const;
+    VIncrement(VIncrement &&incr) noexcept;
+    auto operator=(VIncrement &&incr) noexcept -> VIncrement &;
 
-    void    SetIndex(quint32 index);
-    quint32 GetIndex() const;
+    void SetFormula(qreal base, const QString &formula, bool ok);
+    auto GetFormula() const -> QString;
+    auto IsFormulaOk() const -> bool;
 
-    VContainer   *GetData();
-    IncrementType GetIncrementType() const;
+    void SetIndex(quint32 index);
+    auto GetIndex() const -> quint32;
 
-    bool IsPreviewCalculation() const;
+    auto GetData() -> VContainer *;
+    auto GetIncrementType() const -> IncrementType;
+
+    auto IsPreviewCalculation() const -> bool;
     void SetPreviewCalculation(bool value);
 
-    bool IsSpecialUnits() const;
+    auto IsSpecialUnits() const -> bool;
     void SetSpecialUnits(bool special);
 
 private:
