@@ -110,7 +110,7 @@ void VLineAngle::SetValue(const VPointF *p1, const VPointF *p2)
     // Correct angle. Try avoid results like 6,7563e-15.
     const qreal angle =
         qFloor(QLineF(static_cast<QPointF>(*p1), static_cast<QPointF>(*p2)).angle() * 100000.) / 100000.;
-    VInternalVariable::SetValue(angle);
+    StoreValue(angle);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
