@@ -49,7 +49,7 @@ VMeasurement::VMeasurement(quint32 index, const QString &name)
     d(new VMeasurementData(index, MeasurementType::Separator))
 {
     SetType(VarType::MeasurementSeparator);
-    VInternalVariable::SetValue(0);
+    StoreValue(0);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -63,7 +63,7 @@ VMeasurement::VMeasurement(quint32 index, const QString &name, qreal baseA, qrea
     d(new VMeasurementData(index, baseA, baseB, baseC, base))
 {
     SetType(VarType::Measurement);
-    VInternalVariable::SetValue(d->shiftBase);
+    StoreValue(d->shiftBase);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -78,7 +78,7 @@ VMeasurement::VMeasurement(VContainer *data, quint32 index, const QString &name,
     d(new VMeasurementData(data, index, formula, ok, base))
 {
     SetType(VarType::Measurement);
-    VInternalVariable::SetValue(base);
+    StoreValue(base);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -162,10 +162,10 @@ auto VMeasurement::CalcValue() const -> qreal
 //---------------------------------------------------------------------------------------------------------------------
 auto VMeasurement::Correction() const -> qreal
 {
-    const QString hash = CorrectionHash(d->currentBaseA, d->currentBaseB, d->currentBaseC);
-    if (d->corrections.contains(hash))
+    if (const QString hash = CorrectionHash(d->currentBaseA, d->currentBaseB, d->currentBaseC);
+        d->corrections.contains(hash))
     {
-        return d->corrections.value(hash);
+        return d->corrections.value(hash).correction;
     }
 
     return 0;
@@ -232,7 +232,7 @@ auto VMeasurement::GetValue() const -> qreal
 //---------------------------------------------------------------------------------------------------------------------
 auto VMeasurement::GetValue() -> qreal *
 {
-    VInternalVariable::SetValue(CalcValue());
+    StoreValue(CalcValue());
     return VInternalVariable::GetValue();
 }
 
@@ -385,17 +385,22 @@ void VMeasurement::SetDimension(IMD type)
 //---------------------------------------------------------------------------------------------------------------------
 auto VMeasurement::GetCorrection(qreal baseA, qreal baseB, qreal baseC) const -> qreal
 {
-    return d->corrections.value(VMeasurement::CorrectionHash(baseA, baseB, baseC), 0);
+    if (const QString hash = VMeasurement::CorrectionHash(baseA, baseB, baseC); d->corrections.contains(hash))
+    {
+        return d->corrections[hash].correction;
+    }
+
+    return 0;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VMeasurement::GetCorrections() const -> QMap<QString, qreal>
+auto VMeasurement::GetCorrections() const -> QMap<QString, VMeasurementCorrection>
 {
     return d->corrections;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VMeasurement::SetCorrections(const QMap<QString, qreal> &corrections)
+void VMeasurement::SetCorrections(const QMap<QString, VMeasurementCorrection> &corrections)
 {
     d->corrections = corrections;
 }
@@ -411,3 +416,31 @@ void VMeasurement::SetImage(const VPatternImage &image)
 {
     d->image = image;
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VMeasurement::GetValueAlias(qreal baseA, qreal baseB, qreal baseC) const -> QString
+{
+    if (const QString hash = VMeasurement::CorrectionHash(baseA, baseB, baseC); d->corrections.contains(hash))
+    {
+        return d->corrections[hash].alias;
+    }
+
+    return {};
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VMeasurement::GetValueAlias() const -> QString
+{
+    if (qFuzzyIsNull(d->currentBaseA))
+    {
+        return d->valueAlias;
+    }
+
+    return GetValueAlias(d->currentBaseA, d->currentBaseB, d->currentBaseC);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VMeasurement::SetValueAlias(const QString &alias)
+{
+    d->valueAlias = alias;
+}
