@@ -36,25 +36,24 @@
 
 //---------------------------------------------------------------------------------------------------------------------
 VVariable::VVariable()
-    :VInternalVariable(), d(new VVariableData)
-{}
+  : d(new VVariableData)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 VVariable::VVariable(const QString &name, const QString &description)
-    :VInternalVariable(), d(new VVariableData(description))
+  : d(new VVariableData(description))
 {
     SetName(name);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VVariable::VVariable(const VVariable &var)
-    :VInternalVariable(var), d(var.d)
-{}
+COPY_CONSTRUCTOR_IMPL_2(VVariable, VInternalVariable)
 
 //---------------------------------------------------------------------------------------------------------------------
-VVariable &VVariable::operator=(const VVariable &var)
+auto VVariable::operator=(const VVariable &var) -> VVariable &
 {
-    if ( &var == this )
+    if (&var == this)
     {
         return *this;
     }
@@ -63,32 +62,30 @@ VVariable &VVariable::operator=(const VVariable &var)
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VVariable::VVariable(VVariable &&var) Q_DECL_NOTHROW
-    :VInternalVariable(std::move(var)), d(std::move(var.d))
-{}
+VVariable::VVariable(VVariable &&var) noexcept
+  : VInternalVariable(std::move(var)),
+    d(std::move(var.d)) // NOLINT(bugprone-use-after-move)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-VVariable &VVariable::operator=(VVariable &&var) Q_DECL_NOTHROW
+auto VVariable::operator=(VVariable &&var) noexcept -> VVariable &
 {
     VInternalVariable::operator=(var);
     std::swap(d, var.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
-VVariable::~VVariable()
-{}
+VVariable::~VVariable() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VVariable::GetDescription() const
+auto VVariable::GetDescription() const -> QString
 {
     return d->description;
 }
 
-
 //---------------------------------------------------------------------------------------------------------------------
 void VVariable::SetDescription(const QString &desc)
 {
