@@ -428,8 +428,7 @@ void VContainer::ClearVariables(const QVector<VarType> &types)
         }
         else
         {
-            QHash<QString, QSharedPointer<VInternalVariable>>::iterator i;
-            for (i = d->variables.begin(); i != d->variables.end();)
+            for (auto i = d->variables.begin(); i != d->variables.end();)
             {
                 if (types.contains(i.value()->GetType()))
                 {
@@ -712,8 +711,7 @@ template <typename T> auto VContainer::DataVar(const VarType &type) const -> QMa
 {
     QMap<QString, QSharedPointer<T>> map;
     // Sorting QHash by id
-    QHash<QString, QSharedPointer<VInternalVariable>>::const_iterator i;
-    for (i = d->variables.constBegin(); i != d->variables.constEnd(); ++i)
+    for (auto i = d->variables.constBegin(); i != d->variables.constEnd(); ++i)
     {
         if (i.value()->GetType() == type)
         {
