@@ -92,7 +92,7 @@ public:
                     PassmarkSide side) const -> QVector<QLineF>;
     auto BuiltInSAPassmark(const VPiece &piece, const VContainer *data) const -> QVector<QLineF>;
 
-    auto BuiltInSAPassmarkBaseLine(const VPiece &piece) const -> QVector<QLineF>;
+    auto BuiltInSAPassmarkBaseLine(const VPiece &piece, const QLineF& mirrorLine) const -> QVector<QLineF>;
     auto SAPassmarkBaseLine(const VPiece &piece, const VContainer *data, PassmarkSide side) const -> QVector<QLineF>;
     auto SAPassmarkBaseLine(const QVector<QPointF> &seamAllowance, const QVector<QPointF> &rotatedSeamAllowance,
                             PassmarkSide side) const -> QVector<QLineF>;
@@ -122,6 +122,9 @@ private:
 
     auto CreatePassmarkLines(const QVector<QLineF> &lines, const QVector<QPointF> &seamAllowance,
                              PassmarkSide side) const -> QVector<QLineF>;
+
+    auto CalculatePassmarkLength(const VPiece &piece) const -> qreal;
+    auto DetermineEdges(const VPiece &piece, const QLineF &mirrorLine) const -> std::pair<QLineF, QLineF>;
 };
 
 #endif // VPASSMARK_H
