@@ -145,6 +145,8 @@ public:
     auto GetUnitedPath(const VContainer *data) const -> QVector<VPieceNode>;
 
     auto SeamAllowancePointsWithRotation(const VContainer *data, vsizetype makeFirst) const -> QVector<VLayoutPoint>;
+    auto FullSeamAllowancePointsWithRotation(const VContainer *data, vsizetype makeFirst) const
+        -> QVector<VLayoutPoint>;
 
     void SetGradationLabel(const QString &label);
     auto GetGradationLabel() const -> QString;
@@ -175,6 +177,7 @@ public:
     auto ExternalArea(const VContainer *data) const -> qreal;
     auto SeamLineArea(const VContainer *data) const -> qreal;
 
+    auto SeamMirrorLinePoints(const VContainer *data) const -> QVector<VPointF>;
     auto SeamMirrorLine(const VContainer *data) const -> QLineF;
     auto SeamAllowanceMirrorLine(const VContainer *data) const -> QLineF;
 
