@@ -27,37 +27,33 @@
  *************************************************************************/
 
 #include "vpiecenode.h"
-#include "vpiecenode_p.h"
-#include "vcontainer.h"
-#include "calculator.h"
-#include "vformula.h"
 #include "../vmisc/vabstractvalapplication.h"
+#include "vcontainer.h"
+#include "vformula.h"
+#include "vpiecenode_p.h"
 
 #include <QDataStream>
 #include <QtNumeric>
 
-const quint32 VPieceNodeData::streamHeader = 0x2198CBC8; // CRC-32Q string "VPieceNodeData"
-const quint16 VPieceNodeData::classVersion = 1;
-
 //---------------------------------------------------------------------------------------------------------------------
 VPieceNode::VPieceNode()
-    : d(new VPieceNodeData)
-{}
+  : d(new VPieceNodeData)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 VPieceNode::VPieceNode(quint32 id, Tool typeTool, bool reverse)
-    : d(new VPieceNodeData(id, typeTool, reverse))
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-VPieceNode::VPieceNode(const VPieceNode &node)
-    : d (node.d)
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-VPieceNode &VPieceNode::operator=(const VPieceNode &node)
+  : d(new VPieceNodeData(id, typeTool, reverse))
 {
-    if ( &node == this )
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+COPY_CONSTRUCTOR_IMPL(VPieceNode)
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPieceNode::operator=(const VPieceNode &node) -> VPieceNode &
+{
+    if (&node == this)
     {
         return *this;
     }
@@ -65,41 +61,39 @@ VPieceNode &VPieceNode::operator=(const VPieceNode &node)
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VPieceNode::VPieceNode(VPieceNode &&node) Q_DECL_NOTHROW
-    : d (std::move(node.d))
-{}
+VPieceNode::VPieceNode(VPieceNode &&node) noexcept
+  : d(std::move(node.d))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-VPieceNode &VPieceNode::operator=(VPieceNode &&node) Q_DECL_NOTHROW
+auto VPieceNode::operator=(VPieceNode &&node) noexcept -> VPieceNode &
 {
     std::swap(d, node.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
-VPieceNode::~VPieceNode()
-{}
+VPieceNode::~VPieceNode() = default;
 
 // Friend functions
 //---------------------------------------------------------------------------------------------------------------------
-QDataStream &operator<<(QDataStream &out, const VPieceNode &p)
+auto operator<<(QDataStream &out, const VPieceNode &p) -> QDataStream &
 {
     out << *p.d;
     return out;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDataStream &operator>>(QDataStream &in, VPieceNode &p)
+auto operator>>(QDataStream &in, VPieceNode &p) -> QDataStream &
 {
     in >> *p.d;
     return in;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 VPieceNode::GetId() const
+auto VPieceNode::GetId() const -> quint32
 {
     return d->m_id;
 }
@@ -111,7 +105,7 @@ void VPieceNode::SetId(quint32 id)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-Tool VPieceNode::GetTypeTool() const
+auto VPieceNode::GetTypeTool() const -> Tool
 {
     return d->m_typeTool;
 }
@@ -123,7 +117,7 @@ void VPieceNode::SetTypeTool(Tool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VPieceNode::GetReverse() const
+auto VPieceNode::GetReverse() const -> bool
 {
     return d->m_reverse;
 }
@@ -138,7 +132,7 @@ void VPieceNode::SetReverse(bool reverse)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VPieceNode::GetSABefore(const VContainer *data) const
+auto VPieceNode::GetSABefore(const VContainer *data) const -> qreal
 {
     if (d->m_formulaWidthBefore == currentSeamAllowance)
     {
@@ -146,7 +140,6 @@ qreal VPieceNode::GetSABefore(const VContainer *data) const
     }
 
     VFormula formula(d->m_formulaWidthBefore, data);
-    formula.setCheckZero(false);
     formula.Eval();
 
     if (formula.error())
@@ -157,19 +150,21 @@ qreal VPieceNode::GetSABefore(const VContainer *data) const
             nodeName = data->GetGObject(d->m_id)->name();
         }
         catch (const VExceptionBadId &)
-        {}
+        {
+        }
 
         const QString errorMsg = QObject::tr("Cannot calculate seam allowance before for point '%1'. Reason: %2.")
-                .arg(nodeName, formula.Reason());
-        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+                                     .arg(nodeName, formula.Reason());
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
         return -1;
     }
     return formula.getDoubleValue();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VPieceNode::GetSABefore(const VContainer *data, Unit unit) const
+auto VPieceNode::GetSABefore(const VContainer *data, Unit unit) const -> qreal
 {
     if (d->m_formulaWidthBefore == currentSeamAllowance)
     {
@@ -177,7 +172,6 @@ qreal VPieceNode::GetSABefore(const VContainer *data, Unit unit) const
     }
 
     VFormula formula(d->m_formulaWidthBefore, data);
-    formula.setCheckZero(false);
     formula.Eval();
 
     if (formula.error())
@@ -188,12 +182,14 @@ qreal VPieceNode::GetSABefore(const VContainer *data, Unit unit) const
             nodeName = data->GetGObject(d->m_id)->name();
         }
         catch (const VExceptionBadId &)
-        {}
+        {
+        }
 
         const QString errorMsg = QObject::tr("Cannot calculate seam allowance before for point '%1'. Reason: %2.")
-                .arg(nodeName, formula.Reason());
-        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+                                     .arg(nodeName, formula.Reason());
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
         return -1;
     }
 
@@ -206,7 +202,7 @@ qreal VPieceNode::GetSABefore(const VContainer *data, Unit unit) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VPieceNode::GetFormulaSABefore() const
+auto VPieceNode::GetFormulaSABefore() const -> QString
 {
     return d->m_formulaWidthBefore;
 }
@@ -221,7 +217,7 @@ void VPieceNode::SetFormulaSABefore(const QString &formula)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VPieceNode::GetSAAfter(const VContainer *data) const
+auto VPieceNode::GetSAAfter(const VContainer *data) const -> qreal
 {
     if (d->m_formulaWidthAfter == currentSeamAllowance)
     {
@@ -229,7 +225,6 @@ qreal VPieceNode::GetSAAfter(const VContainer *data) const
     }
 
     VFormula formula(d->m_formulaWidthAfter, data);
-    formula.setCheckZero(false);
     formula.Eval();
 
     if (formula.error())
@@ -240,12 +235,14 @@ qreal VPieceNode::GetSAAfter(const VContainer *data) const
             nodeName = data->GetGObject(d->m_id)->name();
         }
         catch (const VExceptionBadId &)
-        {}
+        {
+        }
 
         const QString errorMsg = QObject::tr("Cannot calculate seam allowance after for point '%1'. Reason: %2.")
-                .arg(nodeName, formula.Reason());
-        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+                                     .arg(nodeName, formula.Reason());
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
         return -1;
     }
 
@@ -253,7 +250,7 @@ qreal VPieceNode::GetSAAfter(const VContainer *data) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VPieceNode::GetSAAfter(const VContainer *data, Unit unit) const
+auto VPieceNode::GetSAAfter(const VContainer *data, Unit unit) const -> qreal
 {
     if (d->m_formulaWidthAfter == currentSeamAllowance)
     {
@@ -261,7 +258,6 @@ qreal VPieceNode::GetSAAfter(const VContainer *data, Unit unit) const
     }
 
     VFormula formula(d->m_formulaWidthAfter, data);
-    formula.setCheckZero(false);
     formula.Eval();
 
     if (formula.error())
@@ -272,12 +268,14 @@ qreal VPieceNode::GetSAAfter(const VContainer *data, Unit unit) const
             nodeName = data->GetGObject(d->m_id)->name();
         }
         catch (const VExceptionBadId &)
-        {}
+        {
+        }
 
-        const QString errorMsg = QObject::tr("Cannot calculate seam allowance after for point '%1'. Reason: ")
-                .arg(nodeName, formula.Reason());
-        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+        const QString errorMsg = QObject::tr("Cannot calculate seam allowance after for point '%1'. Reason: %2.")
+                                     .arg(nodeName, formula.Reason());
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
         return -1;
     }
 
@@ -291,7 +289,7 @@ qreal VPieceNode::GetSAAfter(const VContainer *data, Unit unit) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VPieceNode::GetFormulaSAAfter() const
+auto VPieceNode::GetFormulaSAAfter() const -> QString
 {
     return d->m_formulaWidthAfter;
 }
@@ -306,7 +304,7 @@ void VPieceNode::SetFormulaSAAfter(const QString &formula)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VPieceNode::GetFormulaPassmarkLength() const
+auto VPieceNode::GetFormulaPassmarkLength() const -> QString
 {
     return d->m_formulaPassmarkLength;
 }
@@ -321,13 +319,43 @@ void VPieceNode::SetFormulaPassmarkLength(const QString &formula)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VPieceNode::GetPassmarkLength(const VContainer *data, Unit unit) const
+auto VPieceNode::GetFormulaPassmarkWidth() const -> QString
+{
+    return d->m_formulaPassmarkWidth;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPieceNode::SetFormulaPassmarkWidth(const QString &formula)
+{
+    if (d->m_typeTool == Tool::NodePoint)
+    {
+        d->m_formulaPassmarkWidth = formula;
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPieceNode::GetFormulaPassmarkAngle() const -> QString
+{
+    return d->m_formulaPassmarkAngle;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPieceNode::SetFormulaPassmarkAngle(const QString &formula)
+{
+    if (d->m_typeTool == Tool::NodePoint)
+    {
+        d->m_formulaPassmarkAngle = formula;
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPieceNode::GetPassmarkLength(const VContainer *data, Unit unit) const -> qreal
 {
     if (d->m_manualPassmarkLength)
     {
         VFormula formula(d->m_formulaPassmarkLength, data);
-        formula.setCheckZero(false);
-        formula.setCheckLessThanZero(false);
+        formula.setCheckZero(true);
+        formula.setCheckLessThanZero(true);
         formula.Eval();
 
         if (formula.error())
@@ -338,12 +366,14 @@ qreal VPieceNode::GetPassmarkLength(const VContainer *data, Unit unit) const
                 nodeName = data->GetGObject(d->m_id)->name();
             }
             catch (const VExceptionBadId &)
-            {}
+            {
+            }
 
             const QString errorMsg = QObject::tr("Cannot calculate passmark length for point '%1'. Reason: %2.")
-                    .arg(nodeName, formula.Reason());
-            VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+                                         .arg(nodeName, formula.Reason());
+            VAbstractApplication::VApp()->IsPedantic()
+                ? throw VException(errorMsg)
+                : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
             return VSAPoint::maxPassmarkLength;
         }
 
@@ -353,7 +383,72 @@ qreal VPieceNode::GetPassmarkLength(const VContainer *data, Unit unit) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-PieceNodeAngle VPieceNode::GetAngleType() const
+auto VPieceNode::GetPassmarkWidth(const VContainer *data, Unit unit) const -> qreal
+{
+    if (d->m_manualPassmarkWidth)
+    {
+        VFormula formula(d->m_formulaPassmarkWidth, data);
+        formula.setCheckZero(true);
+        formula.Eval();
+
+        if (formula.error())
+        {
+            QString nodeName;
+            try
+            {
+                nodeName = data->GetGObject(d->m_id)->name();
+            }
+            catch (const VExceptionBadId &)
+            {
+            }
+
+            const QString errorMsg = QObject::tr("Cannot calculate passmark width for point '%1'. Reason: %2.")
+                                         .arg(nodeName, formula.Reason());
+            VAbstractApplication::VApp()->IsPedantic()
+                ? throw VException(errorMsg)
+                : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+            return 0;
+        }
+
+        return ToPixel(formula.getDoubleValue(), unit);
+    }
+    return -1;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPieceNode::GetPassmarkAngle(const VContainer *data) const -> qreal
+{
+    if (d->m_manualPassmarkAngle)
+    {
+        VFormula formula(d->m_formulaPassmarkAngle, data);
+        formula.Eval();
+
+        if (formula.error())
+        {
+            QString nodeName;
+            try
+            {
+                nodeName = data->GetGObject(d->m_id)->name();
+            }
+            catch (const VExceptionBadId &)
+            {
+            }
+
+            const QString errorMsg = QObject::tr("Cannot calculate passmark angle for point '%1'. Reason: %2.")
+                                         .arg(nodeName, formula.Reason());
+            VAbstractApplication::VApp()->IsPedantic()
+                ? throw VException(errorMsg)
+                : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+            return 0;
+        }
+
+        return formula.getDoubleValue();
+    }
+    return 0;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPieceNode::GetAngleType() const -> PieceNodeAngle
 {
     return d->m_angleType;
 }
@@ -368,7 +463,7 @@ void VPieceNode::SetAngleType(PieceNodeAngle type)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VPieceNode::IsPassmark() const
+auto VPieceNode::IsPassmark() const -> bool
 {
     return d->m_isPassmark;
 }
@@ -383,7 +478,7 @@ void VPieceNode::SetPassmark(bool passmark)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VPieceNode::IsMainPathNode() const
+auto VPieceNode::IsMainPathNode() const -> bool
 {
     return d->m_isMainPathNode;
 }
@@ -395,7 +490,7 @@ void VPieceNode::SetMainPathNode(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-PassmarkLineType VPieceNode::GetPassmarkLineType() const
+auto VPieceNode::GetPassmarkLineType() const -> PassmarkLineType
 {
     return d->m_passmarkLineType;
 }
@@ -407,7 +502,7 @@ void VPieceNode::SetPassmarkLineType(PassmarkLineType lineType)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-PassmarkAngleType VPieceNode::GetPassmarkAngleType() const
+auto VPieceNode::GetPassmarkAngleType() const -> PassmarkAngleType
 {
     return d->m_passmarkAngleType;
 }
@@ -419,7 +514,7 @@ void VPieceNode::SetPassmarkAngleType(PassmarkAngleType angleType)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VPieceNode::IsShowSecondPassmark() const
+auto VPieceNode::IsShowSecondPassmark() const -> bool
 {
     return d->m_isShowSecondPassmark;
 }
@@ -431,7 +526,19 @@ void VPieceNode::SetShowSecondPassmark(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VPieceNode::IsCheckUniqueness() const
+auto VPieceNode::IsPassmarkClockwiseOpening() const -> bool
+{
+    return d->m_isPassmarkClockwiseOpening;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPieceNode::SetPassmarkClockwiseOpening(bool value)
+{
+    d->m_isPassmarkClockwiseOpening = value;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPieceNode::IsCheckUniqueness() const -> bool
 {
     return d->m_checkUniqueness;
 }
@@ -443,7 +550,7 @@ void VPieceNode::SetCheckUniqueness(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VPieceNode::IsManualPassmarkLength() const
+auto VPieceNode::IsManualPassmarkLength() const -> bool
 {
     return d->m_manualPassmarkLength;
 }
@@ -455,7 +562,43 @@ void VPieceNode::SetManualPassmarkLength(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VPieceNode::IsExcluded() const
+auto VPieceNode::IsManualPassmarkWidth() const -> bool
+{
+    return d->m_manualPassmarkWidth;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPieceNode::SetManualPassmarkWidth(bool value)
+{
+    d->m_manualPassmarkWidth = value;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPieceNode::IsManualPassmarkAngle() const -> bool
+{
+    return d->m_manualPassmarkAngle;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPieceNode::SetManualPassmarkAngle(bool value)
+{
+    d->m_manualPassmarkAngle = value;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPieceNode::IsTurnPoint() const -> bool
+{
+    return d->m_typeTool == Tool::NodePoint ? d->m_turnPoint : false;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPieceNode::SetTurnPoint(bool value)
+{
+    d->m_turnPoint = value;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPieceNode::IsExcluded() const -> bool
 {
     return d->m_excluded;
 }
