@@ -29,52 +29,41 @@
 #ifndef VTRANSLATEVARS_H
 #define VTRANSLATEVARS_H
 
-#include <qcompilerdetection.h>
+#include <QMap>
 #include <QtGlobal>
 
-#include "vtranslatemeasurements.h"
+#include "../qmuparser/qmutranslation.h"
 #include "../vmisc/defglobal.h"
 
-class VTranslateVars : public VTranslateMeasurements
+class VTranslateVars
 {
 public:
     explicit VTranslateVars();
-    ~VTranslateVars() override = default;
-
-    auto VariablesFromUser(QString &newFormula, int position, const QString &token, int &bias) const -> bool;
-    auto FunctionsFromUser(QString &newFormula, int position, const QString &token, int &bias) const -> bool;
-    auto VariablesToUser(QString &newFormula, int position, const QString &token, int &bias) const -> bool;
+    ~VTranslateVars() = default;
 
     auto InternalVarToUser(const QString &var) const -> QString;
 
     auto VarToUser(const QString &var) const -> QString;
     auto VarFromUser(const QString &var) const -> QString;
 
-    auto PMSystemName(const QString &code) const -> QString;
-    auto PMSystemAuthor(const QString &code) const -> QString;
-    auto PMSystemBook(const QString &code) const -> QString;
-
     auto FormulaFromUser(const QString &formula, bool osSeparator) const -> QString;
     static auto TryFormulaFromUser(const QString &formula, bool osSeparator) -> QString;
 
     auto FormulaToUser(const QString &formula, bool osSeparator) const -> QString;
     static auto TryFormulaToUser(const QString &formula, bool osSeparator) -> QString;
 
-    void Retranslate() override;
+    void Retranslate();
 
     auto GetTranslatedFunctions() const -> QMap<QString, QString>;
     auto GetFunctions() const -> QMap<QString, qmu::QmuTranslation>;
     auto GetFunctionsDescriptions() const -> QMap<QString, qmu::QmuTranslation>;
     auto GetFunctionsArguments() const -> QMap<QString, QString>;
 
-    static void BiasTokens(int position, int bias, QMap<int, QString> &tokens);
+    static void BiasTokens(vsizetype position, vsizetype bias, QMap<vsizetype, QString> &tokens);
 
 private:
     // cppcheck-suppress unknownMacro
-    Q_DISABLE_COPY_MOVE(VTranslateVars) //NOLINT
-    QMap<QString, qmu::QmuTranslation> PMSystemNames{};
-    QMap<QString, qmu::QmuTranslation> PMSystemAuthors{};
-    QMap<QString, qmu::QmuTranslation> PMSystemBooks{};
+    Q_DISABLE_COPY_MOVE(VTranslateVars) // NOLINT
     QMap<QString, qmu::QmuTranslation> variables{};
     QMap<QString, qmu::QmuTranslation> functions{};
     QMap<QString, qmu::QmuTranslation> functionsDescriptions{};
@@ -82,24 +71,29 @@ private:
     QMap<QString, qmu::QmuTranslation> stDescriptions{};
     QMap<QString, QString> translatedFunctions{};
 
-    void InitPatternMakingSystems();
     void InitVariables();
     void InitFunctions();
 
+    auto VariablesFromUser(QString &newFormula, vsizetype position, const QString &token, vsizetype &bias) const
+        -> bool;
+    auto FunctionsFromUser(QString &newFormula, vsizetype position, const QString &token, vsizetype &bias) const
+        -> bool;
+    auto VariablesToUser(QString &newFormula, vsizetype position, const QString &token, vsizetype &bias) const -> bool;
+
     void PrepareFunctionTranslations();
 
-    void InitSystem(const QString &code, const qmu::QmuTranslation &name, const qmu::QmuTranslation &author,
-                    const qmu::QmuTranslation &book);
+    static void CorrectionsPositions(vsizetype position, vsizetype bias, QMap<vsizetype, QString> &tokens,
+                                     QMap<vsizetype, QString> &numbers);
 
-    static void CorrectionsPositions(int position, int bias, QMap<int, QString> &tokens, QMap<int, QString> &numbers);
+    void TranslateVarsFromUser(QString &newFormula, QMap<vsizetype, QString> &tokens,
+                               QMap<vsizetype, QString> &numbers) const;
+    static void TranslateNumbersFromUser(QString &newFormula, QMap<vsizetype, QString> &tokens,
+                                         QMap<vsizetype, QString> &numbers, bool osSeparator);
 
-    void TranslateVarsFromUser(QString &newFormula, QMap<int, QString> &tokens, QMap<int, QString> &numbers) const;
-    static void TranslateNumbersFromUser(QString &newFormula, QMap<int, QString> &tokens, QMap<int, QString> &numbers,
-                                         bool osSeparator);
-
-    void TranslateVarsToUser(QString &newFormula, QMap<int, QString> &tokens, QMap<int, QString> &numbers) const;
-    static void TranslateNumbersToUser(QString &newFormula, QMap<int, QString> &tokens, QMap<int, QString> &numbers,
-                                       bool osSeparator);
+    void TranslateVarsToUser(QString &newFormula, QMap<vsizetype, QString> &tokens,
+                             QMap<vsizetype, QString> &numbers) const;
+    static void TranslateNumbersToUser(QString &newFormula, QMap<vsizetype, QString> &tokens,
+                                       QMap<vsizetype, QString> &numbers, bool osSeparator);
 };
 
 #endif // VTRANSLATEVARS_H
