@@ -21,13 +21,11 @@
 #ifndef VEMPTYPROPERTY_H
 #define VEMPTYPROPERTY_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
 #include <QStyleOptionViewItem>
 #include <QVariant>
-#include <Qt>
 #include <QtGlobal>
 
 #include "../vproperty.h"
@@ -36,7 +34,7 @@
 namespace VPE
 {
 class VPropertyPrivate;
-}  // namespace VPE
+} // namespace VPE
 
 namespace VPE
 {
@@ -47,44 +45,45 @@ QT_WARNING_DISABLE_GCC("-Wsuggest-final-types")
 class VPROPERTYEXPLORERSHARED_EXPORT VEmptyProperty : public VProperty
 {
     Q_OBJECT // NOLINT
+
 public:
     //! Standard constructor, takes a name and a parent property as argument
-    explicit VEmptyProperty(const QString& name);
+    explicit VEmptyProperty(const QString &name);
 
     //! Destructor
     virtual ~VEmptyProperty() override;
 
     //! Get the data how it should be displayed
-    virtual QVariant data (int column = DPC_Name, int role = Qt::DisplayRole) const override;
+    virtual auto data(int column = DPC_Name, int role = Qt::DisplayRole) const -> QVariant override;
 
     //! Returns an editor widget, or NULL if it doesn't supply one
     //! \param parent The widget to which the editor will be added as a child
     //! \options Render options
     //! \delegate A pointer to the QAbstractItemDelegate requesting the editor. This can be used to connect signals and
     //! slots.
-    virtual QWidget* createEditor(QWidget* parent, const QStyleOptionViewItem& options,
-                                  const QAbstractItemDelegate* delegate) override;
+    virtual auto createEditor(QWidget *parent, const QStyleOptionViewItem &options,
+                              const QAbstractItemDelegate *delegate) -> QWidget * override;
 
     //! Gets the data from the widget
-    virtual QVariant getEditorData(const QWidget* editor) const override;
+    virtual auto getEditorData(const QWidget *editor) const -> QVariant override;
 
     //! Returns item flags
-    virtual Qt::ItemFlags flags(int column = DPC_Name) const override;
+    virtual auto flags(int column = DPC_Name) const -> Qt::ItemFlags override;
 
     //! Returns a string containing the type of the property
-    virtual QString type() const override;
+    virtual auto type() const -> QString override;
 
     //! Clones this property
     //! \param include_children Indicates whether to also clone the children
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
-                                               VProperty* container = nullptr) const override;
+    Q_REQUIRED_RESULT virtual auto clone(bool include_children = true, VProperty *container = nullptr) const
+        -> VProperty * override;
 
 protected:
     //! Protected constructor
-    explicit VEmptyProperty(VPropertyPrivate* d);
+    explicit VEmptyProperty(VPropertyPrivate *d);
 
 private:
     Q_DISABLE_COPY_MOVE(VEmptyProperty) // NOLINT
@@ -92,6 +91,6 @@ private:
 
 QT_WARNING_POP
 
-}
+} // namespace VPE
 
 #endif // VEMPTYPROPERTY_H
