@@ -36,11 +36,11 @@ VPE::VEnumProperty::VEnumProperty(const QString& name)
 #endif
       EnumerationLiterals()
 {
-    VProperty::d_ptr->VariantValue = 0;
+    VProperty::vproperty_d_ptr->VariantValue = 0;
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-    VProperty::d_ptr->VariantValue.convert(QMetaType(QMetaType::Int));
+    VProperty::vproperty_d_ptr->VariantValue.convert(QMetaType(QMetaType::Int));
 #else
-    VProperty::d_ptr->VariantValue.convert(QVariant::Int);
+    VProperty::vproperty_d_ptr->VariantValue.convert(QVariant::Int);
 #endif
 }
 
@@ -53,7 +53,7 @@ auto VPE::VEnumProperty::data(int column, int role) const -> QVariant
         return QVariant();
     }
 
-    int tmpIndex = VProperty::d_ptr->VariantValue.toInt();
+    int tmpIndex = VProperty::vproperty_d_ptr->VariantValue.toInt();
 
     if (tmpIndex < 0 || tmpIndex >= EnumerationLiterals.count())
     {
@@ -83,11 +83,11 @@ auto VPE::VEnumProperty::createEditor(QWidget *parent, const QStyleOptionViewIte
     tmpEditor->clear();
     tmpEditor->setLocale(parent->locale());
     tmpEditor->addItems(EnumerationLiterals);
-    tmpEditor->setCurrentIndex(VProperty::d_ptr->VariantValue.toInt());
+    tmpEditor->setCurrentIndex(VProperty::vproperty_d_ptr->VariantValue.toInt());
     connect(tmpEditor, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &VEnumProperty::currentIndexChanged);
 
-    VProperty::d_ptr->editor = tmpEditor;
-    return VProperty::d_ptr->editor;
+    VProperty::vproperty_d_ptr->editor = tmpEditor;
+    return VProperty::vproperty_d_ptr->editor;
 }
 
 //! Gets the data from the widget
@@ -124,16 +124,16 @@ void VPE::VEnumProperty::setValue(const QVariant& value)
         tmpIndex = 0;
     }
 
-    VProperty::d_ptr->VariantValue = tmpIndex;
+    VProperty::vproperty_d_ptr->VariantValue = tmpIndex;
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-    VProperty::d_ptr->VariantValue.convert(QMetaType(QMetaType::Int));
+    VProperty::vproperty_d_ptr->VariantValue.convert(QMetaType(QMetaType::Int));
 #else
-    VProperty::d_ptr->VariantValue.convert(QVariant::Int);
+    VProperty::vproperty_d_ptr->VariantValue.convert(QVariant::Int);
 #endif
 
-    if (VProperty::d_ptr->editor != nullptr)
+    if (VProperty::vproperty_d_ptr->editor != nullptr)
     {
-        setEditorData(VProperty::d_ptr->editor);
+        setEditorData(VProperty::vproperty_d_ptr->editor);
     }
 }
 
@@ -174,5 +174,5 @@ void VPE::VEnumProperty::currentIndexChanged(int index)
 {
     Q_UNUSED(index)
     auto *event = new UserChangeEvent();
-    QCoreApplication::postEvent ( VProperty::d_ptr->editor, event );
+    QCoreApplication::postEvent ( VProperty::vproperty_d_ptr->editor, event );
 }
