@@ -21,7 +21,6 @@
 #ifndef VFILEPROPERTY_H
 #define VFILEPROPERTY_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QPointer>
@@ -29,7 +28,6 @@
 #include <QStringList>
 #include <QStyleOptionViewItem>
 #include <QVariant>
-#include <Qt>
 #include <QtGlobal>
 
 #include "../vproperty.h"
@@ -45,6 +43,7 @@ QT_WARNING_DISABLE_GCC("-Wsuggest-final-methods")
 class VPROPERTYEXPLORERSHARED_EXPORT VFileProperty : public VProperty
 {
     Q_OBJECT // NOLINT
+
 public:
     explicit VFileProperty(const QString &name);
 
@@ -52,58 +51,58 @@ public:
     virtual ~VFileProperty() override;
 
     //! Sets the file filters. The file filters have to be like the ones passed a QFileOpenDialog.
-    virtual void setFileFilters(const QString& filefilters);
+    virtual void setFileFilters(const QString &filefilters);
 
     //! Returns the current file filters as a string
-    virtual QString getFileFilters() const;
+    virtual auto getFileFilters() const -> QString;
 
     //! Set file
-    virtual void setFile(const QString& file);
+    virtual void setFile(const QString &file);
 
     //! Get file
-    virtual QString getFile() const;
+    virtual auto getFile() const -> QString;
 
     //! Get the data how it should be displayed
-    virtual QVariant data (int column = DPC_Name, int role = Qt::DisplayRole) const override;
+    virtual auto data(int column = DPC_Name, int role = Qt::DisplayRole) const -> QVariant override;
 
     //! Returns an editor widget, or NULL if it doesn't supply one
     //! \param parent The widget to which the editor will be added as a child
     //! \options Render options
     //! \delegate A pointer to the QAbstractItemDelegate requesting the editor. This can be used to connect signals and
     //! slots.
-    virtual QWidget* createEditor(QWidget* parent, const QStyleOptionViewItem& options,
-                                  const QAbstractItemDelegate* delegate) override;
+    virtual auto createEditor(QWidget *parent, const QStyleOptionViewItem &options,
+                              const QAbstractItemDelegate *delegate) -> QWidget * override;
 
     //! Sets the property's data to the editor (returns false, if the standard delegate should do that)
-    virtual bool setEditorData(QWidget* editor) override;
+    virtual auto setEditorData(QWidget *editor) -> bool override;
 
     //! Gets the data from the widget
-    virtual QVariant getEditorData(const QWidget* editor) const override;
+    virtual auto getEditorData(const QWidget *editor) const -> QVariant override;
 
     //! Sets the settings. Available settings:
     //!
     //! key: "FileFilters" - value: File filters in the same format the QFileDialog expects it
-    virtual void setSetting(const QString& key, const QVariant& value) override;
+    virtual void setSetting(const QString &key, const QVariant &value) override;
 
     //! Get the settings. This function has to be implemented in a subclass in order to have an effect
-    virtual QVariant getSetting(const QString& key) const override;
+    virtual auto getSetting(const QString &key) const -> QVariant override;
 
     //! Returns the list of keys of the property's settings
-    virtual QStringList getSettingKeys() const override;
+    virtual auto getSettingKeys() const -> QStringList override;
 
     //! Returns a string containing the type of the property
-    virtual QString type() const override;
+    virtual auto type() const -> QString override;
 
     //! Clones this property
     //! \param include_children Indicates whether to also clone the children
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
-                                               VProperty* container = nullptr) const override;
+    Q_REQUIRED_RESULT virtual auto clone(bool include_children = true, VProperty *container = nullptr) const
+        -> VProperty * override;
 
     //! Returns whether this is a file (false) or a directory (true)
-    virtual bool isDirectory() const;
+    virtual auto isDirectory() const -> bool;
 
     //! Sets whether this is a file (false) or a directory (true)
     virtual void setDirectory(bool is_directory);
@@ -114,6 +113,6 @@ private:
 
 QT_WARNING_POP
 
-}
+} // namespace VPE
 
 #endif // VFILEPROPERTY_H
