@@ -29,7 +29,6 @@
 #ifndef VLINETYPEPROPERTY_H
 #define VLINETYPEPROPERTY_H
 
-#include <qcompilerdetection.h>
 #include <QIcon>
 #include <QMap>
 #include <QMetaObject>
@@ -38,7 +37,6 @@
 #include <QStyleOptionViewItem>
 #include <QVariant>
 #include <QVector>
-#include <Qt>
 #include <QtGlobal>
 
 #include "../vproperty.h"
@@ -50,48 +48,49 @@ namespace VPE
 class VPROPERTYEXPLORERSHARED_EXPORT VLineTypeProperty : public VProperty
 {
     Q_OBJECT // NOLINT
+
 public:
     //! Constructor
-    explicit VLineTypeProperty(const QString& name);
+    explicit VLineTypeProperty(const QString &name);
 
     //! Destructor
-    virtual ~VLineTypeProperty() override {}
+    ~VLineTypeProperty() override = default;
 
     //! Get the data how it should be displayed
-    virtual QVariant data (int column = DPC_Name, int role = Qt::DisplayRole) const override;
+    auto data(int column = DPC_Name, int role = Qt::DisplayRole) const -> QVariant override;
 
     //! Returns an editor widget, or NULL if it doesn't supply one
     //! \param parent The widget to which the editor will be added as a child
     //! \options Render options
     //! \delegate A pointer to the QAbstractItemDelegate requesting the editor. This can be used to connect signals and
     //! slots.
-    virtual QWidget* createEditor(QWidget* parent, const QStyleOptionViewItem& options,
-                                  const QAbstractItemDelegate* delegate) override;
+    auto createEditor(QWidget *parent, const QStyleOptionViewItem &options, const QAbstractItemDelegate *delegate)
+        -> QWidget * override;
 
     //! Gets the data from the widget
-    virtual QVariant getEditorData(const QWidget* editor) const override;
+    auto getEditorData(const QWidget *editor) const -> QVariant override;
 
     //! Sets the line styles
     virtual void setStyles(const QMap<QString, QIcon> &styles);
 
     //! Get the settings. This function has to be implemented in a subclass in order to have an effect
-    virtual QMap<QString, QIcon> getStyles() const;
+    virtual auto getStyles() const -> QMap<QString, QIcon>;
 
     //! Sets the value of the property
-    virtual void setValue(const QVariant& value) override;
+    void setValue(const QVariant &value) override;
 
     //! Returns a string containing the type of the property
-    virtual QString type() const override;
+    auto type() const -> QString override;
 
     //! Clones this property
     //! \param include_children Indicates whether to also clone the children
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
-                                               VProperty* container = nullptr) const override;
+    Q_REQUIRED_RESULT auto clone(bool include_children = true, VProperty *container = nullptr) const
+        -> VProperty * override;
 
-    static int IndexOfStyle(const QMap<QString, QIcon> &styles, const QString &style);
+    static auto IndexOfStyle(const QMap<QString, QIcon> &styles, const QString &style) -> vpesizetype;
 
 public slots:
     void currentIndexChanged(int index);
@@ -101,11 +100,12 @@ protected:
     QMap<QString, QIcon> styles;
     QVector<QString> indexList;
     // No use of d-pointer in this case, because it is unlikely this will change. If it does, we can still add other
-    //members by reimplementing the VPropertyPrivate class without touching this header file.
+    // members by reimplementing the VPropertyPrivate class without touching this header file.
+
 private:
     Q_DISABLE_COPY_MOVE(VLineTypeProperty) // NOLINT
 };
 
-}
+} // namespace VPE
 
 #endif // VLINETYPEPROPERTY_H
