@@ -21,13 +21,11 @@
 #ifndef VPOINTFPROPERTY_H
 #define VPOINTFPROPERTY_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QPointF>
 #include <QString>
 #include <QVariant>
-#include <Qt>
 #include <QtGlobal>
 
 #include "../vproperty.h"
@@ -39,47 +37,48 @@ namespace VPE
 class VPROPERTYEXPLORERSHARED_EXPORT VPointFProperty : public VProperty
 {
     Q_OBJECT // NOLINT
+
 public:
-    explicit VPointFProperty(const QString& name);
+    explicit VPointFProperty(const QString &name);
 
     virtual ~VPointFProperty() override {}
 
     //! Get the data how it should be displayed
-    virtual QVariant data (int column = DPC_Name, int role = Qt::DisplayRole) const override;
+    virtual auto data(int column = DPC_Name, int role = Qt::DisplayRole) const -> QVariant override;
 
     //! Returns item flags
-    Qt::ItemFlags flags(int column = DPC_Name) const override;
+    auto flags(int column = DPC_Name) const -> Qt::ItemFlags override;
 
     //! Returns the QPointF
-    virtual QPointF getPointF() const;
+    virtual auto getPointF() const -> QPointF;
 
     //! Sets the QPointF
-    virtual void setPointF(const QPointF& point);
+    virtual void setPointF(const QPointF &point);
 
     //! Sets the QPointF
     virtual void setPointF(qreal x, qreal y);
 
     //! Returns a string containing the type of the property
-    virtual QString type() const override;
+    virtual auto type() const -> QString override;
 
     //! Clones this property
     //! \param include_children Indicates whether to also clone the children
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
-                                               VProperty* container = nullptr) const override;
+    Q_REQUIRED_RESULT virtual auto clone(bool include_children = true, VProperty *container = nullptr) const
+        -> VProperty * override;
 
     //! Sets the value of the property
-    virtual void setValue(const QVariant& value) override;
+    virtual void setValue(const QVariant &value) override;
 
     //! Returns the value of the property as a QVariant
-    virtual QVariant getValue() const override;
+    virtual auto getValue() const -> QVariant override;
 
 private:
     Q_DISABLE_COPY_MOVE(VPointFProperty) // NOLINT
 };
 
-}
+} // namespace VPE
 
 #endif // VPOINTFPROPERTY_H
