@@ -37,7 +37,7 @@
 #include "vpropertyexplorer_global.h"
 
 // Header <ciso646> is removed in C++20.
-#if __cplusplus <= 201703L
+#if defined(Q_CC_MSVC) && __cplusplus <= 201703L
 #include <ciso646> // and, not, or
 #endif
 
@@ -182,7 +182,7 @@ public:
     virtual auto getParent() const -> VProperty *;
 
     //! Sets the parent of this property
-    virtual void setParent(VProperty *parent);
+    virtual void setPropertyParent(VProperty *parent);
 
     //! Removes a child from the children list, doesn't delete the child!
     virtual void removeChild(VProperty *child);
@@ -237,7 +237,7 @@ protected:
     explicit VProperty(VPropertyPrivate *d);
 
     //! The protected structure holding the member variables (to assure binary compatibility)
-    VPropertyPrivate *d_ptr;
+    VPropertyPrivate *vproperty_d_ptr;
 
 private:
     // Provide access functions for the d_ptr
