@@ -64,13 +64,13 @@ void VPE::VPropertyFormView::setModel(VPropertyModel *model)
     removeModelAndSet();
 
     // Set model
-    static_cast<VPropertyFormViewPrivate *>(d_ptr)->Model = model;
+    static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->Model = model;
     if (model)
     {
         // Set the property list
         if (model->getPropertySet())
         {
-            d_ptr->Properties = model->getPropertySet()->getRootProperties();
+            vproperty_d_ptr->Properties = model->getPropertySet()->getRootProperties();
         }
 
         // Connect signals // todo: more signals neccesary!!!
@@ -90,11 +90,11 @@ void VPE::VPropertyFormView::setPropertySet(VPropertySet *property_set)
     removeModelAndSet();
 
     // Set property set
-    static_cast<VPropertyFormViewPrivate *>(d_ptr)->PropertySet = property_set;
+    static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->PropertySet = property_set;
     if (property_set)
     {
         // Set the property list
-        d_ptr->Properties = property_set->getRootProperties();
+        vproperty_d_ptr->Properties = property_set->getRootProperties();
     }
 
     // Build the widget
@@ -138,61 +138,61 @@ void VPE::VPropertyFormView::dataChanged(const QModelIndex &top_left, const QMod
 
 void VPE::VPropertyFormView::dataSubmitted(VProperty *property)
 {
-    VPropertyModel *tmpModel = static_cast<VPropertyFormViewPrivate *>(d_ptr)->Model;
+    VPropertyModel *tmpModel = static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->Model;
 
-    if (tmpModel && d_ptr->UpdateEditors)
+    if (tmpModel && vproperty_d_ptr->UpdateEditors)
     {
-        static_cast<VPropertyFormViewPrivate *>(d_ptr)->IgnoreDataChangedSignal = true;
+        static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->IgnoreDataChangedSignal = true;
         tmpModel->onDataChangedByModel(property);
-        static_cast<VPropertyFormViewPrivate *>(d_ptr)->IgnoreDataChangedSignal = false;
+        static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->IgnoreDataChangedSignal = false;
     }
 }
 
 void VPE::VPropertyFormView::showEvent(QShowEvent *event)
 {
     Q_UNUSED(event)
-    if (static_cast<VPropertyFormViewPrivate *>(d_ptr)->NeedsRebuild)
+    if (static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->NeedsRebuild)
     {
         build();
     }
-    static_cast<VPropertyFormViewPrivate *>(d_ptr)->NeedsRebuild = false;
+    static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->NeedsRebuild = false;
 }
 
 void VPE::VPropertyFormView::updatePropertyList()
 {
-    VPropertyModel *tmpModel = static_cast<VPropertyFormViewPrivate *>(d_ptr)->Model;
-    VPropertySet *tmpSet = static_cast<VPropertyFormViewPrivate *>(d_ptr)->PropertySet;
+    VPropertyModel *tmpModel = static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->Model;
+    VPropertySet *tmpSet = static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->PropertySet;
 
     if (tmpModel && tmpModel->getPropertySet())
     {
-        d_ptr->Properties = tmpModel->getPropertySet()->getRootProperties();
+        vproperty_d_ptr->Properties = tmpModel->getPropertySet()->getRootProperties();
     }
     else if (tmpSet)
     {
-        d_ptr->Properties = tmpSet->getRootProperties();
+        vproperty_d_ptr->Properties = tmpSet->getRootProperties();
     }
     else
-        d_ptr->Properties.clear();
+        vproperty_d_ptr->Properties.clear();
 
     if (isVisible())
     {
         build();
     }
     else
-        static_cast<VPropertyFormViewPrivate *>(d_ptr)->NeedsRebuild = true;
+        static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->NeedsRebuild = true;
 }
 
 void VPE::VPropertyFormView::removeModelAndSet()
 {
-    if (static_cast<VPropertyFormViewPrivate *>(d_ptr)->Model)
+    if (static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->Model)
     {
-        disconnect(static_cast<VPropertyFormViewPrivate *>(d_ptr)->Model, nullptr, this, nullptr);
-        static_cast<VPropertyFormViewPrivate *>(d_ptr)->Model = nullptr;
+        disconnect(static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->Model, nullptr, this, nullptr);
+        static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->Model = nullptr;
     }
 
-    static_cast<VPropertyFormViewPrivate *>(d_ptr)->NeedsRebuild = true;
-    d_ptr->Properties.clear();
-    static_cast<VPropertyFormViewPrivate *>(d_ptr)->PropertySet = nullptr;
+    static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->NeedsRebuild = true;
+    vproperty_d_ptr->Properties.clear();
+    static_cast<VPropertyFormViewPrivate *>(vproperty_d_ptr)->PropertySet = nullptr;
 }
 
 void VPE::VPropertyFormView::connectPropertyFormWidget(VPropertyFormWidget *widget)
