@@ -28,13 +28,13 @@
 #include "vpropertytreeview_p.h"
 
 VPE::VPropertyTreeView::VPropertyTreeView(QWidget *parent)
-    : QTreeView(parent), d_ptr(new VPropertyTreeViewPrivate())
+    : QTreeView(parent), vproperty_d_ptr(new VPropertyTreeViewPrivate())
 {
     VPE::VPropertyTreeView::init();
 }
 
 VPE::VPropertyTreeView::VPropertyTreeView(VPropertyModel *model, QWidget *parent)
-    : QTreeView(parent), d_ptr(new VPropertyTreeViewPrivate())
+    : QTreeView(parent), vproperty_d_ptr(new VPropertyTreeViewPrivate())
 {
     VPE::VPropertyTreeView::init();
 
@@ -45,7 +45,7 @@ VPE::VPropertyTreeView::VPropertyTreeView(VPropertyModel *model, QWidget *parent
 }
 
 VPE::VPropertyTreeView::VPropertyTreeView(VPropertyTreeViewPrivate *d, bool init_, QWidget *parent)
-    : QTreeView(parent), d_ptr(d)
+    : QTreeView(parent), vproperty_d_ptr(d)
 {
     if (init_)
     {
@@ -55,21 +55,21 @@ VPE::VPropertyTreeView::VPropertyTreeView(VPropertyTreeViewPrivate *d, bool init
 
 VPE::VPropertyTreeView::~VPropertyTreeView()
 {
-    delete d_ptr;
+    delete vproperty_d_ptr;
 }
 
 
 void VPE::VPropertyTreeView::setRowHeight(int height, bool add_to_standard)
 {
-    d_ptr->PropertyDelegate->setRowHeight(height, add_to_standard);
+    vproperty_d_ptr->PropertyDelegate->setRowHeight(height, add_to_standard);
 }
 
 void VPE::VPropertyTreeView::init()
 {
     setAlternatingRowColors(true);
     setUniformRowHeights(true);
-    d_ptr->PropertyDelegate = new VPropertyDelegate(this);
-    setItemDelegate(d_ptr->PropertyDelegate);
+    vproperty_d_ptr->PropertyDelegate = new VPropertyDelegate(this);
+    setItemDelegate(vproperty_d_ptr->PropertyDelegate);
 
     setSelectionMode(QTreeView::SingleSelection);
     setSelectionBehavior(QTreeView::SelectRows);
