@@ -46,6 +46,10 @@
 #include <QtGlobal>
 #include <qtestcase.h>
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+#include <QDirListing>
+#endif
+
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
 #include "../vgeometry/vspline.h"
@@ -153,15 +157,15 @@ void AbstractTest::PassmarkDataFromJson(const QString &json, VPiecePassmarkData
     try
     {
         VSAPoint previousSAPoint;
-        PointFromJson(passmarkData[QStringLiteral("previousSAPoint")].toObject(), previousSAPoint);
+        ItemFromJson(passmarkData[QStringLiteral("previousSAPoint")].toObject(), previousSAPoint);
         data.previousSAPoint = previousSAPoint;
 
         VSAPoint passmarkSAPoint;
-        PointFromJson(passmarkData[QStringLiteral("passmarkSAPoint")].toObject(), passmarkSAPoint);
+        ItemFromJson(passmarkData[QStringLiteral("passmarkSAPoint")].toObject(), passmarkSAPoint);
         data.passmarkSAPoint = passmarkSAPoint;
 
         VSAPoint nextSAPoint;
-        PointFromJson(passmarkData[QStringLiteral("nextSAPoint")].toObject(), nextSAPoint);
+        ItemFromJson(passmarkData[QStringLiteral("nextSAPoint")].toObject(), nextSAPoint);
         data.nextSAPoint = nextSAPoint;
     }
     catch (const VException &e)
@@ -338,56 +342,25 @@ void AbstractTest::CompareLinesDistance(const QVector<QLineF> &result, const QVe
 //---------------------------------------------------------------------------------------------------------------------
 auto AbstractTest::PuzzlePath() const -> QString
 {
-#ifdef QBS_BUILD
     return QStringLiteral(PUZZLE_BUILDDIR);
-#else
-    const auto path = QStringLiteral("/../../../app/puzzle/bin/puzzle");
-#ifdef Q_OS_WIN
-    return QCoreApplication::applicationDirPath() + path + ".exe"_L1;
-#else
-    return QCoreApplication::applicationDirPath() + path;
-#endif
-#endif
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto AbstractTest::ValentinaPath() const -> QString
 {
-#ifdef QBS_BUILD
     return QStringLiteral(VALENTINA_BUILDDIR);
-#else
-    const auto path = QStringLiteral("/../../../app/valentina/bin/valentina");
-#ifdef Q_OS_WIN
-    return QCoreApplication::applicationDirPath() + path + ".exe"_L1;
-#else
-    return QCoreApplication::applicationDirPath() + path;
-#endif
-#endif
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto AbstractTest::TapePath() const -> QString
 {
-#ifdef QBS_BUILD
     return QStringLiteral(TAPE_BUILDDIR);
-#else
-    const auto path = QStringLiteral("/../../../app/tape/bin/tape");
-#ifdef Q_OS_WIN
-    return QCoreApplication::applicationDirPath() + path + ".exe"_L1;
-#else
-    return QCoreApplication::applicationDirPath() + path;
-#endif
-#endif
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto AbstractTest::TranslationsPath() -> QString
 {
-#ifdef QBS_BUILD
     return QStringLiteral(TRANSLATIONS_DIR);
-#else
-    return QCoreApplication::applicationDirPath() + QStringLiteral("/../../../app/valentina/bin/translations");
-#endif
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -455,17 +428,32 @@ auto AbstractTest::Run(int exit, const QString &program, const QStringList &argu
 //---------------------------------------------------------------------------------------------------------------------
 auto AbstractTest::CopyRecursively(const QString &srcFilePath, const QString &tgtFilePath) const -> bool
 {
-    QFileInfo const srcFileInfo(srcFilePath);
-    if (srcFileInfo.isDir())
+    if (QFileInfo const srcFileInfo(srcFilePath); srcFileInfo.isDir())
     {
         QDir targetDir(tgtFilePath);
         targetDir.cdUp();
         const QString dirName = QFileInfo(tgtFilePath).fileName();
+
         if (not targetDir.mkdir(dirName))
         {
             qWarning("Can't create dir '%s'.", qUtf8Printable(dirName));
             return false;
         }
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+        using ItFlag = QDirListing::IteratorFlag;
+        QDirListing sourceDirListing(srcFilePath, ItFlag::IncludeHidden);
+        for (const auto &entry : sourceDirListing)
+        {
+            const QString newSrcFilePath = entry.absoluteFilePath();
+            const QString newTgtFilePath = tgtFilePath + QDir::separator() + entry.fileName();
+
+            if (!CopyRecursively(newSrcFilePath, newTgtFilePath))
+            {
+                return false;
+            }
+        }
+#else
         QDir const sourceDir(srcFilePath);
         const QStringList fileNames =
             sourceDir.entryList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot | QDir::Hidden | QDir::System);
@@ -478,6 +466,7 @@ auto AbstractTest::CopyRecursively(const QString &srcFilePath, const QString &tg
                 return false;
             }
         }
+#endif
     }
     else
     {
@@ -616,7 +605,7 @@ void AbstractTest::ReadPointValue(const QJsonObject &itemObject, const QString &
 {
     if (itemObject.contains(attribute))
     {
-        PointFromJson(itemObject[attribute].toObject(), value);
+        ItemFromJson(itemObject[attribute].toObject(), value);
     }
     else
     {
@@ -819,8 +808,8 @@ auto AbstractTest::QLineFromJson(const QJsonObject &itemObject) -> QLineF
 {
     QPointF p1;
     QPointF p2;
-    PointFromJson(itemObject[QStringLiteral("p1")].toObject(), p1);
-    PointFromJson(itemObject[QStringLiteral("p2")].toObject(), p2);
+    ItemFromJson(itemObject[QStringLiteral("p1")].toObject(), p1);
+    ItemFromJson(itemObject[QStringLiteral("p2")].toObject(), p2);
     return {p1, p2};
 }
 
@@ -911,7 +900,7 @@ void AbstractTest::DBFromJson(const QJsonObject &dbObject, QSharedPointer<VConta
                 case GOType::Point:
                 {
                     VPointF point;
-                    PointFromJson(itemObject, point);
+                    ItemFromJson(itemObject, point);
                     data->UpdateGObject(point.id(), new VPointF(point));
                     break;
                 }
