@@ -29,6 +29,7 @@
 
 #include "../ifc/exception/vexceptionbadid.h"
 #include "../qmuparser/qmudef.h"
+#include "../tools/drawTools/operation/vabstractoperation.h"
 #include "../vgeometry/varc.h"
 #include "../vgeometry/vcubicbezier.h"
 #include "../vgeometry/vcubicbezierpath.h"
@@ -43,11 +44,14 @@
 #include "../vpatterndb/variables/vcurvelength.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vpiecenode.h"
-#include "qdialogbuttonbox.h"
+#include "../vpropertyexplorer/qtcolorpicker.h"
+#include "../vtools/tools/vabstracttool.h"
 
+#include <qnumeric.h>
 #include <QBuffer>
 #include <QDebug>
 #include <QDialog>
+#include <QDialogButtonBox>
 #include <QLabel>
 #include <QLineEdit>
 #include <QListWidget>
@@ -56,9 +60,9 @@
 #include <QPlainTextEdit>
 #include <QPushButton>
 #include <QRegularExpression>
+#include <QScreen>
 #include <QTextCursor>
 #include <QTimer>
-#include <qnumeric.h>
 
 #if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
 #include "../vmisc/compatibility.h"
@@ -191,7 +195,7 @@ auto RowNode(QListWidget *listWidget, int i) -> VPieceNode
     }
 
     const QListWidgetItem *rowItem = listWidget->item(i);
-    SCASSERT(rowItem != nullptr);
+    SCASSERT(rowItem != nullptr)
     return qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
 }
 
@@ -250,8 +254,8 @@ auto FilterObject(QObject *object, QEvent *event) -> bool
     {
         if (event->type() == QEvent::KeyPress)
         {
-            auto *keyEvent = static_cast<QKeyEvent *>(event);
-            if ((keyEvent->key() == Qt::Key_Period) && (keyEvent->modifiers() & Qt::KeypadModifier))
+            if (const auto *keyEvent = static_cast<QKeyEvent *>(event);
+                (keyEvent->key() == Qt::Key_Period) && (keyEvent->modifiers() & Qt::KeypadModifier))
             {
                 if (VAbstractApplication::VApp()->Settings()->GetOsSeparator())
                 {
@@ -402,53 +406,7 @@ auto FindNotExcludedNeighborNodeDown(QListWidget *listWidget, int candidate) ->
     do
     {
         const QListWidgetItem *rowItem = listWidget->item(i);
-        SCASSERT(rowItem != nullptr);
-        rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
-
-        if (not rowNode.IsExcluded())
-        {
-            index = i;
-            foundNeighbor = true;
-            break;
-        }
-
-        --i;
-        if (i < 0)
-        {
-            // Wrap around to the end of the list
-            i = listWidget->count() - 1;
-        }
-
-    } while (i != candidate);
-
-    if (!foundNeighbor)
-    {
-        // No not excluded neighbor found
-        index = -1;
-    }
-
-    return index;
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-auto FindNotExcludedNeighborNodeUp(QListWidget *listWidget, int candidate) -> int
-{
-    SCASSERT(listWidget != nullptr);
-
-    int index = -1;
-    if (candidate < 0 || candidate >= listWidget->count())
-    {
-        return index;
-    }
-
-    int i = candidate;
-    VPieceNode rowNode;
-    bool foundNeighbor = false;
-
-    do
-    {
-        const QListWidgetItem *rowItem = listWidget->item(i);
-        SCASSERT(rowItem != nullptr);
+        SCASSERT(rowItem != nullptr)
         rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
 
         if (not rowNode.IsExcluded())
@@ -476,6 +434,52 @@ auto FindNotExcludedNeighborNodeUp(QListWidget *listWidget, int candidate) -> in
     return index;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto FindNotExcludedNeighborNodeUp(QListWidget *listWidget, int candidate) -> int
+{
+    SCASSERT(listWidget != nullptr);
+
+    int index = -1;
+    if (candidate < 0 || candidate >= listWidget->count())
+    {
+        return index;
+    }
+
+    int i = candidate;
+    VPieceNode rowNode;
+    bool foundNeighbor = false;
+
+    do
+    {
+        const QListWidgetItem *rowItem = listWidget->item(i);
+        SCASSERT(rowItem != nullptr)
+        rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
+
+        if (not rowNode.IsExcluded())
+        {
+            index = i;
+            foundNeighbor = true;
+            break;
+        }
+
+        --i;
+        if (i < 0)
+        {
+            // Wrap around to the end of the list
+            i = listWidget->count() - 1;
+        }
+
+    } while (i != candidate);
+
+    if (!foundNeighbor)
+    {
+        // No not excluded neighbor found
+        index = -1;
+    }
+
+    return index;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto FindNotExcludedNodeDown(QListWidget *listWidget, int candidate) -> int
 {
@@ -492,7 +496,7 @@ auto FindNotExcludedNodeDown(QListWidget *listWidget, int candidate) -> int
     do
     {
         const QListWidgetItem *rowItem = listWidget->item(i);
-        SCASSERT(rowItem != nullptr);
+        SCASSERT(rowItem != nullptr)
         rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
 
         if (not rowNode.IsExcluded())
@@ -522,7 +526,7 @@ auto FindNotExcludedNodeUp(QListWidget *listWidget, int candidate) -> int
     do
     {
         const QListWidgetItem *rowItem = listWidget->item(i);
-        SCASSERT(rowItem != nullptr);
+        SCASSERT(rowItem != nullptr)
         rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
 
         if (not rowNode.IsExcluded())
@@ -595,7 +599,7 @@ auto EachPointLabelIsUnique(QListWidget *listWidget) -> bool
     for (int i = 0; i < listWidget->count(); ++i)
     {
         const QListWidgetItem *rowItem = listWidget->item(i);
-        SCASSERT(rowItem != nullptr);
+        SCASSERT(rowItem != nullptr)
         const auto rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
         if (rowNode.GetTypeTool() == Tool::NodePoint && not rowNode.IsExcluded())
         {
@@ -608,11 +612,20 @@ auto EachPointLabelIsUnique(QListWidget *listWidget) -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto DialogWarningIcon() -> QString
+auto DialogWarningIcon(const QWidget *w) -> QString
 {
     const QIcon icon = FromTheme(VThemeIcon::DialogWarning);
 
-    const QPixmap pixmap = icon.pixmap(QSize(16, 16));
+    qreal scaleFactor = 1;
+    if (w != nullptr)
+    {
+        if (const QScreen *wScreen = w->screen())
+        {
+            scaleFactor = wScreen->devicePixelRatio();
+        }
+    }
+
+    const QPixmap pixmap = icon.pixmap(QSize(qRound(16 / scaleFactor), qRound(16 / scaleFactor)));
     QByteArray byteArray;
     QBuffer buffer(&byteArray);
     pixmap.save(&buffer, "PNG");
@@ -665,25 +678,6 @@ void SetTabStopDistance(QPlainTextEdit *edit, int tabWidthChar)
     edit->setTabStopDistance(tabWidthChar * singleCharWidthDouble);
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-auto LineColor(const QColor &borderColor, int size, const QString &color) -> QIcon
-{
-    // On Mac pixmap should be little bit smaller.
-#if defined(Q_OS_MAC)
-    size -= 2; // Two pixels should be enough.
-#endif         // defined(Q_OS_MAC)
-
-    QPixmap pix(size, size);
-    pix.fill(QColor(color));
-
-    // Draw a white border around the icon
-    QPainter painter(&pix);
-    painter.setPen(borderColor);
-    painter.drawRect(0, 0, size - 1, size - 1);
-
-    return {pix};
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 auto SegmentAliases(GOType curveType, const QString &alias1, const QString &alias2) -> QPair<QString, QString>
 {
@@ -769,7 +763,7 @@ auto GetNodeName(const VContainer *data, const VPieceNode &node, bool showPassma
 
         if (not node.IsTurnPoint())
         {
-            name += QStringLiteral(" ⦿");
+            name += QStringLiteral(" ⊙");
         }
     }
 
@@ -792,7 +786,7 @@ auto FindNotExcludedPointDown(QListWidget *listWidget, int start) -> int
     do
     {
         const QListWidgetItem *rowItem = listWidget->item(i);
-        SCASSERT(rowItem != nullptr);
+        SCASSERT(rowItem != nullptr)
         auto rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
 
         if (not rowNode.IsExcluded() && rowNode.GetTypeTool() == Tool::NodePoint && rowNode.GetId() != NULL_ID)
@@ -829,7 +823,7 @@ auto FindNotExcludedCurveDown(QListWidget *listWidget, int start) -> int
     do
     {
         const QListWidgetItem *rowItem = listWidget->item(i);
-        SCASSERT(rowItem != nullptr);
+        SCASSERT(rowItem != nullptr)
         auto rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
 
         if (not rowNode.IsExcluded() && rowNode.GetTypeTool() != Tool::NodePoint && rowNode.GetId() != NULL_ID)
@@ -982,8 +976,8 @@ auto MirrorLinePointsNeighbors(QListWidget *listWidget, quint32 startPoint, quin
         prevIndex = listWidget->count() - 1;
     }
 
-    const int next = FindNotExcludedNeighborNodeDown(listWidget, prevIndex);
-    const int prev = FindNotExcludedNeighborNodeUp(listWidget, nextIndex);
+    const int next = FindNotExcludedNeighborNodeDown(listWidget, nextIndex);
+    const int prev = FindNotExcludedNeighborNodeUp(listWidget, prevIndex);
 
     return (next >= 0 && endPoint == RowNode(listWidget, next).GetId()) ||
            (prev >= 0 && endPoint == RowNode(listWidget, prev).GetId());
@@ -997,7 +991,7 @@ auto NodeRowIndex(QListWidget *listWidget, quint32 id) -> int
     for (int i = 0, sz = listWidget->count(); i < sz; ++i)
     {
         const QListWidgetItem *rowItem = listWidget->item(i);
-        SCASSERT(rowItem != nullptr);
+        SCASSERT(rowItem != nullptr)
         auto rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
 
         if (id == rowNode.GetId())
@@ -1008,3 +1002,53 @@ auto NodeRowIndex(QListWidget *listWidget, quint32 id) -> int
 
     return -1;
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+void InitColorPicker(VPE::QtColorPicker *button, const QVector<QColor> &customColor)
+{
+    SCASSERT(button != nullptr)
+
+    const QMap<QString, QString> defaultColors = VAbstractTool::ColorsList();
+
+    auto i = defaultColors.constBegin();
+    while (i != defaultColors.constEnd())
+    {
+        button->insertColor(QColor(i.key()), i.value());
+        ++i;
+    }
+
+    for (auto color : customColor)
+    {
+        button->insertCustomColor(color);
+    }
+
+    button->setCurrentColor(QColor(Qt::black));
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void InitOperationColorPicker(VPE::QtColorPicker *button, const QVector<QColor> &customColor)
+{
+    SCASSERT(button != nullptr)
+
+    QMap<QString, QString> defaultColors = VAbstractOperation::OperationColorsList();
+
+    if (defaultColors.contains(ColorDefault))
+    {
+        button->insertColor(QColor(), defaultColors.value(ColorDefault));
+        defaultColors.remove(ColorDefault);
+    }
+
+    auto i = defaultColors.constBegin();
+    while (i != defaultColors.constEnd())
+    {
+        button->insertColor(QColor(i.key()), i.value());
+        ++i;
+    }
+
+    for (auto color : customColor)
+    {
+        button->insertCustomColor(color);
+    }
+
+    button->setCurrentColor(QColor());
+}
