@@ -32,11 +32,9 @@
 #include <QDialog>
 #include <QMap>
 
-#include "../vmisc/defglobal.h"
-
 namespace Ui
 {
-    class DialogEditLabel;
+class DialogEditLabel;
 }
 
 struct VLabelTemplateLine;
@@ -52,9 +50,9 @@ class DialogEditLabel : public QDialog
 
 public:
     explicit DialogEditLabel(const VAbstractPattern *doc, const VContainer *data, QWidget *parent = nullptr);
-    virtual ~DialogEditLabel();
+    ~DialogEditLabel() override;
 
-    QVector<VLabelTemplateLine> GetTemplate() const;
+    auto GetTemplate() const -> QVector<VLabelTemplateLine>;
     void SetTemplate(const QVector<VLabelTemplateLine> &lines);
 
     void SetPiece(const VPiece &piece);
@@ -77,17 +75,18 @@ private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(DialogEditLabel) // NOLINT
     Ui::DialogEditLabel *ui;
-    QMenu               *m_placeholdersMenu;
+    QMenu *m_placeholdersMenu;
     const VAbstractPattern *m_doc;
-    const VContainer    *m_data;
+    const VContainer *m_data;
 
-    QMap<QString, QPair<QString, QString>> m_placeholders;
+    QMap<QString, QPair<QString, QString>> m_placeholders{};
 
     void SetupControls();
+    auto SortedActions() const -> QMap<QString, QString>;
     void InitPlaceholdersMenu();
     void InitPlaceholders();
 
-    QString ReplacePlaceholders(QString line) const;
+    auto ReplacePlaceholders(QString line) const -> QString;
 
     void InitPreviewLines(const QVector<VLabelTemplateLine> &lines);
 };
