@@ -35,7 +35,6 @@
 #include <QPushButton>
 #include <QTimer>
 #include <QToolButton>
-#include <climits>
 
 #include "../../visualization/path/vistoolarc.h"
 #include "../../visualization/visualization.h"
@@ -45,6 +44,7 @@
 #include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
+#include "../vmisc/vvalentinasettings.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/global.h"
@@ -90,7 +90,8 @@ DialogArc::DialogArc(const VContainer *data, VAbstractPattern *doc, quint32 tool
     InitOkCancelApply(ui);
 
     FillComboBoxPoints(ui->comboBoxBasePoint);
-    FillComboBoxLineColors(ui->comboBoxColor);
+    InitColorPicker(ui->pushButtonColor, VAbstractValApplication::VApp()->ValentinaSettings()->GetUserToolColors());
+    ui->pushButtonColor->setUseNativeDialog(!VAbstractApplication::VApp()->Settings()->IsDontUseNativeDialog());
     FillComboBoxTypeLine(ui->comboBoxPenStyle,
                          CurvePenStylesPics(ui->comboBoxPenStyle->palette().color(QPalette::Base),
                                             ui->comboBoxPenStyle->palette().color(QPalette::Text)));
@@ -141,6 +142,7 @@ void DialogArc::DeployF2TextEdit()
 //---------------------------------------------------------------------------------------------------------------------
 DialogArc::~DialogArc()
 {
+    VAbstractValApplication::VApp()->ValentinaSettings()->SetUserToolColors(ui->pushButtonColor->CustomColors());
     delete ui;
 }
 
@@ -196,13 +198,13 @@ void DialogArc::SetPenStyle(const QString &value)
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogArc::GetColor() const -> QString
 {
-    return GetComboBoxCurrentData(ui->comboBoxColor, ColorBlack);
+    return ui->pushButtonColor->currentColor().name();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArc::SetColor(const QString &value)
 {
-    ChangeCurrentData(ui->comboBoxColor, value);
+    ui->pushButtonColor->setCurrentColor(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -374,7 +376,7 @@ void DialogArc::ChosenObject(quint32 id, const SceneObject &type)
     {
         if (vis != nullptr)
         {
-            auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
+            const auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
             SCASSERT(window != nullptr)
             connect(vis.data(), &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
 
