@@ -29,7 +29,6 @@
 #ifndef DIALOGCURVEINTERSECTAXIS_H
 #define DIALOGCURVEINTERSECTAXIS_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -40,7 +39,7 @@
 
 namespace Ui
 {
-    class DialogCurveIntersectAxis;
+class DialogCurveIntersectAxis;
 }
 
 class DialogCurveIntersectAxis final : public DialogTool
@@ -48,58 +47,63 @@ class DialogCurveIntersectAxis final : public DialogTool
     Q_OBJECT // NOLINT
 
 public:
-    DialogCurveIntersectAxis(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogCurveIntersectAxis() override;
+    DialogCurveIntersectAxis(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent = nullptr);
+    ~DialogCurveIntersectAxis() override;
 
-    QString      GetPointName() const;
-    void         SetPointName(const QString &value);
+    auto GetPointName() const -> QString;
+    void SetPointName(const QString &value);
 
-    QString      GetTypeLine() const;
-    void         SetTypeLine(const QString &value);
+    auto GetTypeLine() const -> QString;
+    void SetTypeLine(const QString &value);
 
-    QString      GetAngle() const;
-    void         SetAngle(const QString &value);
+    auto GetAngle() const -> QString;
+    void SetAngle(const QString &value);
 
-    quint32      GetBasePointId() const;
-    void         SetBasePointId(quint32 value);
+    auto GetBasePointId() const -> quint32;
+    void SetBasePointId(quint32 value);
 
-    quint32      getCurveId() const;
-    void         setCurveId(quint32 value);
+    auto getCurveId() const -> quint32;
+    void setCurveId(quint32 value);
 
-    QString      GetLineColor() const;
-    void         SetLineColor(const QString &value);
+    auto GetLineColor() const -> QString;
+    void SetLineColor(const QString &value);
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
 
-    void    SetAliasSuffix1(const QString &alias);
-    QString GetAliasSuffix1() const;
+    void SetAliasSuffix1(const QString &alias);
+    auto GetAliasSuffix1() const -> QString;
 
-    void    SetAliasSuffix2(const QString &alias);
-    QString GetAliasSuffix2() const;
+    void SetAliasSuffix2(const QString &alias);
+    auto GetAliasSuffix2() const -> QString;
+
+    void ShowDialog(bool click) override;
 
-    virtual void ShowDialog(bool click) override;
 public slots:
-    virtual void ChosenObject(quint32 id, const SceneObject &type) override;
-    void         EvalAngle();
-    void         DeployAngleTextEdit();
-    void         FXAngle();
+    void ChosenObject(quint32 id, const SceneObject &type) override;
+    void EvalAngle();
+    void DeployAngleTextEdit();
+    void FXAngle();
+
 protected:
-    virtual void ShowVisualization() override;
+    void ShowVisualization() override;
     /**
      * @brief SaveData Put dialog data in local variables
      */
-    virtual void SaveData() override;
-    virtual void closeEvent(QCloseEvent *event) override;
-    virtual bool IsValid() const final;
+    void SaveData() override;
+    void closeEvent(QCloseEvent *event) override;
+    void changeEvent(QEvent *event) override;
+    auto IsValid() const -> bool override;
+
 private slots:
     void ValidateAlias();
+
 private:
     Q_DISABLE_COPY_MOVE(DialogCurveIntersectAxis) // NOLINT
     Ui::DialogCurveIntersectAxis *ui;
 
     QString formulaAngle;
-    int     formulaBaseHeightAngle;
+    int formulaBaseHeightAngle;
 
     QString pointName;
 
@@ -116,11 +120,13 @@ private:
     QString originAliasSuffix2{};
 
     /** @brief number number of handled objects */
-    qint32  number{0};
+    qint32 number{0};
+
+    void InitIcons();
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool DialogCurveIntersectAxis::IsValid() const
+inline auto DialogCurveIntersectAxis::IsValid() const -> bool
 {
     return flagFormula && flagName && flagAlias1 && flagAlias2;
 }
