@@ -36,18 +36,19 @@
 #include <QTimer>
 #include <QToolButton>
 
-#include "../vpatterndb/vtranslatevars.h"
-#include "../vpatterndb/vcontainer.h"
 #include "../../visualization/path/vistoolcutsplinepath.h"
 #include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
+#include "../qmuparser/qmudef.h"
 #include "../support/dialogeditwrongformula.h"
+#include "../vgeometry/vsplinepath.h"
+#include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
-#include "ui_dialogcutsplinepath.h"
-#include "../vgeometry/vsplinepath.h"
-#include "../qmuparser/qmudef.h"
+#include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/vabstractmainwindow.h"
+#include "ui_dialogcutsplinepath.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -55,20 +56,22 @@
  * @param data container with data
  * @param parent parent widget
  */
-DialogCutSplinePath::DialogCutSplinePath(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogCutSplinePath),
-      m_timerFormula(new QTimer(this))
+DialogCutSplinePath::DialogCutSplinePath(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogCutSplinePath),
+    m_timerFormula(new QTimer(this))
 {
     ui->setupUi(this);
 
+    InitIcons();
+
     m_timerFormula->setSingleShot(true);
     connect(m_timerFormula, &QTimer::timeout, this, &DialogCutSplinePath::EvalFormula);
 
     ui->lineEditNamePoint->setClearButtonEnabled(true);
 
     ui->lineEditNamePoint->setText(
-                VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
     this->m_formulaBaseHeight = ui->plainTextEditFormula->height();
     ui->plainTextEditFormula->installEventFilter(this);
 
@@ -77,15 +80,15 @@ DialogCutSplinePath::DialogCutSplinePath(const VContainer *data, quint32 toolId,
     FillComboBoxSplinesPath(ui->comboBoxSplinePath);
 
     connect(ui->toolButtonExprLength, &QPushButton::clicked, this, &DialogCutSplinePath::FXLength);
-    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
-    {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data, m_flagName);
-        CheckState();
-    });
-    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        m_timerFormula->start(formulaTimerTimeout);
-    });
+    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data,
+                                m_flagName);
+                CheckState();
+            });
+    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this,
+            [this]() { m_timerFormula->start(formulaTimerTimeout); });
     connect(ui->pushButtonGrowLength, &QPushButton::clicked, this, &DialogCutSplinePath::DeployFormulaTextEdit);
     connect(ui->comboBoxSplinePath, &QComboBox::currentTextChanged, this, &DialogCutSplinePath::SplinePathChanged);
 
@@ -128,8 +131,8 @@ void DialogCutSplinePath::SetPointName(const QString &value)
  */
 void DialogCutSplinePath::SetFormula(const QString &value)
 {
-    m_formula = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    m_formula = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed. TODO : see if I can get the max number of caracters in one line
     // of this PlainTextEdit to change 80 to this value
     if (m_formula.length() > 80)
@@ -167,24 +170,26 @@ void DialogCutSplinePath::setSplinePathId(quint32 value)
  */
 void DialogCutSplinePath::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare)// After first choose we ignore all objects
+    if (prepare) // After first choose we ignore all objects
     {
         return;
     }
 
-    if (type == SceneObject::SplinePath)
+    if (type == SceneObject::SplinePath && SetObject(id, ui->comboBoxSplinePath, QString()))
     {
-        if (SetObject(id, ui->comboBoxSplinePath, QString()))
+        if (vis != nullptr)
         {
-            if (vis != nullptr)
-            {
-                vis->VisualMode(id);
-            }
-            prepare = true;
+            vis->VisualMode(id);
+        }
+        prepare = true;
 
-            auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
-            SCASSERT(window != nullptr)
-            connect(vis.data(), &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
+        auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
+        SCASSERT(window != nullptr)
+        connect(vis.data(), &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
+
+        if (not VAbstractValApplication::VApp()->Settings()->IsInteractiveTools())
+        {
+            FinishCreating();
         }
     }
 }
@@ -210,16 +215,34 @@ void DialogCutSplinePath::closeEvent(QCloseEvent *event)
     DialogTool::closeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogCutSplinePath::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    DialogTool::changeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCutSplinePath::SplinePathChanged()
 {
-    CurrentCurveLength(getSplinePathId(), const_cast<VContainer *> (data));
+    CurrentCurveLength(getSplinePathId(), const_cast<VContainer *>(data));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCutSplinePath::ValidateAlias()
 {
-    QRegularExpression rx(NameRegExp());
+    QRegularExpression const rx(NameRegExp());
 
     VSplinePath path1;
     path1.SetAliasSuffix(GetAliasSuffix1());
@@ -258,6 +281,25 @@ void DialogCutSplinePath::ValidateAlias()
     CheckState();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogCutSplinePath::FinishCreating()
+{
+    vis->SetMode(Mode::Show);
+    vis->RefreshGeometry();
+    emit ToolTip(QString());
+    setModal(true);
+    show();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogCutSplinePath::InitIcons()
+{
+    auto const resource = QStringLiteral("icon");
+
+    ui->toolButtonExprLength->setIcon(VTheme::GetIconResource(resource, QStringLiteral("24x24/fx.png")));
+    ui->label_4->setPixmap(VTheme::GetPixmapResource(resource, QStringLiteral("24x24/equal.png")));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCutSplinePath::DeployFormulaTextEdit()
 {
@@ -287,7 +329,6 @@ void DialogCutSplinePath::EvalFormula()
     formulaData.labelEditFormula = ui->labelEditFormula;
     formulaData.labelResult = ui->labelResultCalculation;
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
-    formulaData.checkZero = false;
 
     Eval(formulaData, m_flagFormula);
 }
@@ -381,19 +422,10 @@ void DialogCutSplinePath::ShowDialog(bool click)
 
         const QSharedPointer<VAbstractCubicBezierPath> curve =
             data->GeometricObject<VAbstractCubicBezierPath>(getSplinePathId());
-        QPointF p = curve->ClosestPoint(scene->getScenePos());
-        qreal len = curve->GetLengthByPoint(p);
-        if (len > 0)
-        {
-            SetFormula(QString::number(FromPixel(len, *data->GetPatternUnit())));
-        }
+        QPointF const p = curve->ClosestPoint(scene->getScenePos());
+        qreal const len = curve->GetLengthByPoint(p);
+        SetFormula(QString::number(FromPixel(len, *data->GetPatternUnit())));
     }
 
-    vis->SetMode(Mode::Show);
-    vis->RefreshGeometry();
-
-    emit ToolTip(QString());
-
-    setModal(true);
-    show();
+    FinishCreating();
 }
