@@ -29,7 +29,6 @@
 #ifndef DIALOGENDLINE_H
 #define DIALOGENDLINE_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -40,61 +39,66 @@
 
 namespace Ui
 {
-    class DialogEndLine;
+class DialogEndLine;
 }
 
 /**
  * @brief The DialogEndLine class dialog for ToolEndLine. Help create point and edit option.
  */
-class DialogEndLine : public DialogTool
+class DialogEndLine final : public DialogTool
 {
     Q_OBJECT // NOLINT
+
 public:
-    DialogEndLine(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogEndLine() override;
+    DialogEndLine(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent = nullptr);
+    ~DialogEndLine() override;
 
-    QString           GetPointName() const;
-    void              SetPointName(const QString &value);
+    auto GetPointName() const -> QString;
+    void SetPointName(const QString &value);
 
-    QString           GetTypeLine() const;
-    void              SetTypeLine(const QString &value);
+    auto GetTypeLine() const -> QString;
+    void SetTypeLine(const QString &value);
 
-    QString           GetFormula() const;
-    void              SetFormula(const QString &value);
+    auto GetFormula() const -> QString;
+    void SetFormula(const QString &value);
 
-    QString           GetAngle() const;
-    void              SetAngle(const QString &value);
+    auto GetAngle() const -> QString;
+    void SetAngle(const QString &value);
 
-    quint32           GetBasePointId() const;
-    void              SetBasePointId(const quint32 &value);
+    auto GetBasePointId() const -> quint32;
+    void SetBasePointId(const quint32 &value);
 
-    QString           GetLineColor() const;
-    void              SetLineColor(const QString &value);
+    auto GetLineColor() const -> QString;
+    void SetLineColor(const QString &value);
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
+
+    void ShowDialog(bool click) override;
 
-    virtual void      ShowDialog(bool click) override;
 public slots:
-    virtual void      ChosenObject(quint32 id, const SceneObject &type) override;
+    void ChosenObject(quint32 id, const SceneObject &type) override;
 
-    void             EvalLength();
-    void             EvalAngle();
+    void EvalLength();
+    void EvalAngle();
 
     /** @brief DeployFormulaTextEdit grow or shrink formula input */
-    void             DeployFormulaTextEdit();
-    void             DeployAngleTextEdit();
+    void DeployFormulaTextEdit();
+    void DeployAngleTextEdit();
+
+    void FXAngle();
+    void FXLength();
 
-    void             FXAngle();
-    void             FXLength();
 protected:
-    virtual void     ShowVisualization() override;
+    void ShowVisualization() override;
     /**
      * @brief SaveData Put dialog data in local variables
      */
-    virtual void     SaveData() override;
-    virtual void     closeEvent(QCloseEvent *event) override;
-    virtual bool     IsValid() const final;
+    void SaveData() override;
+    void closeEvent(QCloseEvent *event) override;
+    void changeEvent(QEvent *event) override;
+    auto IsValid() const -> bool override;
+
 private:
     Q_DISABLE_COPY_MOVE(DialogEndLine) // NOLINT
 
@@ -121,10 +125,14 @@ private:
     bool flagFormula;
     bool flagError;
     bool flagName;
+
+    void FinishCreating();
+
+    void InitIcons();
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool DialogEndLine::IsValid() const
+inline auto DialogEndLine::IsValid() const -> bool
 {
     return flagFormula && flagError && flagName;
 }
