@@ -31,7 +31,6 @@
 
 #include "dialogtool.h"
 
-#include <qcompilerdetection.h>
 #include <QList>
 #include <QMetaObject>
 #include <QObject>
@@ -39,53 +38,54 @@
 #include <QVector>
 #include <QtGlobal>
 
-#include "../vmisc/def.h"
 #include "../../tools/toolsdef.h"
+#include "../vmisc/def.h"
 
 namespace Ui
 {
-    class DialogFlippingByAxis;
+class DialogFlippingByAxis;
 }
 
-class DialogFlippingByAxis : public DialogTool
+class DialogFlippingByAxis final : public DialogTool
 {
     Q_OBJECT // NOLINT
 
 public:
-    explicit DialogFlippingByAxis(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogFlippingByAxis();
+    explicit DialogFlippingByAxis(const VContainer *data, VAbstractPattern *doc, quint32 toolId,
+                                  QWidget *parent = nullptr);
+    ~DialogFlippingByAxis() override;
 
-    quint32 GetOriginPointId() const;
-    void    SetOriginPointId(quint32 value);
+    auto GetOriginPointId() const -> quint32;
+    void SetOriginPointId(quint32 value);
 
-    AxisType GetAxisType() const;
-    void     SetAxisType(AxisType type);
+    auto GetAxisType() const -> AxisType;
+    void SetAxisType(AxisType type);
 
-    QString GetSuffix() const;
-    void    SetSuffix(const QString &value);
+    auto GetSuffix() const -> QString;
+    void SetSuffix(const QString &value);
 
-    QString GetVisibilityGroupName() const;
-    void    SetVisibilityGroupName(const QString &name);
+    auto GetVisibilityGroupName() const -> QString;
+    void SetVisibilityGroupName(const QString &name);
 
-    bool HasLinkedVisibilityGroup() const;
+    auto HasLinkedVisibilityGroup() const -> bool;
     void SetHasLinkedVisibilityGroup(bool linked);
 
-    void        SetVisibilityGroupTags(const QStringList &tags);
-    QStringList GetVisibilityGroupTags() const;
+    void SetVisibilityGroupTags(const QStringList &tags);
+    auto GetVisibilityGroupTags() const -> QStringList;
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
 
-    virtual void SetGroupCategories(const QStringList &categories) override;
+    void SetGroupCategories(const QStringList &categories) override;
 
-    virtual void ShowDialog(bool click) override;
+    void ShowDialog(bool click) override;
 
-    QVector<SourceItem> GetSourceObjects() const;
-    void                SetSourceObjects(const QVector<SourceItem> &value);
+    auto GetSourceObjects() const -> QVector<SourceItem>;
+    void SetSourceObjects(const QVector<SourceItem> &value);
 
 public slots:
-    virtual void ChosenObject(quint32 id, const SceneObject &type) override;
-    virtual void SelectedObject(bool selected, quint32 object, quint32 tool) override;
+    void ChosenObject(quint32 id, const SceneObject &type) override;
+    void SelectedObject(bool selected, quint32 object, quint32 tool) override;
 
 private slots:
     void SuffixChanged();
@@ -96,11 +96,11 @@ private slots:
     void ColorChanged();
 
 protected:
-    virtual void ShowVisualization() override;
+    void ShowVisualization() override;
 
     /** @brief SaveData Put dialog data in local variables */
-    virtual void SaveData() override;
-    virtual bool IsValid() const final;
+    void SaveData() override;
+    auto IsValid() const -> bool override;
 
 private slots:
     void PointChanged();
