@@ -29,7 +29,6 @@
 #ifndef DIALOGLINE_H
 #define DIALOGLINE_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -40,43 +39,47 @@
 
 namespace Ui
 {
-    class DialogLine;
+class DialogLine;
 }
 
 /**
  * @brief The DialogLine class dialog for ToolLine. Help create line and edit option.
  */
-class DialogLine : public DialogTool
+class DialogLine final : public DialogTool
 {
     Q_OBJECT // NOLINT
+
 public:
-    DialogLine(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogLine() override;
+    DialogLine(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent = nullptr);
+    ~DialogLine() override;
 
-    quint32        GetFirstPoint() const;
-    void           SetFirstPoint(quint32 value);
+    auto GetFirstPoint() const -> quint32;
+    void SetFirstPoint(quint32 value);
 
-    quint32        GetSecondPoint() const;
-    void           SetSecondPoint(quint32 value);
+    auto GetSecondPoint() const -> quint32;
+    void SetSecondPoint(quint32 value);
 
-    QString        GetTypeLine() const;
-    void           SetTypeLine(const QString &value);
+    auto GetTypeLine() const -> QString;
+    void SetTypeLine(const QString &value);
 
-    QString        GetLineColor() const;
-    void           SetLineColor(const QString &value);
+    auto GetLineColor() const -> QString;
+    void SetLineColor(const QString &value);
+
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
 public slots:
-    virtual void   ChosenObject(quint32 id, const SceneObject &type) override;
-    virtual void   PointNameChanged() override;
+    void ChosenObject(quint32 id, const SceneObject &type) override;
+    void PointNameChanged() override;
+
 protected:
-    virtual void   ShowVisualization() override;
+    void ShowVisualization() override;
     /**
      * @brief SaveData Put dialog data in local variables
      */
-    virtual void   SaveData() override;
-    virtual bool   IsValid() const final;
+    void SaveData() override;
+    auto IsValid() const -> bool override;
+
 private:
     Q_DISABLE_COPY_MOVE(DialogLine) // NOLINT
 
@@ -86,11 +89,11 @@ private:
     bool flagError;
 
     /** @brief number number of handled objects */
-    qint32  number{0};
+    qint32 number{0};
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool DialogLine::IsValid() const
+inline auto DialogLine::IsValid() const -> bool
 {
     return flagError;
 }
