@@ -29,7 +29,6 @@
 #ifndef DIALOGLINEINTERSECT_H
 #define DIALOGLINEINTERSECT_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -40,47 +39,51 @@
 
 namespace Ui
 {
-    class DialogLineIntersect;
+class DialogLineIntersect;
 }
 
 /**
  * @brief The DialogLineIntersect class dialog for ToolLineIntersect. Help create point and edit option.
  */
-class DialogLineIntersect : public DialogTool
+class DialogLineIntersect final : public DialogTool
 {
     Q_OBJECT // NOLINT
+
 public:
-    DialogLineIntersect(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogLineIntersect() override;
+    DialogLineIntersect(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent = nullptr);
+    ~DialogLineIntersect() override;
 
-    quint32                 GetP1Line1() const;
-    void                    SetP1Line1(quint32 value);
+    auto GetP1Line1() const -> quint32;
+    void SetP1Line1(quint32 value);
 
-    quint32                 GetP2Line1() const;
-    void                    SetP2Line1(quint32 value);
+    auto GetP2Line1() const -> quint32;
+    void SetP2Line1(quint32 value);
 
-    quint32                 GetP1Line2() const;
-    void                    SetP1Line2(quint32 value);
+    auto GetP1Line2() const -> quint32;
+    void SetP1Line2(quint32 value);
 
-    quint32                 GetP2Line2() const;
-    void                    SetP2Line2(quint32 value);
+    auto GetP2Line2() const -> quint32;
+    void SetP2Line2(quint32 value);
 
-    QString                 GetPointName() const;
-    void                    SetPointName(const QString &value);
+    auto GetPointName() const -> QString;
+    void SetPointName(const QString &value);
+
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
 public slots:
-    virtual void            ChosenObject(quint32 id, const SceneObject &type) override;
-    void                    PointChanged();
-    virtual void            PointNameChanged() override;
+    void ChosenObject(quint32 id, const SceneObject &type) override;
+    void PointChanged();
+    void PointNameChanged() override;
+
 protected:
-    virtual void            ShowVisualization() override;
+    void ShowVisualization() override;
     /**
      * @brief SaveData Put dialog data in local variables
      */
-    virtual void            SaveData() override;
-    virtual bool            IsValid() const final;
+    void SaveData() override;
+    auto IsValid() const -> bool override;
+
 private:
     Q_DISABLE_COPY_MOVE(DialogLineIntersect) // NOLINT
 
@@ -99,11 +102,11 @@ private:
     /** @brief number number of handled objects */
     qint32 number{0};
 
-    bool                    CheckIntersecion();
+    auto CheckIntersecion() -> bool;
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool DialogLineIntersect::IsValid() const
+inline auto DialogLineIntersect::IsValid() const -> bool
 {
     return flagName && flagError && flagPoint;
 }
