@@ -29,7 +29,6 @@
 #ifndef DIALOGLINEINTERSECTAXIS_H
 #define DIALOGLINEINTERSECTAXIS_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -40,62 +39,66 @@
 
 namespace Ui
 {
-    class DialogLineIntersectAxis;
+class DialogLineIntersectAxis;
 }
 
-class DialogLineIntersectAxis : public DialogTool
+class DialogLineIntersectAxis final : public DialogTool
 {
     Q_OBJECT // NOLINT
 
 public:
-    DialogLineIntersectAxis(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogLineIntersectAxis() override;
+    DialogLineIntersectAxis(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent = nullptr);
+    ~DialogLineIntersectAxis() override;
 
-    QString      GetPointName() const;
-    void         SetPointName(const QString &value);
+    auto GetPointName() const -> QString;
+    void SetPointName(const QString &value);
 
-    QString      GetTypeLine() const;
-    void         SetTypeLine(const QString &value);
+    auto GetTypeLine() const -> QString;
+    void SetTypeLine(const QString &value);
 
-    QString      GetAngle() const;
-    void         SetAngle(const QString &value);
+    auto GetAngle() const -> QString;
+    void SetAngle(const QString &value);
 
-    quint32      GetBasePointId() const;
-    void         SetBasePointId(quint32 value);
+    auto GetBasePointId() const -> quint32;
+    void SetBasePointId(quint32 value);
 
-    quint32      GetFirstPointId() const;
-    void         SetFirstPointId(quint32 value);
+    auto GetFirstPointId() const -> quint32;
+    void SetFirstPointId(quint32 value);
 
-    quint32      GetSecondPointId() const;
-    void         SetSecondPointId(quint32 value);
+    auto GetSecondPointId() const -> quint32;
+    void SetSecondPointId(quint32 value);
 
-    QString      GetLineColor() const;
-    void         SetLineColor(const QString &value);
+    auto GetLineColor() const -> QString;
+    void SetLineColor(const QString &value);
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
+
+    void ShowDialog(bool click) override;
 
-    virtual void ShowDialog(bool click) override;
 public slots:
-    virtual void ChosenObject(quint32 id, const SceneObject &type) override;
-    void         EvalAngle();
-    void         DeployAngleTextEdit();
-    virtual void PointNameChanged() override;
-    void         FXAngle();
+    void ChosenObject(quint32 id, const SceneObject &type) override;
+    void EvalAngle();
+    void DeployAngleTextEdit();
+    void PointNameChanged() override;
+    void FXAngle();
+
 protected:
-    virtual void ShowVisualization() override;
+    void ShowVisualization() override;
     /**
      * @brief SaveData Put dialog data in local variables
      */
-    virtual void SaveData() override;
-    virtual void closeEvent(QCloseEvent *event) override;
-    virtual bool IsValid() const final;
+    void SaveData() override;
+    void closeEvent(QCloseEvent *event) override;
+    void changeEvent(QEvent *event) override;
+    auto IsValid() const -> bool override;
+
 private:
     Q_DISABLE_COPY_MOVE(DialogLineIntersectAxis) // NOLINT
     Ui::DialogLineIntersectAxis *ui;
 
     QString formulaAngle;
-    int     formulaBaseHeightAngle;
+    int formulaBaseHeightAngle;
 
     QString pointName;
 
@@ -109,10 +112,12 @@ private:
 
     /** @brief number number of handled objects */
     qint32 number{0};
+
+    void InitIcons();
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool DialogLineIntersectAxis::IsValid() const
+inline auto DialogLineIntersectAxis::IsValid() const -> bool
 {
     return flagFormula && flagName;
 }
