@@ -45,9 +45,7 @@
 #include <QStringList>
 #include <QTimer>
 #include <QToolButton>
-#include <new>
 
-#include "../../tools/drawTools/operation/vabstractoperation.h"
 #include "../../visualization/line/operation/vistoolmove.h"
 #include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
@@ -56,6 +54,7 @@
 #include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
+#include "../vmisc/vvalentinasettings.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/vabstractmainwindow.h"
@@ -116,7 +115,9 @@ DialogMove::DialogMove(const VContainer *data, VAbstractPattern *doc, quint32 to
                          OperationLineStylesPics(ui->comboBoxPenStyle->palette().color(QPalette::Base),
                                                  ui->comboBoxPenStyle->palette().color(QPalette::Text)),
                          TypeLineDefault);
-    FillComboBoxLineColors(ui->comboBoxColor, VAbstractOperation::OperationColorsList());
+    InitOperationColorPicker(ui->pushButtonColor,
+                             VAbstractValApplication::VApp()->ValentinaSettings()->GetUserToolColors());
+    ui->pushButtonColor->setUseNativeDialog(!VAbstractApplication::VApp()->Settings()->IsDontUseNativeDialog());
     FillComboBoxPoints(ui->comboBoxRotationOriginPoint);
 
     ui->comboBoxRotationOriginPoint->blockSignals(true);
@@ -145,7 +146,7 @@ DialogMove::DialogMove(const VContainer *data, VAbstractPattern *doc, quint32 to
     connect(ui->lineEditAlias, &QLineEdit::textEdited, this, &DialogMove::AliasChanged);
     connect(ui->comboBoxPenStyle, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
             &DialogMove::PenStyleChanged);
-    connect(ui->comboBoxColor, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &DialogMove::ColorChanged);
+    connect(ui->pushButtonColor, &VPE::QtColorPicker::colorChanged, this, &DialogMove::ColorChanged);
 
     vis = new VisToolMove(data);
 
@@ -158,6 +159,7 @@ DialogMove::DialogMove(const VContainer *data, VAbstractPattern *doc, quint32 to
 //---------------------------------------------------------------------------------------------------------------------
 DialogMove::~DialogMove()
 {
+    VAbstractValApplication::VApp()->ValentinaSettings()->SetUserToolColors(ui->pushButtonColor->CustomColors());
     delete ui;
 }
 
@@ -506,8 +508,7 @@ void DialogMove::FXLength()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::SuffixChanged()
 {
-    auto *edit = qobject_cast<QLineEdit *>(sender());
-    if (edit)
+    if (const auto *edit = qobject_cast<QLineEdit *>(sender()); edit)
     {
         const QString suffix = edit->text();
         if (suffix.isEmpty())
@@ -546,8 +547,7 @@ void DialogMove::SuffixChanged()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::GroupNameChanged()
 {
-    auto *edit = qobject_cast<QLineEdit *>(sender());
-    if (edit)
+    if (const auto *edit = qobject_cast<QLineEdit *>(sender()); edit)
     {
         const QString name = edit->text();
         if (name.isEmpty())
@@ -570,7 +570,7 @@ void DialogMove::ShowSourceDetails(int row)
 {
     ui->lineEditAlias->setDisabled(true);
     ui->comboBoxPenStyle->setDisabled(true);
-    ui->comboBoxColor->setDisabled(true);
+    ui->pushButtonColor->setDisabled(true);
 
     if (ui->listWidget->count() == 0)
     {
@@ -586,13 +586,13 @@ void DialogMove::ShowSourceDetails(int row)
         ui->labelAlias->setText(tr("Label:"));
 
         ui->comboBoxPenStyle->blockSignals(true);
-        ui->comboBoxColor->blockSignals(true);
+        ui->pushButtonColor->blockSignals(true);
 
         ui->comboBoxPenStyle->setCurrentIndex(-1);
-        ui->comboBoxColor->setCurrentIndex(-1);
+        ui->pushButtonColor->setCurrentColor(QColor());
 
         ui->comboBoxPenStyle->blockSignals(false);
-        ui->comboBoxColor->blockSignals(false);
+        ui->pushButtonColor->blockSignals(false);
     }
     else
     {
@@ -625,18 +625,21 @@ void DialogMove::ShowSourceDetails(int row)
             ui->comboBoxPenStyle->setItemText(index, '<' + tr("Default") + '>');
         }
 
-        SetValue(ui->comboBoxColor, sourceItem.color, ColorDefault);
+        ui->pushButtonColor->blockSignals(true);
+
+        QColor const color(sourceItem.color);
+        ui->pushButtonColor->setCurrentColor(color.isValid() ? color : ColorDefault);
+
+        ui->pushButtonColor->blockSignals(false);
 
         if (sourceItem.color.isEmpty() || sourceItem.color == ColorDefault)
         {
             const QSharedPointer<VAbstractCurve> curve = data->GeometricObject<VAbstractCurve>(sourceItem.id);
-            int const index = ui->comboBoxColor->currentIndex();
-            ui->comboBoxColor->setItemIcon(index, LineColor(ui->comboBoxColor->palette().color(QPalette::Text),
-                                                            ui->comboBoxColor->iconSize().height(), curve->GetColor()));
+            ui->pushButtonColor->setDefaultColor(curve->GetColor());
         }
 
         ui->comboBoxPenStyle->setEnabled(true);
-        ui->comboBoxColor->setEnabled(true);
+        ui->pushButtonColor->setEnabled(true);
     }
 
     ui->lineEditAlias->blockSignals(true);
@@ -694,7 +697,8 @@ void DialogMove::ColorChanged()
     if (auto *item = ui->listWidget->currentItem())
     {
         auto sourceItem = qvariant_cast<SourceItem>(item->data(Qt::UserRole));
-        sourceItem.color = GetComboBoxCurrentData(ui->comboBoxColor, ColorDefault);
+        QColor const color = ui->pushButtonColor->currentColor();
+        sourceItem.color = color.isValid() ? color.name() : ColorDefault;
         item->setData(Qt::UserRole, QVariant::fromValue(sourceItem));
     }
 }
