@@ -29,7 +29,6 @@
 #ifndef DIALOGNORMAL_H
 #define DIALOGNORMAL_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -40,17 +39,18 @@
 
 namespace Ui
 {
-    class DialogNormal;
+class DialogNormal;
 }
 
 /**
  * @brief The DialogNormal class dialog for ToolNormal. Help create point and edit option.
  */
-class DialogNormal : public DialogTool
+class DialogNormal final : public DialogTool
 {
     Q_OBJECT // NOLINT
+
 public:
-    DialogNormal(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
+    DialogNormal(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent = nullptr);
     ~DialogNormal() override;
 
     auto GetPointName() const -> QString;
@@ -78,6 +78,7 @@ public:
     auto GetNotes() const -> QString;
 
     void ShowDialog(bool click) override;
+
 public slots:
     void ChosenObject(quint32 id, const SceneObject &type) override;
     /**
@@ -87,6 +88,7 @@ public slots:
     void PointNameChanged() override;
     void FXLength();
     void EvalFormula();
+
 protected:
     void ShowVisualization() override;
     /**
@@ -94,7 +96,9 @@ protected:
      */
     void SaveData() override;
     void closeEvent(QCloseEvent *event) override;
-    auto IsValid() const -> bool final;
+    void changeEvent(QEvent *event) override;
+    auto IsValid() const -> bool override;
+
 private:
     Q_DISABLE_COPY_MOVE(DialogNormal) // NOLINT
 
@@ -122,6 +126,10 @@ private:
 
     /** @brief number number of handled objects */
     qint32 m_number{0};
+
+    void FinishCreating();
+
+    void InitIcons();
 };
 
 //---------------------------------------------------------------------------------------------------------------------
