@@ -29,7 +29,6 @@
 #ifndef DIALOGPOINTFROMARCANDTANGENT_H
 #define DIALOGPOINTFROMARCANDTANGENT_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -41,42 +40,43 @@
 
 namespace Ui
 {
-    class DialogPointFromArcAndTangent;
+class DialogPointFromArcAndTangent;
 }
 
-class DialogPointFromArcAndTangent : public DialogTool
+class DialogPointFromArcAndTangent final : public DialogTool
 {
     Q_OBJECT // NOLINT
 
 public:
-    DialogPointFromArcAndTangent(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    ~DialogPointFromArcAndTangent();
+    DialogPointFromArcAndTangent(const VContainer *data, VAbstractPattern *doc, quint32 toolId,
+                                 QWidget *parent = nullptr);
+    ~DialogPointFromArcAndTangent() override;
 
-    QString        GetPointName() const;
-    void           SetPointName(const QString &value);
+    auto GetPointName() const -> QString;
+    void SetPointName(const QString &value);
 
-    quint32        GetArcId() const;
-    void           SetArcId(quint32 value);
+    auto GetArcId() const -> quint32;
+    void SetArcId(quint32 value);
 
-    quint32        GetTangentPointId() const;
-    void           SetTangentPointId(quint32 value);
+    auto GetTangentPointId() const -> quint32;
+    void SetTangentPointId(quint32 value);
 
-    CrossCirclesPoint GetCrossCirclesPoint() const;
-    void              SetCrossCirclesPoint(CrossCirclesPoint p);
+    auto GetCrossCirclesPoint() const -> CrossCirclesPoint;
+    void SetCrossCirclesPoint(CrossCirclesPoint p);
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
 
 public slots:
-    virtual void   ChosenObject(quint32 id, const SceneObject &type) override;
+    void ChosenObject(quint32 id, const SceneObject &type) override;
 
 protected:
-    virtual void   ShowVisualization() override;
+    void ShowVisualization() override;
     /**
      * @brief SaveData Put dialog data in local variables
      */
-    virtual void   SaveData() override;
-    virtual bool   IsValid() const final;
+    void SaveData() override;
+    auto IsValid() const -> bool override;
 
 private:
     Q_DISABLE_COPY_MOVE(DialogPointFromArcAndTangent) // NOLINT
@@ -88,11 +88,11 @@ private:
     bool flagName;
 
     /** @brief number number of handled objects */
-    qint32  number{0};
+    qint32 number{0};
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool DialogPointFromArcAndTangent::IsValid() const
+inline auto DialogPointFromArcAndTangent::IsValid() const -> bool
 {
     return flagName;
 }
