@@ -29,7 +29,6 @@
 #ifndef DIALOGPOINTFROMCIRCLEANDTANGENT_H
 #define DIALOGPOINTFROMCIRCLEANDTANGENT_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -41,15 +40,16 @@
 
 namespace Ui
 {
-    class DialogPointFromCircleAndTangent;
+class DialogPointFromCircleAndTangent;
 }
 
-class DialogPointFromCircleAndTangent : public DialogTool
+class DialogPointFromCircleAndTangent final : public DialogTool
 {
     Q_OBJECT // NOLINT
 
 public:
-    DialogPointFromCircleAndTangent(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
+    DialogPointFromCircleAndTangent(const VContainer *data, VAbstractPattern *doc, quint32 toolId,
+                                    QWidget *parent = nullptr);
     ~DialogPointFromCircleAndTangent() override;
 
     auto GetPointName() const -> QString;
@@ -71,6 +71,7 @@ public:
     auto GetNotes() const -> QString;
 
     void ShowDialog(bool click) override;
+
 public slots:
     void ChosenObject(quint32 id, const SceneObject &type) override;
     void PointChanged();
@@ -86,23 +87,28 @@ protected:
      */
     void SaveData() override;
     void closeEvent(QCloseEvent *event) override;
-    auto IsValid() const -> bool final;
+    void changeEvent(QEvent *event) override;
+    auto IsValid() const -> bool override;
 
 private:
     Q_DISABLE_COPY_MOVE(DialogPointFromCircleAndTangent) // NOLINT
 
     Ui::DialogPointFromCircleAndTangent *ui;
 
-    QTimer* m_timerCircleRadius{nullptr};
+    QTimer *m_timerCircleRadius{nullptr};
     QString m_circleRadius{};
-    int     m_formulaBaseHeightCircleRadius{0};
+    int m_formulaBaseHeightCircleRadius{0};
     QString m_pointName{};
-    bool    m_flagCircleRadius{false};
-    bool    m_flagName{true};
-    bool    m_flagError{true};
+    bool m_flagCircleRadius{false};
+    bool m_flagName{true};
+    bool m_flagError{true};
     /** @brief number number of handled objects */
-    qint32  m_number{0};
-    bool    m_firstRelease{false};
+    qint32 m_number{0};
+    bool m_firstRelease{false};
+
+    void FinishCreating();
+
+    void InitIcons();
 };
 
 //---------------------------------------------------------------------------------------------------------------------
