@@ -29,7 +29,6 @@
 #ifndef DIALOGPOINTOFCONTACT_H
 #define DIALOGPOINTOFCONTACT_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -37,21 +36,21 @@
 
 #include "../vmisc/def.h"
 #include "dialogtool.h"
-#include "ui_dialogpointofcontact.h"
 
 namespace Ui
 {
-    class DialogPointOfContact;
+class DialogPointOfContact;
 }
 
 /**
  * @brief The DialogPointOfContact class dialog for ToolPointOfContact. Help create point and edit option.
  */
-class DialogPointOfContact : public DialogTool
+class DialogPointOfContact final : public DialogTool
 {
     Q_OBJECT // NOLINT
+
 public:
-    DialogPointOfContact(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
+    DialogPointOfContact(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent = nullptr);
     ~DialogPointOfContact() override;
 
     auto GetPointName() const -> QString;
@@ -73,6 +72,7 @@ public:
     auto GetNotes() const -> QString;
 
     void ShowDialog(bool click) override;
+
 public slots:
     void ChosenObject(quint32 id, const SceneObject &type) override;
     /**
@@ -82,6 +82,7 @@ public slots:
     void PointNameChanged() override;
     void FXRadius();
     void EvalFormula();
+
 protected:
     void ShowVisualization() override;
     /**
@@ -89,7 +90,9 @@ protected:
      */
     void SaveData() override;
     void closeEvent(QCloseEvent *event) override;
-    auto IsValid() const -> bool final;
+    void changeEvent(QEvent *event) override;
+    auto IsValid() const -> bool override;
+
 private:
     Q_DISABLE_COPY_MOVE(DialogPointOfContact) // NOLINT
 
@@ -114,6 +117,10 @@ private:
     qint32 m_number{0};
 
     bool m_firstRelease{false};
+
+    void FinishCreating();
+
+    void InitIcons();
 };
 
 //---------------------------------------------------------------------------------------------------------------------
