@@ -34,8 +34,8 @@
 #include <QLineEdit>
 #include <QPointer>
 
-#include "../../visualization/visualization.h"
 #include "../../visualization/line/vistoolpointofintersection.h"
+#include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "dialogtool.h"
 #include "ui_dialogpointofintersection.h"
@@ -46,37 +46,38 @@
  * @param data container with data
  * @param parent parent widget
  */
-DialogPointOfIntersection::DialogPointOfIntersection(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogPointOfIntersection),
-      pointName(),
-      flagName(true),
-      flagError(true)
+DialogPointOfIntersection::DialogPointOfIntersection(const VContainer *data, VAbstractPattern *doc, quint32 toolId,
+                                                     QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogPointOfIntersection),
+    pointName(),
+    flagName(true),
+    flagError(true)
 {
     ui->setupUi(this);
 
     ui->lineEditNamePoint->setClearButtonEnabled(true);
 
     ui->lineEditNamePoint->setText(
-                VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
 
     InitOkCancelApply(ui);
 
     FillComboBoxPoints(ui->comboBoxFirstPoint);
     FillComboBoxPoints(ui->comboBoxSecondPoint);
 
-    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
-    {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
-        CheckState();
-    });
-    connect(ui->comboBoxFirstPoint, &QComboBox::currentTextChanged,
-            this, &DialogPointOfIntersection::PointNameChanged);
-    connect(ui->comboBoxSecondPoint, &QComboBox::currentTextChanged,
-            this, &DialogPointOfIntersection::PointNameChanged);
+    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
+                CheckState();
+            });
+    connect(ui->comboBoxFirstPoint, &QComboBox::currentTextChanged, this, &DialogPointOfIntersection::PointNameChanged);
+    connect(ui->comboBoxSecondPoint, &QComboBox::currentTextChanged, this,
+            &DialogPointOfIntersection::PointNameChanged);
 
     vis = new VisToolPointOfIntersection(data);
-    vis->VisualMode(NULL_ID);//Show vertical axis
+    vis->VisualMode(NULL_ID); // Show vertical axis
 
     ui->tabWidget->setCurrentIndex(0);
     SetTabStopDistance(ui->plainTextEditToolNotes);
@@ -89,7 +90,7 @@ DialogPointOfIntersection::~DialogPointOfIntersection()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPointOfIntersection::GetPointName() const
+auto DialogPointOfIntersection::GetPointName() const -> QString
 {
     return pointName;
 }
@@ -103,7 +104,7 @@ void DialogPointOfIntersection::SetSecondPointId(quint32 value)
 {
     setCurrentPointId(ui->comboBoxSecondPoint, value);
 
-    VisToolPointOfIntersection *line = qobject_cast<VisToolPointOfIntersection *>(vis);
+    auto *line = qobject_cast<VisToolPointOfIntersection *>(vis);
     SCASSERT(line != nullptr)
     line->SetPoint2Id(value);
 }
@@ -116,38 +117,33 @@ void DialogPointOfIntersection::SetSecondPointId(quint32 value)
  */
 void DialogPointOfIntersection::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (prepare == false && type == SceneObject::Point) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
-        {
-            VisToolPointOfIntersection *line = qobject_cast<VisToolPointOfIntersection *>(vis);
-            SCASSERT(line != nullptr)
+        auto *line = qobject_cast<VisToolPointOfIntersection *>(vis);
+        SCASSERT(line != nullptr)
 
-            switch (number)
-            {
-                case 0:
-                    if (SetObject(id, ui->comboBoxFirstPoint, tr("Select point for Y value (horizontal)")))
-                    {
-                        number++;
-                        line->SetPoint1Id(id);
-                        line->RefreshGeometry();
-                    }
-                    break;
-                case 1:
-                    if (getCurrentObjectId(ui->comboBoxFirstPoint) != id)
-                    {
-                        if (SetObject(id, ui->comboBoxSecondPoint, QString()))
-                        {
-                            line->SetPoint2Id(id);
-                            line->RefreshGeometry();
-                            prepare = true;
-                            DialogAccepted();
-                        }
-                    }
-                    break;
-                default:
-                    break;
-            }
+        switch (number)
+        {
+            case 0:
+                if (SetObject(id, ui->comboBoxFirstPoint, tr("Select point for Y value (horizontal)")))
+                {
+                    number++;
+                    line->SetPoint1Id(id);
+                    line->RefreshGeometry();
+                }
+                break;
+            case 1:
+                if (getCurrentObjectId(ui->comboBoxFirstPoint) != id &&
+                    SetObject(id, ui->comboBoxSecondPoint, QString()))
+                {
+                    line->SetPoint2Id(id);
+                    line->RefreshGeometry();
+                    prepare = true;
+                    DialogAccepted();
+                }
+                break;
+            default:
+                break;
         }
     }
 }
@@ -157,7 +153,7 @@ void DialogPointOfIntersection::SaveData()
 {
     pointName = ui->lineEditNamePoint->text();
 
-    VisToolPointOfIntersection *line = qobject_cast<VisToolPointOfIntersection *>(vis);
+    auto *line = qobject_cast<VisToolPointOfIntersection *>(vis);
     SCASSERT(line != nullptr)
 
     line->SetPoint1Id(GetFirstPointId());
@@ -199,7 +195,7 @@ void DialogPointOfIntersection::SetFirstPointId(quint32 value)
 {
     setCurrentPointId(ui->comboBoxFirstPoint, value);
 
-    VisToolPointOfIntersection *line = qobject_cast<VisToolPointOfIntersection *>(vis);
+    auto *line = qobject_cast<VisToolPointOfIntersection *>(vis);
     SCASSERT(line != nullptr)
     line->SetPoint1Id(value);
 }
@@ -220,7 +216,7 @@ void DialogPointOfIntersection::SetPointName(const QString &value)
  * @brief GetFirstPointId return id of first point
  * @return id
  */
-quint32 DialogPointOfIntersection::GetFirstPointId() const
+auto DialogPointOfIntersection::GetFirstPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxFirstPoint);
 }
@@ -230,7 +226,7 @@ quint32 DialogPointOfIntersection::GetFirstPointId() const
  * @brief GetSecondPointId return id of second point
  * @return id
  */
-quint32 DialogPointOfIntersection::GetSecondPointId() const
+auto DialogPointOfIntersection::GetSecondPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxSecondPoint);
 }
@@ -242,7 +238,7 @@ void DialogPointOfIntersection::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPointOfIntersection::GetNotes() const
+auto DialogPointOfIntersection::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
