@@ -34,26 +34,26 @@
 #include <QLineEdit>
 #include <QPointer>
 
-#include "../../visualization/visualization.h"
 #include "../../visualization/line/vistoolpointofintersectionarcs.h"
-#include "../vmisc/vabstractapplication.h"
-#include "dialogs/tools/dialogtool.h"
+#include "../../visualization/visualization.h"
+#include "dialogtool.h"
 #include "ui_dialogpointofintersectionarcs.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogPointOfIntersectionArcs::DialogPointOfIntersectionArcs(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogPointOfIntersectionArcs),
-      pointName(),
-      flagName(true),
-      flagError(true)
+DialogPointOfIntersectionArcs::DialogPointOfIntersectionArcs(const VContainer *data, VAbstractPattern *doc,
+                                                             quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogPointOfIntersectionArcs),
+    pointName(),
+    flagName(true),
+    flagError(true)
 {
     ui->setupUi(this);
 
     ui->lineEditNamePoint->setClearButtonEnabled(true);
 
     ui->lineEditNamePoint->setText(
-                VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
 
     InitOkCancelApply(ui);
 
@@ -61,15 +61,14 @@ DialogPointOfIntersectionArcs::DialogPointOfIntersectionArcs(const VContainer *d
     FillComboBoxArcs(ui->comboBoxArc2);
     FillComboBoxCrossCirclesPoints(ui->comboBoxResult);
 
-    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
-    {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
-        CheckState();
-    });
-    connect(ui->comboBoxArc1, &QComboBox::currentTextChanged,
-            this, &DialogPointOfIntersectionArcs::ArcChanged);
-    connect(ui->comboBoxArc1, &QComboBox::currentTextChanged,
-            this, &DialogPointOfIntersectionArcs::ArcChanged);
+    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
+                CheckState();
+            });
+    connect(ui->comboBoxArc1, &QComboBox::currentTextChanged, this, &DialogPointOfIntersectionArcs::ArcChanged);
+    connect(ui->comboBoxArc1, &QComboBox::currentTextChanged, this, &DialogPointOfIntersectionArcs::ArcChanged);
 
     vis = new VisToolPointOfIntersectionArcs(data);
 
@@ -84,7 +83,7 @@ DialogPointOfIntersectionArcs::~DialogPointOfIntersectionArcs()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPointOfIntersectionArcs::GetPointName() const
+auto DialogPointOfIntersectionArcs::GetPointName() const -> QString
 {
     return pointName;
 }
@@ -97,7 +96,7 @@ void DialogPointOfIntersectionArcs::SetPointName(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogPointOfIntersectionArcs::GetFirstArcId() const
+auto DialogPointOfIntersectionArcs::GetFirstArcId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxArc1);
 }
@@ -107,13 +106,13 @@ void DialogPointOfIntersectionArcs::SetFirstArcId(quint32 value)
 {
     setCurrentArcId(ui->comboBoxArc1, value);
 
-    VisToolPointOfIntersectionArcs *point = qobject_cast<VisToolPointOfIntersectionArcs *>(vis);
+    auto *point = qobject_cast<VisToolPointOfIntersectionArcs *>(vis);
     SCASSERT(point != nullptr)
     point->SetArc1Id(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogPointOfIntersectionArcs::GetSecondArcId() const
+auto DialogPointOfIntersectionArcs::GetSecondArcId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxArc2);
 }
@@ -123,13 +122,13 @@ void DialogPointOfIntersectionArcs::SetSecondArcId(quint32 value)
 {
     setCurrentArcId(ui->comboBoxArc2, value);
 
-    VisToolPointOfIntersectionArcs *point = qobject_cast<VisToolPointOfIntersectionArcs *>(vis);
+    auto *point = qobject_cast<VisToolPointOfIntersectionArcs *>(vis);
     SCASSERT(point != nullptr)
     point->SetArc2Id(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-CrossCirclesPoint DialogPointOfIntersectionArcs::GetCrossArcPoint() const
+auto DialogPointOfIntersectionArcs::GetCrossArcPoint() const -> CrossCirclesPoint
 {
     return getCurrentCrossPoint<CrossCirclesPoint>(ui->comboBoxResult);
 }
@@ -142,7 +141,7 @@ void DialogPointOfIntersectionArcs::SetCrossArcPoint(CrossCirclesPoint p)
     {
         ui->comboBoxResult->setCurrentIndex(index);
 
-        VisToolPointOfIntersectionArcs *point = qobject_cast<VisToolPointOfIntersectionArcs *>(vis);
+        auto *point = qobject_cast<VisToolPointOfIntersectionArcs *>(vis);
         SCASSERT(point != nullptr)
         point->SetCrossPoint(p);
     }
@@ -151,38 +150,32 @@ void DialogPointOfIntersectionArcs::SetCrossArcPoint(CrossCirclesPoint p)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointOfIntersectionArcs::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (prepare == false && type == SceneObject::Arc) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Arc)
-        {
-            VisToolPointOfIntersectionArcs *point = qobject_cast<VisToolPointOfIntersectionArcs *>(vis);
-            SCASSERT(point != nullptr)
+        auto *point = qobject_cast<VisToolPointOfIntersectionArcs *>(vis);
+        SCASSERT(point != nullptr)
 
-            switch (number)
-            {
-                case 0:
-                    if (SetObject(id, ui->comboBoxArc1, tr("Select second an arc")))
-                    {
-                        number++;
-                        point->VisualMode(id);
-                    }
-                    break;
-                case 1:
-                    if (getCurrentObjectId(ui->comboBoxArc1) != id)
-                    {
-                        if (SetObject(id, ui->comboBoxArc2, QString()))
-                        {
-                            number = 0;
-                            point->SetArc2Id(id);
-                            point->RefreshGeometry();
-                            prepare = true;
-                            DialogAccepted();
-                        }
-                    }
-                    break;
-                default:
-                    break;
-            }
+        switch (number)
+        {
+            case 0:
+                if (SetObject(id, ui->comboBoxArc1, tr("Select second an arc")))
+                {
+                    number++;
+                    point->VisualMode(id);
+                }
+                break;
+            case 1:
+                if (getCurrentObjectId(ui->comboBoxArc1) != id && SetObject(id, ui->comboBoxArc2, QString()))
+                {
+                    number = 0;
+                    point->SetArc2Id(id);
+                    point->RefreshGeometry();
+                    prepare = true;
+                    DialogAccepted();
+                }
+                break;
+            default:
+                break;
         }
     }
 }
@@ -217,7 +210,7 @@ void DialogPointOfIntersectionArcs::SaveData()
 {
     pointName = ui->lineEditNamePoint->text();
 
-    VisToolPointOfIntersectionArcs *point = qobject_cast<VisToolPointOfIntersectionArcs *>(vis);
+    auto *point = qobject_cast<VisToolPointOfIntersectionArcs *>(vis);
     SCASSERT(point != nullptr)
 
     point->SetArc1Id(GetFirstArcId());
@@ -233,7 +226,7 @@ void DialogPointOfIntersectionArcs::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPointOfIntersectionArcs::GetNotes() const
+auto DialogPointOfIntersectionArcs::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
