@@ -29,7 +29,6 @@
 #ifndef DIALOGROTATION_H
 #define DIALOGROTATION_H
 
-#include <qcompilerdetection.h>
 #include <QList>
 #include <QMetaObject>
 #include <QObject>
@@ -37,53 +36,54 @@
 #include <QVector>
 #include <QtGlobal>
 
+#include "../../tools/toolsdef.h"
 #include "../vmisc/def.h"
 #include "dialogtool.h"
-#include "../../tools/toolsdef.h"
 
 namespace Ui
 {
-    class DialogRotation;
+class DialogRotation;
 }
 
-class DialogRotation : public DialogTool
+class DialogRotation final : public DialogTool
 {
     Q_OBJECT // NOLINT
+
 public:
-    explicit DialogRotation(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogRotation();
+    explicit DialogRotation(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent = nullptr);
+    ~DialogRotation() override;
 
-    quint32 GetOrigPointId() const;
-    void    SetOrigPointId(quint32 value);
+    auto GetOrigPointId() const -> quint32;
+    void SetOrigPointId(quint32 value);
 
-    QString GetAngle() const;
-    void    SetAngle(const QString &value);
+    auto GetAngle() const -> QString;
+    void SetAngle(const QString &value);
 
-    QString GetSuffix() const;
-    void    SetSuffix(const QString &value);
+    auto GetSuffix() const -> QString;
+    void SetSuffix(const QString &value);
 
-    QString GetVisibilityGroupName() const;
-    void    SetVisibilityGroupName(const QString &name);
+    auto GetVisibilityGroupName() const -> QString;
+    void SetVisibilityGroupName(const QString &name);
 
-    bool HasLinkedVisibilityGroup() const;
+    auto HasLinkedVisibilityGroup() const -> bool;
     void SetHasLinkedVisibilityGroup(bool linked);
 
-    void        SetVisibilityGroupTags(const QStringList &tags);
-    QStringList GetVisibilityGroupTags() const;
+    void SetVisibilityGroupTags(const QStringList &tags);
+    auto GetVisibilityGroupTags() const -> QStringList;
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
 
-    virtual void SetGroupCategories(const QStringList &categories) override;
+    void SetGroupCategories(const QStringList &categories) override;
 
-    virtual void ShowDialog(bool click) override;
+    void ShowDialog(bool click) override;
 
-    QVector<SourceItem> GetSourceObjects() const;
-    void                SetSourceObjects(const QVector<SourceItem> &value);
+    auto GetSourceObjects() const -> QVector<SourceItem>;
+    void SetSourceObjects(const QVector<SourceItem> &value);
 
 public slots:
-    virtual void ChosenObject(quint32 id, const SceneObject &type) override;
-    virtual void SelectedObject(bool selected, quint32 object, quint32 tool) override;
+    void ChosenObject(quint32 id, const SceneObject &type) override;
+    void SelectedObject(bool selected, quint32 object, quint32 tool) override;
 
 private slots:
     /** @brief DeployAngleTextEdit grow or shrink formula input */
@@ -98,12 +98,13 @@ private slots:
     void ColorChanged();
 
 protected:
-    virtual void ShowVisualization() override;
+    void ShowVisualization() override;
 
     /** @brief SaveData Put dialog data in local variables */
-    virtual void SaveData() override;
-    virtual void closeEvent(QCloseEvent *event) override;
-    virtual bool IsValid() const final;
+    void SaveData() override;
+    void closeEvent(QCloseEvent *event) override;
+    void changeEvent(QEvent *event) override;
+    auto IsValid() const -> bool override;
 
 private slots:
     void PointChanged();
@@ -113,13 +114,13 @@ private:
     Ui::DialogRotation *ui;
 
     /** @brief timerAngle timer of check formula of angle */
-    QTimer  *timerAngle;
+    QTimer *timerAngle;
 
     /** @brief angle formula of angle */
     QString formulaAngle;
 
     /** @brief formulaBaseHeightAngle base height defined by dialogui */
-    int     formulaBaseHeightAngle;
+    int formulaBaseHeightAngle;
 
     QVector<SourceItem> sourceObjects{};
 
@@ -142,6 +143,8 @@ private:
 
     void ValidateSourceAliases();
     void SetAliasValid(quint32 id, bool valid);
+
+    void InitIcons();
 };
 
 #endif // DIALOGROTATION_H
