@@ -29,7 +29,6 @@
 #ifndef DIALOGSHOULDERPOINT_H
 #define DIALOGSHOULDERPOINT_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -40,17 +39,18 @@
 
 namespace Ui
 {
-    class DialogShoulderPoint;
+class DialogShoulderPoint;
 }
 
 /**
  * @brief The DialogShoulderPoint class dialog for ToolShoulderPoint. Help create point and edit option.
  */
-class DialogShoulderPoint : public DialogTool
+class DialogShoulderPoint final : public DialogTool
 {
     Q_OBJECT // NOLINT
+
 public:
-    DialogShoulderPoint(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
+    DialogShoulderPoint(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent = nullptr);
     ~DialogShoulderPoint() override;
 
     auto GetPointName() const -> QString;
@@ -78,6 +78,7 @@ public:
     auto GetNotes() const -> QString;
 
     void ShowDialog(bool click) override;
+
 public slots:
     void ChosenObject(quint32 id, const SceneObject &type) override;
     /**
@@ -87,6 +88,7 @@ public slots:
     void PointNameChanged() override;
     void FXLength();
     void EvalFormula();
+
 protected:
     void ShowVisualization() override;
     /**
@@ -94,7 +96,9 @@ protected:
      */
     void SaveData() override;
     void closeEvent(QCloseEvent *event) override;
-    auto IsValid() const -> bool final;
+    void changeEvent(QEvent *event) override;
+    auto IsValid() const -> bool override;
+
 private:
     Q_DISABLE_COPY_MOVE(DialogShoulderPoint) // NOLINT
 
@@ -121,6 +125,10 @@ private:
     qint32 m_number{0};
 
     void ChosenThirdPoint(quint32 id);
+
+    void FinishCreating();
+
+    void InitIcons();
 };
 
 //---------------------------------------------------------------------------------------------------------------------
