@@ -29,7 +29,6 @@
 #ifndef DIALOGSINGLEPOINT_H
 #define DIALOGSINGLEPOINT_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QPointF>
@@ -40,35 +39,38 @@
 
 namespace Ui
 {
-    class DialogSinglePoint;
+class DialogSinglePoint;
 }
 
 /**
  * @brief The DialogSinglePoint class dialog for ToolSinglePoint. Help create point and edit option.
  */
-class DialogSinglePoint : public DialogTool
+class DialogSinglePoint final : public DialogTool
 {
     Q_OBJECT // NOLINT
+
 public:
-    DialogSinglePoint(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogSinglePoint() override;
+    DialogSinglePoint(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent = nullptr);
+    ~DialogSinglePoint() override;
 
-    void           SetData(const QString &name, const QPointF &point);
-    QPointF        GetPoint()const;
+    void SetData(const QString &name, const QPointF &point);
+    auto GetPoint() const -> QPointF;
 
-    QString        GetPointName() const;
+    auto GetPointName() const -> QString;
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
 
 public slots:
-    void           mousePress(const QPointF &scenePos);
+    void mousePress(const QPointF &scenePos);
+
 protected:
     /**
      * @brief SaveData Put dialog data in local variables
      */
-    virtual void   SaveData() override;
-    virtual bool   IsValid() const final;
+    void SaveData() override;
+    auto IsValid() const -> bool override;
+
 private:
     Q_DISABLE_COPY_MOVE(DialogSinglePoint) // NOLINT
 
@@ -84,7 +86,7 @@ private:
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool DialogSinglePoint::IsValid() const
+inline auto DialogSinglePoint::IsValid() const -> bool
 {
     return flagName;
 }
