@@ -54,8 +54,6 @@
 #include <QTimer>
 #include <QWidget>
 #include <QtDebug>
-#include <climits>
-#include <new>
 #include <qiterator.h>
 #include <qnumeric.h>
 
@@ -108,10 +106,7 @@ DialogTool::DialogTool(const VContainer *data, VAbstractPattern *doc, quint32 to
 //---------------------------------------------------------------------------------------------------------------------
 DialogTool::~DialogTool()
 {
-    if (not vis.isNull())
-    {
-        delete vis;
-    }
+    delete vis.data();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -203,9 +198,8 @@ void DialogTool::FillComboBoxSplines(QComboBox *box) const
     box->blockSignals(true);
 
     const auto *const objs = data->CalculationGObjects();
-    QHash<quint32, QSharedPointer<VGObject>>::const_iterator i;
     QMap<QString, quint32> list;
-    for (i = objs->constBegin(); i != objs->constEnd(); ++i)
+    for (auto i = objs->constBegin(); i != objs->constEnd(); ++i)
     {
         if (i.key() != toolId && IsSpline(i.value()))
         {
@@ -224,9 +218,8 @@ void DialogTool::FillComboBoxSplinesPath(QComboBox *box) const
     box->blockSignals(true);
 
     const auto *const objs = data->CalculationGObjects();
-    QHash<quint32, QSharedPointer<VGObject>>::const_iterator i;
     QMap<QString, quint32> list;
-    for (i = objs->constBegin(); i != objs->constEnd(); ++i)
+    for (auto i = objs->constBegin(); i != objs->constEnd(); ++i)
     {
         if (i.key() != toolId && IsSplinePath(i.value()))
         {
@@ -244,8 +237,7 @@ void DialogTool::FillComboBoxCurves(QComboBox *box) const
     SCASSERT(box != nullptr)
     const auto *const objs = data->CalculationGObjects();
     QMap<QString, quint32> list;
-    QHash<quint32, QSharedPointer<VGObject>>::const_iterator i;
-    for (i = objs->constBegin(); i != objs->constEnd(); ++i)
+    for (auto i = objs->constBegin(); i != objs->constEnd(); ++i)
     {
         if (i.key() != toolId)
         {
@@ -283,28 +275,6 @@ void DialogTool::FillComboBoxTypeLine(QComboBox *box, const QMap<QString, QIcon>
     }
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-void DialogTool::FillComboBoxLineColors(QComboBox *box) const
-{
-    FillComboBoxLineColors(box, VAbstractTool::ColorsList());
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-void DialogTool::FillComboBoxLineColors(QComboBox *box, const QMap<QString, QString> &lineColors) const
-{
-    SCASSERT(box != nullptr)
-
-    box->clear();
-
-    QMap<QString, QString>::const_iterator i = lineColors.constBegin();
-    while (i != lineColors.constEnd())
-    {
-        box->addItem(LineColor(box->palette().color(QPalette::Text), box->iconSize().height(), i.key()), i.value(),
-                     QVariant(i.key()));
-        ++i;
-    }
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 void DialogTool::FillComboBoxCrossCirclesPoints(QComboBox *box) const
 {
@@ -624,7 +594,7 @@ void DialogTool::FillList(QComboBox *box, const QMap<QString, quint32> &list) co
     SCASSERT(box != nullptr)
     box->clear();
 
-    QMapIterator<QString, quint32> iter(list);
+    QMapIterator iter(list);
     while (iter.hasNext())
     {
         iter.next();
@@ -780,9 +750,8 @@ void DialogTool::FillCombo(QComboBox *box, GOType gType, FillComboBox rule, cons
     box->blockSignals(true);
 
     const QHash<quint32, QSharedPointer<VGObject>> *objs = data->CalculationGObjects();
-    QHash<quint32, QSharedPointer<VGObject>>::const_iterator i;
     QMap<QString, quint32> list;
-    for (i = objs->constBegin(); i != objs->constEnd(); ++i)
+    for (auto i = objs->constBegin(); i != objs->constEnd(); ++i)
     {
         if (rule == FillComboBox::NoChildren)
         {
