@@ -35,8 +35,8 @@
 #include <QPointer>
 #include <QSet>
 
-#include "../../visualization/visualization.h"
 #include "../../visualization/line/vistooltriangle.h"
+#include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "dialogtool.h"
 #include "ui_dialogtriangle.h"
@@ -47,19 +47,19 @@
  * @param data container with data
  * @param parent parent widget
  */
-DialogTriangle::DialogTriangle(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogTriangle),
-      pointName(),
-      flagName(false),
-      flagError(false)
+DialogTriangle::DialogTriangle(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogTriangle),
+    pointName(),
+    flagName(false),
+    flagError(false)
 {
     ui->setupUi(this);
 
     ui->lineEditNamePoint->setClearButtonEnabled(true);
 
     ui->lineEditNamePoint->setText(
-                VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
 
     InitOkCancelApply(ui);
 
@@ -68,19 +68,16 @@ DialogTriangle::DialogTriangle(const VContainer *data, quint32 toolId, QWidget *
     FillComboBoxPoints(ui->comboBoxFirstPoint);
     FillComboBoxPoints(ui->comboBoxSecondPoint);
 
-    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
-    {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
-        CheckState();
-    });
-    connect(ui->comboBoxFirstPoint, &QComboBox::currentTextChanged,
-            this, &DialogTriangle::PointNameChanged);
-    connect(ui->comboBoxSecondPoint, &QComboBox::currentTextChanged,
-            this, &DialogTriangle::PointNameChanged);
-    connect(ui->comboBoxAxisP1, &QComboBox::currentTextChanged,
-            this, &DialogTriangle::PointNameChanged);
-    connect(ui->comboBoxAxisP2, &QComboBox::currentTextChanged,
-            this, &DialogTriangle::PointNameChanged);
+    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
+                CheckState();
+            });
+    connect(ui->comboBoxFirstPoint, &QComboBox::currentTextChanged, this, &DialogTriangle::PointNameChanged);
+    connect(ui->comboBoxSecondPoint, &QComboBox::currentTextChanged, this, &DialogTriangle::PointNameChanged);
+    connect(ui->comboBoxAxisP1, &QComboBox::currentTextChanged, this, &DialogTriangle::PointNameChanged);
+    connect(ui->comboBoxAxisP2, &QComboBox::currentTextChanged, this, &DialogTriangle::PointNameChanged);
 
     vis = new VisToolTriangle(data);
 
@@ -102,74 +99,63 @@ DialogTriangle::~DialogTriangle()
  */
 void DialogTriangle::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (prepare == false && type == SceneObject::Point) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
+        auto *line = qobject_cast<VisToolTriangle *>(vis);
+        SCASSERT(line != nullptr)
+
+        switch (number)
         {
-            VisToolTriangle *line = qobject_cast<VisToolTriangle *>(vis);
-            SCASSERT(line != nullptr)
-
-            switch (number)
+            case (0):
+                if (SetObject(id, ui->comboBoxAxisP1, tr("Select second point of axis")))
+                {
+                    number++;
+                    line->VisualMode(id);
+                }
+                break;
+            case (1):
+                if (getCurrentObjectId(ui->comboBoxAxisP1) != id &&
+                    SetObject(id, ui->comboBoxAxisP2, tr("Select first point")))
+                {
+                    number++;
+                    line->SetObject2Id(id);
+                    line->RefreshGeometry();
+                }
+                break;
+            case (2):
             {
-                case (0):
-                    if (SetObject(id, ui->comboBoxAxisP1, tr("Select second point of axis")))
-                    {
-                        number++;
-                        line->VisualMode(id);
-                    }
-                    break;
-                case (1):
-                    if (getCurrentObjectId(ui->comboBoxAxisP1) != id)
-                    {
-                        if (SetObject(id, ui->comboBoxAxisP2, tr("Select first point")))
-                        {
-                            number++;
-                            line->SetObject2Id(id);
-                            line->RefreshGeometry();
-                        }
-                    }
-                    break;
-                case (2):
-                {
-                    QSet<quint32> set;
-                    set.insert(getCurrentObjectId(ui->comboBoxAxisP1));
-                    set.insert(getCurrentObjectId(ui->comboBoxAxisP2));
-                    set.insert(id);
+                QSet<quint32> set;
+                set.insert(getCurrentObjectId(ui->comboBoxAxisP1));
+                set.insert(getCurrentObjectId(ui->comboBoxAxisP2));
+                set.insert(id);
 
-                    if (set.size() == 3)
-                    {
-                        if (SetObject(id, ui->comboBoxFirstPoint, tr("Select second point")))
-                        {
-                            number++;
-                            line->SetHypotenuseP1Id(id);
-                            line->RefreshGeometry();
-                        }
-                    }
-                }
-                    break;
-                case (3):
+                if (set.size() == 3 && SetObject(id, ui->comboBoxFirstPoint, tr("Select second point")))
                 {
-                    QSet<quint32> set;
-                    set.insert(getCurrentObjectId(ui->comboBoxAxisP1));
-                    set.insert(getCurrentObjectId(ui->comboBoxAxisP2));
-                    set.insert(getCurrentObjectId(ui->comboBoxFirstPoint));
-                    set.insert(id);
-
-                    if (set.size() == 4)
-                    {
-                        if (SetObject(id, ui->comboBoxSecondPoint, QString()))
-                        {
-                            line->SetHypotenuseP2Id(id);
-                            line->RefreshGeometry();
-                            prepare = true;
-                            DialogAccepted();
-                        }
-                    }
+                    number++;
+                    line->SetHypotenuseP1Id(id);
+                    line->RefreshGeometry();
                 }
-                    break;
-                default:
-                    break;
             }
+            break;
+            case (3):
+            {
+                QSet<quint32> set;
+                set.insert(getCurrentObjectId(ui->comboBoxAxisP1));
+                set.insert(getCurrentObjectId(ui->comboBoxAxisP2));
+                set.insert(getCurrentObjectId(ui->comboBoxFirstPoint));
+                set.insert(id);
+
+                if (set.size() == 4 && SetObject(id, ui->comboBoxSecondPoint, QString()))
+                {
+                    line->SetHypotenuseP2Id(id);
+                    line->RefreshGeometry();
+                    prepare = true;
+                    DialogAccepted();
+                }
+            }
+            break;
+            default:
+                break;
         }
     }
 }
@@ -179,7 +165,7 @@ void DialogTriangle::SaveData()
 {
     pointName = ui->lineEditNamePoint->text();
 
-    VisToolTriangle *line = qobject_cast<VisToolTriangle *>(vis);
+    auto *line = qobject_cast<VisToolTriangle *>(vis);
     SCASSERT(line != nullptr)
 
     line->SetObject1Id(GetAxisP1Id());
@@ -199,7 +185,7 @@ void DialogTriangle::PointNameChanged()
     set.insert(getCurrentObjectId(ui->comboBoxAxisP2));
 
     QColor color;
-    if (set.size() < 3)//Need tree or more unique points for creation triangle
+    if (set.size() < 3) // Need tree or more unique points for creation triangle
     {
         flagError = false;
         color = errorColor;
@@ -242,13 +228,13 @@ void DialogTriangle::SetSecondPointId(const quint32 &value)
 {
     setCurrentPointId(ui->comboBoxSecondPoint, value);
 
-    VisToolTriangle *line = qobject_cast<VisToolTriangle *>(vis);
+    auto *line = qobject_cast<VisToolTriangle *>(vis);
     SCASSERT(line != nullptr)
     line->SetHypotenuseP2Id(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogTriangle::GetPointName() const
+auto DialogTriangle::GetPointName() const -> QString
 {
     return pointName;
 }
@@ -262,7 +248,7 @@ void DialogTriangle::SetFirstPointId(const quint32 &value)
 {
     setCurrentPointId(ui->comboBoxFirstPoint, value);
 
-    VisToolTriangle *line = qobject_cast<VisToolTriangle *>(vis);
+    auto *line = qobject_cast<VisToolTriangle *>(vis);
     SCASSERT(line != nullptr)
     line->SetHypotenuseP1Id(value);
 }
@@ -276,7 +262,7 @@ void DialogTriangle::SetAxisP2Id(const quint32 &value)
 {
     setCurrentPointId(ui->comboBoxAxisP2, value);
 
-    VisToolTriangle *line = qobject_cast<VisToolTriangle *>(vis);
+    auto *line = qobject_cast<VisToolTriangle *>(vis);
     SCASSERT(line != nullptr)
     line->SetObject2Id(value);
 }
@@ -290,7 +276,7 @@ void DialogTriangle::SetAxisP1Id(const quint32 &value)
 {
     setCurrentPointId(ui->comboBoxAxisP1, value);
 
-    VisToolTriangle *line = qobject_cast<VisToolTriangle *>(vis);
+    auto *line = qobject_cast<VisToolTriangle *>(vis);
     SCASSERT(line != nullptr)
     line->SetObject1Id(value);
 }
@@ -300,7 +286,7 @@ void DialogTriangle::SetAxisP1Id(const quint32 &value)
  * @brief GetAxisP1Id return id first point of axis
  * @return id
  */
-quint32 DialogTriangle::GetAxisP1Id() const
+auto DialogTriangle::GetAxisP1Id() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxAxisP1);
 }
@@ -310,7 +296,7 @@ quint32 DialogTriangle::GetAxisP1Id() const
  * @brief GetAxisP2Id return id second point of axis
  * @return id
  */
-quint32 DialogTriangle::GetAxisP2Id() const
+auto DialogTriangle::GetAxisP2Id() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxAxisP2);
 }
@@ -320,7 +306,7 @@ quint32 DialogTriangle::GetAxisP2Id() const
  * @brief GetFirstPointId return id of first point
  * @return id
  */
-quint32 DialogTriangle::GetFirstPointId() const
+auto DialogTriangle::GetFirstPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxFirstPoint);
 }
@@ -330,7 +316,7 @@ quint32 DialogTriangle::GetFirstPointId() const
  * @brief GetSecondPointId return id of second point
  * @return id
  */
-quint32 DialogTriangle::GetSecondPointId() const
+auto DialogTriangle::GetSecondPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxSecondPoint);
 }
@@ -342,7 +328,7 @@ void DialogTriangle::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogTriangle::GetNotes() const
+auto DialogTriangle::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
