@@ -33,32 +33,33 @@
 
 namespace Ui
 {
-    class DialogPin;
+class DialogPin;
 }
 
-class DialogPin : public DialogTool
+class DialogPin final : public DialogTool
 {
     Q_OBJECT // NOLINT
+
 public:
-    explicit DialogPin(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogPin();
+    explicit DialogPin(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent = nullptr);
+    ~DialogPin() override;
 
     void EnbleShowMode(bool disable);
 
-    quint32 GetPieceId() const;
-    void    SetPieceId(quint32 id);
+    auto GetPieceId() const -> quint32;
+    void SetPieceId(quint32 id);
 
-    quint32 GetPointId() const;
-    void    SetPointId(quint32 id);
+    auto GetPointId() const -> quint32;
+    void SetPointId(quint32 id);
 
-    virtual void SetPiecesList(const QVector<quint32> &list) override;
+    void SetPiecesList(const QVector<quint32> &list) override;
 
 public slots:
-    virtual void ChosenObject(quint32 id, const SceneObject &type) override;
+    void ChosenObject(quint32 id, const SceneObject &type) override;
 
 protected:
-    virtual void ShowVisualization() override;
-    virtual bool IsValid() const final;
+    void ShowVisualization() override;
+    auto IsValid() const -> bool override;
 
 private:
     Q_DISABLE_COPY_MOVE(DialogPin) // NOLINT
@@ -72,7 +73,7 @@ private:
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool DialogPin::IsValid() const
+inline auto DialogPin::IsValid() const -> bool
 {
     return m_flagPoint && m_flagError;
 }
