@@ -72,15 +72,7 @@ public slots:
     void ShowDialog(bool click) override;
 
 protected:
-    /** @brief SaveData Put dialog data in local variables */
-    void SaveData() override;
-    void CheckState() override;
-    void closeEvent(QCloseEvent *event) override;
-    void showEvent(QShowEvent *event) override;
-    void resizeEvent(QResizeEvent *event) override;
-    void changeEvent(QEvent *event) override;
-    auto IsValid() const -> bool override;
-    void SetPatternDoc(VAbstractPattern *doc) override;
+    auto eventFilter(QObject *obj, QEvent *event) -> bool override;
 
 private slots:
     void NameDetailChanged();
@@ -179,6 +171,7 @@ private slots:
 
     void EditPieceLabel();
     void SetMoveControls();
+    void SetOptionControls();
 
     void PatternLabelDataChanged();
     void EditPatternLabel();
@@ -392,6 +385,16 @@ private:
     void InitFoldHeightFormula(const VPiece &piece);
     void InitFoldWidthFormula(const VPiece &piece);
     void InitFoldCenterFormula(const VPiece &piece);
+
+    /** @brief SaveData Put dialog data in local variables */
+    void SaveData() override;
+    void CheckState() override;
+    void closeEvent(QCloseEvent *event) override;
+    void showEvent(QShowEvent *event) override;
+    void resizeEvent(QResizeEvent *event) override;
+    void changeEvent(QEvent *event) override;
+    auto IsValid() const -> bool override;
+    void SetPatternDoc(VAbstractPattern *doc) override;
 };
 
 //---------------------------------------------------------------------------------------------------------------------
