@@ -50,6 +50,12 @@
 #include <QMessageBox>
 #include <QUndoStack>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
+#include "../vmisc/backport/qpainterstateguard.h"
+#else
+#include <QPainterStateGuard>
+#endif
+
 //---------------------------------------------------------------------------------------------------------------------
 VBackgroundImageItem::VBackgroundImageItem(const VBackgroundPatternImage &image, VAbstractPattern *doc,
                                            QGraphicsItem *parent)
@@ -153,14 +159,12 @@ void VBackgroundImageItem::paint(QPainter *painter, const QStyleOptionGraphicsIt
 
     if (m_showHover)
     {
-        painter->save();
+        QPainterStateGuard const guard(painter);
 
         QBrush const brush(QColor(177, 216, 250, 25));
         painter->setBrush(brush);
 
         painter->drawRect(boundingRect());
-
-        painter->restore();
     }
 }
 
@@ -445,7 +449,7 @@ void VBackgroundImageItem::contextMenuEvent(QGraphicsSceneContextMenuEvent *even
     QAction *actionReset = menu.addAction(tr("Reset transformation"));
     actionReset->setEnabled(not m_image.Hold());
 
-    QAction *actionRemove = menu.addAction(FromTheme(VThemeIcon::EditDelete), tr("Delete"));
+    const QAction *actionRemove = menu.addAction(FromTheme(VThemeIcon::EditDelete), tr("Delete"));
 
     QAction *selectedAction = menu.exec(event->screenPos());
     if (selectedAction == holdOption)
