@@ -64,7 +64,7 @@ void VAbstractFlipping::CreateDestination(VAbstractOperationInitData &initData,
             QT_WARNING_DISABLE_GCC("-Wswitch-default")
             QT_WARNING_DISABLE_CLANG("-Wswitch-default")
 
-            switch (static_cast<GOType>(obj->getType()))
+            switch (obj->getType())
             {
                 case GOType::Point:
                     initData.destination.append(
@@ -117,7 +117,7 @@ void VAbstractFlipping::CreateDestination(VAbstractOperationInitData &initData,
             QT_WARNING_DISABLE_GCC("-Wswitch-default")
             QT_WARNING_DISABLE_CLANG("-Wswitch-default")
 
-            switch (static_cast<GOType>(obj->getType()))
+            switch (obj->getType())
             {
                 case GOType::Point:
                 {
