@@ -35,53 +35,55 @@
 
 struct VToolFlippingByAxisInitData : VAbstractOperationInitData
 {
-    VToolFlippingByAxisInitData()
-        : VAbstractOperationInitData(),
-          originPointId(NULL_ID),
-          axisType(AxisType::VerticalAxis)
-    {}
-
-    quint32 originPointId;
-    AxisType axisType;
+    quint32 originPointId{NULL_ID};
+    AxisType axisType{AxisType::VerticalAxis};
 };
 
 class VToolFlippingByAxis : public VAbstractFlipping
 {
     Q_OBJECT // NOLINT
+
 public:
-    virtual ~VToolFlippingByAxis() = default;
-    virtual void setDialog() override;
-    static VToolFlippingByAxis* Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene,
-                                       VAbstractPattern *doc, VContainer *data);
-    static VToolFlippingByAxis* Create(VToolFlippingByAxisInitData initData);
+    ~VToolFlippingByAxis() override = default;
+
+    void SetDialog() override;
+
+    static auto Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
+                       VContainer *data) -> VToolFlippingByAxis *;
+    static auto Create(VToolFlippingByAxisInitData initData) -> VToolFlippingByAxis *;
 
     static const QString ToolType;
 
-    virtual int type() const override {return Type;}
-    enum { Type = UserType + static_cast<int>(Tool::FlippingByAxis)};
+    auto type() const -> int override { return Type; }
+    enum
+    {
+        Type = UserType + static_cast<int>(Tool::FlippingByAxis)
+    };
 
-    AxisType GetAxisType() const;
-    void     SetAxisType(AxisType value);
+    auto GetAxisType() const -> AxisType;
+    void SetAxisType(AxisType value);
 
-    QString OriginPointName() const;
+    auto OriginPointName() const -> QString;
+
+    void ShowVisualization(bool show) override;
 
-    virtual void ShowVisualization(bool show) override;
 protected slots:
-    virtual void ShowContextMenu(QGraphicsSceneContextMenuEvent *event, quint32 id=NULL_ID) override;
+    void ShowContextMenu(QGraphicsSceneContextMenuEvent *event, quint32 id = NULL_ID) override;
+
 protected:
-    virtual void    SetVisualization() override;
-    virtual void    SaveDialog(QDomElement &domElement, QList<quint32> &oldDependencies,
-                               QList<quint32> &newDependencies) override;
-    virtual void    ReadToolAttributes(const QDomElement &domElement) override;
-    virtual void    SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &obj) override;
-    virtual QString MakeToolTip() const override;
+    void SetVisualization() override;
+    void SaveDialog(QDomElement &domElement, QList<quint32> &oldDependencies, QList<quint32> &newDependencies) override;
+    void ReadToolAttributes(const QDomElement &domElement) override;
+    void SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &obj) override;
+    auto MakeToolTip() const -> QString override;
+
 private:
     Q_DISABLE_COPY_MOVE(VToolFlippingByAxis) // NOLINT
 
-    quint32  m_originPointId;
+    quint32 m_originPointId;
     AxisType m_axisType;
 
-    VToolFlippingByAxis(const VToolFlippingByAxisInitData &initData, QGraphicsItem *parent = nullptr);
+    explicit VToolFlippingByAxis(const VToolFlippingByAxisInitData &initData, QGraphicsItem *parent = nullptr);
 };
 
 #endif // VTOOLFLIPPINGBYAXIS_H
