@@ -216,8 +216,7 @@ auto VAbstractOperation::ExtractSourceData(const QDomElement &domElement) -> QVe
             const QDomNodeList srcList = dataElement.childNodes();
             for (qint32 j = 0; j < srcList.size(); ++j)
             {
-                const QDomElement element = srcList.at(j).toElement();
-                if (not element.isNull())
+                if (const QDomElement element = srcList.at(j).toElement(); not element.isNull())
                 {
                     SourceItem item;
                     item.id = VDomDocument::GetParametrUInt(element, AttrIdObject, NULL_ID_STR);
@@ -247,8 +246,7 @@ auto VAbstractOperation::ExtractDestinationData(const QDomElement &domElement) -
             const QDomNodeList srcList = dataElement.childNodes();
             for (qint32 j = 0; j < srcList.size(); ++j)
             {
-                const QDomElement element = srcList.at(j).toElement();
-                if (not element.isNull())
+                if (const QDomElement element = srcList.at(j).toElement(); not element.isNull())
                 {
                     DestinationItem d;
                     d.id = VDomDocument::GetParametrUInt(element, AttrIdObject, NULL_ID_STR);
@@ -272,7 +270,7 @@ auto VAbstractOperation::ExtractDestinationData(const QDomElement &domElement) -
 auto VAbstractOperation::OperationColorsList() -> QMap<QString, QString>
 {
     QMap<QString, QString> list = VAbstractTool::ColorsList();
-    list.insert(ColorDefault, '<' + QCoreApplication::translate("VAbstractOperation", "default") + '>');
+    list.insert(ColorDefault, QCoreApplication::translate("VAbstractOperation", "default"));
     return list;
 }
 
@@ -280,7 +278,7 @@ auto VAbstractOperation::OperationColorsList() -> QMap<QString, QString>
 void VAbstractOperation::FullUpdateFromFile()
 {
     ReadAttributes();
-    QMapIterator<quint32, VAbstractSimple *> i(operatedObjects);
+    QMapIterator i(operatedObjects);
     while (i.hasNext())
     {
         i.next();
@@ -305,7 +303,7 @@ void VAbstractOperation::FullUpdateFromFile()
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractOperation::AllowHover(bool enabled)
 {
-    QMapIterator<quint32, VAbstractSimple *> i(operatedObjects);
+    QMapIterator i(operatedObjects);
     while (i.hasNext())
     {
         i.next();
@@ -327,7 +325,7 @@ void VAbstractOperation::AllowHover(bool enabled)
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractOperation::AllowSelecting(bool enabled)
 {
-    QMapIterator<quint32, VAbstractSimple *> i(operatedObjects);
+    QMapIterator i(operatedObjects);
     while (i.hasNext())
     {
         i.next();
@@ -349,7 +347,7 @@ void VAbstractOperation::AllowSelecting(bool enabled)
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractOperation::EnableToolMove(bool move)
 {
-    QMapIterator<quint32, VAbstractSimple *> i(operatedObjects);
+    QMapIterator i(operatedObjects);
     while (i.hasNext())
     {
         i.next();
@@ -365,7 +363,7 @@ void VAbstractOperation::EnableToolMove(bool move)
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractOperation::AllowPointHover(bool enabled)
 {
-    QMapIterator<quint32, VAbstractSimple *> i(operatedObjects);
+    QMapIterator i(operatedObjects);
     while (i.hasNext())
     {
         i.next();
@@ -381,7 +379,7 @@ void VAbstractOperation::AllowPointHover(bool enabled)
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractOperation::AllowPointSelecting(bool enabled)
 {
-    QMapIterator<quint32, VAbstractSimple *> i(operatedObjects);
+    QMapIterator i(operatedObjects);
     while (i.hasNext())
     {
         i.next();
@@ -397,7 +395,7 @@ void VAbstractOperation::AllowPointSelecting(bool enabled)
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractOperation::AllowPointLabelHover(bool enabled)
 {
-    QMapIterator<quint32, VAbstractSimple *> i(operatedObjects);
+    QMapIterator i(operatedObjects);
     while (i.hasNext())
     {
         i.next();
@@ -413,7 +411,7 @@ void VAbstractOperation::AllowPointLabelHover(bool enabled)
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractOperation::AllowPointLabelSelecting(bool enabled)
 {
-    QMapIterator<quint32, VAbstractSimple *> i(operatedObjects);
+    QMapIterator i(operatedObjects);
     while (i.hasNext())
     {
         i.next();
@@ -482,7 +480,7 @@ void VAbstractOperation::AllowElArcSelecting(bool enabled)
 void VAbstractOperation::ToolSelectionType(const SelectionType &type)
 {
     VAbstractTool::ToolSelectionType(type);
-    QMapIterator<quint32, VAbstractSimple *> i(operatedObjects);
+    QMapIterator i(operatedObjects);
     while (i.hasNext())
     {
         i.next();
@@ -501,7 +499,7 @@ void VAbstractOperation::Disable(bool disable, const QString &namePP)
     const bool enabled = !CorrectDisable(disable, namePP);
     setEnabled(enabled);
 
-    QMapIterator<quint32, VAbstractSimple *> i(operatedObjects);
+    QMapIterator i(operatedObjects);
     while (i.hasNext())
     {
         i.next();
@@ -566,7 +564,7 @@ VAbstractOperation::VAbstractOperation(const VAbstractOperationInitData &initDat
     connect(initData.doc, &VAbstractPattern::UpdateToolTip, this,
             [this]()
             {
-                QMapIterator<quint32, VAbstractSimple *> i(operatedObjects);
+                QMapIterator i(operatedObjects);
                 while (i.hasNext())
                 {
                     i.next();
@@ -710,7 +708,7 @@ void VAbstractOperation::ReadToolAttributes(const QDomElement &domElement)
 
     source = ExtractSourceData(domElement);
     destination = ExtractDestinationData(domElement);
-    suffix = doc->GetParametrString(domElement, AttrSuffix);
+    suffix = VDomDocument::GetParametrString(domElement, AttrSuffix);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -814,7 +812,7 @@ void VAbstractOperation::InitCurve(quint32 id, VContainer *data, GOType curveTyp
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractOperation::AllowCurveHover(bool enabled, GOType type)
 {
-    QMapIterator<quint32, VAbstractSimple *> i(operatedObjects);
+    QMapIterator i(operatedObjects);
     while (i.hasNext())
     {
         i.next();
@@ -833,7 +831,7 @@ void VAbstractOperation::AllowCurveHover(bool enabled, GOType type)
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractOperation::AllowCurveSelecting(bool enabled, GOType type)
 {
-    QMapIterator<quint32, VAbstractSimple *> i(operatedObjects);
+    QMapIterator i(operatedObjects);
     while (i.hasNext())
     {
         i.next();
@@ -890,7 +888,7 @@ void VAbstractOperation::InitOperatedObjects()
         QT_WARNING_DISABLE_GCC("-Wswitch-default")
         QT_WARNING_DISABLE_CLANG("-Wswitch-default")
 
-        switch (static_cast<GOType>(obj->getType()))
+        switch (obj->getType())
         {
             case GOType::Point:
             {
@@ -983,9 +981,10 @@ void VAbstractOperation::CreateVisibilityGroup(const VAbstractOperationInitData
 
     const QMap<quint32, quint32> groupData = VisibilityGroupDataFromSource(initData.data, initData.source);
     vidtype const groupId = initData.data->getNextId();
-    const QDomElement group = initData.doc->CreateGroup(groupId, initData.visibilityGroupName,
-                                                        initData.visibilityGroupTags, groupData, initData.id);
-    if (not group.isNull())
+
+    if (const QDomElement group = initData.doc->CreateGroup(groupId, initData.visibilityGroupName,
+                                                            initData.visibilityGroupTags, groupData, initData.id);
+        not group.isNull())
     {
         auto *addGroup = new AddGroup(group, initData.doc);
         connect(addGroup, &AddGroup::UpdateGroups, initData.doc, &VAbstractPattern::UpdateVisiblityGroups);
