@@ -154,7 +154,7 @@ auto VToolRotation::Create(VToolRotationInitData &initData) -> VToolRotation *
             QT_WARNING_DISABLE_GCC("-Wswitch-default")
             QT_WARNING_DISABLE_CLANG("-Wswitch-default")
 
-            switch (static_cast<GOType>(obj->getType()))
+            switch (obj->getType())
             {
                 case GOType::Point:
                     initData.destination.append(
@@ -207,7 +207,7 @@ auto VToolRotation::Create(VToolRotationInitData &initData) -> VToolRotation *
             QT_WARNING_DISABLE_GCC("-Wswitch-default")
             QT_WARNING_DISABLE_CLANG("-Wswitch-default")
 
-            switch (static_cast<GOType>(obj->getType()))
+            switch (obj->getType())
             {
                 case GOType::Point:
                 {
@@ -376,8 +376,8 @@ void VToolRotation::ReadToolAttributes(const QDomElement &domElement)
 {
     VAbstractOperation::ReadToolAttributes(domElement);
 
-    origPointId = doc->GetParametrUInt(domElement, AttrCenter, NULL_ID_STR);
-    formulaAngle = doc->GetParametrString(domElement, AttrAngle, QChar('0'));
+    origPointId = VAbstractPattern::GetParametrUInt(domElement, AttrCenter, NULL_ID_STR);
+    formulaAngle = VDomDocument::GetParametrString(domElement, AttrAngle, QChar('0'));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
