@@ -29,7 +29,6 @@
 #ifndef VTOOLROTATION_H
 #define VTOOLROTATION_H
 
-#include <qcompilerdetection.h>
 #include <QMap>
 #include <QMetaObject>
 #include <QObject>
@@ -37,10 +36,10 @@
 #include <QVector>
 #include <QtGlobal>
 
-#include "vabstractoperation.h"
+#include "../ifc/xml/vabstractpattern.h"
 #include "../vgeometry/vgeometrydef.h"
 #include "../vmisc/def.h"
-#include "../ifc/xml/vabstractpattern.h"
+#include "vabstractoperation.h"
 
 template <class T> class QSharedPointer;
 class VFormula;
@@ -48,10 +47,11 @@ class VFormula;
 struct VToolRotationInitData : VAbstractOperationInitData
 {
     VToolRotationInitData()
-        : VAbstractOperationInitData(),
-          origin(NULL_ID),
-          angle()
-    {}
+      : VAbstractOperationInitData(),
+        origin(NULL_ID),
+        angle()
+    {
+    }
 
     quint32 origin;
     QString angle;
@@ -60,56 +60,63 @@ struct VToolRotationInitData : VAbstractOperationInitData
 class VToolRotation : public VAbstractOperation
 {
     Q_OBJECT // NOLINT
+
 public:
-    virtual ~VToolRotation() = default;
-    virtual void setDialog() override;
-    static VToolRotation* Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
-                                 VContainer *data);
-    static VToolRotation* Create(VToolRotationInitData &initData);
+    ~VToolRotation() override = default;
+
+    void SetDialog() override;
+
+    static auto Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
+                       VContainer *data) -> VToolRotation *;
+    static auto Create(VToolRotationInitData &initData) -> VToolRotation *;
 
     static const QString ToolType;
 
-    virtual int type() const override {return Type;}
-    enum { Type = UserType + static_cast<int>(Tool::Rotation)};
+    auto type() const -> int override { return Type; }
+    enum
+    {
+        Type = UserType + static_cast<int>(Tool::Rotation)
+    };
 
-    QString OriginPointName() const;
+    auto OriginPointName() const -> QString;
 
-    VFormula GetFormulaAngle() const;
-    void     SetFormulaAngle(const VFormula &value);
+    auto GetFormulaAngle() const -> VFormula;
+    void SetFormulaAngle(const VFormula &value);
+
+    void ShowVisualization(bool show) override;
 
-    virtual void ShowVisualization(bool show) override;
 protected slots:
-    virtual void ShowContextMenu(QGraphicsSceneContextMenuEvent *event, quint32 id=NULL_ID) override;
+    void ShowContextMenu(QGraphicsSceneContextMenuEvent *event, quint32 id = NULL_ID) override;
+
 protected:
-    virtual void    SetVisualization() override;
-    virtual void    SaveDialog(QDomElement &domElement, QList<quint32> &oldDependencies,
-                               QList<quint32> &newDependencies) override;
-    virtual void    ReadToolAttributes(const QDomElement &domElement) override;
-    virtual void    SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &obj) override;
-    virtual QString MakeToolTip() const override;
+    void SetVisualization() override;
+    void SaveDialog(QDomElement &domElement, QList<quint32> &oldDependencies, QList<quint32> &newDependencies) override;
+    void ReadToolAttributes(const QDomElement &domElement) override;
+    void SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &obj) override;
+    auto MakeToolTip() const -> QString override;
 
 private:
     Q_DISABLE_COPY_MOVE(VToolRotation) // NOLINT
     quint32 origPointId;
     QString formulaAngle;
 
-    VToolRotation(const VToolRotationInitData &initData, QGraphicsItem *parent = nullptr);
+    explicit VToolRotation(const VToolRotationInitData &initData, QGraphicsItem *parent = nullptr);
 
-    static DestinationItem CreatePoint(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
-                                       const QString &suffix, VContainer *data);
+    static auto CreatePoint(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
+                            const QString &suffix, VContainer *data) -> DestinationItem;
 
     template <class Item>
-    static DestinationItem CreateItem(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
-                                                   const QString &suffix, VContainer *data);
+    static auto CreateItem(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
+                           const QString &suffix, VContainer *data) -> DestinationItem;
     template <class Item>
-    static DestinationItem CreateArc(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
-                                     const QString &suffix, VContainer *data);
+    static auto CreateArc(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
+                          const QString &suffix, VContainer *data) -> DestinationItem;
     template <class Item>
-    static DestinationItem CreateCurve(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
-                                       const QString &suffix, VContainer *data);
+    static auto CreateCurve(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
+                            const QString &suffix, VContainer *data) -> DestinationItem;
     template <class Item>
-    static DestinationItem CreateCurveWithSegments(quint32 idTool, const SourceItem &sItem, const QPointF &origin,
-                                                   qreal angle, const QString &suffix, VContainer *data);
+    static auto CreateCurveWithSegments(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
+                                        const QString &suffix, VContainer *data) -> DestinationItem;
 
     static void UpdatePoint(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
                             const QString &suffix, VContainer *data, const DestinationItem &item);
