@@ -88,7 +88,7 @@ public:
 
     auto name() const -> QString;
 
-    auto GetApproximationScale() const -> qreal;
+    virtual auto GetApproximationScale() const -> qreal;
 
     auto GetDuplicate() const -> quint32;
 
@@ -177,7 +177,7 @@ template <typename T> inline void VAbstractSpline::ShowToolVisualization(bool sh
     }
     else
     {
-        delete vis;
+        delete vis.data();
     }
 
     if (m_detailsMode)
