@@ -40,24 +40,21 @@
 #include <QPoint>
 #include <QRectF>
 #include <QSharedPointer>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
 #include <QUndoStack>
-#include <Qt>
-#include <new>
 #include <QtMath>
 
-#include "../../../dialogs/tools/dialogtool.h"
 #include "../../../dialogs/tools/dialogsplinepath.h"
+#include "../../../dialogs/tools/dialogtool.h"
 #include "../../../undocommands/movesplinepath.h"
 #include "../../../undocommands/vundocommand.h"
-#include "../../../visualization/visualization.h"
 #include "../../../visualization/path/vistoolsplinepath.h"
+#include "../../../visualization/visualization.h"
+#include "../../vabstracttool.h"
 #include "../ifc/exception/vexception.h"
-#include "../ifc/xml/vdomdocument.h"
 #include "../ifc/ifcdef.h"
+#include "../ifc/xml/vdomdocument.h"
 #include "../qmuparser/qmutokenparser.h"
+#include "../vdrawtool.h"
 #include "../vgeometry/vabstractcubicbezierpath.h"
 #include "../vgeometry/vabstractcurve.h"
 #include "../vgeometry/vgobject.h"
@@ -67,11 +64,9 @@
 #include "../vmisc/vabstractapplication.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vwidgets/../vgeometry/vsplinepath.h"
+#include "../vwidgets/global.h"
 #include "../vwidgets/vcontrolpointspline.h"
 #include "../vwidgets/vmaingraphicsscene.h"
-#include "../vwidgets/global.h"
-#include "../../vabstracttool.h"
-#include "../vdrawtool.h"
 #include "vabstractspline.h"
 
 const QString VToolSplinePath::ToolType = QStringLiteral("pathInteractive");
@@ -84,77 +79,15 @@ const QString VToolSplinePath::OldToolType = QStringLiteral("path");
  * @param parent parent object.
  */
 VToolSplinePath::VToolSplinePath(const VToolSplinePathInitData &initData, QGraphicsItem *parent)
-    : VAbstractSpline(initData.doc, initData.data, initData.id, initData.notes, parent),
-      oldPosition(),
-      splIndex(-1),
-      moved(false),
-      oldMoveSplinePath(),
-      newMoveSplinePath()
+  : VAbstractSpline(initData.doc, initData.data, initData.id, initData.notes, parent)
 {
-    sceneType = SceneObject::SplinePath;
+    SetSceneType(SceneObject::SplinePath);
 
     this->setFlag(QGraphicsItem::ItemIsMovable, true);
-    this->setFlag(QGraphicsItem::ItemIsFocusable, true);// For keyboard input focus
-
-    auto InitControlPoint = [this](VControlPointSpline* cPoint)
-    {
-        connect(cPoint, &VControlPointSpline::ControlPointChangePosition, this,
-                &VToolSplinePath::ControlPointChangePosition);
-        connect(this, &VToolSplinePath::setEnabledPoint, cPoint, &VControlPointSpline::setEnabledPoint);
-        connect(cPoint, &VControlPointSpline::ShowContextMenu, this, &VToolSplinePath::contextMenuEvent);
-        connect(cPoint, &VControlPointSpline::Released, this, &VToolSplinePath::CurveReleased);
-        connect(cPoint, &VControlPointSpline::Selected, this, &VToolSplinePath::CurveSelected);
-        controlPoints.append(cPoint);
-    };
+    this->setFlag(QGraphicsItem::ItemIsFocusable, true); // For keyboard input focus
 
     const QSharedPointer<VSplinePath> splPath = initData.data->GeometricObject<VSplinePath>(initData.id);
-    for (qint32 i = 1; i<=splPath->CountSubSpl(); ++i)
-    {
-        const VSpline spl = splPath->GetSpline(i);
-
-        bool freeAngle1 = true;
-
-        if (i > 1)
-        {
-            const VSpline prevSpl = splPath->GetSpline(i-1);
-            freeAngle1 = qmu::QmuTokenParser::IsSingle(spl.GetStartAngleFormula()) &&
-                         qmu::QmuTokenParser::IsSingle(prevSpl.GetEndAngleFormula());
-        }
-        else
-        {
-            freeAngle1 = qmu::QmuTokenParser::IsSingle(spl.GetStartAngleFormula());
-        }
-
-        const bool freeLength1 = qmu::QmuTokenParser::IsSingle(spl.GetC1LengthFormula());
-
-        auto *controlPoint = new VControlPointSpline(i, SplinePointPosition::FirstPoint,
-                                                     static_cast<QPointF>(spl.GetP2()), freeAngle1, freeLength1, this);
-        InitControlPoint(controlPoint);
-
-        bool freeAngle2 = true;
-
-        if (i < splPath->CountSubSpl())
-        {
-            const VSpline nextSpl = splPath->GetSpline(i+1);
-            freeAngle2 = qmu::QmuTokenParser::IsSingle(nextSpl.GetStartAngleFormula()) &&
-                         qmu::QmuTokenParser::IsSingle(spl.GetEndAngleFormula());
-        }
-        else
-        {
-            freeAngle2 = qmu::QmuTokenParser::IsSingle(spl.GetEndAngleFormula());
-        }
-
-        const bool freeLength2 = qmu::QmuTokenParser::IsSingle(spl.GetC2LengthFormula());
-
-        controlPoint = new VControlPointSpline(i, SplinePointPosition::LastPoint, static_cast<QPointF>(spl.GetP3()),
-                                               freeAngle2, freeLength2, this);
-        InitControlPoint(controlPoint);
-    }
-
-    VToolSplinePath::RefreshCtrlPoints();
-
-    ShowHandles(detailsMode);
-
+    InitControlPoints(splPath.data());
     ToolCreation(initData.typeCreation);
 }
 
@@ -162,7 +95,7 @@ VToolSplinePath::VToolSplinePath(const VToolSplinePathInitData &initData, QGraph
 /**
  * @brief setDialog set dialog when user want change tool option.
  */
-void VToolSplinePath::setDialog()
+void VToolSplinePath::SetDialog()
 {
     SCASSERT(not m_dialog.isNull())
     const QPointer<DialogSplinePath> dialogTool = qobject_cast<DialogSplinePath *>(m_dialog);
@@ -180,8 +113,8 @@ void VToolSplinePath::setDialog()
  * @param doc dom document container.
  * @param data container with variables.
  */
-VToolSplinePath* VToolSplinePath::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene,
-                                         VAbstractPattern *doc, VContainer *data)
+auto VToolSplinePath::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
+                             VContainer *data) -> VToolSplinePath *
 {
     SCASSERT(not dialog.isNull())
     const QPointer<DialogSplinePath> dialogTool = qobject_cast<DialogSplinePath *>(dialog);
@@ -195,13 +128,13 @@ VToolSplinePath* VToolSplinePath::Create(const QPointer<DialogTool> &dialog, VMa
     initData.typeCreation = Source::FromGui;
     initData.notes = dialogTool->GetNotes();
 
-    VSplinePath *path = new VSplinePath(dialogTool->GetPath());
+    auto *path = new VSplinePath(dialogTool->GetPath());
     for (qint32 i = 0; i < path->CountPoints(); ++i)
     {
         doc->IncrementReferens((*path)[i].P().getIdTool());
     }
 
-    VToolSplinePath* spl = Create(initData, path);
+    VToolSplinePath *spl = Create(initData, path);
     if (spl != nullptr)
     {
         spl->m_dialog = dialog;
@@ -215,7 +148,7 @@ VToolSplinePath* VToolSplinePath::Create(const QPointer<DialogTool> &dialog, VMa
  * @param initData init data.
  * @param path spline path.
  */
-VToolSplinePath* VToolSplinePath::Create(VToolSplinePathInitData &initData,  VSplinePath *path)
+auto VToolSplinePath::Create(VToolSplinePathInitData &initData, VSplinePath *path) -> VToolSplinePath *
 {
     if (initData.typeCreation == Source::FromGui)
     {
@@ -237,7 +170,7 @@ VToolSplinePath* VToolSplinePath::Create(VToolSplinePathInitData &initData,  VSp
     if (initData.parse == Document::FullParse)
     {
         VAbstractTool::AddRecord(initData.id, Tool::SplinePath, initData.doc);
-        VToolSplinePath *spl = new VToolSplinePath(initData);
+        auto *spl = new VToolSplinePath(initData);
         initData.scene->addItem(spl);
         InitSplinePathToolConnections(initData.scene, spl);
         VAbstractPattern::AddTool(initData.id, spl);
@@ -247,9 +180,9 @@ VToolSplinePath* VToolSplinePath::Create(VToolSplinePathInitData &initData,  VSp
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VToolSplinePath *VToolSplinePath::Create(VToolSplinePathInitData &initData)
+auto VToolSplinePath::Create(VToolSplinePathInitData &initData) -> VToolSplinePath *
 {
-    auto* path = new VSplinePath();
+    auto *path = new VSplinePath();
 
     if (initData.duplicate > 0)
     {
@@ -262,9 +195,9 @@ VToolSplinePath *VToolSplinePath::Create(VToolSplinePathInitData &initData)
         const qreal calcAngle2 = CheckFormula(initData.id, initData.a2[i], initData.data);
 
         const qreal calcLength1 =
-                VAbstractValApplication::VApp()->toPixel(CheckFormula(initData.id, initData.l1[i], initData.data));
+            VAbstractValApplication::VApp()->toPixel(CheckFormula(initData.id, initData.l1[i], initData.data));
         const qreal calcLength2 =
-                VAbstractValApplication::VApp()->toPixel(CheckFormula(initData.id, initData.l2[i], initData.data));
+            VAbstractValApplication::VApp()->toPixel(CheckFormula(initData.id, initData.l2[i], initData.data));
 
         const auto p = *initData.data->GeometricObject<VPointF>(initData.points.at(i));
 
@@ -298,7 +231,7 @@ void VToolSplinePath::ControlPointChangePosition(const qint32 &indexSpline, cons
         moved = true;
     }
 
-    QSharedPointer<VSplinePath> newSplPath = QSharedPointer<VSplinePath>::create(*oldSplPath);
+    auto newSplPath = QSharedPointer<VSplinePath>::create(*oldSplPath);
     const VSpline spl = CorrectedSpline(newSplPath->GetSpline(indexSpline), position, pos);
 
     UpdateControlPoints(spl, newSplPath, indexSpline);
@@ -325,12 +258,34 @@ void VToolSplinePath::EnableToolMove(bool move)
 {
     this->setFlag(QGraphicsItem::ItemIsMovable, move);
 
-    for (auto point : qAsConst(controlPoints))
+    for (auto *point : qAsConst(controlPoints))
     {
         point->setFlag(QGraphicsItem::ItemIsMovable, move);
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VToolSplinePath::AllowHover(bool enabled)
+{
+    VAbstractSpline::AllowHover(enabled);
+
+    for (auto *point : qAsConst(controlPoints))
+    {
+        point->setAcceptHoverEvents(enabled);
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VToolSplinePath::AllowSelecting(bool enabled)
+{
+    VAbstractSpline::AllowSelecting(enabled);
+
+    for (auto *point : qAsConst(controlPoints))
+    {
+        point->setFlag(QGraphicsItem::ItemIsSelectable, enabled);
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VToolSplinePath::ShowContextMenu(QGraphicsSceneContextMenuEvent *event, quint32 id)
 {
@@ -339,10 +294,23 @@ void VToolSplinePath::ShowContextMenu(QGraphicsSceneContextMenuEvent *event, qui
     {
         ContextMenu<DialogSplinePath>(event);
     }
-    catch(const VExceptionToolWasDeleted &e)
+    catch (const VExceptionToolWasDeleted &e)
     {
         Q_UNUSED(e)
-        return;//Leave this method immediately!!!
+        return; // Leave this method immediately!!!
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VToolSplinePath::CurveSelected(bool selected)
+{
+    setSelected(selected);
+
+    for (auto *point : qAsConst(controlPoints))
+    {
+        point->blockSignals(true);
+        point->setSelected(selected);
+        point->blockSignals(false);
     }
 }
 
@@ -358,9 +326,9 @@ void VToolSplinePath::UpdateControlPoints(const VSpline &spl, QSharedPointer<VSp
 {
     VSplinePoint p = splPath->GetSplinePoint(indexSpline, SplinePointPosition::FirstPoint);
 
-    if (indexSpline >1)
+    if (indexSpline > 1)
     {
-        VSpline prevSpline = splPath->GetSpline(indexSpline-1);
+        VSpline const prevSpline = splPath->GetSpline(indexSpline - 1);
         if (qmu::QmuTokenParser::IsSingle(prevSpline.GetEndAngleFormula()))
         {
             p.SetAngle2(spl.GetStartAngle(), spl.GetStartAngleFormula());
@@ -371,7 +339,6 @@ void VToolSplinePath::UpdateControlPoints(const VSpline &spl, QSharedPointer<VSp
         p.SetAngle2(spl.GetStartAngle(), spl.GetStartAngleFormula());
     }
 
-
     p.SetLength2(spl.GetC1Length(), spl.GetC1LengthFormula());
     splPath->UpdatePoint(indexSpline, SplinePointPosition::FirstPoint, p);
 
@@ -379,7 +346,7 @@ void VToolSplinePath::UpdateControlPoints(const VSpline &spl, QSharedPointer<VSp
 
     if (indexSpline < splPath->CountSubSpl())
     {
-        VSpline nextSpline = splPath->GetSpline(indexSpline+1);
+        VSpline const nextSpline = splPath->GetSpline(indexSpline + 1);
         if (qmu::QmuTokenParser::IsSingle(nextSpline.GetStartAngleFormula()))
         {
             p.SetAngle1(spl.GetEndAngle(), spl.GetEndAngleFormula());
@@ -399,7 +366,7 @@ void VToolSplinePath::SetSplinePathAttributes(QDomElement &domElement, const VSp
 {
     doc->SetAttribute(domElement, AttrType, ToolType);
     doc->SetAttributeOrRemoveIf<quint32>(domElement, AttrDuplicate, path.GetDuplicate(),
-                                         [](quint32 duplicate) noexcept {return duplicate == 0;});
+                                         [](quint32 duplicate) noexcept { return duplicate == 0; });
 
     if (domElement.hasAttribute(AttrKCurve))
     {
@@ -410,7 +377,7 @@ void VToolSplinePath::SetSplinePathAttributes(QDomElement &domElement, const VSp
     doc->SetAttribute(domElement, AttrPenStyle, path.GetPenStyle());
     doc->SetAttribute(domElement, AttrAScale, path.GetApproximationScale());
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrAlias, path.GetAliasSuffix(),
-                                         [](const QString &suffix) noexcept {return suffix.isEmpty();});
+                                         [](const QString &suffix) noexcept { return suffix.isEmpty(); });
 
     UpdatePathPoints(doc, domElement, path);
 }
@@ -418,11 +385,72 @@ void VToolSplinePath::SetSplinePathAttributes(QDomElement &domElement, const VSp
 //---------------------------------------------------------------------------------------------------------------------
 void VToolSplinePath::UndoCommandMove(const VSplinePath &oldPath, const VSplinePath &newPath)
 {
-    MoveSplinePath *moveSplPath = new MoveSplinePath(doc, oldPath, newPath, m_id);
+    auto *moveSplPath = new MoveSplinePath(doc, oldPath, newPath, m_id);
     connect(moveSplPath, &VUndoCommand::NeedLiteParsing, doc, &VAbstractPattern::LiteParseTree);
     VAbstractApplication::VApp()->getUndoStack()->push(moveSplPath);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VToolSplinePath::InitControlPoints(const VSplinePath *splPath)
+{
+    auto InitControlPoint = [this](VControlPointSpline *cPoint)
+    {
+        connect(cPoint, &VControlPointSpline::ControlPointChangePosition, this,
+                &VToolSplinePath::ControlPointChangePosition);
+        connect(this, &VToolSplinePath::setEnabledPoint, cPoint, &VControlPointSpline::setEnabledPoint);
+        connect(cPoint, &VControlPointSpline::ShowContextMenu, this, &VToolSplinePath::contextMenuEvent);
+        connect(cPoint, &VControlPointSpline::Released, this, &VToolSplinePath::CurveReleased);
+        connect(cPoint, &VControlPointSpline::Selected, this, &VToolSplinePath::CurveSelected);
+        controlPoints.append(cPoint);
+    };
+
+    for (qint32 i = 1; i <= splPath->CountSubSpl(); ++i)
+    {
+        const VSpline spl = splPath->GetSpline(i);
+
+        bool freeAngle1 = true;
+
+        if (i > 1)
+        {
+            const VSpline prevSpl = splPath->GetSpline(i - 1);
+            freeAngle1 = qmu::QmuTokenParser::IsSingle(spl.GetStartAngleFormula()) &&
+                         qmu::QmuTokenParser::IsSingle(prevSpl.GetEndAngleFormula());
+        }
+        else
+        {
+            freeAngle1 = qmu::QmuTokenParser::IsSingle(spl.GetStartAngleFormula());
+        }
+
+        const bool freeLength1 = qmu::QmuTokenParser::IsSingle(spl.GetC1LengthFormula());
+
+        auto *controlPoint = new VControlPointSpline(i, SplinePointPosition::FirstPoint,
+                                                     static_cast<QPointF>(spl.GetP2()), freeAngle1, freeLength1, this);
+        InitControlPoint(controlPoint);
+
+        bool freeAngle2 = true;
+
+        if (i < splPath->CountSubSpl())
+        {
+            const VSpline nextSpl = splPath->GetSpline(i + 1);
+            freeAngle2 = qmu::QmuTokenParser::IsSingle(nextSpl.GetStartAngleFormula()) &&
+                         qmu::QmuTokenParser::IsSingle(spl.GetEndAngleFormula());
+        }
+        else
+        {
+            freeAngle2 = qmu::QmuTokenParser::IsSingle(spl.GetEndAngleFormula());
+        }
+
+        const bool freeLength2 = qmu::QmuTokenParser::IsSingle(spl.GetC2LengthFormula());
+
+        controlPoint = new VControlPointSpline(i, SplinePointPosition::LastPoint, static_cast<QPointF>(spl.GetP3()),
+                                               freeAngle2, freeLength2, this);
+        InitControlPoint(controlPoint);
+    }
+
+    VToolSplinePath::RefreshCtrlPoints();
+    VToolSplinePath::ShowHandles(IsDetailsMode());
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief UpdatePathPoints update spline path in pattern file.
@@ -440,9 +468,9 @@ void VToolSplinePath::UpdatePathPoints(VAbstractPattern *doc, QDomElement &eleme
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VSplinePath VToolSplinePath::getSplinePath() const
+auto VToolSplinePath::getSplinePath() const -> VSplinePath
 {
-    QSharedPointer<VSplinePath> splPath = VAbstractTool::data.GeometricObject<VSplinePath>(m_id);
+    QSharedPointer<VSplinePath> const splPath = VAbstractTool::data.GeometricObject<VSplinePath>(m_id);
     return *splPath.data();
 }
 
@@ -450,7 +478,7 @@ VSplinePath VToolSplinePath::getSplinePath() const
 void VToolSplinePath::setSplinePath(const VSplinePath &splPath)
 {
     QSharedPointer<VGObject> obj = VAbstractTool::data.GetGObject(m_id);
-    QSharedPointer<VSplinePath> splinePath = qSharedPointerDynamicCast<VSplinePath>(obj);
+    QSharedPointer<VSplinePath> const splinePath = qSharedPointerDynamicCast<VSplinePath>(obj);
     *splinePath.data() = splPath;
     SaveOption(obj);
 }
@@ -461,6 +489,16 @@ void VToolSplinePath::ShowVisualization(bool show)
     ShowToolVisualization<VisToolSplinePath>(show);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VToolSplinePath::ShowHandles(bool show)
+{
+    for (auto *point : qAsConst(controlPoints))
+    {
+        point->setVisible(show);
+    }
+    VAbstractSpline::ShowHandles(show);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief AddPathPoint write path point to pattern file.
@@ -532,23 +570,12 @@ void VToolSplinePath::SaveDialog(QDomElement &domElement, QList<quint32> &oldDep
         AddDependence(newDependencies, splPath.at(i).P().id());
     }
 
-    for (qint32 i = 1; i <= splPath.CountSubSpl(); ++i)
-    {
-        VSpline spl = splPath.GetSpline(i);
-        qint32 j = i*2;
-
-        controlPoints[j-2]->blockSignals(true);
-        controlPoints[j-1]->blockSignals(true);
-
-        controlPoints[j-2]->setPos(static_cast<QPointF>(spl.GetP2()));
-        controlPoints[j-1]->setPos(static_cast<QPointF>(spl.GetP3()));
-
-        controlPoints[j-2]->blockSignals(false);
-        controlPoints[j-1]->blockSignals(false);
-    }
+    qDeleteAll(controlPoints);
+    controlPoints.clear();
+    InitControlPoints(&splPath);
 
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrNotes, dialogTool->GetNotes(),
-                                         [](const QString &notes) noexcept {return notes.isEmpty();});
+                                         [](const QString &notes) noexcept { return notes.isEmpty(); });
 
     SetSplinePathAttributes(domElement, splPath);
 }
@@ -558,7 +585,7 @@ void VToolSplinePath::SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &ob
 {
     VAbstractSpline::SaveOptions(tag, obj);
 
-    QSharedPointer<VSplinePath> splPath = qSharedPointerDynamicCast<VSplinePath>(obj);
+    QSharedPointer<VSplinePath> const splPath = qSharedPointerDynamicCast<VSplinePath>(obj);
     SCASSERT(splPath.isNull() == false)
 
     SetSplinePathAttributes(tag, *splPath);
@@ -567,18 +594,16 @@ void VToolSplinePath::SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &ob
 //---------------------------------------------------------------------------------------------------------------------
 void VToolSplinePath::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
-    if (flags() & QGraphicsItem::ItemIsMovable)
+    if (flags() & QGraphicsItem::ItemIsMovable && event->button() == Qt::LeftButton &&
+        event->type() != QEvent::GraphicsSceneMouseDoubleClick)
     {
-        if (event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick)
+        oldPosition = event->scenePos();
+        const auto splPath = VAbstractTool::data.GeometricObject<VSplinePath>(m_id);
+        splIndex = splPath->Segment(oldPosition);
+        if (IsMovable(splIndex))
         {
-            oldPosition = event->scenePos();
-            const auto splPath = VAbstractTool::data.GeometricObject<VSplinePath>(m_id);
-            splIndex = splPath->Segment(oldPosition);
-            if (IsMovable(splIndex))
-            {
-                SetItemOverrideCursor(this, cursorArrowCloseHand, 1, 1);
-                event->accept();
-            }
+            SetItemOverrideCursor(this, cursorArrowCloseHand, 1, 1);
+            event->accept();
         }
     }
     VAbstractSpline::mousePressEvent(event);
@@ -587,15 +612,13 @@ void VToolSplinePath::mousePressEvent(QGraphicsSceneMouseEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void VToolSplinePath::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
-    if (flags() & QGraphicsItem::ItemIsMovable)
+    if (flags() & QGraphicsItem::ItemIsMovable && event->button() == Qt::LeftButton &&
+        event->type() != QEvent::GraphicsSceneMouseDoubleClick)
     {
-        if (event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick)
-        {
-            oldPosition = event->scenePos();
-            SetItemOverrideCursor(this, cursorArrowOpenHand, 1, 1);
+        oldPosition = event->scenePos();
+        SetItemOverrideCursor(this, cursorArrowOpenHand, 1, 1);
 
-            CurveReleased();
-        }
+        CurveReleased();
     }
     VAbstractSpline::mouseReleaseEvent(event);
 }
@@ -619,7 +642,7 @@ void VToolSplinePath::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 
         newMoveSplinePath = QSharedPointer<VSplinePath>::create(*oldSplPath);
 
-        VSpline spline = newMoveSplinePath->GetSpline(splIndex);
+        VSpline const spline = newMoveSplinePath->GetSpline(splIndex);
         const qreal t = spline.ParamT(oldPosition);
 
         if (qFloor(t) == -1)
@@ -642,7 +665,7 @@ void VToolSplinePath::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
         }
         else if (t <= 5.0 / 6.0)
         {
-            weight = (1 - pow((6 * (1-t) - 1) / 2.0, 3)) / 2 + 0.5;
+            weight = (1 - pow((6 * (1 - t) - 1) / 2.0, 3)) / 2 + 0.5;
         }
         else
         {
@@ -650,15 +673,15 @@ void VToolSplinePath::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
         }
 
         const QPointF delta = event->scenePos() - oldPosition;
-        const QPointF offset0 = ((1-weight)/(3*t*(1-t)*(1-t))) * delta;
-        const QPointF offset1 = (weight/(3*t*t*(1-t))) * delta;
+        const QPointF offset0 = ((1 - weight) / (3 * t * (1 - t) * (1 - t))) * delta;
+        const QPointF offset1 = (weight / (3 * t * t * (1 - t))) * delta;
 
-        const QPointF p2 = static_cast<QPointF>(spline.GetP2()) + offset0;
-        const QPointF p3 = static_cast<QPointF>(spline.GetP3()) + offset1;
+        const auto p2 = static_cast<QPointF>(spline.GetP2()) + offset0;
+        const auto p3 = static_cast<QPointF>(spline.GetP3()) + offset1;
 
         oldPosition = event->scenePos(); // Now mouse here
 
-        const VSpline spl = VSpline(spline.GetP1(), p2, p3, spline.GetP4());
+        const auto spl = VSpline(spline.GetP1(), p2, p3, spline.GetP4());
 
         UpdateControlPoints(spl, newMoveSplinePath, splIndex);
 
@@ -682,23 +705,23 @@ void VToolSplinePath::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
         static bool changeFinished = true;
         if (changeFinished)
         {
-           changeFinished = false;
+            changeFinished = false;
 
-           const QList<QGraphicsView *> viewList = scene()->views();
-           if (not viewList.isEmpty())
-           {
-               if (VMainGraphicsView *view = qobject_cast<VMainGraphicsView *>(viewList.at(0)))
-               {
-                   VMainGraphicsScene *currentScene = qobject_cast<VMainGraphicsScene *>(scene());
-                   SCASSERT(currentScene)
-                   const QPointF cursorPosition = currentScene->getScenePos();
-                   const qreal scale = SceneScale(scene());
-                   view->EnsureVisibleWithDelay(QRectF(cursorPosition.x()-5/scale, cursorPosition.y()-5/scale, 10/scale,
-                                                       10/scale),
-                                                VMainGraphicsView::scrollDelay);
-               }
-           }
-           changeFinished = true;
+            const QList<QGraphicsView *> viewList = scene()->views();
+            if (not viewList.isEmpty())
+            {
+                if (auto *view = qobject_cast<VMainGraphicsView *>(viewList.at(0)))
+                {
+                    auto *currentScene = qobject_cast<VMainGraphicsScene *>(scene());
+                    SCASSERT(currentScene)
+                    const QPointF cursorPosition = currentScene->getScenePos();
+                    const qreal scale = SceneScale(scene());
+                    view->EnsureVisibleWithDelay(
+                        QRectF(cursorPosition.x() - 5 / scale, cursorPosition.y() - 5 / scale, 10 / scale, 10 / scale),
+                        VMainGraphicsView::scrollDelay);
+                }
+            }
+            changeFinished = true;
         }
     }
 }
@@ -706,7 +729,7 @@ void VToolSplinePath::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void VToolSplinePath::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
 {
-    if (m_acceptHoverEvents)
+    if (GetAcceptHoverEvents())
     {
         if (flags() & QGraphicsItem::ItemIsMovable)
         {
@@ -738,7 +761,7 @@ void VToolSplinePath::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void VToolSplinePath::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
 {
-    if (m_acceptHoverEvents)
+    if (GetAcceptHoverEvents())
     {
         VAbstractSpline::hoverLeaveEvent(event);
     }
@@ -752,7 +775,7 @@ void VToolSplinePath::SetVisualization()
         auto *visual = qobject_cast<VisToolSplinePath *>(vis);
         SCASSERT(visual != nullptr)
 
-        QSharedPointer<VSplinePath> splPath = VAbstractTool::data.GeometricObject<VSplinePath>(m_id);
+        QSharedPointer<VSplinePath> const splPath = VAbstractTool::data.GeometricObject<VSplinePath>(m_id);
         visual->SetPath(*splPath.data());
         visual->SetLineStyle(LineStyleToPenStyle(splPath->GetPenStyle()));
         visual->SetMode(Mode::Show);
@@ -761,7 +784,7 @@ void VToolSplinePath::SetVisualization()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VToolSplinePath::IsMovable(int index) const
+auto VToolSplinePath::IsMovable(int index) const -> bool
 {
     const auto splPath = VAbstractTool::data.GeometricObject<VSplinePath>(m_id);
 
@@ -787,12 +810,17 @@ void VToolSplinePath::RefreshCtrlPoints()
 
     const auto splPath = VAbstractTool::data.GeometricObject<VSplinePath>(m_id);
 
-    for (qint32 i = 1; i<=splPath->CountSubSpl(); ++i)
+    for (qint32 i = 1; i <= splPath->CountSubSpl(); ++i)
     {
-        const qint32 j = i*2;
+        const qint32 j = i * 2;
 
-        controlPoints[j-2]->blockSignals(true);
-        controlPoints[j-1]->blockSignals(true);
+        if (j - 2 >= controlPoints.size())
+        {
+            break;
+        }
+
+        controlPoints[j - 2]->blockSignals(true);
+        controlPoints[j - 1]->blockSignals(true);
 
         const auto spl = splPath->GetSpline(i);
 
@@ -801,7 +829,7 @@ void VToolSplinePath::RefreshCtrlPoints()
 
             if (i > 1)
             {
-                const VSpline prevSpl = splPath->GetSpline(i-1);
+                const VSpline prevSpl = splPath->GetSpline(i - 1);
                 freeAngle1 = qmu::QmuTokenParser::IsSingle(spl.GetStartAngleFormula()) &&
                              qmu::QmuTokenParser::IsSingle(prevSpl.GetEndAngleFormula());
             }
@@ -813,8 +841,9 @@ void VToolSplinePath::RefreshCtrlPoints()
             const bool freeLength1 = qmu::QmuTokenParser::IsSingle(spl.GetC1LengthFormula());
 
             const auto splinePoint = spl.GetP1();
-            controlPoints[j-2]->RefreshCtrlPoint(i, SplinePointPosition::FirstPoint, static_cast<QPointF>(spl.GetP2()),
-                                                 static_cast<QPointF>(splinePoint), freeAngle1, freeLength1);
+            controlPoints[j - 2]->RefreshCtrlPoint(i, SplinePointPosition::FirstPoint,
+                                                   static_cast<QPointF>(spl.GetP2()), static_cast<QPointF>(splinePoint),
+                                                   freeAngle1, freeLength1);
         }
 
         {
@@ -822,7 +851,7 @@ void VToolSplinePath::RefreshCtrlPoints()
 
             if (i < splPath->CountSubSpl())
             {
-                const VSpline nextSpl = splPath->GetSpline(i+1);
+                const VSpline nextSpl = splPath->GetSpline(i + 1);
                 freeAngle2 = qmu::QmuTokenParser::IsSingle(nextSpl.GetStartAngleFormula()) &&
                              qmu::QmuTokenParser::IsSingle(spl.GetEndAngleFormula());
             }
@@ -834,12 +863,12 @@ void VToolSplinePath::RefreshCtrlPoints()
             const bool freeLength2 = qmu::QmuTokenParser::IsSingle(spl.GetC2LengthFormula());
 
             const auto splinePoint = spl.GetP4();
-            controlPoints[j-1]->RefreshCtrlPoint(i, SplinePointPosition::LastPoint, static_cast<QPointF>(spl.GetP3()),
-                                                 static_cast<QPointF>(splinePoint), freeAngle2, freeLength2);
+            controlPoints[j - 1]->RefreshCtrlPoint(i, SplinePointPosition::LastPoint, static_cast<QPointF>(spl.GetP3()),
+                                                   static_cast<QPointF>(splinePoint), freeAngle2, freeLength2);
         }
 
-        controlPoints[j-2]->blockSignals(false);
-        controlPoints[j-1]->blockSignals(false);
+        controlPoints[j - 2]->blockSignals(false);
+        controlPoints[j - 1]->blockSignals(false);
     }
 
     for (auto *point : qAsConst(controlPoints))
