@@ -28,64 +28,59 @@
 
 #include "vtoolcurveintersectaxis.h"
 
-#include <climits>
 #include <QLineF>
 #include <QMap>
 #include <QRectF>
 #include <QSharedPointer>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
 #include <QVector>
+#include <climits>
 #include <new>
 
-#include "../../../../../dialogs/tools/dialogtool.h"
 #include "../../../../../dialogs/tools/dialogcurveintersectaxis.h"
-#include "../ifc/ifcdef.h"
+#include "../../../../../dialogs/tools/dialogtool.h"
+#include "../../../../vabstracttool.h"
+#include "../../../vdrawtool.h"
 #include "../ifc/exception/vexception.h"
 #include "../ifc/exception/vexceptionobjecterror.h"
-#include "../qmuparser/qmudef.h"
+#include "../ifc/ifcdef.h"
 #include "../toolcut/vtoolcutsplinepath.h"
-#include "../vgeometry/vabstractcubicbezier.h"
-#include "../vgeometry/vabstractcubicbezierpath.h"
 #include "../vgeometry/vabstractcurve.h"
-#include "../vgeometry/varc.h"
-#include "../vgeometry/vellipticalarc.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
-#include "../vgeometry/vspline.h"
-#include "../vgeometry/vsplinepath.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vtranslatevars.h"
-#include "../vtools/visualization/visualization.h"
 #include "../vtools/visualization/line/vistoolcurveintersectaxis.h"
+#include "../vtools/visualization/visualization.h"
 #include "../vwidgets/vmaingraphicsscene.h"
-#include "../../../../vabstracttool.h"
-#include "../../../vdrawtool.h"
 #include "vtoollinepoint.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
+
 template <class T> class QSharedPointer;
 
 const QString VToolCurveIntersectAxis::ToolType = QStringLiteral("curveIntersectAxis");
 
 //---------------------------------------------------------------------------------------------------------------------
-VToolCurveIntersectAxis::VToolCurveIntersectAxis(const VToolCurveIntersectAxisInitData &initData,
-                                                 QGraphicsItem *parent)
-    :VToolLinePoint(initData.doc, initData.data, initData.id, initData.typeLine, initData.lineColor, QString(),
-                    initData.basePointId, 0, initData.notes, parent),
-      formulaAngle(initData.formulaAngle),
-      curveId(initData.curveId),
-      m_segments(initData.segments),
-      m_aliasSuffix1(initData.aliasSuffix1),
-      m_aliasSuffix2(initData.aliasSuffix2)
+VToolCurveIntersectAxis::VToolCurveIntersectAxis(const VToolCurveIntersectAxisInitData &initData, QGraphicsItem *parent)
+  : VToolLinePoint(initData.doc, initData.data, initData.id, initData.typeLine, initData.lineColor, QString(),
+                   initData.basePointId, 0, initData.notes, parent),
+    formulaAngle(initData.formulaAngle),
+    curveId(initData.curveId),
+    m_segments(initData.segments),
+    m_aliasSuffix1(initData.aliasSuffix1),
+    m_aliasSuffix2(initData.aliasSuffix2)
 {
     ToolCreation(initData.typeCreation);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VToolCurveIntersectAxis::setDialog()
+void VToolCurveIntersectAxis::SetDialog()
 {
     SCASSERT(not m_dialog.isNull())
     m_dialog->setModal(true);
@@ -104,15 +99,20 @@ void VToolCurveIntersectAxis::setDialog()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VToolCurveIntersectAxis *VToolCurveIntersectAxis::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene,
-                                                         VAbstractPattern *doc,
-                                                         VContainer *data)
+auto VToolCurveIntersectAxis::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene,
+                                     VAbstractPattern *doc, VContainer *data) -> VToolCurveIntersectAxis *
 {
     SCASSERT(not dialog.isNull())
     const QPointer<DialogCurveIntersectAxis> dialogTool = qobject_cast<DialogCurveIntersectAxis *>(dialog);
     SCASSERT(not dialogTool.isNull())
 
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_GCC("-Wnoexcept")
+
     VToolCurveIntersectAxisInitData initData;
+
+    QT_WARNING_POP
+
     initData.formulaAngle = dialogTool->GetAngle();
     initData.basePointId = dialogTool->GetBasePointId();
     initData.curveId = dialogTool->getCurveId();
@@ -137,7 +137,7 @@ VToolCurveIntersectAxis *VToolCurveIntersectAxis::Create(const QPointer<DialogTo
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VToolCurveIntersectAxis *VToolCurveIntersectAxis::Create(VToolCurveIntersectAxisInitData &initData)
+auto VToolCurveIntersectAxis::Create(VToolCurveIntersectAxisInitData &initData) -> VToolCurveIntersectAxis *
 {
     const QSharedPointer<VPointF> basePoint = initData.data->GeometricObject<VPointF>(initData.basePointId);
     const qreal angle = CheckFormula(initData.id, initData.formulaAngle, initData.data);
@@ -150,9 +150,11 @@ VToolCurveIntersectAxis *VToolCurveIntersectAxis::Create(VToolCurveIntersectAxis
     {
         const QString errorMsg = tr("Error calculating point '%1'. There is no intersection with curve '%2' and axis"
                                     " through point '%3' with angle %4°")
-                .arg(initData.name, curve->ObjectName(), basePoint->name()).arg(angle);
-        VAbstractApplication::VApp()->IsPedantic() ? throw VExceptionObjectError(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+                                     .arg(initData.name, curve->ObjectName(), basePoint->name())
+                                     .arg(angle);
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VExceptionObjectError(errorMsg)
+            : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
     }
 
     const qreal segLength = curve->GetLengthByPoint(fPoint);
@@ -203,17 +205,16 @@ VToolCurveIntersectAxis *VToolCurveIntersectAxis::Create(VToolCurveIntersectAxis
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VToolCurveIntersectAxis::FindPoint(const QPointF &point, qreal angle, const QVector<QPointF> &curvePoints,
-                                        QPointF *intersectionPoint)
+auto VToolCurveIntersectAxis::FindPoint(const QPointF &point, qreal angle, const QVector<QPointF> &curvePoints,
+                                        QPointF *intersectionPoint) -> bool
 {
     return VAbstractCurve::CurveIntersectAxis(point, angle, curvePoints, intersectionPoint);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VFormula VToolCurveIntersectAxis::GetFormulaAngle() const
+auto VToolCurveIntersectAxis::GetFormulaAngle() const -> VFormula
 {
     VFormula fAngle(formulaAngle, getData());
-    fAngle.setCheckZero(false);
     fAngle.setToolId(m_id);
     fAngle.setPostfix(degreeSymbol);
     fAngle.Eval();
@@ -233,7 +234,7 @@ void VToolCurveIntersectAxis::SetFormulaAngle(const VFormula &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolCurveIntersectAxis::CurveName() const
+auto VToolCurveIntersectAxis::CurveName() const -> QString
 {
     return VAbstractTool::data.GetGObject(curveId)->ObjectName();
 }
@@ -251,10 +252,10 @@ void VToolCurveIntersectAxis::ShowContextMenu(QGraphicsSceneContextMenuEvent *ev
     {
         ContextMenu<DialogCurveIntersectAxis>(event, id);
     }
-    catch(const VExceptionToolWasDeleted &e)
+    catch (const VExceptionToolWasDeleted &e)
     {
         Q_UNUSED(e)
-        return;//Leave this method immediately!!!
+        return; // Leave this method immediately!!!
     }
 }
 
@@ -278,11 +279,11 @@ void VToolCurveIntersectAxis::SaveDialog(QDomElement &domElement, QList<quint32>
     doc->SetAttribute(domElement, AttrBasePoint, QString().setNum(dialogTool->GetBasePointId()));
     doc->SetAttribute(domElement, AttrCurve, QString().setNum(dialogTool->getCurveId()));
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrAlias1, dialogTool->GetAliasSuffix1(),
-                                         [](const QString &suffix) noexcept {return suffix.isEmpty();});
+                                         [](const QString &suffix) noexcept { return suffix.isEmpty(); });
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrAlias2, dialogTool->GetAliasSuffix2(),
-                                         [](const QString &suffix) noexcept {return suffix.isEmpty();});
+                                         [](const QString &suffix) noexcept { return suffix.isEmpty(); });
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrNotes, dialogTool->GetNotes(),
-                                         [](const QString &notes) noexcept {return notes.isEmpty();});
+                                         [](const QString &notes) noexcept { return notes.isEmpty(); });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -295,9 +296,9 @@ void VToolCurveIntersectAxis::SaveOptions(QDomElement &tag, QSharedPointer<VGObj
     doc->SetAttribute(tag, AttrBasePoint, basePointId);
     doc->SetAttribute(tag, AttrCurve, curveId);
     doc->SetAttributeOrRemoveIf<QString>(tag, AttrAlias1, m_aliasSuffix1,
-                                         [](const QString &suffix) noexcept {return suffix.isEmpty();});
+                                         [](const QString &suffix) noexcept { return suffix.isEmpty(); });
     doc->SetAttributeOrRemoveIf<QString>(tag, AttrAlias2, m_aliasSuffix2,
-                                         [](const QString &suffix) noexcept {return suffix.isEmpty();});
+                                         [](const QString &suffix) noexcept { return suffix.isEmpty(); });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -324,8 +325,8 @@ void VToolCurveIntersectAxis::SetVisualization()
 
         visual->SetCurveId(curveId);
         visual->setAxisPointId(basePointId);
-        visual->SetAngle(VAbstractApplication::VApp()->TrVars()
-                         ->FormulaToUser(formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        visual->SetAngle(VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
         visual->SetLineStyle(LineStyleToPenStyle(m_lineType));
         visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
@@ -333,27 +334,28 @@ void VToolCurveIntersectAxis::SetVisualization()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolCurveIntersectAxis::MakeToolTip() const
+auto VToolCurveIntersectAxis::MakeToolTip() const -> QString
 {
     const QSharedPointer<VPointF> first = VAbstractTool::data.GeometricObject<VPointF>(basePointId);
     const QSharedPointer<VPointF> second = VAbstractTool::data.GeometricObject<VPointF>(m_id);
 
     const QLineF line(static_cast<QPointF>(*first), static_cast<QPointF>(*second));
 
-    const QString toolTip = QString("<table>"
-                                    "<tr> <td><b>%6:</b> %7</td> </tr>"
-                                    "<tr> <td><b>%1:</b> %2 %3</td> </tr>"
-                                    "<tr> <td><b>%4:</b> %5°</td> </tr>"
-                                    "<tr> <td><b>%8:</b> %9</td> </tr>"
-                                    "<tr> <td><b>%10:</b> %11</td> </tr>"
-                                    "</table>")
-            .arg(tr("Length")) // 1
-            .arg(VAbstractValApplication::VApp()->fromPixel(line.length())) // 2
+    const QString toolTip =
+        u"<table>"
+        u"<tr> <td><b>%6:</b> %7</td> </tr>"
+        u"<tr> <td><b>%1:</b> %2 %3</td> </tr>"
+        u"<tr> <td><b>%4:</b> %5°</td> </tr>"
+        u"<tr> <td><b>%8:</b> %9</td> </tr>"
+        u"<tr> <td><b>%10:</b> %11</td> </tr>"
+        u"</table>"_s
+            .arg(tr("Length"))                                                                   // 1
+            .arg(VAbstractValApplication::VApp()->fromPixel(line.length()))                      // 2
             .arg(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true), tr("Angle")) // 3, 4
-            .arg(line.angle()) // 5
-            .arg(tr("Label"), second->name(), /* 6, 7 */
-                 tr("Segment 1"), m_segments.first, /* 8, 9 */
-                 tr("Segment 2"), m_segments.second); /* 10, 11 */
+            .arg(line.angle())                                                                   // 5
+            .arg(tr("Label"), second->name(),                                                    /* 6, 7 */
+                 tr("Segment 1"), m_segments.first,                                              /* 8, 9 */
+                 tr("Segment 2"), m_segments.second);                                            /* 10, 11 */
     return toolTip;
 }
 
