@@ -29,7 +29,7 @@
 #ifndef VTOOLHEIGHT_H
 #define VTOOLHEIGHT_H
 
-#include <qcompilerdetection.h>
+
 #include <QDomElement>
 #include <QGraphicsItem>
 #include <QLineF>
@@ -66,17 +66,17 @@ class VToolHeight: public VToolLinePoint
 {
     Q_OBJECT // NOLINT
 public:
-    virtual void   setDialog() override;
-    static VToolHeight *Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene  *scene, VAbstractPattern *doc,
-                               VContainer *data);
-    static VToolHeight *Create(VToolHeightInitData initData);
-    static QPointF FindPoint(const QLineF &line, const QPointF &point);
+    virtual void   SetDialog() override;
+    static auto Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
+                       VContainer *data) -> VToolHeight *;
+    static auto Create(VToolHeightInitData initData) -> VToolHeight *;
+    static auto FindPoint(const QLineF &line, const QPointF &point) -> QPointF;
     static const QString ToolType;
-    virtual int    type() const override {return Type;}
+    virtual auto type() const -> int override { return Type; }
     enum { Type = UserType + static_cast<int>(Tool::Height)};
 
-    QString FirstLinePointName() const;
-    QString SecondLinePointName() const;
+    auto FirstLinePointName() const -> QString;
+    auto SecondLinePointName() const -> QString;
 
     virtual void   ShowVisualization(bool show) override;
 protected slots:
@@ -87,7 +87,8 @@ protected:
     virtual void    SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &obj) override;
     virtual void    ReadToolAttributes(const QDomElement &domElement) override;
     virtual void    SetVisualization() override;
-    virtual QString MakeToolTip() const override;
+    virtual auto MakeToolTip() const -> QString override;
+
 private:
     Q_DISABLE_COPY_MOVE(VToolHeight) // NOLINT
 
