@@ -31,31 +31,27 @@
 #include <QLine>
 #include <QLineF>
 #include <QSharedPointer>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
-#include <new>
 #include <QtMath>
 
-#include "../../../../dialogs/tools/dialogtriangle.h"
 #include "../../../../dialogs/tools/dialogtool.h"
-#include "../../../../visualization/visualization.h"
+#include "../../../../dialogs/tools/dialogtriangle.h"
 #include "../../../../visualization/line/vistooltriangle.h"
+#include "../../../../visualization/visualization.h"
+#include "../../../vabstracttool.h"
+#include "../../vdrawtool.h"
 #include "../ifc/exception/vexception.h"
 #include "../ifc/exception/vexceptionobjecterror.h"
 #include "../ifc/ifcdef.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
+#include "../vmisc/compatibility.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vwidgets/vmaingraphicsscene.h"
-#include "../../../vabstracttool.h"
-#include "../../vdrawtool.h"
 #include "vtoolsinglepoint.h"
-#include "../vmisc/compatibility.h"
 
 template <class T> class QSharedPointer;
 
-const QString VToolTriangle::ToolType = QStringLiteral("triangle");
+const QString VToolTriangle::ToolType = QStringLiteral("triangle"); // NOLINT
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -64,11 +60,11 @@ const QString VToolTriangle::ToolType = QStringLiteral("triangle");
  * @param parent parent object.
  */
 VToolTriangle::VToolTriangle(const VToolTriangleInitData &initData, QGraphicsItem *parent)
-    :VToolSinglePoint(initData.doc, initData.data, initData.id, initData.notes, parent),
-      axisP1Id(initData.axisP1Id),
-      axisP2Id(initData.axisP2Id),
-      firstPointId(initData.firstPointId),
-      secondPointId(initData.secondPointId)
+  : VToolSinglePoint(initData.doc, initData.data, initData.id, initData.notes, parent),
+    axisP1Id(initData.axisP1Id),
+    axisP2Id(initData.axisP2Id),
+    firstPointId(initData.firstPointId),
+    secondPointId(initData.secondPointId)
 {
     ToolCreation(initData.typeCreation);
 }
@@ -77,7 +73,7 @@ VToolTriangle::VToolTriangle(const VToolTriangleInitData &initData, QGraphicsIte
 /**
  * @brief setDialog set dialog when user want change tool option.
  */
-void VToolTriangle::setDialog()
+void VToolTriangle::SetDialog()
 {
     SCASSERT(not m_dialog.isNull())
     const QPointer<DialogTriangle> dialogTool = qobject_cast<DialogTriangle *>(m_dialog);
@@ -100,8 +96,8 @@ void VToolTriangle::setDialog()
  * @param data container with variables.
  * @return the created tool
  */
-VToolTriangle* VToolTriangle::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene,
-                                     VAbstractPattern *doc, VContainer *data)
+auto VToolTriangle::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
+                           VContainer *data) -> VToolTriangle *
 {
     SCASSERT(not dialog.isNull())
     const QPointer<DialogTriangle> dialogTool = qobject_cast<DialogTriangle *>(dialog);
@@ -120,7 +116,7 @@ VToolTriangle* VToolTriangle::Create(const QPointer<DialogTool> &dialog, VMainGr
     initData.typeCreation = Source::FromGui;
     initData.notes = dialogTool->GetNotes();
 
-    VToolTriangle* point = Create(initData);
+    VToolTriangle *point = Create(initData);
     if (point != nullptr)
     {
         point->m_dialog = dialog;
@@ -134,7 +130,7 @@ VToolTriangle* VToolTriangle::Create(const QPointer<DialogTool> &dialog, VMainGr
  * @param initData init data.
  * @return the created tool
  */
-VToolTriangle* VToolTriangle::Create(VToolTriangleInitData initData)
+auto VToolTriangle::Create(VToolTriangleInitData initData) -> VToolTriangle *
 {
     const QSharedPointer<VPointF> axisP1 = initData.data->GeometricObject<VPointF>(initData.axisP1Id);
     const QSharedPointer<VPointF> axisP2 = initData.data->GeometricObject<VPointF>(initData.axisP2Id);
@@ -147,13 +143,14 @@ VToolTriangle* VToolTriangle::Create(VToolTriangleInitData initData)
 
     if (not success)
     {
-        const QString errorMsg = tr("Error calculating point '%1'. Point of intersection cannot be found")
-                      .arg(initData.name);
-        VAbstractApplication::VApp()->IsPedantic() ? throw VExceptionObjectError(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+        const QString errorMsg =
+            tr("Error calculating point '%1'. Point of intersection cannot be found").arg(initData.name);
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VExceptionObjectError(errorMsg)
+            : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
     }
 
-    VPointF *p = new VPointF(point, initData.name, initData.mx, initData.my);
+    auto *p = new VPointF(point, initData.name, initData.mx, initData.my);
     p->SetShowLabel(initData.showLabel);
 
     if (initData.typeCreation == Source::FromGui)
@@ -172,7 +169,7 @@ VToolTriangle* VToolTriangle::Create(VToolTriangleInitData initData)
     if (initData.parse == Document::FullParse)
     {
         VAbstractTool::AddRecord(initData.id, Tool::Triangle, initData.doc);
-        VToolTriangle *point = new VToolTriangle(initData);
+        auto *point = new VToolTriangle(initData);
         initData.scene->addItem(point);
         InitToolConnections(initData.scene, point);
         VAbstractPattern::AddTool(initData.id, point);
@@ -195,41 +192,41 @@ VToolTriangle* VToolTriangle::Create(VToolTriangleInitData initData)
  * @param intersectionPoint point intersection two foots right triangle
  * @return true if the intersection exists.
  */
-bool VToolTriangle::FindPoint(const QPointF &axisP1, const QPointF &axisP2, const QPointF &firstPoint,
-                              const QPointF &secondPoint, QPointF *intersectionPoint)
+auto VToolTriangle::FindPoint(const QPointF &axisP1, const QPointF &axisP2, const QPointF &firstPoint,
+                              const QPointF &secondPoint, QPointF *intersectionPoint) -> bool
 {
     SCASSERT(intersectionPoint != nullptr)
 
-    QLineF axis(axisP1, axisP2);
-    QLineF hypotenuse(firstPoint, secondPoint);
+    QLineF const axis(axisP1, axisP2);
+    QLineF const hypotenuse(firstPoint, secondPoint);
 
     QPointF startPoint;
-    QLineF::IntersectType intersect = Intersects(axis, hypotenuse, &startPoint);
+    QLineF::IntersectType const intersect = axis.intersects(hypotenuse, &startPoint);
 
     if (intersect != QLineF::UnboundedIntersection && intersect != QLineF::BoundedIntersection)
     {
         return false;
     }
-    if (VFuzzyComparePossibleNulls(axis.angle(), hypotenuse.angle())
-        || VFuzzyComparePossibleNulls(qAbs(axis.angle() - hypotenuse.angle()), 180))
+    if (VFuzzyComparePossibleNulls(axis.angle(), hypotenuse.angle()) ||
+        VFuzzyComparePossibleNulls(qAbs(axis.angle() - hypotenuse.angle()), 180))
     {
         return false;
     }
 
-    qreal step = 1;
+    qreal const step = 1;
 
     QLineF line;
     line.setP1(startPoint);
     line.setAngle(axis.angle());
     line.setLength(step);
 
-    qint64 c = qFloor(hypotenuse.length());
-    while (1)
+    qint64 const c = qFloor(hypotenuse.length());
+    while (true)
     {
-        line.setLength(line.length()+step);
-        qint64 a = qFloor(QLineF(line.p2(), firstPoint).length());
-        qint64 b = qFloor(QLineF(line.p2(), secondPoint).length());
-        if (c*c <= (a*a + b*b))
+        line.setLength(line.length() + step);
+        qint64 const a = qFloor(QLineF(line.p2(), firstPoint).length());
+        qint64 const b = qFloor(QLineF(line.p2(), secondPoint).length());
+        if (c * c <= (a * a + b * b))
         {
             *intersectionPoint = line.p2();
             return true;
@@ -239,25 +236,25 @@ bool VToolTriangle::FindPoint(const QPointF &axisP1, const QPointF &axisP2, cons
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolTriangle::AxisP1Name() const
+auto VToolTriangle::AxisP1Name() const -> QString
 {
     return VAbstractTool::data.GetGObject(axisP1Id)->name();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolTriangle::AxisP2Name() const
+auto VToolTriangle::AxisP2Name() const -> QString
 {
     return VAbstractTool::data.GetGObject(axisP2Id)->name();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolTriangle::FirstPointName() const
+auto VToolTriangle::FirstPointName() const -> QString
 {
     return VAbstractTool::data.GetGObject(firstPointId)->name();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolTriangle::SecondPointName() const
+auto VToolTriangle::SecondPointName() const -> QString
 {
     return VAbstractTool::data.GetGObject(secondPointId)->name();
 }
@@ -307,7 +304,7 @@ void VToolTriangle::SaveDialog(QDomElement &domElement, QList<quint32> &oldDepen
 
     const QString notes = dialogTool->GetNotes();
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrNotes, notes,
-                                         [](const QString &notes) noexcept {return notes.isEmpty();});
+                                         [](const QString &notes) noexcept { return notes.isEmpty(); });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -327,10 +324,10 @@ void VToolTriangle::ReadToolAttributes(const QDomElement &domElement)
 {
     VToolSinglePoint::ReadToolAttributes(domElement);
 
-    axisP1Id = doc->GetParametrUInt(domElement, AttrAxisP1, NULL_ID_STR);
-    axisP2Id = doc->GetParametrUInt(domElement, AttrAxisP2, NULL_ID_STR);
-    firstPointId = doc->GetParametrUInt(domElement, AttrFirstPoint, NULL_ID_STR);
-    secondPointId = doc->GetParametrUInt(domElement, AttrSecondPoint, NULL_ID_STR);
+    axisP1Id = VAbstractPattern::GetParametrUInt(domElement, AttrAxisP1, NULL_ID_STR);
+    axisP2Id = VAbstractPattern::GetParametrUInt(domElement, AttrAxisP2, NULL_ID_STR);
+    firstPointId = VAbstractPattern::GetParametrUInt(domElement, AttrFirstPoint, NULL_ID_STR);
+    secondPointId = VAbstractPattern::GetParametrUInt(domElement, AttrSecondPoint, NULL_ID_STR);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -338,7 +335,7 @@ void VToolTriangle::SetVisualization()
 {
     if (not vis.isNull())
     {
-        auto * visual = qobject_cast<VisToolTriangle *>(vis);
+        auto *visual = qobject_cast<VisToolTriangle *>(vis);
         SCASSERT(visual != nullptr)
 
         visual->SetObject1Id(axisP1Id);
@@ -357,10 +354,10 @@ void VToolTriangle::ShowContextMenu(QGraphicsSceneContextMenuEvent *event, quint
     {
         ContextMenu<DialogTriangle>(event, id);
     }
-    catch(const VExceptionToolWasDeleted &e)
+    catch (const VExceptionToolWasDeleted &e)
     {
         Q_UNUSED(e)
-        return;//Leave this method immediately!!!
+        return; // Leave this method immediately!!!
     }
 }
 
