@@ -29,7 +29,7 @@
 #ifndef VNODEARC_H
 #define VNODEARC_H
 
-#include <qcompilerdetection.h>
+
 #include <QGraphicsPathItem>
 #include <QMetaObject>
 #include <QObject>
@@ -50,7 +50,7 @@ public:
     static void Create(const VAbstractNodeInitData &initData);
 
     static const QString ToolType;
-    virtual QString getTagName() const override;
+    virtual auto getTagName() const -> QString override;
 public slots:
     virtual void FullUpdateFromFile() override {}
     virtual void AllowHover(bool enabled) override;
