@@ -49,13 +49,13 @@ class VToolPiecePath : public VAbstractNode, public QGraphicsPathItem
 {
     Q_OBJECT // NOLINT
 public:
-    static VToolPiecePath* Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
-                                  VContainer *data);
-    static VToolPiecePath *Create(VToolPiecePathInitData initData);
+    static auto Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
+                       VContainer *data) -> VToolPiecePath *;
+    static auto Create(VToolPiecePathInitData initData) -> VToolPiecePath *;
 
-    virtual int  type() const override {return Type;}
+    virtual auto type() const -> int override { return Type; }
     enum { Type = UserType + static_cast<int>(Tool::PiecePath)};
-    virtual QString getTagName() const override;
+    virtual auto getTagName() const -> QString override;
 
     virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
                        QWidget *widget = nullptr) override;
