@@ -36,22 +36,22 @@
 #include <QPen>
 #include <QPixmap>
 #include <QRegularExpression>
-#include <QVector>
 #include <QStyle>
+#include <QVector>
 
-#include "../vgeometry/vgobject.h"
 #include "../qmuparser/qmudef.h"
+#include "../vgeometry/vgobject.h"
+#include "../vmisc/vabstractvalapplication.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vpropertyexplorer/checkablemessagebox.h"
-#include "../vmisc/vabstractvalapplication.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<quint32> SourceToObjects(const QVector<SourceItem> &source)
+auto SourceToObjects(const QVector<SourceItem> &source) -> QVector<quint32>
 {
     QVector<quint32> ids;
     ids.reserve(source.size());
 
-    for (auto s: source)
+    for (const auto &s : source)
     {
         ids.append(s.id);
     }
@@ -60,13 +60,11 @@ QVector<quint32> SourceToObjects(const QVector<SourceItem> &source)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool SourceAliasValid(const SourceItem &item, const QSharedPointer<VGObject> &obj, const VContainer *data,
-                      const QString &originAlias)
+auto SourceAliasValid(const SourceItem &item, const QSharedPointer<VGObject> &obj, const VContainer *data,
+                      const QString &originAlias) -> bool
 {
     SCASSERT(data != nullptr)
 
-    QRegularExpression rx(NameRegExp());
-
     QString alias;
 
     if (obj->getType() == GOType::Point)
@@ -81,8 +79,8 @@ bool SourceAliasValid(const SourceItem &item, const QSharedPointer<VGObject> &ob
         obj->SetAliasSuffix(oldAlias);
     }
 
-    if (not alias.isEmpty() && originAlias != alias &&
-        (not rx.match(alias).hasMatch() || not data->IsUnique(alias)))
+    if (QRegularExpression const rx(NameRegExp());
+        not alias.isEmpty() && originAlias != alias && (not rx.match(alias).hasMatch() || not data->IsUnique(alias)))
     {
         return false;
     }
@@ -91,33 +89,30 @@ bool SourceAliasValid(const SourceItem &item, const QSharedPointer<VGObject> &ob
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString OriginAlias(quint32 id, const QVector<SourceItem> &source, const QSharedPointer<VGObject> &obj)
+auto OriginAlias(quint32 id, const QVector<SourceItem> &source, const QSharedPointer<VGObject> &obj) -> QString
 {
-    auto item = std::find_if(source.begin(), source.end(),
-                            [id](const SourceItem &sItem) { return sItem.id == id; });
+    auto item = std::find_if(source.begin(), source.end(), [id](const SourceItem &sItem) { return sItem.id == id; });
     if (item != source.end())
     {
         if (obj->getType() == GOType::Point)
         {
             return item->alias;
         }
-        else
-        {
-            const QString oldAlias = obj->GetAliasSuffix();
-            obj->SetAliasSuffix(item->alias);
-            QString alias = obj->GetAlias();
-            obj->SetAliasSuffix(oldAlias);
-            return alias;
-        }
+
+        const QString oldAlias = obj->GetAliasSuffix();
+        obj->SetAliasSuffix(item->alias);
+        QString alias = obj->GetAlias();
+        obj->SetAliasSuffix(oldAlias);
+        return alias;
     }
 
     return QString();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QMap<QString, QIcon> OperationLineStylesPics()
+auto OperationLineStylesPics(QColor backgroundColor, QColor textColor) -> QMap<QString, QIcon>
 {
-    QMap<QString, QIcon> map = LineStylesPics();
+    QMap<QString, QIcon> map = LineStylesPics(backgroundColor, textColor);
     map.insert(TypeLineDefault, QIcon());
     return map;
 }
@@ -135,9 +130,9 @@ auto ConfirmDeletion() -> int
     msgBox.setText(QObject::tr("Do you really want to delete?"));
     msgBox.setStandardButtons(QDialogButtonBox::Yes | QDialogButtonBox::No);
     msgBox.setDefaultButton(QDialogButtonBox::No);
-    msgBox.setIconPixmap(QApplication::style()->standardIcon(QStyle::SP_MessageBoxQuestion).pixmap(32, 32) );
+    msgBox.setIconPixmap(QApplication::style()->standardIcon(QStyle::SP_MessageBoxQuestion).pixmap(32, 32));
 
-    int dialogResult = msgBox.exec();
+    int const dialogResult = msgBox.exec();
 
     if (dialogResult == QDialog::Accepted)
     {
