@@ -109,10 +109,7 @@ VAbstractTool::VAbstractTool(VAbstractPattern *doc, VContainer *data, quint32 id
 //---------------------------------------------------------------------------------------------------------------------
 VAbstractTool::~VAbstractTool()
 {
-    if (not vis.isNull())
-    {
-        delete vis;
-    }
+    delete vis.data();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -125,7 +122,8 @@ VAbstractTool::~VAbstractTool()
  * @param toolId [in] tool's id.
  * @param formula [in|out] string with formula.
  * @param data [in] container with variables. Need for math parser.
- * @throw QmuParserError.
+ * @throw QmuParserError If a parsing error occurs in the formula.
+ * @throw VExceptionUndo If the user fails to fix the wrong formula and decides to undo.
  * @return result of calculation formula.
  */
 auto VAbstractTool::CheckFormula(const quint32 &toolId, QString &formula, VContainer *data) -> qreal
@@ -134,12 +132,12 @@ auto VAbstractTool::CheckFormula(const quint32 &toolId, QString &formula, VConta
     qreal result = 0;
     try
     {
-        QScopedPointer<Calculator> const cal(new Calculator());
-        result = cal->EvalFormula(data->DataVariables(), formula);
+        Calculator cal;
+        result = cal.EvalFormula(data->DataVariables(), formula);
 
         if (qIsInf(result) || qIsNaN(result))
         {
-            qDebug() << "Invalid the formula value";
+            qDebug() << "Invalid formula value";
             return 0;
         }
     }
@@ -162,8 +160,9 @@ auto VAbstractTool::CheckFormula(const quint32 &toolId, QString &formula, VConta
                     const UndoButton resultUndo = dialogUndo->Result();
                     if (resultUndo == UndoButton::Fix)
                     {
-                        auto *dialog =
-                            new DialogEditWrongFormula(data, toolId, VAbstractValApplication::VApp()->getMainWindow());
+                        QScopedPointer<DialogEditWrongFormula> dialog(
+                            new DialogEditWrongFormula(data, toolId, VAbstractValApplication::VApp()->getMainWindow()));
+
                         dialog->setWindowTitle(tr("Edit wrong formula"));
                         dialog->SetFormula(formula);
                         if (dialog->exec() == QDialog::Accepted)
@@ -171,7 +170,7 @@ auto VAbstractTool::CheckFormula(const quint32 &toolId, QString &formula, VConta
                             formula = dialog->GetFormula();
                             /* Need delete dialog here because parser in dialog don't allow use correct separator for
                              * parsing here. */
-                            delete dialog;
+                            dialog.reset();
                             QScopedPointer<Calculator> const cal1(new Calculator());
                             result = cal1->EvalFormula(data->DataVariables(), formula);
 
@@ -183,7 +182,6 @@ auto VAbstractTool::CheckFormula(const quint32 &toolId, QString &formula, VConta
 
                             break;
                         }
-                        delete dialog;
                     }
                     else
                     {
@@ -331,8 +329,7 @@ auto VAbstractTool::PointsList() const -> QMap<QString, quint32>
 {
     const QHash<quint32, QSharedPointer<VGObject>> *objs = data.CalculationGObjects();
     QMap<QString, quint32> list;
-    QHash<quint32, QSharedPointer<VGObject>>::const_iterator i;
-    for (i = objs->constBegin(); i != objs->constEnd(); ++i)
+    for (auto i = objs->constBegin(); i != objs->constEnd(); ++i)
     {
         if (i.key() != m_id)
         {
@@ -591,12 +588,12 @@ auto VAbstractTool::AddSANode(VAbstractPattern *doc, const QString &tagName, con
         doc->SetAttributeOrRemoveIf<bool>(nod, VAbstractPattern::AttrManualPassmarkAngle, node.IsManualPassmarkAngle(),
                                           [node](bool manualPassmarkAngle) noexcept {
                                               return not manualPassmarkAngle ||
-                                                     node.GetPassmarkAngleType() == PassmarkAngleType::Straightforward;
+                                                     node.GetPassmarkAngleType() != PassmarkAngleType::Straightforward;
                                           });
         doc->SetAttributeOrRemoveIf<QString>(nod, VAbstractPattern::AttrPassmarkAngle, node.GetFormulaPassmarkAngle(),
                                              [node](const QString &) noexcept {
                                                  return not node.IsManualPassmarkAngle() ||
-                                                        node.GetPassmarkAngleType() ==
+                                                        node.GetPassmarkAngleType() !=
                                                             PassmarkAngleType::Straightforward;
                                              });
     }
