@@ -102,6 +102,7 @@ public:
     static void AddGrainline(VAbstractPattern *doc, QDomElement &domElement, const VPiece &piece);
     static void AddMirrorLine(VAbstractPattern *doc, QDomElement &domElement, const VPiece &piece);
 
+    void SetName(const QString &name);
     void Move(qreal x, qreal y);
     void Update(const VPiece &piece);
     void DisconnectOutsideSignals();
@@ -128,9 +129,9 @@ public slots:
     void EnableToolMove(bool move);
     void AllowHover(bool enabled) override;
     void AllowSelecting(bool enabled) override;
-    virtual void ResetChildren(QGraphicsItem *pItem);
-    virtual void UpdateAll();
-    virtual void retranslateUi();
+    void ResetChildren(QGraphicsItem *pItem);
+    void UpdateAll();
+    void retranslateUi();
     void Highlight(quint32 id);
     void UpdateDetailLabel();
     void UpdatePatternInfo();
