@@ -28,24 +28,21 @@
 
 #include "addpatternpiece.h"
 
-#include "../vmisc/def.h"
 #include "../ifc/xml/vabstractpattern.h"
+#include "../vmisc/def.h"
 #include "vundocommand.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 AddPatternPiece::AddPatternPiece(const QDomElement &xml, VAbstractPattern *doc, const QString &namePP,
                                  QUndoCommand *parent)
-    : VUndoCommand(xml, doc, parent), namePP(namePP)
+  : VUndoCommand(xml, doc, parent),
+    namePP(namePP)
 {
     // cppcheck-suppress unknownMacro
     SCASSERT(namePP.isEmpty() == false)
     setText(tr("add pattern piece %1").arg(namePP));
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-AddPatternPiece::~AddPatternPiece()
-{}
-
 //---------------------------------------------------------------------------------------------------------------------
 void AddPatternPiece::undo()
 {
@@ -58,7 +55,7 @@ void AddPatternPiece::undo()
     else
     {
         QDomElement rootElement = doc->documentElement();
-        QDomElement patternPiece = doc->GetPPElement(namePP);
+        QDomElement const patternPiece = doc->GetPPElement(namePP);
         rootElement.removeChild(patternPiece);
         emit NeedFullParsing();
     }
