@@ -48,10 +48,7 @@ AddPiece::AddPiece(const QDomElement &xml, VAbstractPattern *doc, const VContain
 //---------------------------------------------------------------------------------------------------------------------
 AddPiece::~AddPiece()
 {
-    if (not m_tool.isNull())
-    {
-        delete m_tool;
-    }
+    delete m_tool.data();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -62,7 +59,7 @@ void AddPiece::undo()
     QDomElement details = GetDetailsSection();
     if (not details.isNull())
     {
-        QDomElement const domElement = doc->elementById(nodeId, VAbstractPattern::TagDetail);
+        QDomElement const domElement = doc->FindElementById(nodeId, VAbstractPattern::TagDetail);
         if (domElement.isElement())
         {
             if (details.removeChild(domElement).isNull())
