@@ -32,7 +32,7 @@
 #include <QtGlobal>
 
 #include "../tools/vtoolseamallowance.h"
-#include "vpiece.h"
+#include "../vpatterndb/vpiece.h"
 #include "vundocommand.h"
 
 class DeletePiece : public VUndoCommand
