@@ -30,13 +30,13 @@
 
 #include <QDomElement>
 
-#include "../ifc/xml/vabstractpattern.h"
 #include "../ifc/ifcdef.h"
-#include "../vmisc/vabstractapplication.h"
+#include "../ifc/xml/vabstractpattern.h"
+#include "../tools/vtoolseamallowance.h"
 #include "../vmisc/def.h"
+#include "../vmisc/vabstractvalapplication.h"
 #include "../vwidgets/vmaingraphicsview.h"
 #include "vundocommand.h"
-#include "../tools/vtoolseamallowance.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 MovePiece::MovePiece(VAbstractPattern *doc, const double &x, const double &y, const quint32 &id,
@@ -52,11 +52,11 @@ MovePiece::MovePiece(VAbstractPattern *doc, const double &x, const double &y, co
     nodeId = id;
 
     SCASSERT(scene != nullptr)
-    QDomElement const domElement = doc->elementById(id, VAbstractPattern::TagDetail);
+    QDomElement const domElement = doc->FindElementById(id, VAbstractPattern::TagDetail);
     if (domElement.isElement())
     {
-        m_oldX = VAbstractValApplication::VApp()->toPixel(doc->GetParametrDouble(domElement, AttrMx, "0.0"));
-        m_oldY = VAbstractValApplication::VApp()->toPixel(doc->GetParametrDouble(domElement, AttrMy, "0.0"));
+        m_oldX = VAbstractValApplication::VApp()->toPixel(VDomDocument::GetParametrDouble(domElement, AttrMx, "0.0"));
+        m_oldY = VAbstractValApplication::VApp()->toPixel(VDomDocument::GetParametrDouble(domElement, AttrMy, "0.0"));
     }
     else
     {
@@ -107,13 +107,13 @@ void MovePiece::Do(qreal x, qreal y)
 {
     qCDebug(vUndo, "Do.");
 
-    QDomElement domElement = doc->elementById(nodeId, VAbstractPattern::TagDetail);
+    QDomElement domElement = doc->FindElementById(nodeId, VAbstractPattern::TagDetail);
     if (domElement.isElement())
     {
         SaveCoordinates(domElement, x, y);
 
         auto *tool = qobject_cast<VToolSeamAllowance *>(VAbstractPattern::getTool(nodeId));
-        if (tool)
+        if (tool != nullptr)
         {
             tool->Move(x, y);
         }
