@@ -29,7 +29,6 @@
 #ifndef MOVESPLINEPATH_H
 #define MOVESPLINEPATH_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -43,33 +42,38 @@ class QGraphicsScene;
 class MoveSplinePath : public VUndoCommand
 {
     Q_OBJECT // NOLINT
+
 public:
     MoveSplinePath(VAbstractPattern *doc, const VSplinePath &oldSplPath, const VSplinePath &newSplPath,
                    const quint32 &id, QUndoCommand *parent = nullptr);
-    virtual ~MoveSplinePath() =default;
-    virtual void undo() override;
-    virtual void redo() override;
-    virtual bool mergeWith(const QUndoCommand *command) override;
-    virtual int  id() const override;
-    quint32      getSplinePathId() const;
-    VSplinePath  getNewSplinePath() const;
+    ~MoveSplinePath() = default;
+
+    void undo() override;
+    void redo() override;
+
+    auto mergeWith(const QUndoCommand *command) -> bool override;
+    auto id() const -> int override;
+
+    auto getSplinePathId() const -> quint32;
+    auto getNewSplinePath() const -> VSplinePath;
+
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(MoveSplinePath) // NOLINT
     VSplinePath oldSplinePath;
     VSplinePath newSplinePath;
     QGraphicsScene *scene;
-    void         Do(const VSplinePath &splPath);
+    void Do(const VSplinePath &splPath);
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline quint32 MoveSplinePath::getSplinePathId() const
+inline auto MoveSplinePath::getSplinePathId() const -> quint32
 {
     return nodeId;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-inline VSplinePath MoveSplinePath::getNewSplinePath() const
+inline auto MoveSplinePath::getNewSplinePath() const -> VSplinePath
 {
     return newSplinePath;
 }
