@@ -29,7 +29,6 @@
 #ifndef RENAMEPP_H
 #define RENAMEPP_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -37,36 +36,40 @@
 
 #include "vundocommand.h"
 
-class RenamePP :public VUndoCommand
+class RenamePP : public VUndoCommand
 {
     Q_OBJECT // NOLINT
+
 public:
     RenamePP(VAbstractPattern *doc, const QString &newPPname, QComboBox *combo, QUndoCommand *parent = nullptr);
-    virtual ~RenamePP() override;
+    ~RenamePP() override;
+
+    void undo() override;
+    void redo() override;
+
+    auto mergeWith(const QUndoCommand *command) -> bool override;
+    auto id() const -> int override;
+
+    auto getNewPPname() const -> QString;
+    auto getOldPPname() const -> QString;
 
-    virtual void undo() override;
-    virtual void redo() override;
-    virtual bool mergeWith(const QUndoCommand *command) override;
-    virtual int  id() const override;
-    QString      getNewPPname() const;
-    QString      getOldPPname() const;
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(RenamePP) // NOLINT
     QComboBox *combo;
-    QString   newPPname;
-    QString   oldPPname;
-    void      ChangeName(const QString &oldName, const QString &newName);
+    QString newPPname;
+    QString oldPPname;
+    void ChangeName(const QString &oldName, const QString &newName);
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline QString RenamePP::getNewPPname() const
+inline auto RenamePP::getNewPPname() const -> QString
 {
     return newPPname;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-inline QString RenamePP::getOldPPname() const
+inline auto RenamePP::getOldPPname() const -> QString
 {
     return oldPPname;
 }
