@@ -57,11 +57,11 @@ void SavePiecePathOptions::undo()
 {
     qCDebug(vUndo, "Undo.");
 
-    QDomElement domElement = doc->elementById(nodeId, VAbstractPattern::TagPath);
+    QDomElement domElement = doc->FindElementById(nodeId, VAbstractPattern::TagPath);
     if (domElement.isElement())
     {
         VToolPiecePath::AddAttributes(doc, domElement, nodeId, m_oldPath);
-        doc->RemoveAllChildren(domElement);//Very important to clear before rewrite
+        VDomDocument::RemoveAllChildren(domElement); //Very important to clear before rewrite
         VToolPiecePath::AddNodes(doc, domElement, m_oldPath);
 
         DecrementReferences(m_newPath.MissingNodes(m_oldPath));
@@ -89,11 +89,11 @@ void SavePiecePathOptions::redo()
 {
     qCDebug(vUndo, "Redo.");
 
-    QDomElement domElement = doc->elementById(nodeId, VAbstractPattern::TagPath);
+    QDomElement domElement = doc->FindElementById(nodeId, VAbstractPattern::TagPath);
     if (domElement.isElement())
     {
         VToolPiecePath::AddAttributes(doc, domElement, nodeId, m_newPath);
-        doc->RemoveAllChildren(domElement);//Very important to clear before rewrite
+        VDomDocument::RemoveAllChildren(domElement); //Very important to clear before rewrite
         VToolPiecePath::AddNodes(doc, domElement, m_newPath);
 
         DecrementReferences(m_oldPath.MissingNodes(m_newPath));
