@@ -53,7 +53,7 @@ void SaveToolOptions::undo()
 {
     qCDebug(vUndo, "Undo.");
 
-    QDomElement const domElement = doc->elementById(nodeId);
+    QDomElement const domElement = doc->FindElementById(nodeId);
     if (domElement.isElement())
     {
         domElement.parentNode().replaceChild(oldXml, domElement);
@@ -74,7 +74,7 @@ void SaveToolOptions::redo()
 {
     qCDebug(vUndo, "Redo.");
 
-    QDomElement const domElement = doc->elementById(nodeId);
+    QDomElement const domElement = doc->FindElementById(nodeId);
     if (domElement.isElement())
     {
         domElement.parentNode().replaceChild(newXml, domElement);
