@@ -297,7 +297,7 @@ auto VisToolMove::CreateOriginObjects(int &iPoint, int &iCurve) -> QVector<QGrap
         QT_WARNING_DISABLE_GCC("-Wswitch-default")
         QT_WARNING_DISABLE_CLANG("-Wswitch-default")
 
-        switch (static_cast<GOType>(obj->getType()))
+        switch (obj->getType())
         {
             case GOType::Point:
             {
@@ -355,7 +355,7 @@ void VisToolMove::CreateMovedRotatedObjects(int &iPoint, int &iCurve, qreal leng
         QT_WARNING_DISABLE_GCC("-Wswitch-default")
         QT_WARNING_DISABLE_CLANG("-Wswitch-default")
 
-        switch (static_cast<GOType>(obj->getType()))
+        switch (obj->getType())
         {
             case GOType::Point:
             {
