@@ -32,27 +32,26 @@
 #include <QLine>
 #include <QPointF>
 #include <QSharedPointer>
-#include <Qt>
 #include <new>
 
 #include "../../tools/drawTools/toolpoint/toolsinglepoint/toollinepoint/vtoolheight.h"
 #include "../vgeometry/vpointf.h"
-#include "../vpatterndb/vcontainer.h"
 #include "../visualization.h"
-#include "visline.h"
 #include "../vmisc/compatibility.h"
+#include "../vpatterndb/vcontainer.h"
+#include "visline.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 VisToolHeight::VisToolHeight(const VContainer *data, QGraphicsItem *parent)
-    : VisLine(data, parent)
+  : VisLine(data, parent)
 {
-    m_basePoint = InitPoint(Color(VColor::SupportColor), this);
-    m_lineP1 = InitPoint(Color(VColor::SupportColor), this);
-    m_lineP2 = InitPoint(Color(VColor::SupportColor), this);
-    m_line = InitItem<VScaledLine>(Color(VColor::SupportColor), this);
-    m_lineIntersection = InitItem<VScaledLine>(Color(VColor::SupportColor), this); //-V656
+    m_basePoint = InitPoint(VColorRole::VisSupportColor, this);
+    m_lineP1 = InitPoint(VColorRole::VisSupportColor, this);
+    m_lineP2 = InitPoint(VColorRole::VisSupportColor, this);
+    m_line = InitItem<VScaledLine>(VColorRole::VisSupportColor, this);
+    m_lineIntersection = InitItem<VScaledLine>(VColorRole::VisSupportColor, this); //-V656
 
-    m_point = InitPoint(Color(VColor::MainColor), this);
+    m_point = InitPoint(VColorRole::VisMainColor, this);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -61,38 +60,38 @@ void VisToolHeight::RefreshGeometry()
     if (m_basePointId > NULL_ID)
     {
         const QSharedPointer<VPointF> first = GetData()->GeometricObject<VPointF>(m_basePointId);
-        DrawPoint(m_basePoint, static_cast<QPointF>(*first), Color(VColor::SupportColor));
+        DrawPoint(m_basePoint, static_cast<QPointF>(*first));
 
         if (m_lineP1Id <= NULL_ID)
         {
-            DrawLine(this, QLineF(static_cast<QPointF>(*first), ScenePos()), Color(VColor::MainColor));
+            DrawLine(this, QLineF(static_cast<QPointF>(*first), ScenePos()));
         }
         else
         {
             const QSharedPointer<VPointF> second = GetData()->GeometricObject<VPointF>(m_lineP1Id);
-            DrawPoint(m_lineP1, static_cast<QPointF>(*second), Color(VColor::SupportColor));
+            DrawPoint(m_lineP1, static_cast<QPointF>(*second));
 
             QLineF base_line;
             if (m_lineP2Id <= NULL_ID)
             {
                 base_line = QLineF(static_cast<QPointF>(*second), ScenePos());
-                DrawLine(m_line, base_line, Color(VColor::SupportColor));
+                DrawLine(m_line, base_line);
             }
             else
             {
                 const QSharedPointer<VPointF> third = GetData()->GeometricObject<VPointF>(m_lineP2Id);
-                DrawPoint(m_lineP2, static_cast<QPointF>(*third), Color(VColor::SupportColor));
+                DrawPoint(m_lineP2, static_cast<QPointF>(*third));
 
                 base_line = QLineF(static_cast<QPointF>(*second), static_cast<QPointF>(*third));
             }
 
-            DrawLine(m_line, base_line, Color(VColor::SupportColor));
+            DrawLine(m_line, base_line);
 
-            QPointF height = VToolHeight::FindPoint(base_line, static_cast<QPointF>(*first));
-            DrawPoint(m_point, height, Color(VColor::MainColor));
+            QPointF const height = VToolHeight::FindPoint(base_line, static_cast<QPointF>(*first));
+            DrawPoint(m_point, height);
 
-            QLineF height_line(static_cast<QPointF>(*first), height);
-            DrawLine(this, height_line, Color(VColor::MainColor), LineStyle());
+            QLineF const height_line(static_cast<QPointF>(*first), height);
+            DrawLine(this, height_line, LineStyle());
 
             ShowIntersection(height_line, base_line);
         }
@@ -110,13 +109,12 @@ void VisToolHeight::VisualMode(quint32 id)
 void VisToolHeight::ShowIntersection(const QLineF &height_line, const QLineF &base_line)
 {
     QPointF p;
-    QLineF::IntersectType intersect = Intersects(height_line, base_line, &p);
+    QLineF::IntersectType const intersect = height_line.intersects(base_line, &p);
 
     if (intersect == QLineF::UnboundedIntersection)
     {
         m_lineIntersection->setVisible(true);
-        DrawLine(m_lineIntersection, QLineF(base_line.p1(), height_line.p2()), Color(VColor::SupportColor),
-                 Qt::DashLine);
+        DrawLine(m_lineIntersection, QLineF(base_line.p1(), height_line.p2()), Qt::DashLine);
     }
     else if (intersect == QLineF::BoundedIntersection)
     {
