@@ -34,28 +34,27 @@
 #include <QPen>
 #include <QPointF>
 #include <QSharedPointer>
-#include <Qt>
 #include <new>
 
 #include "../../tools/drawTools/toolpoint/toolsinglepoint/vtoolpointofintersectionarcs.h"
+#include "../line/visline.h"
 #include "../vgeometry/vabstractcurve.h"
 #include "../vgeometry/varc.h"
-#include "../vpatterndb/vcontainer.h"
 #include "../visualization.h"
-#include "visualization/line/visline.h"
+#include "../vpatterndb/vcontainer.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 VisToolPointOfIntersectionArcs::VisToolPointOfIntersectionArcs(const VContainer *data, QGraphicsItem *parent)
-    : VisLine(data, parent)
+  : VisLine(data, parent)
 {
     this->setPen(QPen(Qt::NoPen)); // don't use parent this time
 
-    m_arc1Path = InitItem<VCurvePathItem>(Qt::darkGreen, this);
+    m_arc1Path = InitItem<VCurvePathItem>(VColorRole::VisSupportColor2, this);
     m_arc1Path->setFlag(QGraphicsItem::ItemStacksBehindParent, false);
-    m_arc2Path = InitItem<VCurvePathItem>(Qt::darkRed, this);
+    m_arc2Path = InitItem<VCurvePathItem>(VColorRole::VisSupportColor4, this);
     m_arc2Path->setFlag(QGraphicsItem::ItemStacksBehindParent, false);
 
-    m_point = InitPoint(Color(VColor::MainColor), this);
+    m_point = InitPoint(VColorRole::VisMainColor, this);
     m_point->setZValue(2);
     m_point->setFlag(QGraphicsItem::ItemStacksBehindParent, false);
 }
@@ -66,16 +65,16 @@ void VisToolPointOfIntersectionArcs::RefreshGeometry()
     if (m_arc1Id > NULL_ID)
     {
         const QSharedPointer<VArc> arc1 = GetData()->GeometricObject<VArc>(m_arc1Id);
-        DrawPath(m_arc1Path, arc1->GetPath(), arc1->DirectionArrows(), Qt::darkGreen, Qt::SolidLine, Qt::RoundCap);
+        DrawPath(m_arc1Path, arc1->GetPath(), arc1->DirectionArrows(), Qt::SolidLine, Qt::RoundCap);
 
         if (m_arc2Id > NULL_ID)
         {
             const QSharedPointer<VArc> arc2 = GetData()->GeometricObject<VArc>(m_arc2Id);
-            DrawPath(m_arc2Path, arc2->GetPath(), arc2->DirectionArrows(), Qt::darkRed, Qt::SolidLine, Qt::RoundCap);
+            DrawPath(m_arc2Path, arc2->GetPath(), arc2->DirectionArrows(), Qt::SolidLine, Qt::RoundCap);
 
             QPointF fPoint;
             VToolPointOfIntersectionArcs::FindPoint(arc1.data(), arc2.data(), m_crossPoint, &fPoint);
-            DrawPoint(m_point, fPoint, Color(VColor::MainColor));
+            DrawPoint(m_point, fPoint);
         }
     }
 }
