@@ -32,30 +32,29 @@
 #include <QLineF>
 #include <QPointF>
 #include <QSharedPointer>
-#include <Qt>
 #include <new>
 
 #include "../../tools/drawTools/toolpoint/toolsinglepoint/toollinepoint/vtoolshoulderpoint.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
-#include "../vpatterndb/vcontainer.h"
 #include "../visualization.h"
-#include "visline.h"
 #include "../vmisc/vmodifierkey.h"
+#include "../vpatterndb/vcontainer.h"
+#include "visline.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 VisToolShoulderPoint::VisToolShoulderPoint(const VContainer *data, QGraphicsItem *parent)
-    :VisLine(data, parent)
+  : VisLine(data, parent)
 {
-    m_line1P1 = InitPoint(Color(VColor::SupportColor), this);
-    m_line1P2 = InitPoint(Color(VColor::SupportColor), this); //-V656
-    m_line1 = InitItem<VScaledLine>(Color(VColor::SupportColor), this);
+    m_line1P1 = InitPoint(VColorRole::VisSupportColor, this);
+    m_line1P2 = InitPoint(VColorRole::VisSupportColor, this); //-V656
+    m_line1 = InitItem<VScaledLine>(VColorRole::VisSupportColor, this);
 
-    m_line2P2 = InitPoint(Color(VColor::SupportColor), this);
-    m_line2 = InitItem<VScaledLine>(Color(VColor::SupportColor), this);
-    m_line3 = InitItem<VScaledLine>(Color(VColor::SupportColor), this); //-V656
+    m_line2P2 = InitPoint(VColorRole::VisSupportColor, this);
+    m_line2 = InitItem<VScaledLine>(VColorRole::VisSupportColor, this);
+    m_line3 = InitItem<VScaledLine>(VColorRole::VisSupportColor, this); //-V656
 
-    m_point = InitPoint(Color(VColor::MainColor), this);
+    m_point = InitPoint(VColorRole::VisMainColor, this);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -64,58 +63,53 @@ void VisToolShoulderPoint::RefreshGeometry()
     if (m_point3Id > NULL_ID)
     {
         const QSharedPointer<VPointF> first = GetData()->GeometricObject<VPointF>(m_point3Id);
-        DrawPoint(m_line1P1, static_cast<QPointF>(*first), Color(VColor::SupportColor));
+        DrawPoint(m_line1P1, static_cast<QPointF>(*first));
 
         if (m_lineP1Id <= NULL_ID)
         {
-            DrawLine(m_line1, QLineF(static_cast<QPointF>(*first), ScenePos()), Color(VColor::SupportColor));
+            DrawLine(m_line1, QLineF(static_cast<QPointF>(*first), ScenePos()));
         }
         else
         {
             const QSharedPointer<VPointF> second = GetData()->GeometricObject<VPointF>(m_lineP1Id);
-            DrawPoint(m_line1P2, static_cast<QPointF>(*second), Color(VColor::SupportColor));
+            DrawPoint(m_line1P2, static_cast<QPointF>(*second));
 
-            DrawLine(m_line1, QLineF(static_cast<QPointF>(*first), static_cast<QPointF>(*second)),
-                     Color(VColor::SupportColor));
+            DrawLine(m_line1, QLineF(static_cast<QPointF>(*first), static_cast<QPointF>(*second)));
 
             if (m_lineP2Id <= NULL_ID)
             {
-                DrawLine(m_line2, QLineF(static_cast<QPointF>(*second), ScenePos()), Color(VColor::SupportColor));
+                DrawLine(m_line2, QLineF(static_cast<QPointF>(*second), ScenePos()));
             }
             else
             {
                 const QSharedPointer<VPointF> third = GetData()->GeometricObject<VPointF>(m_lineP2Id);
-                DrawPoint(m_line2P2, static_cast<QPointF>(*third), Color(VColor::SupportColor));
+                DrawPoint(m_line2P2, static_cast<QPointF>(*third));
 
-                DrawLine(m_line2, QLineF(static_cast<QPointF>(*second), static_cast<QPointF>(*third)),
-                         Color(VColor::SupportColor));
+                DrawLine(m_line2, QLineF(static_cast<QPointF>(*second), static_cast<QPointF>(*third)));
 
                 if (not qFuzzyIsNull(m_length))
                 {
-                    QPointF fPoint = VToolShoulderPoint::FindPoint(static_cast<QPointF>(*second),
-                                                                   static_cast<QPointF>(*third),
-                                                                   static_cast<QPointF>(*first), m_length);
-                    QLineF mainLine = QLineF(static_cast<QPointF>(*second), fPoint);
-                    DrawLine(this, mainLine, Color(VColor::MainColor), LineStyle());
+                    QPointF const fPoint =
+                        VToolShoulderPoint::FindPoint(static_cast<QPointF>(*second), static_cast<QPointF>(*third),
+                                                      static_cast<QPointF>(*first), m_length);
+                    auto const mainLine = QLineF(static_cast<QPointF>(*second), fPoint);
+                    DrawLine(this, mainLine, LineStyle());
 
-                    DrawPoint(m_point, mainLine.p2(), Color(VColor::MainColor));
-                    DrawLine(m_line3, QLineF(static_cast<QPointF>(*first), mainLine.p2()), Color(VColor::SupportColor),
-                             Qt::DashLine);
+                    DrawPoint(m_point, mainLine.p2());
+                    DrawLine(m_line3, QLineF(static_cast<QPointF>(*first), mainLine.p2()), Qt::DashLine);
                 }
                 else if (GetMode() == Mode::Creation)
                 {
-                    QLineF cursorLine (static_cast<QPointF>(*first), ScenePos());
+                    QLineF const cursorLine(static_cast<QPointF>(*first), ScenePos());
 
-                    qreal len = cursorLine.length();
-                    QPointF fPoint = VToolShoulderPoint::FindPoint(static_cast<QPointF>(*second),
-                                                                   static_cast<QPointF>(*third),
-                                                                   static_cast<QPointF>(*first), len);
-                    QLineF mainLine = QLineF(static_cast<QPointF>(*second), fPoint);
-                    DrawLine(this, mainLine, Color(VColor::MainColor), LineStyle());
+                    qreal const len = cursorLine.length();
+                    QPointF const fPoint = VToolShoulderPoint::FindPoint(
+                        static_cast<QPointF>(*second), static_cast<QPointF>(*third), static_cast<QPointF>(*first), len);
+                    auto const mainLine = QLineF(static_cast<QPointF>(*second), fPoint);
+                    DrawLine(this, mainLine, LineStyle());
 
-                    DrawPoint(m_point, mainLine.p2(), Color(VColor::MainColor));
-                    DrawLine(m_line3, QLineF(static_cast<QPointF>(*first), mainLine.p2()), Color(VColor::SupportColor),
-                             Qt::DashLine);
+                    DrawPoint(m_point, mainLine.p2());
+                    DrawLine(m_line3, QLineF(static_cast<QPointF>(*first), mainLine.p2()), Qt::DashLine);
 
                     const QString prefix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
                     SetToolTip(tr("Length = %1%2; "
@@ -125,12 +119,11 @@ void VisToolShoulderPoint::RefreshGeometry()
                 }
                 else
                 {
-                    qreal angle = QLineF(static_cast<QPointF>(*second), static_cast<QPointF>(*third)).angle();
-                    QPointF endRay = Ray(static_cast<QPointF>(*second), angle);
-                    QLineF mainLine = VGObject::BuildLine(static_cast<QPointF>(*second),
-                                                          QLineF(static_cast<QPointF>(*second), endRay).length(),
-                                                          angle);
-                    DrawLine(this, mainLine, Color(VColor::MainColor), LineStyle());
+                    qreal const angle = QLineF(static_cast<QPointF>(*second), static_cast<QPointF>(*third)).angle();
+                    QPointF const endRay = Ray(static_cast<QPointF>(*second), angle);
+                    QLineF const mainLine = VGObject::BuildLine(
+                        static_cast<QPointF>(*second), QLineF(static_cast<QPointF>(*second), endRay).length(), angle);
+                    DrawLine(this, mainLine, LineStyle());
                 }
             }
         }
