@@ -34,28 +34,30 @@
 #include <QPen>
 #include <QPointF>
 #include <QSharedPointer>
-#include <new>
 #include <QtMath>
+#include <new>
 
 #include "../../tools/drawTools/toolpoint/toolsinglepoint/vtooltriangle.h"
 #include "../vgeometry/vpointf.h"
-#include "../vpatterndb/vcontainer.h"
 #include "../visualization.h"
+#include "../vpatterndb/vcontainer.h"
 #include "visline.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 VisToolTriangle::VisToolTriangle(const VContainer *data, QGraphicsItem *parent)
-    :VisLine(data, parent)
+  : VisLine(data, parent)
 {
-    m_axisP1 = InitPoint(Color(VColor::SupportColor), this);
-    m_axisP2 = InitPoint(Color(VColor::SupportColor), this);
-    m_axis = InitItem<VCurvePathItem>(Color(VColor::SupportColor), this);
-    m_hypotenuseP1 = InitPoint(Color(VColor::SupportColor), this);
-    m_hypotenuseP2 = InitPoint(Color(VColor::SupportColor), this);
-    m_foot1 = InitItem<VScaledLine>(Color(VColor::SupportColor), this);
-    m_foot2 = InitItem<VScaledLine>(Color(VColor::SupportColor), this); //-V656
+    SetColorRole(VColorRole::VisSupportColor);
 
-    m_point = InitPoint(Color(VColor::MainColor), this);
+    m_axisP1 = InitPoint(VColorRole::VisSupportColor, this);
+    m_axisP2 = InitPoint(VColorRole::VisSupportColor, this);
+    m_axis = InitItem<VCurvePathItem>(VColorRole::VisSupportColor, this);
+    m_hypotenuseP1 = InitPoint(VColorRole::VisSupportColor, this);
+    m_hypotenuseP2 = InitPoint(VColorRole::VisSupportColor, this);
+    m_foot1 = InitItem<VScaledLine>(VColorRole::VisSupportColor, this);
+    m_foot2 = InitItem<VScaledLine>(VColorRole::VisSupportColor, this); //-V656
+
+    m_point = InitPoint(VColorRole::VisMainColor, this);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -64,56 +66,50 @@ void VisToolTriangle::RefreshGeometry()
     if (m_object1Id > NULL_ID)
     {
         const QSharedPointer<VPointF> first = GetData()->GeometricObject<VPointF>(m_object1Id);
-        DrawPoint(m_axisP1, static_cast<QPointF>(*first), Color(VColor::SupportColor));
+        DrawPoint(m_axisP1, static_cast<QPointF>(*first));
 
         if (m_object2Id <= NULL_ID)
         {
-            DrawAimedAxis(m_axis, QLineF(static_cast<QPointF>(*first), ScenePos()), Color(VColor::SupportColor));
+            DrawAimedAxis(m_axis, QLineF(static_cast<QPointF>(*first), ScenePos()));
         }
         else
         {
             const QSharedPointer<VPointF> second = GetData()->GeometricObject<VPointF>(m_object2Id);
-            DrawPoint(m_axisP2, static_cast<QPointF>(*second), Color(VColor::SupportColor));
+            DrawPoint(m_axisP2, static_cast<QPointF>(*second));
 
-            DrawAimedAxis(m_axis, QLineF(static_cast<QPointF>(*first), static_cast<QPointF>(*second)),
-                          Color(VColor::SupportColor));
+            DrawAimedAxis(m_axis, QLineF(static_cast<QPointF>(*first), static_cast<QPointF>(*second)));
 
             if (m_hypotenuseP1Id > NULL_ID)
             {
                 const QSharedPointer<VPointF> third = GetData()->GeometricObject<VPointF>(m_hypotenuseP1Id);
-                DrawPoint(m_hypotenuseP1, static_cast<QPointF>(*third), Color(VColor::SupportColor));
+                DrawPoint(m_hypotenuseP1, static_cast<QPointF>(*third));
 
                 if (m_hypotenuseP2Id <= NULL_ID)
                 {
-                    DrawLine(this, QLineF(static_cast<QPointF>(*third), ScenePos()), Color(VColor::SupportColor),
-                             Qt::DashLine);
+                    DrawLine(this, QLineF(static_cast<QPointF>(*third), ScenePos()), Qt::DashLine);
 
                     QPointF trPoint;
                     VToolTriangle::FindPoint(static_cast<QPointF>(*first), static_cast<QPointF>(*second),
                                              static_cast<QPointF>(*third), ScenePos(), &trPoint);
-                    DrawPoint(m_point, trPoint, Color(VColor::MainColor));
+                    DrawPoint(m_point, trPoint);
 
-                    DrawLine(m_foot1, QLineF(static_cast<QPointF>(*third), trPoint), Color(VColor::SupportColor),
-                             Qt::DashLine);
-                    DrawLine(m_foot2, QLineF(ScenePos(), trPoint), Color(VColor::SupportColor), Qt::DashLine);
+                    DrawLine(m_foot1, QLineF(static_cast<QPointF>(*third), trPoint), Qt::DashLine);
+                    DrawLine(m_foot2, QLineF(ScenePos(), trPoint), Qt::DashLine);
                 }
                 else
                 {
                     const QSharedPointer<VPointF> forth = GetData()->GeometricObject<VPointF>(m_hypotenuseP2Id);
-                    DrawPoint(m_hypotenuseP2, static_cast<QPointF>(*forth), Color(VColor::SupportColor));
+                    DrawPoint(m_hypotenuseP2, static_cast<QPointF>(*forth));
 
-                    DrawLine(this, QLineF(static_cast<QPointF>(*third), static_cast<QPointF>(*forth)),
-                             Color(VColor::SupportColor), Qt::DashLine);
+                    DrawLine(this, QLineF(static_cast<QPointF>(*third), static_cast<QPointF>(*forth)), Qt::DashLine);
 
                     QPointF trPoint;
                     VToolTriangle::FindPoint(static_cast<QPointF>(*first), static_cast<QPointF>(*second),
                                              static_cast<QPointF>(*third), static_cast<QPointF>(*forth), &trPoint);
-                    DrawPoint(m_point, trPoint, Color(VColor::MainColor));
+                    DrawPoint(m_point, trPoint);
 
-                    DrawLine(m_foot1, QLineF(static_cast<QPointF>(*third), trPoint), Color(VColor::SupportColor),
-                             Qt::DashLine);
-                    DrawLine(m_foot2, QLineF(static_cast<QPointF>(*forth), trPoint), Color(VColor::SupportColor),
-                             Qt::DashLine);
+                    DrawLine(m_foot1, QLineF(static_cast<QPointF>(*third), trPoint), Qt::DashLine);
+                    DrawLine(m_foot2, QLineF(static_cast<QPointF>(*forth), trPoint), Qt::DashLine);
                 }
             }
         }
@@ -128,13 +124,11 @@ void VisToolTriangle::VisualMode(quint32 id)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VisToolTriangle::DrawAimedAxis(VCurvePathItem *item, const QLineF &line, const QColor &color,
-                                    Qt::PenStyle style)
+void VisToolTriangle::DrawAimedAxis(VCurvePathItem *item, const QLineF &line, Qt::PenStyle style)
 {
-    SCASSERT (item != nullptr)
+    SCASSERT(item != nullptr)
 
     QPen visPen = item->pen();
-    visPen.setColor(color);
     visPen.setStyle(style);
 
     item->setPen(visPen);
@@ -143,8 +137,8 @@ void VisToolTriangle::DrawAimedAxis(VCurvePathItem *item, const QLineF &line, co
     path.moveTo(line.p1());
     path.lineTo(line.p2());
 
-    qreal arrow_step = 60;
-    qreal arrow_size = 10;
+    qreal const arrow_step = 60;
+    qreal const arrow_size = 10;
 
     if (line.length() < arrow_step)
     {
@@ -156,11 +150,11 @@ void VisToolTriangle::DrawAimedAxis(VCurvePathItem *item, const QLineF &line, co
     axis.setAngle(line.angle());
     axis.setLength(arrow_step);
 
-    int steps = qFloor(line.length()/arrow_step);
-    for (int i=0; i<steps; ++i)
+    int const steps = qFloor(line.length() / arrow_step);
+    for (int i = 0; i < steps; ++i)
     {
         DrawArrow(axis, path, arrow_size);
-        axis.setLength(axis.length()+arrow_step);
+        axis.setLength(axis.length() + arrow_step);
     }
     item->setPath(path);
     item->setVisible(true);
@@ -172,7 +166,7 @@ void VisToolTriangle::DrawArrow(const QLineF &axis, QPainterPath &path, const qr
     QLineF arrowPart1;
     arrowPart1.setP1(axis.p2());
     arrowPart1.setLength(arrow_size);
-    arrowPart1.setAngle(axis.angle()+180+35);
+    arrowPart1.setAngle(axis.angle() + 180 + 35);
 
     path.moveTo(arrowPart1.p1());
     path.lineTo(arrowPart1.p2());
@@ -180,7 +174,7 @@ void VisToolTriangle::DrawArrow(const QLineF &axis, QPainterPath &path, const qr
     QLineF arrowPart2;
     arrowPart2.setP1(axis.p2());
     arrowPart2.setLength(arrow_size);
-    arrowPart2.setAngle(axis.angle()+180-35);
+    arrowPart2.setAngle(axis.angle() + 180 - 35);
 
     path.moveTo(arrowPart2.p1());
     path.lineTo(arrowPart2.p2());
