@@ -41,25 +41,23 @@
 #include <QPoint>
 #include <QPolygonF>
 #include <QRectF>
-#include <Qt>
 
-#include "../vwidgets/global.h"
 #include "../vgeometry/vgobject.h"
-#include "../vmisc/vabstractapplication.h"
 #include "../vmisc/literals.h"
-#include "vmaingraphicsscene.h"
-#include "vmaingraphicsview.h"
-#include "vgraphicssimpletextitem.h"
+#include "../vmisc/theme/themeDef.h"
+#include "../vwidgets/global.h"
 #include "scalesceneitems.h"
+#include "vmaingraphicsview.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-VControlPointSpline::VControlPointSpline(const qint32 &indexSpline, SplinePointPosition position, QGraphicsItem *parent)
-    : VScenePoint(parent),
-      controlLine(nullptr),
-      indexSpline(indexSpline),
-      position(position),
-      freeAngle(true),
-      freeLength(true)
+VControlPointSpline::VControlPointSpline(const vsizetype &indexSpline, SplinePointPosition position,
+                                         QGraphicsItem *parent)
+  : VScenePoint(VColorRole::ControlPointColor, parent),
+    controlLine(nullptr),
+    indexSpline(indexSpline),
+    position(position),
+    freeAngle(true),
+    freeLength(true)
 {
     Init();
 }
@@ -72,22 +70,22 @@ VControlPointSpline::VControlPointSpline(const qint32 &indexSpline, SplinePointP
  * @param controlPoint control point.
  * @param parent parent object.
  */
-VControlPointSpline::VControlPointSpline(const qint32 &indexSpline, SplinePointPosition position,
-                                         const QPointF &controlPoint, bool freeAngle,
-                                         bool freeLength, QGraphicsItem *parent)
-    : VScenePoint(parent),
-      controlLine(nullptr),
-      indexSpline(indexSpline),
-      position(position),
-      freeAngle(freeAngle),
-      freeLength(freeLength)
+VControlPointSpline::VControlPointSpline(const vsizetype &indexSpline, SplinePointPosition position,
+                                         const QPointF &controlPoint, bool freeAngle, bool freeLength,
+                                         QGraphicsItem *parent)
+  : VScenePoint(VColorRole::ControlPointColor, parent),
+    controlLine(nullptr),
+    indexSpline(indexSpline),
+    position(position),
+    freeAngle(freeAngle),
+    freeLength(freeLength)
 {
     Init();
 
+    this->setPos(controlPoint);
     this->setFlag(QGraphicsItem::ItemIsMovable, true);
     this->setFlag(QGraphicsItem::ItemSendsGeometryChanges, true);
     this->setAcceptHoverEvents(true);
-    this->setPos(controlPoint);
 
     // Do not draw control point in constructor. It creates artefacts if they enabled from start.
 }
@@ -95,14 +93,10 @@ VControlPointSpline::VControlPointSpline(const qint32 &indexSpline, SplinePointP
 //---------------------------------------------------------------------------------------------------------------------
 void VControlPointSpline::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
-    QPen lPen = controlLine->pen();
-    lPen.setColor(CorrectColor(controlLine, Qt::black));
-    controlLine->setPen(lPen);
-
     QPointF p1, p2;
     VGObject::LineIntersectCircle(QPointF(), ScaledRadius(SceneScale(scene())),
-                                  QLineF( QPointF(), controlLine->line().p1()), p1, p2);
-    QLineF line(controlLine->line().p1(), p1);
+                                  QLineF(QPointF(), controlLine->line().p1()), p1, p2);
+    QLineF const line(controlLine->line().p1(), p1);
     controlLine->setLine(line);
 
     VScenePoint::paint(painter, option, widget);
@@ -129,7 +123,7 @@ void VControlPointSpline::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
  * @param value value.
  * @return value.
  */
-QVariant VControlPointSpline::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value)
+auto VControlPointSpline::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value) -> QVariant
 {
     switch (change)
     {
@@ -139,8 +133,8 @@ QVariant VControlPointSpline::itemChange(QGraphicsItem::GraphicsItemChange chang
             {
                 const QPointF splPoint = controlLine->line().p1() + pos();
 
-                QLineF newLine(splPoint, value.toPointF());// value - new position.
-                QLineF oldLine(splPoint, pos());// pos() - old position.
+                QLineF newLine(splPoint, value.toPointF()); // value - new position.
+                QLineF const oldLine(splPoint, pos());      // pos() - old position.
 
                 if (not freeAngle)
                 {
@@ -173,7 +167,7 @@ QVariant VControlPointSpline::itemChange(QGraphicsItem::GraphicsItemChange chang
                     const QList<QGraphicsView *> viewList = scene()->views();
                     if (not viewList.isEmpty())
                     {
-                        if (VMainGraphicsView *view = qobject_cast<VMainGraphicsView *>(viewList.at(0)))
+                        if (auto *view = qobject_cast<VMainGraphicsView *>(viewList.at(0)))
                         {
                             view->EnsureItemVisibleWithDelay(this, VMainGraphicsView::scrollDelay);
                         }
@@ -204,7 +198,7 @@ void VControlPointSpline::mousePressEvent(QGraphicsSceneMouseEvent *event)
         }
 
         // Somehow clicking on notselectable object do not clean previous selections.
-        if (not (flags() & ItemIsSelectable) && scene())
+        if (not(flags() & ItemIsSelectable) && scene())
         {
             scene()->clearSelection();
         }
@@ -215,13 +209,11 @@ void VControlPointSpline::mousePressEvent(QGraphicsSceneMouseEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void VControlPointSpline::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
-    if (event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick)
+    if (event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick &&
+        (freeAngle || freeLength))
     {
-        if (freeAngle || freeLength)
-        {
-            SetItemOverrideCursor(this, cursorArrowOpenHand, 1, 1);
-            emit Released();
-        }
+        SetItemOverrideCursor(this, cursorArrowOpenHand, 1, 1);
+        emit Released();
     }
     VScenePoint::mouseReleaseEvent(event);
 }
@@ -235,37 +227,29 @@ void VControlPointSpline::contextMenuEvent(QGraphicsSceneContextMenuEvent *event
 //---------------------------------------------------------------------------------------------------------------------
 void VControlPointSpline::Init()
 {
-    m_baseColor = Qt::red;
     SetOnlyPoint(true);
     this->setBrush(QBrush(Qt::NoBrush));
     this->setZValue(100);
 
-    controlLine = new VScaledLine(this);
+    controlLine = new VScaledLine(VColorRole::ControlLineColor, this);
     controlLine->SetBoldLine(false);
-    //controlLine->setFlag(QGraphicsItem::ItemStacksBehindParent, true);
+    // controlLine->setFlag(QGraphicsItem::ItemStacksBehindParent, true);
     controlLine->setVisible(false);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VControlPointSpline::SetCtrlLine(const QPointF &controlPoint, const QPointF &splinePoint)
 {
-    QLineF circleLine (QPointF(), splinePoint-controlPoint);
+    QLineF const circleLine(QPointF(), splinePoint - controlPoint);
     const qreal radius = ScaledRadius(SceneScale(scene()));
 
-    if (circleLine.length() > radius)
-    {
-        QPointF p1, p2;
-        VGObject::LineIntersectCircle(QPointF(), radius, circleLine, p1, p2);
-        QLineF line(splinePoint-controlPoint, p1);
-        controlLine->setFlag(QGraphicsItem::ItemSendsGeometryChanges, false);
-        controlLine->setLine(line);
-        controlLine->setVisible(not line.isNull());
-        controlLine->setFlag(QGraphicsItem::ItemSendsGeometryChanges, true);
-    }
-    else
-    {
-        controlLine->setVisible(false);
-    }
+    QPointF p1, p2;
+    VGObject::LineIntersectCircle(QPointF(), radius, circleLine, p1, p2);
+    QLineF const line(splinePoint - controlPoint, p1);
+    controlLine->setFlag(QGraphicsItem::ItemSendsGeometryChanges, false);
+    controlLine->setLine(line);
+    controlLine->setVisible(not line.isNull());
+    controlLine->setFlag(QGraphicsItem::ItemSendsGeometryChanges, true);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -276,7 +260,7 @@ void VControlPointSpline::SetCtrlLine(const QPointF &controlPoint, const QPointF
  * @param controlPoint control point.
  * @param splinePoint spline point.
  */
-void VControlPointSpline::RefreshCtrlPoint(const qint32 &indexSpline, SplinePointPosition pos,
+void VControlPointSpline::RefreshCtrlPoint(const vsizetype &indexSpline, SplinePointPosition pos,
                                            const QPointF &controlPoint, const QPointF &splinePoint, bool freeAngle,
                                            bool freeLength)
 {
