@@ -30,8 +30,6 @@
 
 #include <QStyledItemDelegate>
 
-#include "../vmisc/defglobal.h"
-
 class VDecorationAligningDelegate : public QStyledItemDelegate
 {
     Q_OBJECT // NOLINT
@@ -39,7 +37,7 @@ class VDecorationAligningDelegate : public QStyledItemDelegate
 public:
     explicit VDecorationAligningDelegate(Qt::Alignment alignment, QObject *parent = nullptr);
 
-    Qt::Alignment Alignment() const;
+    auto Alignment() const -> Qt::Alignment;
 
     void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
 
@@ -50,7 +48,7 @@ private:
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline Qt::Alignment VDecorationAligningDelegate::Alignment() const
+inline auto VDecorationAligningDelegate::Alignment() const -> Qt::Alignment
 {
     return m_alignment;
 }
