@@ -93,7 +93,8 @@ void VGraphicsSimpleTextItem::paint(QPainter *painter, const QStyleOptionGraphic
     QFont font = this->font();
     if (font.pointSize() != VAbstractApplication::VApp()->Settings()->GetPatternLabelFontSize())
     {
-        font.setPointSize(qMax(VAbstractApplication::VApp()->Settings()->GetPatternLabelFontSize(), 1));
+        font.setPointSize(qMax(VAbstractApplication::VApp()->Settings()->GetPatternLabelFontSize(),
+                               static_cast<int>(minVisibleFontSize)));
         setFont(font);
     }
 
@@ -118,24 +119,22 @@ void VGraphicsSimpleTextItem::paint(QPainter *painter, const QStyleOptionGraphic
     {
         VMainGraphicsView::NewSceneRect(scene, view, this);
     }
+
+    if (font.pointSize() * scale < minVisibleFontSize)
+    {
+        return; // smaller font size will cause problems on Windows
+    }
+
     PaintWithFixItemHighlightSelected<QGraphicsSimpleTextItem>(this, painter, option, widget);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VGraphicsSimpleTextItem::setEnabled(bool enabled)
+void VGraphicsSimpleTextItem::SetEnabledState(bool enabled)
 {
     QGraphicsSimpleTextItem::setEnabled(enabled);
-    if (this->scene())
+    if (scene() != nullptr)
     {
-        const QPalette palet = this->scene()->palette();
-        if (enabled)
-        {
-            setBrush(palet.brush(QPalette::Active, QPalette::Text));
-        }
-        else
-        {
-            setBrush(palet.brush(QPalette::Disabled, QPalette::Text));
-        }
+        setBrush(scene()->palette().brush(enabled ? QPalette::Active : QPalette::Disabled, QPalette::Text));
     }
 }
 
