@@ -31,13 +31,15 @@
 #include <QSyntaxHighlighter>
 #include <QVector>
 
+#include "../vmisc/defglobal.h"
+
 class QString;
 class QTextDocument;
 
 struct ParenthesisInfo
 {
     char character;
-    int position;
+    vsizetype position;
 };
 
 class VTextBlockData final : public QTextBlockUserData
@@ -45,7 +47,7 @@ class VTextBlockData final : public QTextBlockUserData
 public:
     VTextBlockData();
 
-    QVector<ParenthesisInfo *> Parentheses();
+    auto Parentheses() -> QVector<ParenthesisInfo *>;
     void insert(ParenthesisInfo *info);
 
 private:
