@@ -196,10 +196,7 @@ void GraphicsViewZoom::set_zoom_factor_base(double value)
 //---------------------------------------------------------------------------------------------------------------------
 void GraphicsViewZoom::InitScrollingAnimation()
 {
-    if (not verticalScrollAnim.isNull())
-    {
-        delete verticalScrollAnim;
-    }
+    delete verticalScrollAnim.data();
 
     VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
 
@@ -209,10 +206,7 @@ void GraphicsViewZoom::InitScrollingAnimation()
     connect(verticalScrollAnim.data(), &QTimeLine::valueChanged, this, &GraphicsViewZoom::VerticalScrollingTime);
     connect(verticalScrollAnim.data(), &QTimeLine::finished, this, &GraphicsViewZoom::animFinished);
 
-    if (not horizontalScrollAnim.isNull())
-    {
-        delete horizontalScrollAnim;
-    }
+    delete horizontalScrollAnim.data();
 
     horizontalScrollAnim = new QTimeLine(settings->GetScrollingDuration(), this);
     horizontalScrollAnim->setUpdateInterval(settings->GetScrollingUpdateInterval());
@@ -650,39 +644,44 @@ void VMainGraphicsView::mouseDoubleClickEvent(QMouseEvent *event)
 void VMainGraphicsView::dragEnterEvent(QDragEnterEvent *event)
 {
     const QMimeData *mime = event->mimeData();
-    auto *currentScene = qobject_cast<VMainGraphicsScene *>(scene());
-    if (currentScene != nullptr && currentScene->AcceptDrop() && mime != nullptr && mime->hasText())
+
+    if (const auto *currentScene = qobject_cast<VMainGraphicsScene *>(scene());
+        currentScene != nullptr && currentScene->AcceptDrop() && mime != nullptr && mime->hasText())
     {
-        QUrl const urlPath(mime->text().simplified());
-        if (urlPath.isLocalFile())
+        if (QUrl const urlPath(mime->text().simplified()); urlPath.isLocalFile())
         {
             const QString fileName = urlPath.toLocalFile();
-            QFileInfo const f(fileName);
-            if (f.exists() && IsMimeTypeImage(QMimeDatabase().mimeTypeForFile(fileName)))
+            if (QFileInfo const f(fileName); f.exists() && IsMimeTypeImage(QMimeDatabase().mimeTypeForFile(fileName)))
             {
                 event->acceptProposedAction();
             }
+            else
+            {
+                event->ignore();
+            }
         }
     }
-    QGraphicsView::dragEnterEvent(event);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VMainGraphicsView::dragMoveEvent(QDragMoveEvent *event)
 {
     const QMimeData *mime = event->mimeData();
-    auto *currentScene = qobject_cast<VMainGraphicsScene *>(scene());
-    if (currentScene != nullptr && currentScene->AcceptDrop() && mime != nullptr && mime->hasText())
+
+    if (const auto *currentScene = qobject_cast<VMainGraphicsScene *>(scene());
+        currentScene != nullptr && currentScene->AcceptDrop() && mime != nullptr && mime->hasText())
     {
-        QUrl const urlPath(mime->text().simplified());
-        if (urlPath.isLocalFile())
+        if (QUrl const urlPath(mime->text().simplified()); urlPath.isLocalFile())
         {
             const QString fileName = urlPath.toLocalFile();
-            QFileInfo const f(fileName);
-            if (f.exists() && IsMimeTypeImage(QMimeDatabase().mimeTypeForFile(fileName)))
+            if (QFileInfo const f(fileName); f.exists() && IsMimeTypeImage(QMimeDatabase().mimeTypeForFile(fileName)))
             {
                 event->acceptProposedAction();
             }
+            else
+            {
+                event->ignore();
+            }
         }
     }
 }
@@ -691,19 +690,22 @@ void VMainGraphicsView::dragMoveEvent(QDragMoveEvent *event)
 void VMainGraphicsView::dropEvent(QDropEvent *event)
 {
     const QMimeData *mime = event->mimeData();
-    auto *currentScene = qobject_cast<VMainGraphicsScene *>(scene());
-    if (currentScene != nullptr && currentScene->AcceptDrop() && mime != nullptr && mime->hasText())
+
+    if (auto *currentScene = qobject_cast<VMainGraphicsScene *>(scene());
+        currentScene != nullptr && currentScene->AcceptDrop() && mime != nullptr && mime->hasText())
     {
-        QUrl const urlPath(mime->text().simplified());
-        if (urlPath.isLocalFile())
+        if (QUrl const urlPath(mime->text().simplified()); urlPath.isLocalFile())
         {
             const QString fileName = urlPath.toLocalFile();
-            QFileInfo const f(fileName);
-            if (f.exists() && IsMimeTypeImage(QMimeDatabase().mimeTypeForFile(fileName)))
+            if (QFileInfo const f(fileName); f.exists() && IsMimeTypeImage(QMimeDatabase().mimeTypeForFile(fileName)))
             {
                 emit currentScene->AddBackgroundImage(mapToScene(DropEventPos(event)), fileName);
                 event->acceptProposedAction();
             }
+            else
+            {
+                event->ignore();
+            }
         }
     }
 }
