@@ -26,9 +26,10 @@
  **
  *************************************************************************/
 #include "vplaintextedit.h"
+#include <QDebug>
 
 // Header <ciso646> is removed in C++20.
-#if __cplusplus <= 201703L
+#if defined(Q_CC_MSVC) && __cplusplus <= 201703L
 #include <ciso646> // and, not, or
 #endif
 
@@ -80,7 +81,7 @@ void VPlainTextEdit::SetFilter(const QString &filter)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPlainTextEdit::appendPlainText(const QString &text)
+void VPlainTextEdit::appendFilteredText(const QString &text)
 {
     if (m_filter.isEmpty())
     {
@@ -89,8 +90,7 @@ void VPlainTextEdit::appendPlainText(const QString &text)
     else
     {
         m_allLines.append(text);
-        const vsizetype diff = m_allLines.size() - maximumBlockCount();
-        if (diff > 0)
+        if (const vsizetype diff = m_allLines.size() - maximumBlockCount(); diff > 0)
         {
             m_allLines = m_allLines.mid(diff);
         }
@@ -205,6 +205,12 @@ auto VPlainTextEdit::MatchRightParenthesis(QTextBlock currentBlock, int i, int n
 //---------------------------------------------------------------------------------------------------------------------
 void VPlainTextEdit::CreateParenthesisSelection(int pos, bool match)
 {
+    if (pos < 0 || pos >= toPlainText().length())
+    {
+        qDebug() << "String:" << toPlainText() << "Position '" << pos << "' out of range";
+        return;
+    }
+
     QList<QTextEdit::ExtraSelection> selections = extraSelections();
 
     QTextEdit::ExtraSelection selection;
