@@ -49,9 +49,16 @@
 #include "../vmisc/svgfont/vsvgfont.h"
 #include "../vmisc/svgfont/vsvgfontdatabase.h"
 #include "../vmisc/vabstractvalapplication.h"
+#include "../vwidgets/global.h"
 #include "theme/vscenestylesheet.h"
 #include "vtextgraphicsitem.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
+#include "../vmisc/backport/qpainterstateguard.h"
+#else
+#include <QPainterStateGuard>
+#endif
+
 namespace
 {
 constexpr qreal resizeSquare = MmToPixel(3.);
@@ -117,6 +124,117 @@ auto GetBoundingRect(const QRectF &rectBB, qreal dRot) -> QRectF
     rect.setHeight(dY2 - dY1);
     return rect;
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto InitializePainter(QPainter *painter, bool textAsPaths, const QRectF &boundingRect) -> qreal
+{
+    qreal iY = 0;
+    qreal const penWidth = VAbstractApplication::VApp()->Settings()->WidthHairLine();
+
+    if (textAsPaths)
+    {
+        QPen pen = painter->pen();
+        pen.setCapStyle(Qt::RoundCap);
+        pen.setJoinStyle(Qt::RoundJoin);
+        pen.setWidthF(penWidth);
+        painter->setPen(pen);
+
+        iY += penWidth * 2;
+    }
+
+    painter->setClipRect(boundingRect);
+    return iY;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto CalculateNextStep(qreal iY, const QFontMetrics &fm, bool textAsPaths) -> qreal
+{
+    qreal penWidth = textAsPaths ? VAbstractApplication::VApp()->Settings()->WidthHairLine() : 0;
+    return iY + fm.height() + penWidth * 2 + MmToPixel(1.5);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void ConstructPath(const QString &qsText,
+                   const VSingleLineOutlineChar &corrector,
+                   const QFontMetrics &fm,
+                   QPainterPath &path)
+{
+    int w = 0;
+    const VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
+    const qreal penWidth = settings->WidthHairLine();
+    for (auto c : qsText)
+    {
+        path.addPath(corrector.DrawChar(w, static_cast<qreal>(fm.ascent()), c));
+        w += fm.horizontalAdvance(c);
+        if (settings->GetSingleStrokeOutlineFont())
+        {
+            w += qRound(penWidth / 2.0);
+        }
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto CalculateTextAlignment(const TextLine &tl,
+                            const QString &qsText,
+                            const QFontMetrics &fm,
+                            const QRectF &boundingRect) -> qreal
+{
+    if (tl.m_eAlign == 0 || (tl.m_eAlign & Qt::AlignLeft) > 0)
+    {
+        return 0;
+    }
+
+    if ((tl.m_eAlign & Qt::AlignHCenter) > 0)
+    {
+        return (boundingRect.width() - fm.horizontalAdvance(qsText)) / 2;
+    }
+
+    if ((tl.m_eAlign & Qt::AlignRight) > 0)
+    {
+        return boundingRect.width() - fm.horizontalAdvance(qsText);
+    }
+    return 0;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DrawTextAsPaths(const TextLine &tl,
+                     const QFont &fnt,
+                     const QFontMetrics &fm,
+                     const QRectF &boundingRect,
+                     qreal iY,
+                     QPainter *painter)
+{
+    const qreal dX = CalculateTextAlignment(tl, tl.m_qsText, fm, boundingRect);
+
+    VSingleLineOutlineChar const corrector(fnt);
+    if (!corrector.IsPopulated())
+    {
+        corrector.LoadCorrections(VAbstractApplication::VApp()->Settings()->GetPathFontCorrections());
+    }
+
+    QPainterPath path;
+    ConstructPath(tl.m_qsText, corrector, fm, path);
+
+    QTransform matrix;
+    matrix.translate(dX, iY);
+    path = matrix.map(path);
+
+    QPainterStateGuard const guard(painter);
+    painter->setBrush(QBrush(Qt::NoBrush));
+    painter->drawPath(path);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto AdjustFont(const TextLine &tl, QFont fnt) -> QFont
+{
+    fnt.setPointSize(qMax(fnt.pointSize() + tl.m_iFontSize, 1));
+    if (!VAbstractApplication::VApp()->Settings()->GetSingleStrokeOutlineFont())
+    {
+        fnt.setBold(tl.m_bold);
+    }
+    fnt.setItalic(tl.m_italic);
+    return fnt;
+}
 } // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -745,102 +863,17 @@ void VTextGraphicsItem::PaintLabelOutlineFont(QPainter *painter)
 {
     const QRectF boundingRect = this->boundingRect();
     const int iW = qFloor(boundingRect.width());
-    QFont fnt = m_tm.GetFont();
-    const QVector<TextLine> labelLines = m_tm.GetLabelSourceLines(iW, fnt);
-
-    VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
-    bool const textAsPaths = settings->GetSingleStrokeOutlineFont();
+    const QVector<TextLine> labelLines = m_tm.GetLabelSourceLines(iW, m_tm.GetFont());
+    bool const textAsPaths = VAbstractApplication::VApp()->Settings()->GetSingleStrokeOutlineFont();
+    qreal iY = InitializePainter(painter, textAsPaths, boundingRect);
 
     // draw text lines
-    qreal iY = 0;
-    qreal const penWidth = VAbstractApplication::VApp()->Settings()->WidthHairLine();
-
-    if (textAsPaths)
-    {
-        QPen pen = painter->pen();
-        pen.setCapStyle(Qt::RoundCap);
-        pen.setJoinStyle(Qt::RoundJoin);
-        pen.setWidthF(penWidth);
-        painter->setPen(pen);
-
-        iY += penWidth * 2;
-    }
-
-    painter->setClipRect(boundingRect);
-
     for (const auto &tl : labelLines)
     {
-        fnt.setPointSize(qMax(m_tm.GetFont().pointSize() + tl.m_iFontSize, 1));
-        fnt.setBold(tl.m_bold);
-        fnt.setItalic(tl.m_italic);
-
-        QString const qsText = tl.m_qsText;
-        QFontMetrics const fm(fnt);
-        qreal lineHeight = fm.height();
-
-        if (iY + lineHeight > boundingRect.height())
+        if (!ProcessTextLine(tl, painter, boundingRect, iY, iW, textAsPaths))
         {
-            lineHeight = boundingRect.height() - iY;
-        }
-
-        if (textAsPaths)
-        {
-            QString qsText = tl.m_qsText;
-            qreal dX = 0;
-            if (tl.m_eAlign == 0 || (tl.m_eAlign & Qt::AlignLeft) > 0)
-            {
-                dX = 0;
-            }
-            else if ((tl.m_eAlign & Qt::AlignHCenter) > 0)
-            {
-                dX = (boundingRect.width() - fm.horizontalAdvance(qsText)) / 2;
-            }
-            else if ((tl.m_eAlign & Qt::AlignRight) > 0)
-            {
-                dX = boundingRect.width() - fm.horizontalAdvance(qsText);
-            }
-
-            VSingleLineOutlineChar const corrector(fnt);
-            if (!corrector.IsPopulated())
-            {
-                corrector.LoadCorrections(settings->GetPathFontCorrections());
-            }
-
-            QPainterPath path;
-            int w = 0;
-            for (auto c : qAsConst(qsText))
-            {
-                path.addPath(corrector.DrawChar(w, static_cast<qreal>(fm.ascent()), c));
-                w += fm.horizontalAdvance(c);
-            }
-
-            QTransform matrix;
-            matrix.translate(dX, iY);
-            path = matrix.map(path);
-
-            painter->save();
-            painter->setBrush(QBrush(Qt::NoBrush));
-            painter->drawPath(path);
-            painter->restore();
-        }
-        else
-        {
-            painter->save();
-            painter->setFont(fnt);
-            painter->drawText(QRectF(0, iY, iW, lineHeight * 2), static_cast<int>(tl.m_eAlign), qsText);
-            painter->restore();
-        }
-
-        // check if the next line will go out of bounds
-        qreal const nextStep =
-            textAsPaths ? iY + fm.height() + penWidth * 2 + MmToPixel(1.5) : iY + fm.height() + MmToPixel(1.5);
-        if (nextStep > boundingRect.height())
-        {
-            NotEnoughSpace();
             break;
         }
-
-        iY = nextStep + m_tm.GetSpacing();
     }
 }
 
@@ -894,7 +927,7 @@ void VTextGraphicsItem::PaintLabelSVGFont(QPainter *painter)
         engine.Draw(painter, QRectF(0, iY, iW, lineHeight), tl.m_qsText, tl.m_eAlign);
 
         // check if the next line will go out of bounds
-        qreal const nextStep = iY + engine.FontHeight() - painter->pen().widthF() * 2;
+        qreal const nextStep = iY + engine.FontHeight() + painter->pen().widthF() * 2 + MmToPixel(1.);
         if (nextStep > boundingRect.height())
         {
             NotEnoughSpace();
@@ -927,3 +960,49 @@ void VTextGraphicsItem::NotEnoughSpace() const
         ? throw VException(errorMsg)
         : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VTextGraphicsItem::ProcessTextLine(
+    const TextLine &tl, QPainter *painter, const QRectF &boundingRect, qreal &iY, int iW, bool textAsPaths) const
+    -> bool
+{
+    const QFont fnt = AdjustFont(tl, m_tm.GetFont());
+    QFontMetrics const fm(fnt);
+    qreal lineHeight = fm.height();
+
+    if (iY + lineHeight > boundingRect.height())
+    {
+        lineHeight = boundingRect.height() - iY;
+    }
+
+    if (textAsPaths || (fnt.pointSize() * SceneScale(this->scene()) < minVisibleFontSize))
+    {
+        DrawTextAsPaths(tl, fnt, fm, boundingRect, iY, painter);
+    }
+    else
+    {
+        DrawTextAsPlain(tl, fnt, iW, lineHeight, painter, iY);
+    }
+
+    qreal const nextStep = CalculateNextStep(iY, fm, textAsPaths);
+    if (nextStep > boundingRect.height())
+    {
+        NotEnoughSpace();
+        return false;
+    }
+
+    iY = nextStep + m_tm.GetSpacing();
+    return true;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VTextGraphicsItem::DrawTextAsPlain(
+    const TextLine &tl, const QFont &fnt, int iW, qreal lineHeight, QPainter *painter, qreal iY) const
+{
+    if (fnt.pointSize() * SceneScale(this->scene()) >= minVisibleFontSize)
+    {
+        QPainterStateGuard const guard(painter);
+        painter->setFont(fnt);
+        painter->drawText(QRectF(0, iY, iW, lineHeight * 2), static_cast<int>(tl.m_eAlign), tl.m_qsText);
+    }
+}
