@@ -85,16 +85,6 @@ public:
     auto GetTextLines() const -> vsizetype;
     void SetPieceName(const QString &name);
 
-protected:
-    void mousePressEvent(QGraphicsSceneMouseEvent *pME) override;
-    void mouseMoveEvent(QGraphicsSceneMouseEvent *pME) override;
-    void mouseReleaseEvent(QGraphicsSceneMouseEvent *pME) override;
-    void hoverEnterEvent(QGraphicsSceneHoverEvent *pME) override;
-    void hoverMoveEvent(QGraphicsSceneHoverEvent *pHE) override;
-
-    void UpdateBox();
-    void CorrectLabel();
-
 signals:
     void SignalResized(qreal iTW);
     void SignalRotated(qreal dAng);
@@ -125,6 +115,21 @@ private:
     void PaintLabelSVGFont(QPainter *painter);
 
     void NotEnoughSpace() const;
+
+    void mousePressEvent(QGraphicsSceneMouseEvent *pME) override;
+    void mouseMoveEvent(QGraphicsSceneMouseEvent *pME) override;
+    void mouseReleaseEvent(QGraphicsSceneMouseEvent *pME) override;
+    void hoverEnterEvent(QGraphicsSceneHoverEvent *pME) override;
+    void hoverMoveEvent(QGraphicsSceneHoverEvent *pHE) override;
+
+    void UpdateBox();
+    void CorrectLabel();
+
+    auto ProcessTextLine(
+        const TextLine &tl, QPainter *painter, const QRectF &boundingRect, qreal &iY, int iW, bool textAsPaths) const
+        -> bool;
+    void DrawTextAsPlain(
+        const TextLine &tl, const QFont &fnt, int iW, qreal lineHeight, QPainter *painter, qreal iY) const;
 };
 
 #endif // VTEXTGRAPHICSITEM_H
