@@ -30,7 +30,6 @@
 #define TST_ABSTRACTREGEXP_H
 
 #include "../vtest/abstracttest.h"
-#include "../vmisc/defglobal.h"
 
 #include <QPointer>
 
@@ -40,6 +39,7 @@ class VTranslateVars;
 class TST_AbstractRegExp : public AbstractTest
 {
     Q_OBJECT // NOLINT
+
 public:
     TST_AbstractRegExp(const QString &locale, QObject *parent = nullptr);
     virtual ~TST_AbstractRegExp();
@@ -49,10 +49,10 @@ protected:
     QPointer<QTranslator> m_vTranslator;
     VTranslateVars *m_trMs;
 
-    virtual void        PrepareData()=0;
-    virtual QStringList AllNames()=0;
+    virtual void PrepareData() = 0;
+    virtual auto AllNames() -> QStringList = 0;
 
-    int  LoadVariables(const QString &checkedLocale);
+    auto LoadVariables(const QString &checkedLocale) -> int;
     void RemoveTrVariables(const QString &checkedLocale);
     void InitTrMs();
 
