@@ -2,13 +2,13 @@
  **
  **  @file   tst_dxf.h
  **  @author Roman Telezhynskyi <dismine(at)gmail.com>
- **  @date   15 1, 2020
+ **  @date   20 2, 2025
  **
  **  @brief
  **  @copyright
  **  This source code is part of the Valentina project, a pattern making
  **  program, whose allow create and modeling patterns of clothing.
- **  Copyright (C) 2020 Valentina project
+ **  Copyright (C) 2025 Valentina project
  **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
  **
  **  Valentina is free software: you can redistribute it and/or modify
@@ -30,18 +30,17 @@
 
 #include <QObject>
 
-#include "../vmisc/defglobal.h"
-
-class TST_DXF :public QObject
+class TST_DXF : public QObject
 {
     Q_OBJECT // NOLINT
+
 public:
     explicit TST_DXF(QObject *parent = nullptr);
+    ~TST_DXF() override = default;
 
 private slots:
-    void initTestCase();
-    void TestCodecPage_data();
-    void TestCodecPage();
+    void TestDecode_data();
+    void TestDecode();
 
 private:
     Q_DISABLE_COPY_MOVE(TST_DXF) // NOLINT
