@@ -32,11 +32,10 @@
 #include <QLocale>
 #include <QObject>
 
-#include "../vmisc/defglobal.h"
-
 class TST_QmuTokenParser : public QObject
 {
     Q_OBJECT // NOLINT
+
 public:
     explicit TST_QmuTokenParser(QObject *parent = nullptr);
 private slots:
@@ -45,13 +44,14 @@ private slots:
     void TokenFromUser_data();
     void TokenFromUser();
     void cleanupTestCase();
+
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(TST_QmuTokenParser) // NOLINT
     QLocale m_systemLocale;
 
     void PrepareVal(qreal val, const QLocale &locale);
-    bool IsSingleFromUser(const QString &formula);
+    auto IsSingleFromUser(const QString &formula) -> bool;
 };
 
 #endif // TST_QMUTOKENPARSER_H
