@@ -260,6 +260,11 @@ void TST_VAbstractPiece::EquidistantRemoveLoop_data()
     ASSERT_TEST_CASE("Incorrect position of a notch", QStringLiteral("://smart_pattern_#36/input.json"),
                      QStringLiteral("://smart_pattern_#36/output.json"),
                      30.236220472440944 /*seam allowance width (0.8 cm)*/);
+
+    // See file valentina_private_collection/bugs/winter_coat/winter_coat.val
+    ASSERT_TEST_CASE("Incorrect seam allowance", QStringLiteral("://winter_coat/input.json"),
+                     QStringLiteral("://winter_coat/output.json"),
+                     37.795275590551185 /*seam allowance width (1.0 cm)*/);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -952,6 +957,21 @@ void TST_VAbstractPiece::BrokenDetailEquidistant_data()
     // See the file "valentina_private_collection/bugs/25L Knitting Bag.val"
     ASSERT_TEST_CASE("Base", QStringLiteral("://25L_Knitting_Bag/input.json"),
                      QStringLiteral("://25L_Knitting_Bag/output.json"), 36 /*seam allowance width*/);
+
+    // See the file "valentina_private_collection/bugs/prong/650b.val"
+    ASSERT_TEST_CASE("Coat", QStringLiteral("://prong/input.json"), QStringLiteral("://prong/output.json"),
+                     37.795275590551185 /*seam allowance width*/);
+
+    // See the file "collection/bugs/prong_acute_angle.val"
+    ASSERT_TEST_CASE("Coat", QStringLiteral("://prong_acute_angle/input.json"),
+                     QStringLiteral("://prong_acute_angle/output.json"), 37.795275590551185 /*seam allowance width*/);
+
+    // See the file "valentina_private_collection/bugs/Trousers Block/1.228 Men's Trousers Block.val"
+    // X:B180 Y:B6
+    ASSERT_TEST_CASE("Big Poc interfac",
+                     QStringLiteral("://trousers_block/input.json"),
+                     QStringLiteral("://trousers_block/output.json"),
+                     37.795275590551185 /*seam allowance width*/);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1288,7 +1308,7 @@ void TST_VAbstractPiece::TestFullSeamPath_data() const
         QTest::newRow(title) << basePoints << fullPathPoints << mirrorLine;
     };
 
-    QLineF mirrorLine(QPointF(29.9999999999999, 606.9290078740157), QPointF(785.9055118110236, 417.95262992125987));
+    QLineF mirrorLine(QPointF(785.9055118110236, 417.95262992125987), QPointF(29.9999999999999, 606.9290078740157));
 
     // See file src/app/share/collection/bugs/fold_line.val
     ASSERT_TEST_CASE("Piece full path. Case 1", QStringLiteral("://full_seam_path_case_1/input.json"),
@@ -1304,10 +1324,40 @@ void TST_VAbstractPiece::TestFullSeamPath_data() const
                      QStringLiteral("://full_seam_path_case_4/output.json"), mirrorLine);
 
     // See file valentina_private_collection/bugs/full_piece/Basic_Darted_Bodice_Block.val (private collection)
-    mirrorLine = QLineF(QPointF(37.795275590551185, 655.1181102362208), QPointF(37.79527559055022, 4578.897637795276));
+    mirrorLine = QLineF(QPointF(37.79527559055022, 4578.897637795276), QPointF(37.795275590551185, 655.1181102362208));
 
     ASSERT_TEST_CASE("Basic Darted Bodice Block", QStringLiteral("://full_seam_path_case_5/input.json"),
                      QStringLiteral("://full_seam_path_case_5/output.json"), mirrorLine);
+
+    // See file valentina_private_collection/bugs/blazer_for_women_with_one_button/Blazer for women with one button.val
+    // (private collection)
+    mirrorLine =
+        QLineF(QPointF(-2214.4917699559637, 2232.951572921326), QPointF(-1914.963009612374, 2349.0997891917677));
+
+    ASSERT_TEST_CASE("Blazer for women with one button. Full seam path case 1",
+                     QStringLiteral("://full_seam_path_blazer_for_women_with_one_button_case_1/input.json"),
+                     QStringLiteral("://full_seam_path_blazer_for_women_with_one_button_case_1/output.json"),
+                     mirrorLine);
+
+    ASSERT_TEST_CASE("Blazer for women with one button. Full seam path case 2",
+                     QStringLiteral("://full_seam_path_blazer_for_women_with_one_button_case_2/input.json"),
+                     QStringLiteral("://full_seam_path_blazer_for_women_with_one_button_case_2/output.json"),
+                     mirrorLine);
+
+    ASSERT_TEST_CASE("Blazer for women with one button. Full seam path case 3",
+                     QStringLiteral("://full_seam_path_blazer_for_women_with_one_button_case_3/input.json"),
+                     QStringLiteral("://full_seam_path_blazer_for_women_with_one_button_case_3/output.json"),
+                     mirrorLine);
+
+    ASSERT_TEST_CASE("Blazer for women with one button. Full seam path case 4",
+                     QStringLiteral("://full_seam_path_blazer_for_women_with_one_button_case_4/input.json"),
+                     QStringLiteral("://full_seam_path_blazer_for_women_with_one_button_case_4/output.json"),
+                     mirrorLine);
+
+    // See file valentina_private_collection/bugs/capa_over/capa_over.val (private collection)
+    ASSERT_TEST_CASE(
+        "Molde", QStringLiteral("://capa_over/input.json"), QStringLiteral("://capa_over/output.json"),
+        QLineF(QPointF(30.000000000000068, 101.31401574803158), QPointF(1367.9527559055118, 101.31401574803158)));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1341,7 +1391,7 @@ void TST_VAbstractPiece::TestFullSeamAllowancePath_data() const
         QTest::newRow(title) << basePoints << fullPathPoints << mirrorLine;
     };
 
-    QLineF mirrorLine(QPointF(-7.795275590551569, 616.3778267716535), QPointF(823.7007874015749, 408.503811023622));
+    QLineF mirrorLine(QPointF(823.7007874015749, 408.503811023622), QPointF(-7.795275590551569, 616.3778267716535));
 
     // See file src/app/share/collection/bugs/fold_line.val
     ASSERT_TEST_CASE("Piece full path. Case 1", QStringLiteral("://full_seam_allowance_path_case_1/input.json"),
@@ -1357,10 +1407,34 @@ void TST_VAbstractPiece::TestFullSeamAllowancePath_data() const
                      QStringLiteral("://full_seam_allowance_path_case_4/output.json"), mirrorLine);
 
     // See file valentina_private_collection/bugs/full_piece/Basic_Darted_Bodice_Block.val (private collection)
-    mirrorLine = QLineF(QPointF(37.79527559055132, 604.4628631137784), QPointF(37.79527559055033, 4616.693036243291));
+    mirrorLine = QLineF(QPointF(37.79527559055033, 4616.693036243291), QPointF(37.79527559055132, 604.4628631137784));
 
     ASSERT_TEST_CASE("Basic Darted Bodice Block", QStringLiteral("://full_seam_allowance_path_case_5/input.json"),
                      QStringLiteral("://full_seam_allowance_path_case_5/output.json"), mirrorLine);
+
+    // See file valentina_private_collection/bugs/blazer_for women_with_one_button/Blazer for women with one button.val
+    mirrorLine =
+        QLineF(QPointF(-2242.6828986255887, 2222.0199037691837), QPointF(-1886.7717217796137, 2360.0315200625723));
+
+    ASSERT_TEST_CASE("Blazer for women with one button. Full seam allowance path case 1",
+                     QStringLiteral("://full_seam_allowance_path_blazer_for_women_with_one_button_case_1/input.json"),
+                     QStringLiteral("://full_seam_allowance_path_blazer_for_women_with_one_button_case_1/output.json"),
+                     mirrorLine);
+
+    ASSERT_TEST_CASE("Blazer for women with one button. Full seam allowance path case 2",
+                     QStringLiteral("://full_seam_allowance_path_blazer_for_women_with_one_button_case_2/input.json"),
+                     QStringLiteral("://full_seam_allowance_path_blazer_for_women_with_one_button_case_2/output.json"),
+                     mirrorLine);
+
+    ASSERT_TEST_CASE("Blazer for women with one button. Full seam allowance path case 3",
+                     QStringLiteral("://full_seam_allowance_path_blazer_for_women_with_one_button_case_3/input.json"),
+                     QStringLiteral("://full_seam_allowance_path_blazer_for_women_with_one_button_case_3/output.json"),
+                     mirrorLine);
+
+    ASSERT_TEST_CASE("Blazer for women with one button. Full seam allowance path case 4",
+                     QStringLiteral("://full_seam_allowance_path_blazer_for_women_with_one_button_case_4/input.json"),
+                     QStringLiteral("://full_seam_allowance_path_blazer_for_women_with_one_button_case_4/output.json"),
+                     mirrorLine);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1379,6 +1453,50 @@ void TST_VAbstractPiece::TestFullSeamAllowancePath() const
     ComparePaths(res, expected);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void TST_VAbstractPiece::TestSeamLineTurnPoints_data() const
+{
+    QTest::addColumn<QVector<VSAPoint>>("points");
+    QTest::addColumn<qreal>("width");
+    QTest::addColumn<QVector<QPointF>>("turnPoints");
+
+    auto ASSERT_TEST_CASE = [](const char *title, const QString &input, const QString &output, qreal width)
+    {
+        try
+        {
+            QVector<VSAPoint> const inputPoints = AbstractTest::VectorFromJson<VSAPoint>(input);
+            QVector<VLayoutPoint> const turnPoints = AbstractTest::VectorFromJson<VLayoutPoint>(output);
+            QVector<QPointF> outputPoints;
+            CastTo(turnPoints, outputPoints);
+            QTest::newRow(title) << inputPoints << width << outputPoints;
+        }
+        catch (const VException &e)
+        {
+            QFAIL(qUtf8Printable(e.ErrorMessage()));
+        }
+    };
+
+    // See file valentina_private_collection/bugs/shirtv2/shirtv2.val
+    ASSERT_TEST_CASE("fabric_cuff_L", QStringLiteral("://shirtv2_seam_allowance_line/input.json"),
+                     QStringLiteral("://shirtv2_seam_allowance_line/output.json"),
+                     37.795275590551185 /*seam allowance width*/);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void TST_VAbstractPiece::TestSeamLineTurnPoints() const
+{
+    QFETCH(QVector<VSAPoint>, points);
+    QFETCH(qreal, width);
+    QFETCH(QVector<QPointF>, turnPoints);
+
+    QVector<VLayoutPoint> const ekv = VAbstractPiece::Equidistant(points, width, QString());
+    QVector<QPointF> tPoints;
+    CastTo(TurnPointList(ekv), tPoints); // Take result
+
+    // Begin comparison
+    ComparePaths(tPoints, turnPoints);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void TST_VAbstractPiece::Case3() const
 {
