@@ -30,25 +30,26 @@
 #define TST_VELLIPTICALARC_H
 
 #include "../vtest/abstracttest.h"
-#include "../vmisc/defglobal.h"
 
 class TST_VEllipticalArc : public AbstractTest
 {
     Q_OBJECT // NOLINT
+
 public:
     explicit TST_VEllipticalArc(QObject *parent = nullptr);
 
 private slots:
     void CompareTwoWays_data();
     void CompareTwoWays();
-    void NegativeArc();
+    void ArcByLength_data();
+    void ArcByLength();
     void TestGetPoints1_data();
-    void TestGetPoints2_data();
-    void TestGetPoints3_data();
-    void TestGetPoints4_data();
     void TestGetPoints1();
+    void TestGetPoints2_data();
     void TestGetPoints2();
+    void TestGetPoints3_data();
     void TestGetPoints3();
+    void TestGetPoints4_data();
     void TestGetPoints4();
     void TestGetPoints5_data();
     void TestGetPoints5();
