@@ -34,7 +34,7 @@
 
 //---------------------------------------------------------------------------------------------------------------------
 TST_VSpline::TST_VSpline(QObject *parent)
-    :AbstractTest(parent)
+  : AbstractTest(parent)
 {
 }
 
@@ -42,14 +42,14 @@ TST_VSpline::TST_VSpline(QObject *parent)
 void TST_VSpline::GetSegmentPoints()
 {
     // Input data taken from real case
-    VPointF p1(1168.8582803149607, 39.999874015748034, "p1", 5.0000125984251973, 9.9999874015748045);
-    VPointF p4(681.33729132409951, 1815.7969526662778, "p4", 5.0000125984251973, 9.9999874015748045);
+    VPointF const p1(1168.8582803149607, 39.999874015748034, "p1", 5.0000125984251973, 9.9999874015748045);
+    VPointF const p4(681.33729132409951, 1815.7969526662778, "p4", 5.0000125984251973, 9.9999874015748045);
 
     VSpline spl(p1, p4, 229.381, 41.6325, 0.96294100000000005, 1.00054, 1);
     spl.SetApproximationScale(10);
 
-    QPointF begin(957.69885233364062, 943.84482037833141);
-    QPointF end(681.33729132409951, 1815.7969526662778);
+    QPointF const begin(957.69885233364062, 943.84482037833141);
+    QPointF const end(681.33729132409951, 1815.7969526662778);
 
     QVector<QPointF> points;
     points << spl.GetSegmentPoints(begin, end, false);
@@ -162,7 +162,7 @@ void TST_VSpline::GetSegmentPoints()
     origPoints.append(QPointF(681.3372913240995, 1815.7969526662778));
 
     // Begin comparison
-    Comparison(points, origPoints);
+    ComparePathsDistance(points, origPoints);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -170,14 +170,14 @@ void TST_VSpline::GetSegmentPoints_issue412()
 {
     // Input data taken from real case
     // See issue #412 https://bitbucket.org/dismine/valentina/issues/412/error-in-detail-using-segment-a-simple
-    VPointF p1(869.11748031496063, -61.117228346456692, "p1", 5.0000125984251973, 9.9999874015748045);
-    VPointF p4(491.16472440944887, 316.83552755905515, "p4", 5.0000125984251973, 9.9999874015748045);
+    VPointF const p1(869.11748031496063, -61.117228346456692, "p1", 5.0000125984251973, 9.9999874015748045);
+    VPointF const p4(491.16472440944887, 316.83552755905515, "p4", 5.0000125984251973, 9.9999874015748045);
 
     VSpline spl(p1, p4, 270, 0, 1, 1, 1);
     spl.SetApproximationScale(10);
 
-    QPointF begin(869.11748031496063, -61.117228346456692);
-    QPointF end(758.41768107838425, 206.13572832247544);
+    QPointF const begin(869.11748031496063, -61.117228346456692);
+    QPointF const end(758.41768107838425, 206.13572832247544);
 
     QVector<QPointF> points;
     points << spl.GetSegmentPoints(begin, end, false);
@@ -251,7 +251,7 @@ void TST_VSpline::GetSegmentPoints_issue412()
     origPoints.append(QPointF(758.4176810783842, 206.13572832247544));
 
     // Begin comparison
-    Comparison(points, origPoints);
+    ComparePathsDistance(points, origPoints);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -260,14 +260,14 @@ void TST_VSpline::GetSegmentPoints_TestPuzzle()
     // Input data taken from real case
     // See the file <root>/src/app/share/collection/TestPuzzle.val
     // Test issue with method IsPointOnLineSegment.
-    VPointF p1(1168.8582803149607, 39.999874015748034, "p1", 5.0000125984251973, 9.9999874015748045);
-    VPointF p4(681.33729132409951, 1815.7969526662778, "p4", 5.0000125984251973, 9.9999874015748045);
+    VPointF const p1(1168.8582803149607, 39.999874015748034, "p1", 5.0000125984251973, 9.9999874015748045);
+    VPointF const p4(681.33729132409951, 1815.7969526662778, "p4", 5.0000125984251973, 9.9999874015748045);
 
     VSpline spl(p1, p4, 229.381, 41.6325, 0.96294100000000005, 1.00054, 1);
     spl.SetApproximationScale(10);
 
-    QPointF begin(1168.85828031, 39.9998740157);
-    QPointF end(957.69883966, 943.844812978);
+    QPointF const begin(1168.85828031, 39.9998740157);
+    QPointF const end(957.69883966, 943.844812978);
 
     QVector<QPointF> points;
     points << spl.GetSegmentPoints(begin, end, false);
@@ -370,7 +370,7 @@ void TST_VSpline::GetSegmentPoints_TestPuzzle()
     origPoints.append(QPointF(957.69883966, 943.844812978));
 
     // Begin comparison
-    Comparison(points, origPoints);
+    ComparePathsDistance(points, origPoints);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -386,8 +386,8 @@ void TST_VSpline::GetSegmentPoints_NullSegment()
     VSpline spl(p1, p2, p3, p4, 1);
     spl.SetApproximationScale(10);
 
-    const QPointF begin	(146.3718263928647, 6.419281580065625);
-    const QPointF end	(146.3718263928647, 6.419281580065625);
+    const QPointF begin(146.3718263928647, 6.419281580065625);
+    const QPointF end(146.3718263928647, 6.419281580065625);
 
     QVector<QPointF> points;
     points << spl.GetSegmentPoints(begin, end, true);
@@ -525,7 +525,7 @@ void TST_VSpline::GetSegmentPoints_NullSegment()
     origPoints.append(QPointF(146.3718263928647, 6.419281580065625));
 
     // Begin comparison
-    Comparison(points, origPoints);
+    ComparePathsDistance(points, origPoints);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -543,7 +543,7 @@ void TST_VSpline::GetSegmentPoints_RotateTool()
     spl.SetApproximationScale(10);
 
     const QPointF begin(237.32422843061005, 485.80074940371367);
-    const QPointF end  (46.623829088412336, 167.78988631718659);
+    const QPointF end(46.623829088412336, 167.78988631718659);
 
     QVector<QPointF> points;
     points << spl.GetSegmentPoints(begin, end, true);
@@ -627,7 +627,7 @@ void TST_VSpline::GetSegmentPoints_RotateTool()
     origPoints.append(QPointF(46.623829088412336, 167.78988631718659));
 
     // Begin comparison
-    Comparison(points, origPoints);
+    ComparePathsDistance(points, origPoints);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -638,7 +638,7 @@ void TST_VSpline::GetSegmentPoints_issue767()
     // Test issue with method IsPointOnLineSegment.
 
     const QPointF begin(3964.650771379471, 3212.2173150777817);
-    const QPointF end  (4200.023629188538, 2559.9039118110236);
+    const QPointF end(4200.023629188538, 2559.9039118110236);
 
     QVector<QPointF> points;
     points.append(QPointF(3964.650771379471, 3212.2173150777817));
@@ -687,7 +687,7 @@ void TST_VSpline::GetSegmentPoints_issue767()
     origPoints.append(QPointF(4200.083592082314, 2559.5684873884893));
 
     // Begin comparison
-    Comparison(res, origPoints);
+    ComparePathsDistance(res, origPoints);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -695,8 +695,8 @@ void TST_VSpline::CompareThreeWays()
 {
     // Input data taken from real case
     // See the file <root>/src/app/share/collection/TestPuzzle.val
-    VPointF p1(1168.8582803149607, 39.999874015748034, "p1", 5.0000125984251973, 9.9999874015748045);
-    VPointF p4(681.33729132409951, 1815.7969526662778, "p4", 5.0000125984251973, 9.9999874015748045);
+    VPointF const p1(1168.8582803149607, 39.999874015748034, "p1", 5.0000125984251973, 9.9999874015748045);
+    VPointF const p4(681.33729132409951, 1815.7969526662778, "p4", 5.0000125984251973, 9.9999874015748045);
 
     VSpline spl1(p1, p4, 229.381, 41.6325, 0.96294100000000005, 1.00054, 1);
     spl1.SetApproximationScale(10);
@@ -704,17 +704,17 @@ void TST_VSpline::CompareThreeWays()
     VSpline spl2(spl1.GetP1(), static_cast<QPointF>(spl1.GetP2()), static_cast<QPointF>(spl1.GetP3()), spl1.GetP4(), 1);
     spl2.SetApproximationScale(10);
 
-    VSpline spl3(spl1.GetP1(), spl1.GetP4(), spl1.GetStartAngle(), QString(), spl2.GetEndAngle(), QString(), spl2.GetC1Length(), QString(),
-                 spl2.GetC2Length(), QString(), 1);
+    VSpline spl3(spl1.GetP1(), spl1.GetP4(), spl1.GetStartAngle(), QString(), spl2.GetEndAngle(), QString(),
+                 spl2.GetC1Length(), QString(), spl2.GetC2Length(), QString(), 1);
     spl3.SetApproximationScale(10);
 
-    QWARN("Comparing first and second splines.");
+    qWarning("Comparing first and second splines.");
     CompareSplines(spl1, spl2);
 
-    QWARN("Comparing second and third splines.");
+    qWarning("Comparing second and third splines.");
     CompareSplines(spl2, spl3);
 
-    QWARN("Comparing third and first splines.");
+    qWarning("Comparing third and first splines.");
     CompareSplines(spl3, spl1);
 }
 
@@ -737,8 +737,7 @@ void TST_VSpline::TestParametrT_data()
     {
         QTest::newRow(qUtf8Printable(QStringLiteral("Curve 1. Step = %1").arg(step))) << spl << base * step;
         step += 0.001;
-    }
-    while(step <= 1);
+    } while (step <= 1);
 
     p1 = VPointF(3476.6410658375944, 334.08136371135333, QStringLiteral("p1"), -141.34148031496062, 109.00951181102363);
     p4 = VPointF(3483.5141183177025, 333.72231804361377, QStringLiteral("p4"), 48, 102.99930708661418);
@@ -753,8 +752,7 @@ void TST_VSpline::TestParametrT_data()
     {
         QTest::newRow(qUtf8Printable(QStringLiteral("Curve 2. Step = %1").arg(step))) << spl << base * step;
         step += 0.001;
-    }
-    while(step <= 1);
+    } while (step <= 1);
 
     QTest::newRow(qUtf8Printable(QStringLiteral("Curve 2. Bug.").arg(step))) << spl << 4.7813492845686536;
 }
@@ -773,17 +771,17 @@ void TST_VSpline::TestParametrT()
 //---------------------------------------------------------------------------------------------------------------------
 void TST_VSpline::TestLengthByPoint_data()
 {
-    VPointF p1(1168.8582803149607, 39.999874015748034, "p1", 5.0000125984251973, 9.9999874015748045);
-    VPointF p4(681.33729132409951, 1815.7969526662778, "p4", 5.0000125984251973, 9.9999874015748045);
+    VPointF const p1(1168.8582803149607, 39.999874015748034, "p1", 5.0000125984251973, 9.9999874015748045);
+    VPointF const p4(681.33729132409951, 1815.7969526662778, "p4", 5.0000125984251973, 9.9999874015748045);
 
-    VSpline spl(p1, p4, 229.381, 41.6325, 0.96294100000000005, 1.00054, 1);
+    VSpline const spl(p1, p4, 229.381, 41.6325, 0.96294100000000005, 1.00054, 1);
 
     QTest::addColumn<VSpline>("spl");
     QTest::addColumn<QPointF>("point");
     QTest::addColumn<qreal>("length");
 
     const qreal length = spl.GetLength();
-    const qreal testLength = length*(2.0/3.0);
+    const qreal testLength = length * (2.0 / 3.0);
     VSpline spl1, spl2;
     const QPointF p = spl.CutSpline(testLength, spl1, spl2, QString());
 
@@ -812,10 +810,10 @@ void TST_VSpline::TestFlip_data()
     QTest::addColumn<QLineF>("axis");
     QTest::addColumn<QString>("prefix");
 
-    VPointF p1(1168.8582803149607, 39.999874015748034, "p1", 5.0000125984251973, 9.9999874015748045);
-    VPointF p4(681.33729132409951, 1815.7969526662778, "p4", 5.0000125984251973, 9.9999874015748045);
+    VPointF const p1(1168.8582803149607, 39.999874015748034, "p1", 5.0000125984251973, 9.9999874015748045);
+    VPointF const p4(681.33729132409951, 1815.7969526662778, "p4", 5.0000125984251973, 9.9999874015748045);
 
-    VSpline spl(p1, p4, 229.381, 41.6325, 0.96294100000000005, 1.00054, 1);
+    VSpline const spl(p1, p4, 229.381, 41.6325, 0.96294100000000005, 1.00054, 1);
 
     QLineF axis(QPointF(600, 30), QPointF(600, 1800));
 
@@ -841,7 +839,7 @@ void TST_VSpline::TestFlip()
     const VSpline res = spl.Flip(axis, prefix);
 
     // cppcheck-suppress unreadVariable
-    const QString errorMsg = QStringLiteral("The name doesn't contain the prefix '%1'.").arg(prefix);
+    const auto errorMsg = QStringLiteral("The name doesn't contain the prefix '%1'.").arg(prefix);
     QVERIFY2(res.name().endsWith(prefix), qUtf8Printable(errorMsg));
 
     QCOMPARE(spl.GetLength(), res.GetLength());
@@ -857,33 +855,34 @@ void TST_VSpline::TestCutSpline_data()
     QTest::addColumn<QString>("name");
 
     {
-    VPointF p1(187.31716535433043, 51.31464566929152, QStringLiteral("p1"), 140.42872440944885, -22.62372283464567);
-    VPointF p4(-991.8954330708666, 9.739842519685212, QStringLiteral("p4"), 9.999987401574804, 15.0);
+        VPointF const p1(187.31716535433043, 51.31464566929152, QStringLiteral("p1"), 140.42872440944885,
+                         -22.62372283464567);
+        VPointF const p4(-991.8954330708666, 9.739842519685212, QStringLiteral("p4"), 9.999987401574804, 15.0);
 
-    VSpline spl(p1, p4, 181.0, QStringLiteral("181"), 356.0, QStringLiteral("356"), 548.7874015748031,
-                QStringLiteral("Line_Г3_Г6*1.1"), 226.7716535433071, QStringLiteral("6"));
-    spl.SetApproximationScale(0.5);
+        VSpline spl(p1, p4, 181.0, QStringLiteral("181"), 356.0, QStringLiteral("356"), 548.7874015748031,
+                    QStringLiteral("Line_Г3_Г6*1.1"), 226.7716535433071, QStringLiteral("6"));
+        spl.SetApproximationScale(0.5);
 
-    QString name(QStringLiteral("з"));
-    qreal result = 1.35; // Correct distance in cm.
+        auto const name(QStringLiteral("з"));
+        qreal const result = 1.35; // Correct distance in cm.
 
-    // See file valentina_private_collection/bugs/men_jacket/issue_cut_spline.val (private collection)
-    // Size 54 produces incorrect spline segment distance
-    QTest::newRow("Size 54") << spl << result << name;
+        // See file valentina_private_collection/bugs/men_jacket/issue_cut_spline.val (private collection)
+        // Size 54 produces incorrect spline segment distance
+        QTest::newRow("Size 54") << spl << result << name;
     }
 
     {
-    VPointF p1(1898.0384322000489, -143.17624447113994, QStringLiteral("p1"), 9.999987401574804, -105.35848818897638);
-    VPointF p4(1557.8809518850883, -143.17624447113994, QStringLiteral("p4"), 9.999987401574804, 15.0);
+        VPointF const p1(1898.0384322000489, -143.17624447113994, QStringLiteral("p1"), 9.999987401574804,
+                         -105.35848818897638);
+        VPointF const p4(1557.8809518850883, -143.17624447113994, QStringLiteral("p4"), 9.999987401574804, 15.0);
 
-    VSpline spl(p1, p4, 175.0, QStringLiteral("175"), 5.0, QStringLiteral("5"), 151.18110236220474,
-                QStringLiteral("4"), 151.18110236220474, QStringLiteral("4"));
+        VSpline const spl(p1, p4, 175.0, QStringLiteral("175"), 5.0, QStringLiteral("5"), 151.18110236220474,
+                          QStringLiteral("4"), 151.18110236220474, QStringLiteral("4"));
 
-
-    QString name(QStringLiteral("А193"));
-    const qreal result = 4.5090698038574057; // Correct distance in cm.
-    // See file valentina_private_collection/bugs/coat/coat.val (private collection)
-    QTest::newRow("Half of a curve") << spl << result << name;
+        auto const name(QStringLiteral("А193"));
+        const qreal result = 4.5090698038574057; // Correct distance in cm.
+        // See file valentina_private_collection/bugs/coat/coat.val (private collection)
+        QTest::newRow("Half of a curve") << spl << result << name;
     }
 }
 
@@ -895,14 +894,15 @@ void TST_VSpline::TestCutSpline()
     QFETCH(QString, name);
 
     QPointF spl1p2, spl1p3, spl2p2, spl2p3;
-    QPointF point = spl.CutSpline(UnitConvertor(result, Unit::Cm, Unit::Px), spl1p2, spl1p3, spl2p2, spl2p3, name);
+    QPointF const point =
+        spl.CutSpline(UnitConvertor(result, Unit::Cm, Unit::Px), spl1p2, spl1p3, spl2p2, spl2p3, name);
 
-    VPointF p(point, name, -16.590651968503941, 37.574173228346453);
+    VPointF const p(point, name, -16.590651968503941, 37.574173228346453);
 
     VSpline spline1(spl.GetP1(), spl1p2, spl1p3, p);
     spline1.SetApproximationScale(0.5);
 
-    Q_DECL_RELAXED_CONSTEXPR qreal eps = ToPixel(0.0001, Unit::Mm);
+    constexpr qreal eps = ToPixel(0.0001, Unit::Mm);
     QVERIFY(UnitConvertor(spline1.GetLength(), Unit::Px, Unit::Cm) - result < eps);
 }
 
@@ -928,5 +928,5 @@ void TST_VSpline::CompareSplines(const VSpline &spl1, const VSpline &spl2) const
     QCOMPARE(spl1.GetKcurve(), spl2.GetKcurve());
 
     // Compare points
-    Comparison(spl1.GetPoints(), spl2.GetPoints());
+    ComparePathsDistance(spl1.GetPoints(), spl2.GetPoints());
 }
